(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    898520,      20241]
NotebookOptionsPosition[    876070,      19535]
NotebookOutlinePosition[    877757,      19591]
CellTagsIndexPosition[    877714,      19588]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Large-scale linear instability of the Kolmogorov flow with modified viscosity\
\
\>", "Title"],

Cell["\<\
Bernard Legras
Laboratoire de Meteorologie Dynamique
Ecole Normale Superieure
24 rue Lhomond 
F-75231 PARIS Cedex 05
E-mail: legras@lmd.ens.fr
Barbara Villone
Istituto di Fisica dello Spazio Interplanetario
Corso Fiume, 4
I-10137 TORINO
E-mail: villone@to.infn.it \
\>", "Author"],

Cell[CellGroupData[{

Cell["\<\
Smagorinsky-Clark mixed model + friction
Fluid mechanics streamfunction
Calculation are done in terms of U
Here we modify the scaling to have a temporal term at order 3
U is supposed NOT to have the SinI symmetry\
\>", "Subtitle",
 CellChangeTimes->{{3.424787302076682*^9, 3.4247873135143347`*^9}, {
  3.424925305512432*^9, 3.424925344925313*^9}, {3.425025466929504*^9, 
  3.425025517630784*^9}}],

Cell["Settings", "Text"],

Cell[CellGroupData[{

Cell["Last use", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateList", "[", "]"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2009", ",", "1", ",", "22", ",", "16", ",", "55", ",", 
   "12.800087`7.859787907370061"}], "}"}]], "Output",
 CellChangeTimes->{
  3.405677748643395*^9, 3.405686657448234*^9, 3.4056866994312477`*^9, 
   3.405686742241375*^9, 3.405702624881482*^9, 3.405702770362739*^9, 
   3.405705708691693*^9, 3.405705842636776*^9, 3.4057532634380817`*^9, {
   3.424925507282484*^9, 3.424925519976899*^9}, {3.425025637191071*^9, 
   3.425025650281231*^9}, {3.44162850734282*^9, 3.441628512834177*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["General", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laplacian", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]", " ", "=", 
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "X"}]], " ", "#"}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], "#"}]}], ")"}]}], "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Epsilon]", "2"], " ", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"X", ",", "X"}]], "#1"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], "#1"}]}], ")"}]}], "&"}]], "Output",
 CellChangeTimes->{3.40567775505799*^9, 3.4056866581610813`*^9, 
  3.405686699606001*^9, 3.405702625144552*^9, 3.405705709097206*^9, 
  3.424925508353436*^9, 3.425025637900528*^9, 3.441628507516737*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Definition of the turbulent viscosity, Smagorinsky-Clark mixed model\
\>", "Subsubsection"],

Cell["\<\
Standard version with a heuristic component accounting for the vertical shear\
\
\>", "Text",
 CellChangeTimes->{{3.405677175227804*^9, 3.405677198572053*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["S", "_"], "=", " ", 
  RowBox[{
   RowBox[{"\[Sqrt]", " ", 
    RowBox[{
     RowBox[{"4", "  ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"X", ",", "y"}]], "#"}]}], " ", ")"}], "2"]}], " ", "+", 
     " ", 
     SuperscriptBox[
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Epsilon]", "2"], " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"X", ",", "X"}]], "#"}]}], "-", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"y", ",", "y"}]], "#"}]}], ")"}], "2"], "+", " ", 
     RowBox[{"\[Mu]", "  ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", "X"], "#"}]}], " ", ")"}], "2"]}], " ", 
     "+", 
     RowBox[{"\[Mu]", "  ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], "#"}], " ", ")"}], "2"]}]}]}], 
   "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], "#1"}]}], ")"}], "2"]}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Epsilon]", "2"], " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "X"}]], "#1"}]}], "-", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], "#1"}]}], ")"}], "2"], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "X"], "#1"}]}], ")"}], "2"]}], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "#1"}], ")"}], "2"]}]}]], 
  "&"}]], "Output",
 CellChangeTimes->{3.4056777606307793`*^9, 3.405686658761257*^9, 
  3.405686699718836*^9, 3.405702625178161*^9, 3.405705709307059*^9, 
  3.424925508676807*^9, 3.425025638653142*^9, 3.441628507543882*^9}]
}, Open  ]],

Cell[TextData[{
 "Dissipation: C in front of the Smagorinsky component, D in front of the \
Clark component\nIn standard notations C=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[CapitalDelta]", "2"], TraditionalForm]]],
 "/12 and D = C",
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "S"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[CapitalDelta]", "2"], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DS", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"C", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#", "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"y", ",", "y"}]], " ", "#"}]}], " ", "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}], ")"}]}], 
       "-", " ", 
       RowBox[{
        SuperscriptBox["\[Epsilon]", "2"], 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "X"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            OverscriptBox["S", "_"], "[", "#", "]"}], 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"-", " ", 
              RowBox[{
               SubscriptBox["\[PartialD]", 
                RowBox[{"y", ",", "y"}]], " ", "#"}]}], " ", "+", " ", 
             RowBox[{
              SuperscriptBox["\[Epsilon]", "2"], 
              RowBox[{
               SubscriptBox["\[PartialD]", 
                RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}], ")"}]}]}], 
       " ", "-", " ", 
       RowBox[{"4", "  ", 
        SuperscriptBox["\[Epsilon]", "2"], 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            OverscriptBox["S", "_"], "[", "#", "]"}], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "y"}]], " ", "#"}]}], ")"}]}]}]}], ")"}]}], 
    " ", "+", " ", "\[IndentingNewLine]", 
    RowBox[{"D", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], " ", "#"}], " ", 
        RowBox[{"(", "  ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]", "4"], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X", ",", "X", ",", "X"}]], "#"}]}], " ", "-", 
          " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], "#"}]}], ")"}]}], 
       " ", "+", " ", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"\[Epsilon]", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "y", ",", "y", ",", "y"}]], "#"}]}], " ", "+", 
          
          RowBox[{
           SuperscriptBox["\[Epsilon]", "3"], " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X", ",", "X", ",", "y"}]], "#"}]}]}], ")"}], 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y"}]], " ", "#"}], " ", "-", " ", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}]}], " ", 
      ")"}]}]}], " ", "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"C", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"y", ",", "y"}]], "#1"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "X"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"y", ",", "y"}]], "#1"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], " ", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}], ")"}]}]}], "-", 
      
      RowBox[{"4", " ", 
       SuperscriptBox["\[Epsilon]", "2"], " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "y"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y"}]], "#1"}]}], ")"}]}]}]}], ")"}]}], "+", 
   RowBox[{"D", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "y"}]], "#1"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Epsilon]", "4"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X", ",", "X", ",", "X"}]], "#1"}]}], "-", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], "#1"}]}], ")"}]}], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y", ",", "y", ",", "y"}]], "#1"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "3"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X", ",", "X", ",", "y"}]], "#1"}]}]}], ")"}], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y"}]], "#1"}], "-", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}]}], ")"}]}]}], 
  "&"}]], "Output",
 CellChangeTimes->{3.4056777628958063`*^9, 3.4056866596465693`*^9, 
  3.405686699838736*^9, 3.405702625649367*^9, 3.405705709731844*^9, 
  3.42492550945588*^9, 3.425025639628775*^9, 3.441628507672811*^9}],

Cell["\<\
Reference
Pope, S.B. Turbulent flows, C.U.P., 2000\
\>", "Reference",
 CellChangeTimes->{{3.405677233198999*^9, 3.405677274407757*^9}, {
  3.4056773690199203`*^9, 3.405677391583219*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the modified Kolmogorov Flow", "Section"],

Cell[CellGroupData[{

Cell["Velocity and streamfunction", "Subsection"],

Cell["U[y_] := A Sin[\[Theta][y]]", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "y_", "]"}], ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0.", ",", "y"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exemples of flows ", "Subsection"],

Cell["\<\
Standard Kolmogorov flow in Flow1, \"flat\" flow in Flow2, intermediate case \
in Flow3\
\>", "Text",
 CellChangeTimes->{{3.405677494754274*^9, 3.405677541094836*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Flow2", "=", 
   RowBox[{"U", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"#", " ", "+", " ", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"Sin", "[", " ", 
          RowBox[{"2", " ", "#"}], "]"}]}]}], "]"}], "&"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow1", " ", "=", 
   RowBox[{"U", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Sin", "[", "#", " ", "]"}], "&"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow3", "=", 
   RowBox[{"U", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"#", " ", "+", " ", 
        RowBox[{
         FractionBox["1", "4"], 
         RowBox[{"Sin", "[", " ", 
          RowBox[{"2", " ", "#"}], "]"}]}]}], "]"}], "&"}], "]"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.424925402751207*^9, 3.424925448951906*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the flow", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405677785746386*^9, 3.405677789463428*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtmnk8VN//x61F1pmxU6JI0p4+JTmXUNmVUJFShESLpJSyZEtlKdkiIlmy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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{(-2) Pi, 2 Pi}, {-0.9999996658276197, 
         0.9999993650500513}}, {{-6.283185307179586, 
        6.283185307179586}, {-0.9999996658276197, 0.9999993650500513}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwk23k8VF8bAHC7ss8YSyQqSqUoqUjOJClLESqpJJUSUZSlTZaflCVLaSFK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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{(-2) Pi, 2 Pi}, {-0.9999999999999937, 
         0.9999999999999951}}, {{-6.283185307179586, 
        6.283185307179586}, {-0.9999999999999937, 0.9999999999999951}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtm3c0198fx21lfpYRiZRVkiRJct+EzMxKUaGSJKkkpRQJScNIiqyQjCi7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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{(-2) Pi, 2 Pi}, {-0.999999916456827, 
         0.9999998412622314}}, {{-6.283185307179586, 
        6.283185307179586}, {-0.999999916456827, 0.9999998412622314}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{579., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.4056777764286547`*^9, 3.4056777910360394`*^9}, 
   3.4056867426154213`*^9, 3.405702771154598*^9, 3.424925522564547*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnYfbVsXx92/pKOovwVhiVNREQZP8NDGWaMQWNU1RqiIIAlaQjohSVBDs
FVQUER56b9KL9KqIiuj/8r7Xvvvds59zzzmc5zzPQ0m58npdovfh7J6Z787O
zszOzv6j97DH+w3oPeyJPr3b3DWk96DHn+gztM2dA4f4R41PqVQa96tUKhva
VPT/zv9v/MNVfvzxx+ofj+sP/d3/f9rQp0PCf5q5LVu2uH79+rkrrrhCELvb
b7/d9e/fv1H461PdHXfc4c4991z31VdfhR6+//579+STT7rbbrvNdenSxV13
3XVuxYoVoedz/t27fCdhfVj4T2P34osvhs42bdpUaRyenRZanHXWWWlPgwYN
cmeffbb7+uuvw+/BgweHvz9w4EClSdKPBDP8n/4NVP/kP/kDr2RBGj9+fPjE
5s2b4yeauR9++MEdOXIkhfrMM890PXr0aBSbbN26NTQZM2ZM3Sz8B/YfEXos
vi6ZvPDCC/VvpWn4s7FbsGBB+nqjAkqaxWdBzv0z/3eRusbujDPOcHfffXf8
cC3sNflv/HgEPtFgzSpbtx6sDHx6sevZY47r2rnGDXp6iVu5cm+zkq9+8MEH
4dmUKVPSr7Zp08b99re/rX61ib7ZMfxu7mXlR/feu5vc0MFLXcf7Z7ruD852
kyaucfv2fVv5LLxzrtu165Ab/9Jq9/KENe6RXvOciOrccabr88g816XzzPD/
PXvMdt261rjHH1vgejw0J/TT2ff3YLdZ7uGec8L/6/0H/O9BAxe7W9s/Fij9
dNryhhP/t6gLVn++zxO/0fXrM98NHbLUde6UfKRTx4Soh7rPDgR4xiqNRJpv
A1FCteP9M9xDnlAR3NP/O8SDMGzoUjf9063uyy+/q0wL32kVQFowf5ebMnmT
//tlnqG5of8HH5gd+hnkARn93Eq3csVed/jwkcYnZITuix///vsf3IcfbHGv
vrLWDR60OBCskdJ/xeyI4cvcSy987jZsOCBCr0yE6NFk6ah8++33lT6PzK88
9eTCyuxZOyoHD34nEt0nU7/wY77EPTtyuVedh5uUkPzWW2+FZx9//HFCXiN3
2WWXFWmORKhauh07vnZPPL7AjfSdL1u6xyujH9zOnYfczBnbPG4zxErEtoVb
sXyv691rruv/1CI3duwqSbhbt26/O3jwsNg5Pcqpp9Ft3+67fWJkIOa+Dm+7
R/vOd8uW7UGJNYDQv8Ze58zZ4Xr5wRQB06dvdUsW73Z79nzrF5fDldMjgSJ+
795vvdo86KZ+tMW9+85G1/vhef7fuf7dbz6KXXl5cW++sd718o/79J4XeF27
5kCYSI2ivH777RG3evU+L1/b3MSX1/gu5oTJ4YcuKOvjQ79DpGTjhi/dyGeW
+6k6N0y1mpnb3DZP/IEDUNLcM/idoPPiuNmNGb0yUN2//6Ig9e0SCeoXP+Ff
9RI0r/LZ9G0pUdOnf+E63jfD7d3zTaVM2r2Uh2eTJ0+uXdpzbNwf31u/7oDr
cO9nbuPGrypNw7MmQXJffWWde/65FRKOqfHVTz7+wvXzwrBo0a7KzyKHhhyN
gXvaczfAy5hvliruYyHv7pSUHwJqL4z7XMJ5bmz+uVdJAn7xot2VKeFZ0yBB
r3mqhdhcL3G+aeW0uFZremgejnp2hRs9+gVIPh4A74kUagY9/tjCoCTWrz9w
WqRG+uT99zcFKiXPAuTyZMj7xt6++eb7isez4vVrpUX86qaNX4aeNDXKFr5l
y5aFZ952S9+TQaLF7y9/+UuhxXFffG/z5q/cI37u7Pdzhu++/95G99yoFeHX
h/HZtE++CIB5YCtnF9CClL88YbV76cXP+c4x0XZXfE+DOMQP1Ftvrq+cH595
nMKi9+mnWyvvG9T7P7lI70lcz4yPlyzZ466+qnd+fI+Fon/E9zTPtRz7rit8
RoMrLSRp99Rdlh3X4cOWVebN3Zlo6YjRkiW73dMDFgcsa9NBhw8fDhR17969
krcix44dW0hlh/ie9KLUq1eVfjlKnk0Yv1oiGH5Nic88XR7LWeKgck7BmGLc
jvNrxIzPtgVaDV31JYvh1PB4TR5+/cKQKkB37z5Uedc8k9j7pb3y0/hs+PAx
4RvTpi0/Loj+Ht/TkiCxlzblG4sW7Xb3d5gh1VL5VTKKfWIX77+3qeKVYLKm
RFQm+wk9aeJKmaeuU6dOoNY8DvLTTz99lNNU5iTdm4rij0GUVq3aFz+VTISu
3tBas2Z/ZXJ8JrGTPtm9+5s4IZu6Q4cO5clJnTjpcSG9f/+3gZ6G0ncn08dr
z8f6zQ867EKjqLzxEX69nY7OD177zvTGxb7KTyJkefpkUfiFuNkxQva3+KkF
83e6rl1m+fe+q5wVny33K60MYyn+XyaD+UjsYtu2gxW/LlQ0/VpFyoR630em
e1d2lOTJXXvttd722d48/rVcuscff9zdcMMNgXj9d9WqVU1LxvHDDzdLLYRf
reIzPyGDISwL8f34TOuBN3LDL8Zxz549bty4cZaSCEBLt9Qrj7FjVgWAaiGr
UkQX4ydDaenSPeHXRUY5LFiwK/x6Kz4b/fxKJn0cv+ZH0bV8+cYwi7R4NW04
VH81Ol2m3cYNX6Vri0zDcQmblUuz4zeg/6LKpk1BRKLF2DjYqXJBJJVnFXzq
nviel/4wayQWZ5hPyTzWL3SQZotU6HffHalcHJ918h7Ajh2Hwq9TC77x5/je
Om9FPTNiWfjVJj7zS7jMpfDrTaN+vVUVfqF+53tR9m5V+HVmCWR+eda7mbaj
nl2ePrskgax37GL27B0VvzLbbt2L3oHxFnP41Vp/hi8BlIZ1RvxbgNIk0Zzy
zmkKlOyCKVM2h18Atdz7F773KlChZ+AZPGiJhivTYrS3h+d4GvXr9fhMq7qs
PQnXefGZPEWvuqtUhZ7/YlSTd67CL4xDyZbcDSn1CEqvCIqWPT/G3j87XPmf
+Lrchd5BPo4koNRiCMgz8YZ++EXb1av3awzCr3cMjGLAMisYpYmlBYrk6I74
nl+bZNaY8Uyg7dtnXgYoxQnmz0vGHaDkPd3vLXnpuDMKvhEjImFlEY1yQn4e
n8lD830amlPIvNXv18KNRilIgW12PPtpCWQyuf1CkWkrKwhZQPHIqcb6vDQ+
e/edDW7WrO2JCiyBTHbY3Lk7Mm2ffGIhi17l1fhMnjELFpalnP1ZNdutWimE
TBKPGUPb3n44N238ykz5ysOxC2kaL8bBwMfSEOqIdhFkWCkb1n/phg9baqEN
JqifQhnINClnztiaYVsOmHfw64QMbWjbTpv2hRy8DGRj/HqwcuXeDNuaopIe
SVkRZNaQR5ti+X3k10cmaw6yqVO3VFgSWxuScpJXCJliUlu2fJVpKx+CZ28a
tqP9He2DxiEegqS0KPjG7fE9efYjRyzPtJXRqoCPfr0Sn3nTzHXpVBN+XRCf
vf7aulTTtSqBTMbya6+uy7Tt641iKSv9SpbuSs/YhdY9z1LF66/UBMJdFptF
kGE+aTJ4izP8ou0ar8tYm96IzzyEqX77VTr5t2j9rBOyd97ekK5NtA1w70vg
nhSfvfH6eg/P9gzbgvbJxxfWCZnin7t2fZNp6y2YdLLmIFvqfTjWxJ+l+mOd
mx1H539KIFMEQu6JbavQmNSofqGaFThZsnh3hm2Fdr1E1gnZY48uCEuEbauo
y6fTkok5MadMNMwYdF46U117WsE3MAbXrtmf6lqMeTkWvXvZ/lLIvLquaPG3
bGt0nnhsYRWy8CVr2vXrk9g9mHYeYAGdAUrhZLTQZUbctUbrV/O059vi33pL
TIGATAtZgUxM4Fm0aJfDdQMerdQYl6elPQOK7CivZTMtNG2R3wSoSo8IitYv
TAFMMeEfI4ylZtwHUzalihZ4NJ6Kkh869H3lNQMyU/Ty+EzLvh+/Kjy5bwCU
1zaafpm2Mj/Qfi/HZ9KSO+JajNkq5S6lrV9lJm8Y5mje0lZyPvDpxUWQadot
iz4IkIUQahy7Isgw8qz1hJE34aU1slrCL9YrWTHvvbsxw7asa7RBGWSSABYM
2o4dszKVignxmUK6aCasO22OoELKIFOwmgWNtn4epQo+0WCVh2IXhw4dqXTt
UhMUPUae3HBeLzLygOzzVfvci+MScQeyYB5E4xLIpNW8yZFhW0v8wz3m1AmZ
Fh+epXDPE9wbMpBpwUCDwbb2LtCIZZApsq6AjW378dQtsg2KIJP7MnbsyvAL
yKRAvcFaJ2TPPbsiHW3rfDBBWOIVp2IitY3Puj8wO/gP+tWs4Bu3xvcUDfB9
ZtoeOPBd6lcAmTcrQghYv/ADNPT4FWXWXRKQXpBpq29gGeYgk47xrkOGbW0D
+c/VCtnd5lPatNAvXAlFZvySHn5NMu8NiLqsXXymbU78ujLItK/idWamrZW8
l9KJeTi1xjBqgwkyz0ZiiyHzPkAakKGtJqY8SP1KDNhK99iFBBJ2sIslKbg1
Za6EJoN3JzKQxeU3A5k2OYlQwLadXGWQ+YmfTmraagcS+oDMT0rRk2FbXu7I
Z5bXCZlcOz+JM22lBzF0c5BpNZob1TWQLV60O12mA2ThSwAlcQd/Wih+gUMy
0XyUZRpmvYnpBg9cUgUq9Aw82sPCyKCFdApGLfDIr9gdjUtsfruKtkh7xn7T
QDIfaGEBzYEiMcYCgsXgnfuPSOmX+VdSoEOjAsW/UhQKCx54tMTvixb3FfEZ
JOrfoiDdLfE9eROPxiWetor7Dom+6Ivpe0dSiw+zVUOFqVJm8q7wcj7x5TWZ
tjJBxH8Vl8qDsQuJtXdLwy8Mfm/WubVrk0/V5V+hDS6oQpFaOy9XP5+2hW2t
Q4o11wXZ+vUH0jgYbQVPty41Gci0H/Taq2szbOsZU74MMu23+fU901amClM+
B5lXtBUcF9he5c0D4j1lkFl4aGthZL2ya9iV8ZkcK22a1QWZd/3dZ3Hq0VZT
lGn2Qnw2wRu/LBiwbSWvDDL5GvRH2xqv9Af0X2wheyB2IeGTQlYTfCQCGvq7
IshS/2rtAdeje2I90Xbbtq/ToA6QyUl5+60NGbalEbHbyyBTKFh5S7atJIAQ
+QuG7byL1blTTaoQyqw767PS9tChw77PeUWQaWS8MRl+4UFJB2hzW7/KXFKF
4bSTb9vKE8SiGh+fySPDh4BtRfeJjZVBZiWKtp9O25oapuPisyK3SwlJ2Pdl
kCmhCdeOtkrQYRn7eRYyOzFhW0EY9EcZZFoiWMNoq0DKwrilA2SKtiq1RL9+
XZ3UaX9Fe2ztjcTj4dFWkVqGGciK3C4tE2NGr6wTsmdGLEvNEtoGxREjKDnI
PNsVRhG25R0SvCiCDFciiWUlq2Mb84yI5PgCeGBbuXjAWAaZhYe2MgpYRYFM
M2P9ugMZtgU3326o2yVrcdLENRaybrELObXPRbbxoMa/uDpF+OjdGuG/IFpU
F6cfrdo9rGF26v3GTGUstCZpz8CjiK6fJJkW0lEs9mPjM+Vh5l0sSTKxtqNt
us8/36scwUwLv3ApolYEitckFaUxWRZrvHf+5BMLq6DUIkeJUj2SaTvROzMr
4lQGHu3ashsMs3JmsLjL5Mha8LTVVNm5M4nEjYnPYjQ+/MKUDQZxXJ/LvATF
SaGFtgpAst6fl4XMGquwbY3V0m2tvd+m5gEuadB0MUIBZIqN4SXAtl/T0sBd
GWTa88E9pq2SCBcu3JWBTClC+KftDC2YQ2WQydIkxkpbpfGixSNkXWMXWqIx
/ZMgTLPaDhU0in9tziCEFX3o0LHKQmvkunbt6j/Wvn17t3jx4lrBAPCPPqza
VAAeBysDeGAoGg0XNJhCPXETJ060FN58882u4/0T6xwuq2UZLj9UqfnDcHkj
OWSf6tf59aHw6HMckULXuXMX17btHYBYZC1YFxEFxEAra5UYdm6gFdTD8U0G
+ozSExP6bU5YuAnjJ4fkmPfff5+sppEjR7qWLVt6h2J96Ujb+CF+uPbtCEVj
CsqnQmtdcAwkzpgxo4jEJk2a10rizUZJaRtBv2I+ZbAuRwxflhnqJx+vzuBk
qFsfK4nh77RFOmzYiFIYMQ8VzSasi9+mKBgRpdyAa1lRsF6/iGabMyAVRNEe
AhFJ9szIjh073e+u7qhnIKpkG73ep0+fQmpvN5Sxl02cQXoNj5JBv/++GWnb
Xxwjmbt27QqTrYDMnj17lw68Dg7g2zPwSdZVMvdHG82EoXl+rWSeWV8yw28Z
IjU160rhZPCVYYHjjW8gzxezJJnSlS6xC1khxNHJkzn6EEtTDrHUeUglIa15
CNWw1aZ2nrXQ7q677iqVBu32YH8jDdYxxuhUcgmJRq1PAN3kDkPnjTfeVioO
yqJgUfrfAkX7fHymGMq4scmK/5MTQGdiTDcJ8RW5kBHTMolQjAOPFImwEdSc
RChyiCnFbktdR1AYdaWi0VbcrF27Nk6unsk74ZgKxr88/y2bkwWbQEbYpIih
WCxohdVk5P74YzVwUxdFjCcU3HFHJ0PBn+Lfag9yXXRdGEXtfSK5jKKSIcmt
Ob+eFDBS2mTr8dB74FAlAuthQP9F6f4I4yObh+S23PjIS1G6sR2f4hMfTeOo
dO36oOvQIVEzSmHVUdHmzZt7P+PzQhlnfKIzGn4RNdG2n0cjMz6aC6RaXlAv
irwidJ9++mmGombNmvmV9cPSWacseVZVxsuKN+OlA06M4fnHRNFFF15TilF7
gxFLAE6yjqFk9ysrnWMXslpQZWxQ1XVgI/l8M3fPPfd4c+9J17FjR3f11Ve7
O++80y1atKjI9GME5W+MGb0qM4LydLFgGMHgwq8/kBnB+pHVPJA1adKkkCwL
WXPmLAi7s2Vj2dcYzYzlgvnVTSHG0hrX5x8DZJa2y351gx/lOUWQMaBeIaUp
JQyo9g7YQswNqBzlVyatzQxoXSc04udDGvLQIVOlywsDvoyi3fkjSKK1BhMY
m1MbrUqgsqPYEFok6wkVRyPfqIA+tKiSTrEtr4rPlGPG9s1z8ZkNrP+iQfQ1
y9CnOTplymZ517WOZCMFRH9rwGJhPic7fjLpiPEwfnUdzACzxx57zL300rvh
vFDZ+Ml2R2sxfsqswhVk/OyMuOAYaPnkk08y46cENQz7svFTmiZxWsbPBvoY
Pxvl/0WD6GuWoU/jF6MUZTPRBijwqkOKR/QGcyPZ4d7P0pjOz6NuKjuRAXJD
hw71RnVfd8/fJ1QahYBEY7dy5cqUnKLzcrjW1nchUqdslQnjk/gLTkHwyGI4
7qIG0ta3b99AlaEt6GvBUEQbo6o8AG9GhF9XF8zoUUa7EFe6oN60NbO0hX/n
z1/oOnd6vWxE7WY1I6rI3cdTt9gR7RS7kJXDro0NlxQcz+BM1QsvJOch9fVG
4c/GrnHj4OXVOZjW9WAwbRybwVRcnOly0fGR9eYbS4OZVzaOyglfumR3Zhxl
B7ERwzjKct6zx6aPHhNZp5zSyJtOu2tF62aDDAoCPSulT3g+N5ayD0lcIghl
vYWySKX1E2irUxjkUmEp2IA0SGkzgUhCmQ6U1U9AmrY2cA3KdgbBttLttm37
uk7IZI2NHbMy09bajznIFFLCR0uTQYzxVt04uMV0hsFO4EfGOQlmACWTmd1s
mFVYG4e6Udoz8NgVlBbyUXCKnjUKkXACRp11nhqnPQOK8nb8Up1pofA34p2k
lcY6ASSKJ3ilG+xmE6Ns29Raw8Bjd4aBRyHHL75IdqR/l/Saxh/41zpwHe75
LH0OOHbDBHCSNKh1GVa1DrJalMmOXfhoa7eQczApDk5qCTApisTrZTBZc5O2
fU2eIObAo0YmgKmviTQBEyzIESaR6XcGfs6aAZOOb3PkGFa1gLLQlsH0qFlh
aCuzhaHIwSR1zx4NrCqdhLz6MpisVUfbJK1jfwYmKznANGLYslRX52GSNcb+
DTDZoCIwqQ98XKy2vvW02G1/tFVGLUlYOZg0o4nLw6oMRD5XtuZbEwl/yiYH
oVjlRGAi/T7CJCOZ7ag8TKqKQCrl74G6bxXqkfGZVdiwOtxDRwilDCbtqI+O
s6jIhErOEFB+oqLNRpZEzBsdhSbXqiyOYI2Pqtt5JGUJmMIOYownAtNn07em
KjQPk7Xufm9oYjifMRMM+GFVO47snZfBNGvW9jQmRFu7g5mDSToINQhMykph
jSiDyZoCKcQmLYTJIekgCRaYZJjjqudh0mlhkpCAyQYHgUl9sAsAq9qsYC+t
DCZtrpLqdrX5Bul+OZikg1bF12FVAomBVc1IgAm7/GNfCFgCiYAjmSBhIGG2
STL74/JPvzfF97Uth2cFODo16e2tDDj6FjuHMGjzKorNCiSRFpJmkopzkEjf
oN1h0GaQlK0Mdi5be5U9bcBR5jxW1zURHKtXDN5Ws4OLKuSwIw8uqqxD4j0r
gFUjCCNCbrU4qCgHiXkfUYklUCo68keW1/+aT9bHJA3zLh5MpS1JEPqFFlUu
BciDiiXTjKmCZaTsXxOf7d71TbpDCir9CswHRbCIWOSnqJLZiB6xLmoRIjCX
Q2WmF84PP9ic4WzmzKpLXIaKVdq0lVHImRpQsQIAKkl21eE8Kt6eTMUPVKwL
ZVBJuwQV5chiVeRRiftAGRm0RlhyIDJGLZun2QZKG3j44YfdjTfe6EaPHh12
Gi+Jn3v++edDdYRK2Aa70c2dOzfNRVN+2baoJzk3rq1zvMgm0Yt84403UnI5
aSdVwAAWod+mnv21NvAhgy1LaL+ogPe77+7i2rX9fcr7LceJD9tN1oppXU9+
zo2SowpVVLbw/1xSz+bsKirhhMNhp5WQ2qaE1T/e0Duw2v444YiHLTLm/U/r
yc85sV9580xWpL6+mPAta/2cegyYXNzmKr96jQz85mbSgAEDwpbDN98EM97t
3LnTnXrqqWE//9J0SBaGz8yePTtNs8Z5tTNIbU8//XRtKVZ0ym++/3Py5Mmu
V69eBpLsaa0iS6NNPfuzp6QpdnVqAc1tjuY1BPH79pmW8nrLMeKBiFiDtnU9
6T8vzhi5WxieRjrqao50aPGj2kKrAhIvLmGtadMW7rnnRqczpaHsV+Hele54
/bSe9J8bJdmaNPkZUlcfQK1ETLzI0xqAwaSJC12LFi0Df3FmIKVsCQwePDjd
ilBq0yWXJMRBooLG+sycOXPS9UW2PQYucPiJHTYVlR1Df7t3707Z5uCxl+T0
TEXR7Li4nv0BjaJkpKCfWkDzRQX8sgWikNStt94aeG5/HLgwS1RrhzI1Z9WT
D9YVnRqeHEun+X8urWdz1hVVTyOtslUBiW1K2LvsV9e6Cy9M3vjTccAA/NLn
7PW3ricfrCc25sFsqS8WiKLN7z6tnlggEspiueKK6wOfccZQ/ak+CUFvv/12
SlqHDh2ULpGRhqP7aJL28dRTT7m2bds20rrnH1955ZWhy3bt2il3iGRn+cv4
As1r7bV5pp6xevcqwN13333uu+++yxyHJOZWNBcZZNuWZBalTuIEJDy2gIOw
cOvfHAsXphhXwQJ37ZXdccffAmB/+LcA3Nap5LRny2ME/II4ya1/6P/5ZQG+
6Ek5WYRmWtQP34sK8AWba//wZ78aJiHAa8qxse1PDrTAaIOjLY4TWuuo1gGt
1THHAS2iq2Pg7dq2D/jkFtlp06ale+xA+etf/9qdf34yBZMZ0TxcE/CHP/wh
TS0tWnR1/JsAGkPw2muvhYwZlWDkaLecGzz7aizn0oIWZ6ctvk/98+b1oOii
Au4AQ7lBF15wWeCw/QlEAZFRusHmGFo8u4AnMh4UKWWLq1YA8HlthKBFPYhp
U8LYJZe0da1bn5tZTE8EACyuR0e2iwGwBzbrBEAlbTDojheAs866JGWstZ0O
LZTUF17X55XyqRSiCRMmhGdDhw5Nem3mhgwZonyw/FdZARXkZPoiAupFudvz
5s2LE6FpZusnaoU0vc6+DwgKChLxblFOykUlDI0d+yIMtT8hfCP6NlHonAI+
GHmkuTZ+bWSGaX9qOQlt6sHInX/udfMJ5dcmNxXxe37U/B9+sDmNjtbCMvpS
BjrlcFoeP8uDBg3JKPwWcuHC37z55ptu4MCBYZZ7U9INHz5cEwnO/WoUsjwO
HDhQJOHaf2BzE86vv/56r1dau4MHD0bPumni+8TACSN+ecH7sG8PjrUoJ+Wi
Ohi69truft043P6E8M2I21j1uQV8YLeyp10bvzgCqljBWdtTy0loUwcjAwcO
cU8PWHTzCeVXZdE5slzE78+jhNvKLLWwzKS2eUgtj4/lu+58xK1Zszdn0uzf
v9+dcsopbtSoUXGqNVVwLgTiCtarirZZOPhLH88991x4zy8fqSyvXVs9hp6X
Zfs+smxTa1uW0HFRAd0sVXY+3NxA/lpW6ThKZi29yKzOcih1qTa+kFk71qeV
fL9NAb3cl2HtmZuOkS8dIcgfMLH0IpuyftkvqIU1ZFPZYFS+PLWBrDFkKnhA
olS0LqBOZrsOLukX5qgMlF277KnrJjrekV5AZZSubGbyshmMvXv3hhm2ZMmS
tMuXX345NFWeLMJrExAR3kvq2Qfo6Mwi+dmnFZPapoTTcWPf8bokIaH98SHS
IsW/mmtyVj25Qdylh5Qx3xAkQF0bgCSbtiom8eI6OHzowamZWX2MSDAZdKcL
SQGtG4gEcnEsMmEXxFpkogyJSRMnu5HPzD56sjSXVRROqaqQu3/i9u3b51q1
aqV9l0hlk3DClYvrqmCEm4coctA6riHaczjvvPPcvffem56H7Nq1awhu+2UH
ZRHyQWPltxSOOluDxoIF1cPapxXT2KYO9m78Y+90L+QYIEjPq63Zr2pyZmbU
yQTiQMJ3A/hnXthKF62KCbw49lgbb7fc0kdZODcftxQEb4Tsz3pKARCoQI00
7TFAILceJVkKQe283XRTb8I0ifpu5mpqakIVgQceeMBdc801rlu3bjpehsc8
ffr0/PIY06PWGgloptsMNQXd3//+93Cm6aqrrtL6hp+iOnwk+aT+eK2tULhK
KaVuS6sCgmC3iId+fWYHD/iWhvOJpNussZ+VU4z/mUyO1ZV6MMnMHj5saZrq
d3oBNZeUMDlu7LKQnNX+mAczs3TXMZgwqZQwDUsDmAyF2uKBw9qZLGag18Mz
o8zGqxPCcTZsVwLmSl+hdnaI+dxYZTANjvKyau6wSzPUPMN7uC4+wwrQP430
xx/jX9jMYl4O2ebRFx8Sn4Vs81gJlPc+jWV5jupUl4Tg+vKyKuFRh+enWRQU
H8ALuDa+Tq6Z/rnJMIGVynurTVI3ACi7g8yZ6+MzWfj6R78A1FrYkGlLqQ0x
3yATkffk6Sh12NL3wrhVqYHBe0HdxxGObMdbDipSvKTr8rrmEA4G3cqSYvbC
tsIqkA/b2swBxiK2GR2bNcZ7qjbJ/jZsq7Ylqg76FJcWzZY+m0nGe0HjxJSw
HNuLFu6q6Jqu9PVGwRfIblpBq857cD6AvpND3N9laLVDCU/QafsLMdJ45PT6
FI8jaQ0P+tNOLBHqMhGySgf6bK5AjndJDPvmvB5KmgxbloHUZlryXqiSGhPo
B8dndhPkhvhMZxHybCtvFsx5z0JGf4q2knsI28p3zPcnf5E8yOsNLViUObb1
KZTM9YbFfLcK9ZC7yHsq9s1JHshUOWRBZtkRe/n+phoJ5j2r8OjPjiLflV2Q
78+69TcUtE328blgImz0UO+X16XZ893aUv0WTSp0QabNqqY/sZfvT44OSYy8
Z0stDIrPbGEP3pPez/dn1wPes7t+kW1uQSCl17xeUe4POfdlpOtkHbVzeU/3
b6xalahQdj2pW5HrL81m5plgKPoG/gvvKZV0avRWy76RFHPKTiQl0uS/oVs7
SWHlvedHrdBVsRay4AD9HzUOBxH+r/7vyvT/EvuCi8cy+lH/RmVSlN9ZVAew
6FnRUcD6tk2+2yTcPmr2bIuKPx/PZ+pom87lk/iN3HtNeIamb1jzkzsqVxYL
S6i77e2nogMf/wyyorCEACrz6p8vLP+CbzSxz7Tm/icIi07j+nX3Xy0stnLl
f6GweMX670Risgylq7yOrZJNW5R29stau0iO0eDIFV3BaNqmZSkuLXjPZhdz
pK3oQpiitqzK9uBj0VJa1BbH3x7VKboCsAiDMj5sdZeG8mFt3YbyYU+x1MFH
epa2jA9cmobwcXZWvHRUjXhDQ8UrnEf6MJPBWys7ZOuWsaNTj2x5NXRYVBPg
WIfFemh1DQvnoMr42GJ2qhvKh25BnhiD5fXlg0in9VLrGg92mcv4sPVeGyhe
XG7Xz4ScooNdUVyAA683GpJwdK8z7LCnQ7xAfgEkZRzimJpj+yMQfL1hB02K
q3foUDVEzns2rmD7oy3v2ZM492TZtvFG2LaxBtstdQhge50ptQbbilVS+4DP
a/JzO5ftj8P/vGeLNtNf34Jwig0l2f447ER/1iPNsb18+d40zh8jaOFyuuFR
R91kupXto0g0nxeaXHgMmTZixOdVDJTTqJZMvF7eU8yZSif0Z28JqQYOq+uS
7Y+JZKNSQJZjW4fkEcDAdqPKtGlfhHzG0BefUgCPo8EEE4tGwhYfvDHt5XrD
RD4spyrMAt/2krx3ONeLnVxEkZL7sdNrT4U4ccYY/w4jyKDbUWQfnnipPd8/
LD6zqzef1/lrCnJY1FmKUtSNaobZcBA+HhyhPzs6tj8dfVaIuihmmGNbgS3O
xsTQRHqHp34l+alVpzTm1LBDsHJl9aIcOFdaKVEaKLB18jPy1md+nZzbYkQg
LluG3F07MqompzBm0fTOcb5m9f4KZ+bg3FZbyXPutZukDc4lfOyDwLktx3Nd
AUe5mRasIt6z9aiZJnZpg3NtDUyIVUUs55xXL9oayHEuvcsMhHOdGeE2kTzn
8R4HOLf3gcK5tqxJBaqLcxXtUMUn3lOVTTgaVm171G6UvafBck5lgqK9oMg5
9o0ARhX+nmd+Aeb1POdxYhOzs3nzwxkPs8/PGNlaCZZSiZAqQVxXgBqc24K+
cG7rV5n+AokKkNGfjRbnOA9ngqITEw/dhwoMyEGy3d/UWjVpPVuOo9uzQLCv
w/ywanfNUAqWfd1so1LLkJskAO3JsG9rBsG+1CYCd1NuhKKa5VWdU2DXq0MW
ARlfFLIEAd0DxOAVIeDt91AIAwTC9YDx7qAR8ZldyyBDwWLu3LEIEOIHARuw
AgFVOcLYoz87sHkEtB/pLSVetTUgcwjYklsgoPFkizcgkEhWds34XZXVdE2D
fTvLoUH1rLh45Ka0U5jWHXrMbZjesb2ahstss7PoT5Y0rAQzizPFRiLbOAMj
hi2t5CrCZTL5igY+Xu6acq67+9DOVHiwJgmcK6jEDoMdeDR5kW4EA6vtwUDV
x7D78sopOE0vp2p5orm6MoeAagoBTiydFLhHl8W8iIxLoy+o+rLXRZQusVU3
AEGb8dTWgRK7CZZXV2IQPWFLFY0wbRExxlazEJ2QB0GZA15P8WmbcpQDQYYc
t5wCgiQfjVYbCMmNNJsBwd4NBQgqjEe9HCixtll+ymoj9PDhVGkpx5vLZMAh
HNaNwSlwsBVtcjgk2PaZT5dWKUUc4hmWYNkxOrEmStCB6LXacFBdwcEDl1B6
ixmiX5RRUfYdZyfsmomvmR88qa6tW1PVpZtEqfUEDlozWPTBwcrXnwom79O5
dUv16pi892XBkKbkQkjAsMWJ2mfFN/xL6qTNmKEQkYYSrQkqOtGJRr7GvMeQ
51HRVvyC+TtBxR4uBRWbJ1RUWq5IpWEQgordbMyhoppS/FXkLJhIxCpuKUHF
XrH5W8MCzjio2NN3oKID7shPHpUoHKCinDfmB6hYxxlUtpuFpQgVlWtT9TlQ
efedqkOeQ8UmtYKKTGZENqASQAELW7AQLFTxFXf4WXRFQf0pe4NsZvXjcLB9
WZYaaq+oABHKa+7cHWlMMrPaWx8L6Iab2oYRiniWriKtzfdiSbPgN1FeoExA
QgXIxxbatuFStEdzBfJkJuRXAl0+ReJMXkCiQKX612AKJLo7l1ArkGharMgc
8MgKiKbVA91mpSRYUyyHii1CCSpSkQS/i1Dh0II9iUjZwGVLq6cNQQXX3qKi
En0YM7WsC7ZSFcgwE4vqEg8wlQUTVI5eELo/OFv90cSu5vdngdlsTO/IXLiG
jETEW0uAEXXUuAMY1dGioh7AaOISyEjLSBoZKFooWEh4X9XNuBG1aE0rKh1Z
GzqjkzJjNJFPRNJiRCcedar0NiHSKxElc3dXGTr2Zs5fV7lOJ86oAi7qu2Bg
y4KOrcAMOt6uTgvvYRkEuz2Wh63NmIilhEFH0VqiDzl0dDlm7lbZEKtD/ZSh
Y8/c2KtZMQao7Cpfh3rCoCNZIAhchA6zplpHsbpDBjqykfg+6Ngik7WhE2vq
g47SFLH7cujIpScqGCshB2RYBm8rQIcjYIrJEQyhirLNBgWdcGlGXPdAx97k
U4QOOeGgo5I+3EvCqmerl1Kcz+4u1IaOlnm/OICODRXl0JERSGwVdBR/JWpe
ho6cDkQSdJTmRjHGoltNICnkts7cXis6lMoqWr5BJ9SEjvdKgM5TXtGTW1Zm
mdpCF9gdAbU4ikk5YE7FZbarYn3ysF3FShtgCl8CHHt9PODYemiAYyuU2Eqp
eIwZG8SWhv5dlZO0U5CRlcgIgkznjjPT99qnnYJHKPkYmQEPeyd6Dg9FaJYu
TRbEeH9Aevm2ft1eAH3TKgpHXRIr9cLyx90DMQkmg4x1XgvEJoiOnBOrwNmB
QdHbzXFYtdt9ZZaZMkW5Co222pWZHp/lYJLDSNwWmDTH2QQug8l6CcBkvQRg
ssmhZsKn/dW2+saqxTSxxStQa0V3fWqbjSWuDKlwMVQUHpCyt5bmkJJA8DmQ
0v0rixZau+Z4Lzmt6xpWsLdFu8FeE5VtM7C3le9Zvexa0PYkUX30aMrZ85OF
0bQRUkaz6KJdu7na7p8CcaMUpiPpzCy6uyjKx3mxC0U5uQMjno4OnmbWITgh
V6OWXTva1FCP4uWwtpQzA881R9ZEQkCsKdX2ZJF9tITEKyyQkHCpVCwIiYTY
3WIkxN7Y1+6fAzK2qRUHLHdrkXfKioh2E8jij+VLgnmDXq/e637CLlKt7YJS
Lp2xiUtUVFGUJn9Zsl2mEJNQBjHGTS4/maQfLSo1M7a7Z4YvR1QUUkBtIyrK
meFAC6Jil4u2/zywERc/p9LIB2MdSsXFIGJOXEKwOx6+QFyUuAbmdNHQ21Rr
u/UVmZAXhLmATCgfANLHFqBpbX88/cuPm76jB/6LL75yQwYtZeB1xBgFay+2
wzkEInspdLsTDBttddaRkhV816ZcxtGN9dsyIfx432q4ZIja9HTR0LtVs7e7
shzoIA/+PLe7huh/PEA0Lj4bMrhau8OWr2eD8/ITQlWl+NIT6ygUuWa4/4r3
4jC3OyEEMZND/mMM/TMAdjM/N4baICfuSIqixpTEG/ROw+9fLbvttHkVrvQ0
5y9T9qqxJMbUZpEU3Y58+Umh0vqxBE8xo3bsOOS6dakJv7BU7S2xDLS9kKPd
SaHSRpnwSRh4K3q5gdcZXtwmBl6uENCnN6kc49WoJbfJMvqKXRFlYfQ10kti
FJjRtwV+GH27s3j5ySMVEQjH/uOGOiKQ5COtzYjA88+tPOq2dOWGKEvRisBJ
IJWgiE1TIShij7J2zsqBnezIgThgEJCDY7n4tegSUwZfR17ZomTw7cVrDL6s
C+94ZZDXHjB76G1PMH20taWh+W4IF8cwACMeLlyL8wi45bmwj3TFCaaPYVbq
LH4E37AGYxzmWMmkIgeJmCGp49IOwP2blPSG3w9bRCaLVe9ec1PdmdYU8is5
J2NeiM+09Ua0GLiXGM+/7QmmL60Cu2BXGsXju/ZcK8NsF3vgDpc3xbStK04w
fQyz3R7nG8rfYzXMDbMCV6TKR7jDUWVicYn6PK7LYlMSi05IMOw2sMawa/YQ
13sxPutbEP2yW87tTjK9DJEic6NiZA4xsKnTOJF2fzRdzk1tyytPMr2IhfKN
8LkRCyl+aMuJhR7j+yIWEhPinIlYnJTbcJGIZBd5bUYibLgPiejapSYtsINE
hN3mbfbm0pNCKsJg53p6LVjvqqAiDHbPPr1HduASZekZYTgppCJDdtepbQH5
XRI5iLWAQuYMEb5Yji0UpmHb/k79Gb7EsNlrGSngJmuCLfaXUiyqJzkYNnvi
rpqVUhZ50srAwo6PnqT7rsuwaLO+bk97BhR7tRYt7MGeHCjaImOzsU18JpBw
Nu8qwD+tA9tnXlroLLYNmXok+wOPNiLJWYRZLXmkPpZtH8f0tExbuywAVNHl
4fIG2fMp2wjR5UjQTFsbt85Bpv1SVmsgU3NSYssg++TjLWlsDshUbY9JD2Q2
8xe27YZHGWS20DJtbUoVxqWSe7CV07jAlOo52zLIbKEmILNVeyJkF8Quunau
8StxwmKs9BoKI7H1XAZZiHpH9U2VWF2w2KvnnPBrfMHMh227c1YGma6pnTRx
TaatPZtuXXE2hIFMKciEXIogQ9PZVEXCcrbIU9csZDZSGG/kCPl/5OvdXfAp
is9LD+OwcZvHR94AGRvT1ibEZ1rQcc5w2GzSaxlkMek3A5k1aIAsHlzJsG1z
Qu4ogUyGFNvUtP3c3Cicg0wLPRIAZIrZk3ZdBpmOdjExgUwrNCMLZLolC9su
9XFNllwRZNgtNiCB3RIOS8RMPNwBu/cD2zpSQJy5DDIb/Ket0hg44xEhAx7F
p4kNAqNWN+ZxGWRS4VgGFxi9QLbHy/GZjgVwEAO2bbymLAMkXC4cJZm2q4zn
geGkQDInB4mP2ghLGWT2RBGQyfzFnMxBpix4bRzrF0uCpITJ8JeCT3G9kWw5
wvCUKNQ+GUsHkFmLHLaV70FhszLIggcRDzjS1tObQgFk9mZyIJNZwpJQBBnx
CxWiI0uC+IVKe3XplKSAdMtCpi4ZbSBTABjVHCALXwIoLfGkXf7CEMcYA5Rs
IbSOzZ+a+tHmKlCZtJnVn1f1By3s6VzgsbcDw6I9gfLntGdAEfBseNIiObiw
xYLC+vfsM8vT7B5cFcWiwL9MjjR9ej2cBBco1yqZodbXJMbJ7MhjpNuDbGVy
pOnNbjNAWQ2GqWKzbajeaVPY/lwiR0rBR6aBTNFG4vU5yJTtghIkhKcjpKRj
/7XgU5QoUL4qGbbcwfPG69VL6YDMblEDmbXWiyBrWvAeVtEeU4INU0XrGkc9
gEw7N8TPiyDDJ1GtNL6BK6mMEDTxAwlkGKaSKMJcbEyq2B7V48og04EwDn+d
ZyacSNB69wqTdcmeNBERtnWUloWgzJBUWglLPG11JJPb6IFsVVj212TYlmVI
pPHOEsikrT6N51doq/wVaM5BpntfyToke0g+IsL/t4JPUdBD6xCahIL3soCw
24GMKpuW7cStWVcnZDpAQB4xbRW1w2qzBjERSNiWq8PhgzLI5GtQk5G2dg85
B5m3x9MkTyDTgTd0QBlk0hWwA2Q6JECG/atmcuXdFRsMLIPM7ikDmZ8w6UTC
unth7ErFasIvHH4Z0xzBKIIMP6W3mZi4drLkcNUfTCAj8iDvCfeCXFkJMy5R
GWQyGh+JI8tlHXKJCIq9Fp9JvxHGB7IunWpSGMvclb4F7or3UtObBliBJVFP
ZL1h/943aTZomWunuAnZBrSd4w1xwvg5yBRuoloAxxok9JwtClU5w5fOiJ1p
rUM+0mvIvIInwgpQiVGQdVJ0qvrRaLTckfbczPTM1iYt4inF8GuigZEVGO9V
WQW8d1faM6AoowtZBRTJPknHOVAoFKExBRT5iOvWHqiCksMfeGRSsjZxvVZY
S6Iovx6fWTcVZrUviZIus67neW01YlgmCyaYLlu2HMwApcxTUi0uMmxjZhbJ
EZ6Iknb3xbgjzpvWXUzy7glkBH9VBhTXmpOpcjIe6j4r/PpHwadiFaIQ5GDa
Uvvdm7GpBnsDrTGoqjWwroeaJb4MskOHDrse3edk2kqZ8wxTJUho1t8NCQRY
VA31d+UnEiTKQSYTwo9auNQNyGSJEQEug0weO2E4e6mZpEyj+2Z8pox9LRr6
hTFoI7BlhqS1nmhrg+6suwonrommDz6rFhsipmWQaWZIyQuLC8wzSbNmy0MJ
ZGww6vgQp2ap+iE/kVjWPQWf4g5zHVBEyqiJpawZLBYg2+V1RZeONRm2tXFI
DeEyyDSBmQW0VfCHIyJApgpQWIG4YrIMn66Hv6tQJEV3aStThcoUOcjk3T3c
IzFYgUyxowVRXZdBpio4bPRx23I8+xNOuLxtJjCqFNtboT5qkJdBJoMTaaSt
JFQukPQwy4kKVeFi4Z5J8igdXwaZvtE7Gti01Xrf++F5oaJKjwQyshVUHkkG
q4EiSJnIFEn3FnwKeLp1neVIVwNGb/imkwbIdNgDybskJakaoyozJEc9u8Jt
2HAg01bbzhRUALJt275O/QXcM0keKrzMT1FxSJYi2irgTdwvB5kinjLKpHuA
TAdpspV6iiHTiZUh0QJCv8lRlg5Qf+8Y/YZBCNsK9KDfyiDzcKXl1WirFQ79
xqos1wlDBsNZEq+wpU7aFFmQQCap7fCPz8IGJK6dYncEqXsmkJHYqGOQ5HlE
46Ei64fyaqG8QfgS2krOAosD5oaiUIzJu/GZ1hwOWbYx4AlQOV1H20fa6WWx
p4XyZDg0ygqsADXDEuBppISlqo2IMS1PkHNUwKjlhMkaoSCDVzY2qwXlKIWY
JoNG6L4C1AFFbojcDq2ifF6qlDOw78Vncp6xwWBRJd/feD2ZhGU2tdJgGCra
yvDAc3vTsI1Nh2msENKDD8wOuzhldqNUODtMtJURxHcfzkKmALP0kUxUINP8
Z/UpggxDQcHj8bFbG/3qeN+MkDI+OT5T8A0dgD2jM1fScVL/ZQt7r55z3fK4
q5Nul3y0xfWN8KAHtUyga7H9JGWaNNqjLDKCgCyerg8+A6a2isco0Cxx6JVA
xskTWcLs2HLznU5ba9GVWk9qeTULt//269cvvVhJ+ZL9+/cnET5/lKaWkzdF
GXUwqFr6xMgATCdJP4pRTQYgGqhuiffnAFHKn7X76pNOMdQt9pKtrWnBip2m
VVWrtFZ+dLR0pYKNMlBam+GU16G14LqTTjEriOLKok7OLJQsXbo7CLmiSb0T
4eDYmiLHI6PPS/rUBm+13d9hRjiPwm16XD+3adOmuG13mj05E6gtO2lTlHB7
lgFU+ReSZ1SP/F92LT6Iz1at3Ked2jAH7Y4Hwn3NSaQVfaHMfpUCsNFyiauu
hFD4IVG7TcKiqHPeum/U/z8mkcwQTXFt/P7xJJLL95QH0qVLTbhJArtD23oK
Jez0qvSRrDTIWJZ9Lg+Uqt6y4XVSVkYtt0yOHz8+kKwLxRtH0bYHY8xBmnzu
ns7RFFGMIlPs6b57PgsxbWxl3QCqfRXNwo/iM0VChaSMzvMi6AqRjR2zKihX
Pyh/OHnUYvsoZU1fk3mB7bP1i6/CWXgdAJkSn735+nrvXM0MXJ1uqPWrsPNT
TSr/xpNH7U/iF5XuK2p1isNbaBCi4+vaTdTpBr/O9UlkItmwaBKWCN2ZJet5
06Yvucjjm2+OVN5+a33Yi/NjdksB9cQg6jpdU5SXdXakTWaO9sRl23l9RLF/
RWRk1cgT8lLxcXysLB3B+eIL4XRVIlNNQ6xRCkX2ktYgsXTtCSYYMJWgdK+3
hnVyat/eb38GZVu+CpvInTvWaE/iw0iZ6m3otIOcdMmSwjzN46BLrWiuarep
50NzwplIz+tNJ5jw1pEU+fo9H5odNLF2YWRhNY9/J1HVloJI7dK5Juz19kvE
5Mq4dGhnUmk0Dz04u/KM9zgU4enSqabyglfOXgHeWkJ1Xed1wrNwNieRipYB
mgnj14QcR9nwEuquXWYFC2hWzY5g7E4L754flmZvdPh1dKHr5mmX0pA7JUEY
MXSZn6qLvfQv94bt0uDQq+6ezn4PfnpJuITnmeHLQ6GGUc8k///oo/PDBOrq
+9JCKxomeYNafsT1J4TLRJRahXVRg97DD/6DD8xyfbz4ai5oF+H5USsDVaJo
1MgVEqBGIZPh9MCEHo8YttwN9MyJEQVjJP1q+oA3YzV3unnCFbiRVk0m0Blh
Xunohfy+7t1mBblTGzGvZ/1936oTJAAHDlgcyrl5sG8+IXwn9sDp3mn9Mrgo
Ivh+b7ZI9WvfLYyUH5GePeYEKZVJoywq1V14LJHG30TttH37wbCbu/rz/fKo
bi+hr/gQUZEaJR6wfv2XbsXyvSGTNonytg4xDMUd5NQv9bNHErd82V5vwu52
8/wkVs6NJyY8lx2zbOleN3fuTt9P8v/Llqm/g34Avq2UzfD6U5s4ii1Ckum2
rV+HEi9aNPVVUSYO/DxuFKJLLUNgRo8hftHC3WErQ82kpRQvqomaST6lmIhd
+BXvoKzd204I3VxXrHkrcfTeVCBIhXk3et9cyvvJZLSHlXywroNBRarQ6c+f
/Cd0+krdANR1TqYI+zpp/bfptB4A1HWCJNB17r+ygyQYEAujNw2HFBcsWBBS
2+mqeZwNZecgAh1n/zt0kmNIh+HHjRsXjmLpsvLt27en1k0tufyBjHP+de0T
hz5Bo/rH4/+tTyun/D87UzRA\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the streamfunction", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.294302 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .16187 -18 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-6)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-4)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-2)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(2)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(4)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(6)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.08317 .01472 m
.08317 .01847 L
s
.12106 .01472 m
.12106 .01847 L
s
.15895 .01472 m
.15895 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.31053 .01472 m
.31053 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.68947 .01472 m
.68947 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.87894 .01472 m
.87894 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .16187 m
.50625 .16187 L
s
[(0.5)] .4875 .16187 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(1.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(2)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01475 L
.02605 .01484 L
.02729 .01503 L
.02846 .01527 L
.03053 .01587 L
.03279 .01678 L
.03527 .01807 L
.0379 .01979 L
.04262 .02373 L
.05205 .03491 L
.06244 .05214 L
.0842 .10331 L
.10458 .16662 L
.14335 .31094 L
.18458 .46296 L
.20517 .52463 L
.21519 .54917 L
.22428 .5678 L
.2338 .58332 L
.24277 .59399 L
.2477 .59817 L
.25224 .60093 L
.25461 .60196 L
.25597 .60242 L
.25722 .60276 L
.25853 .60303 L
.25925 .60314 L
.25994 .60322 L
.26115 .6033 L
.26184 .60332 L
.26248 .60331 L
.26365 .60324 L
.26489 .60309 L
.26595 .6029 L
.26711 .60263 L
.2697 .60176 L
.2721 .60066 L
.27647 .5979 L
.28114 .59389 L
.28669 .58772 L
.29194 .58051 L
.30174 .56359 L
.32176 .51621 L
.34021 .45972 L
.37961 .31422 L
.4175 .17253 L
.43858 .10619 L
.45784 .05909 L
.46737 .04157 L
Mistroke
.4724 .03402 L
.47776 .0273 L
.48291 .02217 L
.48757 .01867 L
.48982 .01737 L
.49225 .01625 L
.49337 .01584 L
.49455 .01547 L
.49565 .0152 L
.49666 .015 L
.49789 .01483 L
.49854 .01477 L
.49922 .01473 L
.50037 .01472 L
.50164 .01478 L
.50276 .01491 L
.50398 .01512 L
.50512 .01539 L
.50617 .01569 L
.50854 .01658 L
.51113 .01788 L
.51634 .02153 L
.52094 .02588 L
.52585 .03167 L
.53469 .04501 L
.54496 .06499 L
.55607 .09166 L
.57624 .15148 L
.61721 .30188 L
.65666 .44917 L
.6765 .51136 L
.6946 .55618 L
.70461 .57505 L
.71409 .58868 L
.71929 .5943 L
.7241 .59831 L
.72661 .59995 L
.72938 .60138 L
.73077 .60195 L
.73228 .60245 L
.73369 .60282 L
.735 .60307 L
.73627 .60323 L
.73747 .60331 L
.73855 .60331 L
.73973 .60325 L
.741 .6031 L
.74165 .603 L
.74236 .60285 L
.74362 .60254 L
Mistroke
.74478 .60217 L
.74705 .60127 L
.74949 .6 L
.7539 .59695 L
.75897 .59223 L
.76451 .58563 L
.77459 .56986 L
.79428 .52609 L
.81525 .46353 L
.85686 .31013 L
.89694 .16147 L
.91533 .1046 L
.92577 .07747 L
.93551 .0561 L
.94506 .03919 L
.94997 .03216 L
.9553 .02583 L
.95822 .02295 L
.96091 .02067 L
.96344 .01887 L
.96623 .01725 L
.96872 .01614 L
.97106 .01539 L
.97235 .01509 L
.97353 .0149 L
.97483 .01476 L
.97548 .01473 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.233891 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .13166 -18 -4.5 ]
[.4875 .13166 0 4.5 ]
[.4875 .24861 -6 -4.5 ]
[.4875 .24861 0 4.5 ]
[.4875 .36555 -18 -4.5 ]
[.4875 .36555 0 4.5 ]
[.4875 .4825 -6 -4.5 ]
[.4875 .4825 0 4.5 ]
[.4875 .59944 -18 -4.5 ]
[.4875 .59944 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-6)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-4)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-2)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(2)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(4)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(6)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.08317 .01472 m
.08317 .01847 L
s
.12106 .01472 m
.12106 .01847 L
s
.15895 .01472 m
.15895 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.31053 .01472 m
.31053 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.68947 .01472 m
.68947 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.87894 .01472 m
.87894 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13166 m
.50625 .13166 L
s
[(0.5)] .4875 .13166 1 0 Mshowa
.5 .24861 m
.50625 .24861 L
s
[(1)] .4875 .24861 1 0 Mshowa
.5 .36555 m
.50625 .36555 L
s
[(1.5)] .4875 .36555 1 0 Mshowa
.5 .4825 m
.50625 .4825 L
s
[(2)] .4875 .4825 1 0 Mshowa
.5 .59944 m
.50625 .59944 L
s
[(2.5)] .4875 .59944 1 0 Mshowa
.125 Mabswid
.5 .0381 m
.50375 .0381 L
s
.5 .06149 m
.50375 .06149 L
s
.5 .08488 m
.50375 .08488 L
s
.5 .10827 m
.50375 .10827 L
s
.5 .15505 m
.50375 .15505 L
s
.5 .17844 m
.50375 .17844 L
s
.5 .20183 m
.50375 .20183 L
s
.5 .22522 m
.50375 .22522 L
s
.5 .27199 m
.50375 .27199 L
s
.5 .29538 m
.50375 .29538 L
s
.5 .31877 m
.50375 .31877 L
s
.5 .34216 m
.50375 .34216 L
s
.5 .38894 m
.50375 .38894 L
s
.5 .41233 m
.50375 .41233 L
s
.5 .43572 m
.50375 .43572 L
s
.5 .45911 m
.50375 .45911 L
s
.5 .50589 m
.50375 .50589 L
s
.5 .52927 m
.50375 .52927 L
s
.5 .55266 m
.50375 .55266 L
s
.5 .57605 m
.50375 .57605 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01477 L
.02605 .01492 L
.02729 .01521 L
.02846 .01559 L
.03053 .01655 L
.03279 .01797 L
.03527 .02 L
.0379 .02266 L
.04262 .02869 L
.05205 .04511 L
.06244 .06864 L
.10458 .19095 L
.14487 .31522 L
.18364 .43479 L
.20335 .49445 L
.21376 .52432 L
.22486 .5533 L
.23566 .57685 L
.24076 .5858 L
.24546 .59255 L
.25018 .59779 L
.25267 .59987 L
.25394 .60075 L
.2553 .60155 L
.25649 .60213 L
.25759 .60256 L
.25868 .6029 L
.25972 .60313 L
.26093 .60328 L
.26204 .60332 L
.26327 .60324 L
.26457 .60303 L
.26571 .60273 L
.26695 .60228 L
.26946 .60101 L
.27178 .59938 L
.27394 .59749 L
.27883 .59194 L
.28404 .58417 L
.29362 .56561 L
.30232 .5449 L
.3423 .42823 L
.38077 .30958 L
.42169 .18338 L
.44205 .12181 L
.46109 .06932 L
.47046 .04776 L
.47936 .03145 L
.48426 .02459 L
Mistroke
.48685 .02165 L
.48961 .01907 L
.49216 .0172 L
.49447 .01596 L
.49559 .01551 L
.4968 .01513 L
.49793 .01489 L
.49898 .01476 L
.50025 .01472 L
.50145 .0148 L
.50252 .01497 L
.50369 .01527 L
.50497 .01572 L
.50632 .01633 L
.50874 .01781 L
.51098 .01957 L
.51307 .02157 L
.51784 .02733 L
.5278 .04422 L
.53852 .06836 L
.57971 .18769 L
.61939 .31007 L
.65755 .42778 L
.67884 .49239 L
.69816 .54614 L
.70783 .56873 L
.71291 .57883 L
.71829 .58787 L
.72299 .59421 L
.72549 .59694 L
.72816 .59934 L
.73062 .60106 L
.73287 .60221 L
.73395 .60262 L
.73512 .60296 L
.73623 .60318 L
.73726 .60329 L
.73843 .60332 L
.73967 .60322 L
.74073 .60304 L
.74188 .60274 L
.74313 .60229 L
.74447 .60167 L
.74687 .6002 L
.7493 .59826 L
.7516 .59601 L
.7559 .59076 L
.76578 .57405 L
.77649 .54998 L
.81738 .43165 L
Mistroke
.85675 .31023 L
.89461 .19345 L
.91566 .12943 L
.93491 .07533 L
.94443 .05253 L
.94945 .04214 L
.95481 .03263 L
.95995 .02522 L
.96461 .02011 L
.96686 .01823 L
.96929 .01664 L
.97041 .01607 L
.97159 .01557 L
.9726 .01524 L
.97371 .01497 L
.97491 .01478 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.256165 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .1428 -18 -4.5 ]
[.4875 .1428 0 4.5 ]
[.4875 .27088 -6 -4.5 ]
[.4875 .27088 0 4.5 ]
[.4875 .39896 -18 -4.5 ]
[.4875 .39896 0 4.5 ]
[.4875 .52704 -6 -4.5 ]
[.4875 .52704 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-6)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-4)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-2)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(2)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(4)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(6)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.08317 .01472 m
.08317 .01847 L
s
.12106 .01472 m
.12106 .01847 L
s
.15895 .01472 m
.15895 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.31053 .01472 m
.31053 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.68947 .01472 m
.68947 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.87894 .01472 m
.87894 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .1428 m
.50625 .1428 L
s
[(0.5)] .4875 .1428 1 0 Mshowa
.5 .27088 m
.50625 .27088 L
s
[(1)] .4875 .27088 1 0 Mshowa
.5 .39896 m
.50625 .39896 L
s
[(1.5)] .4875 .39896 1 0 Mshowa
.5 .52704 m
.50625 .52704 L
s
[(2)] .4875 .52704 1 0 Mshowa
.125 Mabswid
.5 .04033 m
.50375 .04033 L
s
.5 .06595 m
.50375 .06595 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11718 m
.50375 .11718 L
s
.5 .16841 m
.50375 .16841 L
s
.5 .19403 m
.50375 .19403 L
s
.5 .21965 m
.50375 .21965 L
s
.5 .24526 m
.50375 .24526 L
s
.5 .2965 m
.50375 .2965 L
s
.5 .32211 m
.50375 .32211 L
s
.5 .34773 m
.50375 .34773 L
s
.5 .37335 m
.50375 .37335 L
s
.5 .42458 m
.50375 .42458 L
s
.5 .4502 m
.50375 .4502 L
s
.5 .47581 m
.50375 .47581 L
s
.5 .50143 m
.50375 .50143 L
s
.5 .55266 m
.50375 .55266 L
s
.5 .57828 m
.50375 .57828 L
s
.5 .60389 m
.50375 .60389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01476 L
.02605 .01488 L
.02729 .01512 L
.02846 .01544 L
.03053 .01622 L
.03279 .0174 L
.03527 .01908 L
.0379 .02129 L
.04262 .02633 L
.05205 .04034 L
.06244 .06112 L
.0842 .11807 L
.10458 .18129 L
.14335 .31069 L
.18458 .44782 L
.20517 .51051 L
.21519 .53758 L
.22428 .55917 L
.23316 .57682 L
.24277 .5913 L
.24534 .59427 L
.24806 .59697 L
.25057 .59905 L
.25292 .60063 L
.25512 .60178 L
.25625 .60225 L
.25748 .60266 L
.25817 .60285 L
.25882 .603 L
.26009 .60321 L
.26125 .60331 L
.26248 .60331 L
.26361 .60322 L
.26486 .60303 L
.26616 .60272 L
.26737 .60232 L
.26953 .60138 L
.27185 .60003 L
.27714 .59565 L
.28195 .59015 L
.29135 .57555 L
.30023 .55761 L
.33869 .44954 L
.37961 .31354 L
.41902 .18198 L
.43881 .1204 L
.4569 .07149 L
.46621 .0508 L
.47635 .0329 L
Mistroke
.48191 .02548 L
.48462 .02253 L
.48707 .02026 L
.48944 .01843 L
.492 .01685 L
.49341 .01617 L
.4947 .01565 L
.49594 .01527 L
.49724 .01497 L
.49847 .01479 L
.49916 .01474 L
.4998 .01472 L
.50097 .01475 L
.50222 .01488 L
.50333 .01509 L
.50437 .01535 L
.50552 .01573 L
.50675 .01623 L
.50934 .01762 L
.51206 .01954 L
.51692 .02415 L
.52147 .02977 L
.52569 .03606 L
.53527 .05383 L
.55576 .10478 L
.57436 .16078 L
.6144 .29331 L
.65292 .42239 L
.67244 .48428 L
.69389 .54384 L
.70373 .56607 L
.70915 .57645 L
.71429 .5849 L
.71906 .59142 L
.72425 .59697 L
.72654 .59888 L
.72897 .60055 L
.73105 .60166 L
.73334 .60257 L
.73456 .6029 L
.73569 .60313 L
.73693 .60327 L
.73762 .60331 L
.73825 .60332 L
.73953 .60325 L
.74024 .60317 L
.74091 .60306 L
.74213 .60278 L
.74342 .60237 L
.74569 .60139 L
Mistroke
.74782 .60017 L
.75267 .59629 L
.75791 .59044 L
.76271 .58366 L
.77351 .56389 L
.79251 .51702 L
.81324 .45477 L
.85391 .31995 L
.89306 .18896 L
.91305 .1262 L
.92356 .09609 L
.93466 .06776 L
.94462 .04644 L
.94989 .03705 L
.95554 .02867 L
.96074 .0226 L
.96548 .01853 L
.96776 .01708 L
.96896 .01646 L
.97024 .0159 L
.97135 .0155 L
.97258 .01515 L
.9737 .01492 L
.97475 .01478 L
.9755 .01473 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{679, 130.875},
 ImageMargins->{{34, 0}, {0, 1}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 678}, {129.875, 0}} -> {-0.0880394, -0.0144882, \
0.00468449, 0.00468449}, {{18.75, 218.875}, {126.75, 3.0625}} -> {-8.55224, \
-0.267221, 0.071981, 0.0185364}, {{238.875, 439.062}, {126.75, 3.0625}} -> \
{-24.2418, -0.334415, 0.0715163, 0.0231736}, {{459.062, 659.188}, {126.75, \
3.0625}} -> {-39.6135, -0.302944, 0.070849, 0.0209612}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "GraphicsArray", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots of the forcing (or dissipation)", "Subsection"],

Cell["\<\
Forcing is calculated to equilibrate the dissipation since there is no \
advection for a flow that depends only on y
Some arbitrary values are assumed for the parameters\
\>", "Text",
 CellChangeTimes->{{3.405677580537345*^9, 3.405677646827773*^9}, {
  3.40567768158708*^9, 3.405677702176744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Forcing", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", ">", "0"}], " ", "&&", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], ">", "0"}]}], ",", 
     RowBox[{"Simplify", "[", " ", 
      RowBox[{"DS", "[", "  ", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "]"}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]], 
   RowBox[{"C", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "5"]}], "+", 
      RowBox[{"3", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"3", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]}]], "Output",\

 CellChangeTimes->{3.405677810825055*^9, 3.424925537180129*^9}]
}, Open  ]],

Cell["\<\
Setting \[Mu] -> 0. shows that Flow1 requires a forcing with discontinuities \
that disappear in Flow2 and Flow3.\
\>", "Text",
 CellChangeTimes->{{3.4056778880865917`*^9, 3.4056779589082003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", 
        RowBox[{"\[Mu]", "\[Rule]", "0."}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0."}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0."}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405677815714443*^9, 3.40567781989952*^9}, {
  3.405677852460116*^9, 3.405677854705751*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3k8VN8bx+37OoMZEhGSVL7aJedUlOxJpWhRWRIqSZYkS0IqS0kkWSJb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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {193.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c8Vf8bt/e691opRSgk+9ruOTJutmj4aqOSlMhsJyEUskfKlko2kft5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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {580.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUW3c8lt8btvd8X168r1FCNonylZwnlQgRTQ1SGaU0JQ0poVBIklVJmUVZ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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {967.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{674., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.405677858203236*^9, 3.424925600449761*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
Setting \[Mu] -> 0.5 shows that the discontinuities disappear in Flow1, while \
the forcings in Flow2 and Flow3 are hardly modified\
\>", "Text",
 CellChangeTimes->{{3.4056778880865917`*^9, 3.405678010764269*^9}, {
  3.4056783216133003`*^9, 3.405678349750502*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", 
        RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405677815714443*^9, 3.40567781989952*^9}, {
  3.405678299741843*^9, 3.405678312368596*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c81e8Xt/e6dtS3ooEkUSrr+SRKKBIlqWxCyhZlJSoNKwkhK0SEUMbz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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {193.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3k4VV8Xx83zeC+usUjm+d6LkpxjujJFUmn4SUKDQlKkFJGhVEKlSMmU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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {580.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmnk8lN8XxzGDGftgFlvWrDO2lEKeS9qV9VuSVLK00iKVJEkSZSkkW4st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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {967.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{679., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.405677822668429*^9, 3.405678026726883*^9, {3.405678305770659*^9, 
   3.405678317322577*^9}, 3.424925609309808*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the pertubation problem", "Section"],

Cell[CellGroupData[{

Cell["2D Navier-Stokes with scaling", "Subsection"],

Cell[TextData[{
 StyleBox["We have taken u = ", "Text"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", "\[Psi]"}], " ", "and", " ", 
     "v"}], " ", "=", " ", 
    RowBox[{"-", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", "\[Psi]"}]}]}], 
   TraditionalForm]]],
 " (definition used in fluid mechanics, opposite to the convention in GFD)\n\
The temporal term has its order lowered with respect to the standard \
calculation."
}], "Text",
 CellChangeTimes->{{3.4056784807764606`*^9, 3.405678508854782*^9}, {
  3.425025554856198*^9, 3.42502559558567*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS", "=", 
   RowBox[{
    RowBox[{"\[Epsilon]", 
     RowBox[{
      SubscriptBox["\[PartialD]", "T"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], "-", " ", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "+", "\n", 
    "      ", 
    RowBox[{"\[Epsilon]", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "-", " ", 
    RowBox[{"DS", "[", 
     RowBox[{"\[Psi]", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "+", " ", 
    RowBox[{"DS", "[", 
     RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}]}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.425025547677606*^9, 3.42502554800094*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expansion", "Subsection"],

Cell["\<\
The streamfunction is expanded up to the fourth order in \[Epsilon]\
\>", "Text",
 CellChangeTimes->{{3.405678519006564*^9, 3.4056785401302223`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Psi]", "[", 
   RowBox[{"T_", ",", "X_", ",", "y_"}], "]"}], " ", ":=", "  ", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "+", " ", 
   RowBox[{"\[Psi]0", "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"\[Psi]1", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], " ", 
    RowBox[{"\[Psi]2", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "3"], " ", 
    RowBox[{"\[Psi]3", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "4"], " ", 
    RowBox[{"\[Psi]4", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS2", " ", "=", " ", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{"NS", ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], 
     ",", "\[Epsilon]"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 0", "Section"],

Cell["\<\
Extract order 0 terms from the general expansion and perform algebraic \
simplication.
Fairly lengthy expression anyway.\
\>", "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.4056799005414543`*^9, 3.405679948493458*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a0", " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"NS2", ",", "\[Epsilon]", ",", "0"}], "]"}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.424925731289408*^9, 3.424925734445738*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "C", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"8", " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], ")"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]], "-", 
    RowBox[{"4", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
     RowBox[{
      SuperscriptBox["U", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            RowBox[{"U", "[", "y", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["U", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "3"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "3"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"U", "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}]], 
      ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "+", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"U", "[", "y", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "3"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], ")"}], 
     "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"U", "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], ")"}], 
      
      RowBox[{"3", "/", "2"}]]}], "+", 
    RowBox[{"4", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"U", "[", "y", "]"}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "+", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}], "+", 
       RowBox[{
        SuperscriptBox["\[Psi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "4"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}], "2"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"U", "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["U", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "3"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["U", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "3"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["U", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "4"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"U", "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}]], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405680437302593*^9, 3.405686782110867*^9, 
  3.405702863564118*^9, 3.405705927313441*^9, 3.4249256236271772`*^9, 
  3.424925742004727*^9, 3.425025696907142*^9, 3.441628526930019*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell["\<\
The 0 th order solution satisfies a0 = 0 as soon as it does not depend on the \
fast variable y \
\>", "Text",
 CellChangeTimes->{{3.4056787688339157`*^9, 3.4056788439856663`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule0", "=", " ", 
  RowBox[{"\[Psi]0", " ", "\[Rule]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[CurlyPhi]0", "[", 
      RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Psi]0", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[CurlyPhi]0", "[", 
     RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.405680437709983*^9, 3.40568678273033*^9, 
  3.405702864034481*^9, 3.40570592823939*^9, 3.424925637923162*^9, 
  3.425025703037823*^9, 3.441628532092451*^9, 3.441628704135085*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification", "Subsection",
 CellChangeTimes->{{3.4056812924802628`*^9, 3.405681294988698*^9}}],

Cell["\<\
Check that \[CurlyPhi]0[X, T] satisfies the 0 th order solution\
\>", "Text",
 CellChangeTimes->{{3.405678887077858*^9, 3.405678911528989*^9}, {
  3.405678944352785*^9, 3.40567896841066*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"a0", "  ", "/.", " ", 
    RowBox[{"{", "Rule0", "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.424925771536065*^9, 3.424925774695413*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4056804405524597`*^9, 3.405686785513888*^9, 
  3.405702870471019*^9, 3.405705933507183*^9, 3.424925675950719*^9, 
  3.424925776360183*^9, 3.425025705266735*^9, 3.441628535155465*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Useful rules for simplifications", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Improve", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"Together", "[", "#1", "]"}], "]"}], "&"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.424926465800952*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Together", "[", "#1", "]"}], "]"}], "&"}]], "Output",
 CellChangeTimes->{
  3.40568044119874*^9, 3.405686742026483*^9, 3.405702770031386*^9, 
   3.405705842353067*^9, 3.405705935121743*^9, 3.42492551941725*^9, 
   3.424926467598072*^9, 3.425025649718823*^9, {3.441628512549918*^9, 
   3.441628539187858*^9}}]
}, Open  ]],

Cell["Periodicity in space", "Text",
 CellChangeTimes->{{3.405679044282816*^9, 3.4056790705350523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solva", "[", "expr_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"expr", " ", "/.", " ", 
       RowBox[{"y", " ", "\[Rule]", " ", 
        RowBox[{"2", " ", "\[Pi]"}]}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"expr", " ", "/.", " ", 
       RowBox[{"y", " ", "\[Rule]", "0"}]}], ")"}]}], ")"}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"g___", "[", 
     RowBox[{"2", " ", "\[Pi]"}], "]"}], "\[Rule]", 
    RowBox[{"g", "[", "0", "]"}]}]}]}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 1", "Section"],

Cell[TextData[{
 "Extract order 1 terms from the general expansion, use formal solution to \
order 0 equation and perform algebraic simplication.\nNeed to be put under \
the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]1", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a1", " ", "=", " ", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"NS2", ",", "\[Epsilon]", ",", "1"}], "]"}], "]"}], " ", "/.", 
     " ", "Rule0"}], " ", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.424925802872702*^9, 3.424925804984272*^9}, 
   3.441628566151992*^9}],

Cell[CellGroupData[{

Cell["Extraction of the linear operator and verification", "Subsection"],

Cell["First derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680267654934*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.42502571918484*^9, 3.425025722615148*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]], 
  RowBox[{"C", " ", "\[Mu]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", "\[Mu]", " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "5"]}], "+", 
     RowBox[{"7", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "5"], " ", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "3"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.405680475064075*^9, 3.405686818017201*^9, 
  3.405702947644118*^9, 3.405706187599757*^9, 3.424925846890108*^9, 
  3.425025724378705*^9, 3.441628570212035*^9}]
}, Open  ]],

Cell["Second derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680284810182*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]], 
  RowBox[{"C", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["\[Mu]", "3"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "5"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["\[Mu]", "2"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"5", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["U", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["U", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["\[Mu]", "2"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.405680481735201*^9, 3.405686824150296*^9, 
  3.405702959741571*^9, 3.405706201606166*^9, 3.424925856595809*^9, 
  3.425025736032755*^9, 3.441628575142854*^9}]
}, Open  ]],

Cell["Third derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680267654934*^9}, {
  3.405680300316112*^9, 3.4056803028255*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F3", "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", "]"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"C", " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["\[Mu]", "2"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "3"]}], "+", 
     RowBox[{"\[Mu]", " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"6", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
   RowBox[{"3", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.405680482456992*^9, 3.405686824898526*^9, 
  3.405702961055523*^9, 3.405706202731677*^9, 3.424925861072515*^9, 
  3.425025741703265*^9, 3.441628581284553*^9}]
}, Open  ]],

Cell["Fourth derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680267654934*^9}, {
  3.405680306086762*^9, 3.405680308433175*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F4", "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"C", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
  SqrtBox[
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], "2"]}]]]], "Output",
 CellChangeTimes->{3.40568048286045*^9, 3.405686825095542*^9, 
  3.4057029616301*^9, 3.405706203451018*^9, 3.424925864293939*^9, 
  3.425025746579276*^9, 3.44162858438849*^9}]
}, Open  ]],

Cell["\<\
Complete form of \[ScriptCapitalL] and verification against the terms \
extracted from a1\
\>", "Text",
 CellChangeTimes->{{3.405680327200042*^9, 3.405680367142193*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalL]", "[", "f_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"C", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"y", ",", "y"}]], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"U", "'"}], "[", "y", "]"}], "2"]}]}], " ", ")"}], 
        SqrtBox[
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{"U", "'"}], "[", "y", "]"}], "2"]}]]], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], "f"}]}], "  ", ")"}]}]}], " ", "+", " ", 
   RowBox[{"C", "  ", "\[Mu]", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"y", ",", "y"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"U", "[", "y", "]"}], 
         RowBox[{
          RowBox[{"U", "'"}], "[", "y", "]"}]}], 
        RowBox[{" ", 
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"U", "'"}], "[", "y", "]"}], "2"]}]]}]], 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "f"}]}], ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.42492587478068*^9, 3.424926003497318*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"f", "[", "y", "]"}], "]"}], " ", "-", "  ", 
    RowBox[{"a1F1", "  ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "1", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"a1F2", "  ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "2", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{"a1F3", "   ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{"a1F4", " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}]}], ",", " ", 
   RowBox[{"Trig", "->", "True"}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405680483359929*^9, 3.405686825436984*^9, 
  3.405702962363421*^9, 3.405706205041713*^9, 3.424926035010647*^9, 
  3.4250257542649*^9, 3.441628588930908*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extraction of second member: a1a", "Subsection",
 CellChangeTimes->{{3.405745203832325*^9, 3.405745206527741*^9}}],

Cell["\<\
The second member contains only the first derivative in X of the Oth order \
solution\
\>", "Commentary",
 CellChangeTimes->{{3.405680924835505*^9, 3.405680976013473*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1a", "=", 
  RowBox[{"-", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["U", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.4056811907123632`*^9, 3.405686825639031*^9, 
  3.40570296285511*^9, 3.405706205562864*^9, 3.424926045671801*^9, 
  3.425025758908281*^9, 3.441628591975939*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reconstruction of the first order equation ", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "We", " ", "check", " ", "here", " ", "that", " ", "the", " ", "first", " ",
    "order", " ", "equation", " ", "is", " ", 
   RowBox[{"\[ScriptCapitalL]", "[", 
    RowBox[{"\[Psi]1", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}], "=", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"U", "''"}], "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}]}]], "Commentary",
 CellChangeTimes->{{3.405680993611363*^9, 3.405680997989916*^9}, {
  3.405681035330802*^9, 3.405681097427763*^9}, {3.424926076232111*^9, 
  3.424926079243314*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a1N", "=", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]1", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "-", " ", 
    RowBox[{"a1a", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a1N", " ", "-", " ", "a1"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405681196602668*^9, 3.405686826350112*^9, 
  3.405702963578828*^9, 3.405706207010185*^9, 3.424926299012313*^9, 
  3.425025763632008*^9, 3.441628600054517*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell["\<\
This solution is meant to replace \[Psi]1 in further formal steps of the \
perturbative expansion\
\>", "Commentary",
 CellChangeTimes->{{3.405682181618347*^9, 3.405682241109109*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rule1", " ", "=", 
   RowBox[{"\[Psi]1", " ", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"f1", "[", "#3", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}]}], " ", "&"}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.441628622622371*^9, 3.441628630992306*^9}, {
  3.441628714854061*^9, 3.441628722452819*^9}}],

Cell["Notice that f1 has SinI symmetry", "Commentary",
 CellChangeTimes->{{3.4056822559201202`*^9, 3.405682257900504*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical solution [TO BE ADAPTED]", "Subsection",
 CellChangeTimes->{{3.40568214744515*^9, 3.405682158019816*^9}, {
  3.424926392315331*^9, 3.424926404925798*^9}}],

Cell["\<\
Numerical solution to f1, from the first order equation integrated twice in \
y, and with g1 = f1'\
\>", "Commentary",
 CellChangeTimes->{{3.4056816122258253`*^9, 3.405681633332135*^9}, {
  3.4056816843433733`*^9, 3.405681749314281*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Eqg1", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], 
         RowBox[{"g1", "[", "y", "]"}]}]}], "  ", ")"}], " ", "+", "  ", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], 
          RowBox[{"2", " "}]], 
         RowBox[{"g1", "[", "y", "]"}]}], ")"}]}]}], "\[Equal]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "C"]}], 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}]}], "}"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.4056815996983547`*^9, 3.4056816018673487`*^9}, {
  3.4056817667860727`*^9, 3.405681767066577*^9}, {3.405706246948409*^9, 
  3.40570624749131*^9}, {3.405706314575869*^9, 3.405706337819771*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "\[Mu]", " ", 
     RowBox[{"g1", "[", "y", "]"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}]}], 
   "\[Equal]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}], "C"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.405681454709593*^9, 3.4056817684708776`*^9, 
  3.405686827019577*^9, 3.405702964678041*^9, 3.4057062488632*^9, 
  3.405706344083208*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["With Flow1", "Subsubsection",
 CellChangeTimes->{{3.405706360288899*^9, 3.405706365291543*^9}}],

Cell["No solution when \[Mu] == 0", "Commentary",
 CellChangeTimes->{{3.405682270906063*^9, 3.4056823076350822`*^9}, {
  3.4056823538003397`*^9, 3.405682354189416*^9}, {3.40568242018408*^9, 
  3.4056824220428467`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Eqg1", " ", "/.", " ", 
       RowBox[{"{", 
        RowBox[{"Flow1", ",", 
         RowBox[{"C", "\[Rule]", "1"}], ",", 
         RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"g1", "[", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
    "]"}], ",", "g1", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.405681773347843*^9, 3.405681773941864*^9}, {
   3.40568181377392*^9, 3.405681839055987*^9}, {3.405681869514463*^9, 
   3.405681873703433*^9}, {3.405681909005368*^9, 3.4056819326317368`*^9}, {
   3.40568196556674*^9, 3.4056819888316507`*^9}, 3.4056820216931334`*^9, {
   3.4056822989698257`*^9, 3.405682302285568*^9}, {3.405682359535001*^9, 
   3.405682361288138*^9}, {3.405706507788413*^9, 3.405706509774545*^9}}],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.405681991415235*^9, 3.405682022340774*^9, 
  3.405682364383728*^9, 3.4056868272169847`*^9, 3.405702965323932*^9, 
  3.405706277994282*^9, 3.405706511101094*^9}]
}, Open  ]],

Cell["Exact solution when \[Mu] == 1", "Commentary",
 CellChangeTimes->{{3.405682270906063*^9, 3.4056823076350822`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1A", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "1"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.405681773347843*^9, 3.405681773941864*^9}, {
   3.40568181377392*^9, 3.405681839055987*^9}, {3.405681869514463*^9, 
   3.405681873703433*^9}, {3.405681909005368*^9, 3.4056819326317368`*^9}, {
   3.40568196556674*^9, 3.4056819888316507`*^9}, 3.4056820216931334`*^9, {
   3.4056822989698257`*^9, 3.405682302285568*^9}, {3.405682540698832*^9, 
   3.405682549646378*^9}, {3.40568682429978*^9, 3.405686825979868*^9}, {
   3.405706514455022*^9, 3.405706516182363*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "y", "}"}], ",", 
      RowBox[{"Cos", "[", "y", "]"}]}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.405681991415235*^9, 3.405682022340774*^9, 
  3.405682551470401*^9, 3.4056868274570513`*^9, 3.405702965903803*^9, 
  3.405706297896535*^9, 3.405706521592774*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Numerical", " ", "solutions", " ", "for", " ", "several", " ", 
  "values", " ", "of", " ", "\[Mu]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"When", " ", "\[Mu]"}], "\[Rule]", "0"}], ",", " ", 
  RowBox[{
   RowBox[{
   "the", " ", "second", " ", "derivative", " ", "of", " ", "f1", " ", 
    "tends", " ", "to", " ", "be", " ", "singular", " ", "in"}], " ", "+", 
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"When", " ", "\[Mu]"}], "\[Rule]", "\[Infinity]"}], ",", " ", 
  RowBox[{
  "the", " ", "second", " ", "derivative", " ", "of", " ", "f1", " ", "tends",
    " ", "to", " ", "be", " ", "singular", " ", "in", " ", "0"}], ",", 
  "\[Pi]"}]}], "Commentary",
 CellChangeTimes->{{3.40568232181746*^9, 3.405682323174533*^9}, {
  3.40568256853981*^9, 3.405682595845359*^9}, {3.4056855367856607`*^9, 
  3.405685583688298*^9}, {3.40568563791998*^9, 3.405685651364607*^9}, {
  3.405686856415606*^9, 3.4056868962700033`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"g1B", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "100."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1C", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.1"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1D", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.01"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1E", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "10."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1F", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.001"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405681773347843*^9, 3.405681773941864*^9}, {
   3.40568181377392*^9, 3.405681839055987*^9}, {3.405681869514463*^9, 
   3.405681873703433*^9}, {3.405681909005368*^9, 3.4056819326317368`*^9}, {
   3.40568196556674*^9, 3.405682016653285*^9}, 3.4056820887613773`*^9, {
   3.405682479836936*^9, 3.405682517784671*^9}, {3.405682554131682*^9, 
   3.405682555422155*^9}, {3.405682609625046*^9, 3.4056826300251503`*^9}, {
   3.405682892687722*^9, 3.405682920347066*^9}, {3.405684928580121*^9, 
   3.4056849689274282`*^9}, 3.405685191977766*^9, {3.405685493979383*^9, 
   3.405685496169139*^9}, {3.4056869948874702`*^9, 3.405686997075314*^9}, {
   3.405706560061238*^9, 3.405706581695346*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706583062284*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706583080649*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706583323489*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706583339161*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.40570658335434*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pC", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1C"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pA", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1A"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pB", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1B"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"pD", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1D"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pE", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1E"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pF", "=", 
    RowBox[{"Plot", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1F"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], ",", 
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], ";"}], 
  "\n", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pF", ",", "pD", ",", "pC"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"pA", ",", "pE", ",", "pB"}], "}"}]}], "}"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.405682679304923*^9, 3.405682756118494*^9}, 
   3.405682812014813*^9, {3.4056828831425953`*^9, 3.405682890096424*^9}, {
   3.405684977337996*^9, 3.4056851606579313`*^9}, {3.405685201488823*^9, 
   3.405685201925613*^9}, {3.405685319254837*^9, 3.405685323971859*^9}, 
   3.405685397510726*^9, {3.405685435043001*^9, 3.405685474542745*^9}, {
   3.405687010468215*^9, 3.405687016124189*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8lM8fAPDdfRzrZiukQihSFEWKzBS6CImShBRKRYmSlONbjhwhV4jk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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {193.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c81d8fB3DbvTYZkSKSQooiGs6pVCohWYlIRkX2pqzsUchIUjKShGRF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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {580.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c81d8fB3DbvfZWUmSkkJL0lXCOUEQiskqkUJKVnRINo8hoIJGyEhmR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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {967.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Xk0Vd8XAHBles88axKKlEppkKTOqYiiUKJUpsyJEhr4JkrIECpRoiiJ
ypApZBszy0zILNN77woJid/5/fXWZ9131rl3n733OXddWUvnk9bL2djYUpex
sf3/19O6Xfmv7BxM6ayvG9jtfcB0f2aQxKo5CMpsm1rzyAxh8fBhZZE54HiS
odEc7ozYy3Re2C2fg753Rbfiwr3QAzmgtfbPgq33y5pT4Q9R1MCbntT4Wdip
yW94OiwWZVlcC7aRn4UtMP/lZnAKoi4IjDZs/APq4u80pG4DqvJIa1Dk/A13
879o8mjWo/9CJjzqOKcg43rJrvzvbWhAX5j/ltAvWJe89ps2oxuZXz0Qq9fH
hL6f38+W0QZQkmL4Wzw2CtLcScuOCf9EJUqFIioxQzB7rXx38uwI0p+OVzAK
HgJn95z1u9lHUfdnP3V3zyH4eIdfKod/FM1r6NlkmQxBvfmuDe/WjaId57o/
q0gOwcFRiYN7dEdRnN+C+Z7QQbCwjRNbFjOKfHpVU1R9BkD3e5vbHvUxhMPT
dPbZ9EGSxEjdU8tx5LYnLus/oz74vHRO+rPDOErqCpctPNIHYVaPaptcxpGo
gusfDYU+yNZx3/fbZxz9zFOJPzHSC7tOPNgwEjeOgoby5i0ceiH1onxgUN84
+ng16JTwj25YEWF4ufgsA63Iv7wp4ks3vC5aXslrwUDeXHpLq2K64VhXx5ET
dgxk+Fw4Wc6sG641sccVuDPQfGnEctW+HxCS7vJG9xEDHVnxKs10qAuqNATM
11Qz0I+CTMH3zA7wPQ0zt3czUXTnB1pAdQe4zKx/cE2dic7Pvllm864Dbqzb
XmN2mIm6lCOmpK07YOsrc0NpA+LX7m2Pur7DnriwA2qOxA/2xHpUtwOoetb+
eMlEHUaflXTetYLQJTVmHTsLPbuWprDRrxUuDLalZ9JZyCT0nQyndSv4W2Uz
HgmyUEdllAjItMLIubAsldUs9F391syOyBY4kxHoKr6DhdrX7StY5dcMfSVX
tquYslAbK//4mFUj2PnY98ylsNBgVd0kr2YjdKevuXgrg4UmE3qfbpVvBPc9
tUencliIz4yj/8pQAwRH5+yrK2KhQ9903P9YN0CP1vpHG5tY6GNKRwyHbT3Q
/jXIOk2zUH4g4/AGrXpY88zR0HWWhSptF0e0FOqhJGfTd5cFFqpAGjYS375B
EJJsOcNBoZ0yTSHr6+vgQKinR4UohXj6Jnr2N9aASnL0x93KFJKPElP0Dq+B
nupPoYW7KIQNVF1LT9aAz7L5zMOqFHIv8qLpNFVDTn3U1x2IQn2vBJTPNFfB
sgf7Rz7pUijHcouPS2sFsBgrXA/aUKhplX5NZkQFVLo1y+nbU4jVeE1izqgC
mEVZvMaOFFp/OC/Jq60cKM5fN467UChk/bGmoPavELk+Pb/rPwpZD9rKve0o
hXPbnHXuPSLzN9pe2hxdCr+Oxm2mR1DIv9A2PeVCKWgz2HzvR1IoKdoW5/SW
AFN04KXDCzKfoe35yp/FMH1H8HJ7AoWWDtnGH08shpPdNlyy7ygkpGw71mBf
DPy0C2KWySQ+/LY3OhhF0OG7LKg2hUI3ymwej08Wwtdj4Z1HcygU8Mmm0zmj
ELZGqPEa5VLo2SubddNuhfCFzS7ZJJ9Ct/7WmM/9AmgMt913vJBC7I41kasX
v4DVnumgtnIKSRyvpplL5MIuafbHd1oopLqpOsIu6jNstlOLEG2j0DnOarmr
az5D9iOp5bHtFHr5pQr7rMuB1FtXxGM7KbRJqerGa6UsgE2OMhp9FNLlqeL6
kJYJb7xX2jzrp5DTz8rHmbsyYfuTTyKjAxRKj6lM/aqWAYyCK7HOPymkLlg5
MnIkHTJUKm7LjlPIdLzC/VdlGtz97jelxqCQd3kFx7xuGkhMjNToMin01atC
hvdUKqQfCnp/lqJQQ3boBYX3KSDjaJBuOEGe50roTdX0j6A2+GW19i8KxfY+
TDMpeA/fgxNWrJii0GDkw9pLpckwoZSRPE280eDhqGdVEkz9C3xVOU3uryhE
NrY1Eerm6jPOz1Doz82Q/aldb4F3VXfDqj/kfneEnC3qTwAJvd/6DcRf44LD
BlivwaDliavCHIUKmIe/ZvbEQxBHn34zcbbq/LxffRz8SGzbdWOeQql3U7eZ
FL2CsAodGdG/FEqss7Hakv4StrGERd8Q451qO/5pxoLvxmX8SgsUUq5MeP5K
4QVk8kzxfyQW+e3lNDYWCf8SDeQe/SPrGchoC6mJgBOyt/fOEk/LnD248+Nj
WPi85bThIoWGssqS2h6Gg3H04etviVt1d4h5Xg0FFffk2F/EIWX7/+KEIFi6
qVe3Y4lCzr8k6gLs/eGDqRT7JWJ9qYmXjVvuQZMZ54FnxFbh4cMqvV7wZv/8
7UJihTGN4Aqb6/BH/VfZD+KWuyzrjI7LcFihX2SSONsmwTLl21lIOlZu/Y/4
hqsMv9gWjKZvvihYIn56eSC7758VesJnJTVHTDNDKmazLii5e43PKLEmd3Bo
7VUPtKBfw6gnLjK+/PvFb280o33zQgpx7+bH607vuI9Stm9tvke8uJSrx+f8
APXMTOkbEK9p7vMsSQ5BPQJdTWLEUoYcp/e7hqH4KzPnv5Hn31LwdDwy/BH6
HGnEuEOsvnGzz3TqE3TAX8RnE7FOeMEK/W9PUVfpobWVJL4mCwYpycwoVHxm
eZEZsYPNkCY3XzSKaXRyYJL1uVl/o8tSMQY91Exc5UKsIXV/r5ncS7T+aEMD
k6yvbuM3juCdr5DOnECoObGh38r63ENx6PiM/+kqkh/n1C8+HzGIR1+s7Ndt
JnZImFHWuPIGuX4RaWqYpZDLOfzvqlcCmvFVz5Ykvin0oCI25C3CniHxhiQf
/W9Jmf19/w55nfN/8uk3hRJOaASlj35AW185DXFOUugDe4hx7+xHlPzHUpiD
1IdJ1yVhbo5UZJHuoTVH6skyLLNrl2gaonZpN1WQenP5q30tVPkTqtNZ7bIw
QqGZFuYZhc+fkAyN+pM+TPpLaviBApyBtu2/98Cc1LO3dRedoZeJ2A2vtr0k
9R76zfmlllM20ntstDrrB4W6339oqWZko/HLLttwF4n/g3Ee/Us5KOaRp0dx
B4XKNWzdzth9RulhjfkppP8sfjY9Zm+Zh85ZbKO2NJD4PY32YvbmISEjk9ob
30i/c+3IuGqWjxQiwn/m11Jo9zYj6VvnvyBWQHf11ioKOb4+Pv3ACBDj6h6n
9GIK5XoHbhJsAeSWJKJcSPrhvRSrlMpNhag25tGOrwUUagyKGzyeWIg6p92n
ckk/vay1Vs/oTRHi+lVwSyudQq/zxeVsY0tQzry1ODOW5EdyxoF33SWo4fZH
Ni/S3yejTp0dlypFtTx7d9Kfk3q+HhbiHF2Kim3+u8JF9odOZf6561FlqHqC
78LrQFLPbznq/B+Vo5czxSFObhTyCpu6nuRXjb768+07eJjUS6eVrnpNNcpZ
7Sb/mOxvLvKtMnVCNeil5vYV3fsoZPM5p/JXVA2S9h5YZUz2xxN9/63e+74W
/biX9umHHIXWKtOgvP4bSg74o3SA7LemdgJ3J/kakXfEQLphPgud49e6vG9b
I8KpvqMPslnoTLqX8T2DRlRqfE8vJ52FTi5MbJaIaER0nvUps4ksdCS0qXmv
dBPKCtYcFHzCQko5kRu8lZuRY7KFfdQlFvrHvb5K0KgVFXP2e64XYaHFMObu
nOutKMRbW9KUj4XY1uS8Mo9qRXlvN1mGcrEQx/bjN9O6WpHDQKVg1zwT8Z25
vvHUxTa0dRvHrOAAE61KrL4fcaUdTfdPOY+nMdEebdfDUoEdKOHGH+H/jjLR
Vf+yfMXCbmQi1it/zZyBNpxy9wzpIefe1OhEJXL+65BSUJ9c7EbWSc/ODhgw
0KFP/nmf9/cgOSmL46qHGUisWydXO68HiTm+/BAqz0CdK0fP7TzXi3Ia7/cv
jIyj/5ydzxoY9SGPNja2enI+LV7laRisO4Dq/PzP1pqMoV8SleseXRhAbT0l
P2UNxpCMqMSvSKcBZDLnu8xZawzd5k0Nfh06gH78fTY2uXMM7V0Y+JrXTMbn
WLe/4htDqT909o6dH0QeBUcex+SPotiXq9dqXR5CfuFH/BUkR5HnhrxhtpBh
dHbP1KBU9jDy1S7+031/HPHOcH+70jOIiqSp1znNFOo6ab3prlMfqtHZcugg
9yRyrdd6vPN2J+oW0bzSuTSFGn7qvqpQakYBGROOU+tmkBjfzY0uzeXovAVb
YqHsLPrQymezyJaKPE2VFnwl5pFPvenalKCPsFuFWlu5ewGNicqov7leAeIr
xe4UbV9E5grpckeGmkB7fKht9WY2LFoV+25XRydsntRfaFRdhp/f3J5ZEtEH
cYtMsNq1HO8IjT9zPm8QrG80O+zWZMe7g4UHNlQOg2XHguT2o+xYN7Ykt7Jp
GMzV5csUj7PjKurUB5vuYTBhc5eWOU288LA9ZGoY9P0lm3ms2TEK1118KjUC
apEm+3vvsWN5RctDgVdGQCinVzCwlB0ffWHVNiA8Cvl/GBm9hzmwQKWRT9PB
MTCJ0DpZrsWB92WxP8s7Ngazu+KoDzoceEe3zdUXp8Zgl4uxoscpDvy8s9vo
hPUYvGcUxYpf5MBu4w1FVv5jEN0X8eCYDwf2PhF6xLJ2DDyqsXlGIQd2tlio
Dzs5Discnv97VsqBlQPEhz6YjEMWbeaZdwUHvhOhfqPEchwmNZNbTtRz4L40
TrFOl3FwKBTXGe3hwCHDooy88HEwyRzbvXaJAzd/y71+qGEc1GIf8/rv58S7
NQ+uMTrKgOCLQa9LDnLil186v6kbMKBX4d7+JU1O/EtAMGL1WQbcT73m7H6C
E681cjEosmNAU9HJJiszTuyYzaX1wY8BjoNCzw96c+Ik80c6nKUMiN0UrPi3
lBMb0oJk36owYZJ5r0SlkhMX2jYKBO1nwpF0z/MutZz42MYHNXYaTGCoOYaM
tnBi9bGXafSTTFDV1Zls+8mJS+qVmSOOTGh0oudm0LiwnEyc3+pXTODI8D3q
pMuFB9frpmmws8AJz+ta6HNhrfzHU3k0FrTVOOkbGnJhjzCZwc0CLEgaMjZW
O8+Fy3uyqn6vYIG+pKI1lyMXXgzdFaCsxILoW3V3YgK5cONW2nstYxbsPCiZ
U1fFhWtiBRlD8eR6bWBeUR0X3p56xP9KIgu4TNggo5ELv3ZtSZ56z4J2l9Gy
Zx1c+P3Qk3sDmSy4/TqvyWaMC28S0jG1L2dBFbc5tUjnxn8+VZbxjbLAsi5x
w7aj3PhknKVZ8gYKvO/kyl8/zo1R5XaucEUKXu6okQMDbmzNWF7orETBjwhq
nZ4JN/Yf17ITUqHgjJmKtPMlbtx/7bfjTw0Kjk+USKYEc+MAe93zg+YUOMa1
SPwJ48ZyfyQy9llR8MBwWBxFcGONYQuBB7YUVOTwiH2L4cbCM2lfeZ0oOORt
IESlcGOGjsmW+FsUqIr00LY1cmNBPsQpG06BUekE9/VWbjzyVHzlyGMK3NyX
c0MHNz71z0M24SkF6R3ynHoD3Dj8Uysf9wsKtsY7LnOe5sayQfaq599SoHv6
Nlv2LDeO8TnZ2fGOAgfu0KXFBW6s5lHtqP+egsRLn/6FcNKwU2vMGZk0Ctbt
mp/7KEHDW69l4VO5FBz8yTs3s4qG/YNmNQLyKTCPlJo9IE3DGzmv7sgqoODF
Ap6pU6BhxdSAr9PFFKwo85tkqdKwHT2omKOaAn4j8XGlczS8d/VUoPN38rz1
8YZKZjR8kO+5/mwHBe7HdhRsvUjD+353ytzsoqD3gF7Ylks0fFU3qd+yh4IM
hYA9ih40LPfmWl/rIAWjryRfbfKiYQZ7/az0TwrWrkng2XSXhk0PLaywGKbA
X6jkh0IgDX+O8nWpHqXg/NzCXfnnNCwCoj6YRUHYtUCmXCwZvy+q7ShFwVfm
SmO5eBoWrn29U2eCgu39Korrk2k4fqXe4u5JCqzPlz1al0LDbkeuOUpPUfCs
9dQ/2U/EDht72aYp4Ki+Ui+TR8MvrGzakn9TsFdzaa8M0PCp6HsmbjMUOEFw
vHQJiW+Iab/KHwraPyW5r62m4TUG95dezZL4KO3tlfpG5ne7+VhnjsQnsfyo
VBMNa827bGUSv48eXLOmk4Ztvnx3WPGXgj6Ja/dX99Dw5MEFgThiibBlE6sG
aFgs82HW+gUKdHhDz64apuHLWdcsXhDf8V1bsnKchncNBggK/qMgc+n9lpUU
DR/ozCy8QTx2c1/EiikaZt/zw7WDWHq6cknyDw2/DRvevGuRAkOnM/aSf2n4
392CIV/igJGfjRJLNBz+5ngcOW9DgaWbugQ7Hb8P8rEQXqJgqos9QZybjk/W
6a7XId5oHC4ozkvH+osvhj2JLzTI3BQTpOO9KfYfE4jDdVL6RUXp+LIL2Y2I
y8v264pK0rFEu/bhfuIFVJMpspqOdzofF54mVs41kRaRpuPQso995P0DbHaN
+guvp+M6W4cM8v4Bzz9enxRSoGPzPq8A8v4B9Ru5zgttpuOg/AnzcWLO+Mdl
gtvIfD6Fai3EalLrtwnupGNm7rRENrHz07RIgT10XMl4/DuU+LUwXi6wj4x/
kdRqSfw9sO4SP6LjYIODuVuIBbgutPAdJuMDbV6ySDwO3xk/wKdFx4/qNgUk
Et+Yv5nIq0PHCs+iXU2IP7jSRHj16FjYqdGSg7ifFeHBc4qOr1b0nkog8dcZ
+HSCfo6OHy4fPtBI1k/mmWvitCkdO1qyvTAlntHfvbzXko7by/KPD5D1jyvI
ysxyoONljRFvW+bJfG7XBeOc6Fh752/9w8THt6jaB7vQ8Tr6jePvSD7NRn1e
Y3WLjj3K72BTkn91+rfc9W7T8Wl5oz0fSH7Gc++rV/OhY4t+lvc0yd8Tbvl3
hR/QMd9bKVFHkt+v9WGsIIo4/Yvi0i8KbnHf0Uh6QccmnqxSIWK9Ahzz5BUd
z/24kbGK1NP85mIDx3d0/NHD/7EkqT8D7rKclZ/p+EaWp1kmqc8NBb4inF/o
uIpllBwwQtbb9YjjRCEdv8qNOGFE6jmxv1y6vIKOU+ado9tJ/S9+qbrv2k7H
6b4Cpt6kPzS7BvaaddExNRh8eUU3Be8266rp9JL8uDHd+pb0E8OoWqbsCB3j
yY6cFNJ/klzrDb/9oePc0a0lF5tIfWwO+5j7l47Hq+eTvzRQcLrfgJawRMd3
lyX8EqyngE2/Kc+TmwefqNv95EUNBcabW9cpSvLgNaYz2hfKKNjSH+EpvpoH
Z7tZyd0qoWB5lHErmzQPNtaXMn9YRMFHru8BbRt4sJ6e9nzcF9Iv+jsn7qnw
YMWh9q9OmRSkRvYV9JzmwVGrHipHxVOwzw2JyZjw4H84K5v2ivQngxf25qY8
WBhp6DnHUNDJc1asz4YHBzDuZ8pGUcD1X719/3UevN+06drqENLvLEBsKIoH
Kxko2V90p2B4v5SDfAwP3l1rclHjGgUuqzzAOo4H29R3eKy5QoFfk4rDzyQe
7BVgx5tuT/YTzY8wnMeD747rFricp4Cm+MJh7AcPXs2+TFsHU/CI6y8o9vPg
/hONT2PUSf8dOCN+6ScPbm6zFh9VpWBntFjhOIsHc6dwxVxUpsBUIEicucSD
g3fIsFOypJ9P3iqkZHkxi2EmZr6MAou8MxK/rXlxR+2D8E+fWbDcfGcrw54X
V6UleWOyn7/mEIgYvMyLXS5zDpSlsuDn8RLxZjfy/9stbLlvWeDQu1X8ky8v
nvpPqULrCQtcONnFrr7hxdkpOvfnnVhwT++DMHOQF9e8Py1ftoYF8tN+DYMj
vFi3Zm2cpSQLvkZahnUxeHG7yGz2rDALaP2SwjXTvPhN+PYMAW4WBLn6CCVz
8OH0GDex/gkmPIkyFrSX48OTFfKJCiVMSBhYxj90kQ//Hn62UtWSCQsfblYo
2/Fhqu7TNqtzTDh549fd2458+OtEY5WfIROW+PrmJd348Jom0cjMI0w4o1I4
cuw+Hx67m/M1WZEJPAG3S1MT+XA4h8F+jl8McFb66+HJJNdzxE+7XmeA6s3p
MdHr/PiyGXPnt0vjsO1OTISuBz8OP3pLWfLiOGzw0z7k68WP+eb7QozJeVXs
SXTUjB8/ntm2/FqR9jhQqRra3yP58awklleTH4eEkcdvYnL5seW0k2lR1xiI
ndltvmmRH6fXn/ujemQMJlTcWw74CmDqYqmsJfsoqM9vMtPwFsSRmjzHas1+
wqUnonYaR4Xw1i9bHfJlB8Bn++aJpgoh/N0lt6zkaQ+8N3twu09TGPtlG+aW
P2oHT82QOyG1wvhsT3u5TEg9SChtbtyoK4KNr59PlIouAqNax6eWLSLY947v
3mjbK9B7a3TRhXidXYndovwVcNhoY3OX+LXTwNaiCmfwumu2+zXx3WCL3qPF
TpC492TTELHPoOXWc5mO8PfNHkH7VhE8I87p/N9zO3h5e7mfc5sIthyRrS20
NQfFLV4sL+JSjvYJeqUZZH7/ezqUWC/8tGZ4sSlU7fotl0bsNmUwEpd5HqbG
hosnifdc2bGi9PkZOGJcu+jWTuZ7kqjEZacP9RzHbO4T9+5raFtTcgJM0r/W
RhD7jevob83SBWf+wuhsYqX53H0norUhsiRdbY44fOURtlA7DOuuboujfxfB
ywOLunC2OnxY+56+ivjEe9FsixeqUHzzTbsa8Trl9bbx9ttBV2Ed1iE+KNhy
yz92I7Q2x7w9Rzz7rEy+6pIMmPusFnQkLp84HCt5RQjGt0W6exJPDdj//3tX
wf8A0h8Utw==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {193.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc4lu8XAHBK3iEpoZBNCiWRULlvo1JWiuyRrLIaVlIykojiqyHSUFLJ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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {580.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk0Fc4XAHC79+xZW4hEhVKEEO60KCVRSVLZKkWEIi1KlLInSpS0yVch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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {967.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->{628., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.405706589232052*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["With Flow2", "Subsubsection",
 CellChangeTimes->{{3.405706360288899*^9, 3.405706365291543*^9}, {
  3.405706436700979*^9, 3.40570644212033*^9}}],

Cell["No solution when \[Mu] == 0", "Text",
 CellChangeTimes->{{3.405682270906063*^9, 3.4056823076350822`*^9}, {
  3.4056823538003397`*^9, 3.405682354189416*^9}, {3.40568242018408*^9, 
  3.4056824220428467`*^9}}],

Cell[BoxData[{
 RowBox[{"Numerical", " ", "solutions", " ", "for", " ", "several", " ", 
  "values", " ", "of", " ", "\[Mu]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"When", " ", "\[Mu]"}], "\[Rule]", "0"}], ",", 
  RowBox[{
  "no", " ", "singularity", " ", "occurs"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"When", " ", "\[Mu]"}], "\[Rule]", "\[Infinity]"}], ",", " ", 
  RowBox[{
  "the", " ", "second", " ", "derivative", " ", "of", " ", "f1", " ", "tends",
    " ", "to", " ", "be", " ", "singular", " ", "in", " ", "0"}], ",", 
  "\[Pi]"}]}], "Text",
 CellChangeTimes->{{3.40568232181746*^9, 3.405682323174533*^9}, {
  3.40568256853981*^9, 3.405682595845359*^9}, {3.4056855367856607`*^9, 
  3.405685583688298*^9}, {3.40568563791998*^9, 3.405685651364607*^9}, {
  3.405686856415606*^9, 3.4056868962700033`*^9}, {3.405707000732164*^9, 
  3.405707007707452*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"g1A", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "1."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1B", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "100."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1C", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.1"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1D", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.01"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1E", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "10."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1F", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.001"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405681773347843*^9, 3.405681773941864*^9}, {
   3.40568181377392*^9, 3.405681839055987*^9}, {3.405681869514463*^9, 
   3.405681873703433*^9}, {3.405681909005368*^9, 3.4056819326317368`*^9}, {
   3.40568196556674*^9, 3.405682016653285*^9}, 3.4056820887613773`*^9, {
   3.405682479836936*^9, 3.405682517784671*^9}, {3.405682554131682*^9, 
   3.405682555422155*^9}, {3.405682609625046*^9, 3.4056826300251503`*^9}, {
   3.405682892687722*^9, 3.405682920347066*^9}, {3.405684928580121*^9, 
   3.4056849689274282`*^9}, 3.405685191977766*^9, {3.405685493979383*^9, 
   3.405685496169139*^9}, {3.4056869948874702`*^9, 3.405686997075314*^9}, {
   3.40570645367916*^9, 3.405706471466228*^9}, {3.40570690058339*^9, 
   3.405706940246229*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706957443754*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706957697585*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706957982632*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706958277486*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706958576184*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706959047872*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pC", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1C"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pA", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1A"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pB", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1B"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"pD", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1D"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pE", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1E"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pF", "=", 
    RowBox[{"Plot", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1F"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], ",", 
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], ";"}], 
  "\n", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pF", ",", "pD", ",", "pC"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"pA", ",", "pE", ",", "pB"}], "}"}]}], "}"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.405682679304923*^9, 3.405682756118494*^9}, 
   3.405682812014813*^9, {3.4056828831425953`*^9, 3.405682890096424*^9}, {
   3.405684977337996*^9, 3.4056851606579313`*^9}, {3.405685201488823*^9, 
   3.405685201925613*^9}, {3.405685319254837*^9, 3.405685323971859*^9}, 
   3.405685397510726*^9, {3.405685435043001*^9, 3.405685474542745*^9}, {
   3.405687010468215*^9, 3.405687016124189*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8VW8cB3Cba14yCkWR7Z5bIqOcb4UKJSVpkoqSUlZI1q/shEpISmQL
RankHDNki6xkZm9C1u/xl9f7dZxn3vM8n+9WS7vjV5gYGBguMjMwrP91v9Ky
Y2nrIrEv6GDJDGO99oW9ucHCootE3383RZtUMnEQCh/YIbBIHEx4IxCmQuDM
pQYvrjItEo2elbx2KrV4oDTB0dyzQNR7T3BfUPmNR/W++Z0Vv0BMK8oGn1SZ
wD9cdHhotX2B2Ox+3dRYZQ2fOM87VC83TwgvP5M/psIHlXez6xVY54iCKIpH
AkiCkMsZC+WVWaLXsDVvm4UkWDgyT2Bzs8RuTgbBl56SMGd7klu1f5aQSC1I
CSuQBMkLi3p46SxhLjkhembPVrgD+/JPPJgljHhK3h3dvQ2kWesT3VlnCQ+W
jQI/5KTBjtFN1XNlhjC+WNsSe1AaPq9sK/GemyEGH1+8ft5KGoz+Onb79s8Q
N7p9gt7HS4PbwEbxsNIZIvB+1KWszduhrsIi7M2DGWI79+GSfbwycC9k8m4N
6wyxJS/GVaZdFnz5VRUWV6aJo+MWebv/ykLoE9cWqb/TRKsAo6sEvxwkRDOp
uv6ZJr52BU/e0JODykTBcalv08QpvhjjgbdyIEyoW7j6TxM2h9V+nXGWB8n9
93gTvKaJqAddE8Yh8iBfWphf4zJNBBx25uRLlIc93/U3SV+bJpjODjK1/JCH
Sz/PNdQcniYGNZU8wjAFyJrw0pHmmiZ+X5m3lW1VgM/2pdNHmaeJrAhWXG1M
AYrnKHGuS1OE9BGFe8yMitC8FL5SMzJFlG7R3tsqqwgr7G8+uFZNEQcM2l/b
2ysCW9DQ5YSSKWJBRZzZ+b4iUHlpG2rzp4jNSQdfqkcogrTgRzvpjCnCWtMo
fjlPEfQlK+RqH04R+V7ZHwKXFMEknufn4oMpYlckyRDOpQTnZY4/kPaYIrwk
KxrPiinBLaX2btebU4T7SoWWhqYSRKiPRUsbTRFlSh35ik5K0HuMn8eNOkWs
8b5SuN+lBD7+YiX/2KeIl021l7jHlWAbuf3u3bVJImyobslsSQksMM0h9/FJ
4k+OruABIWXo4LlU6lk1SczF7U900lOGu7o33BlKJgldjSF3rePKIHrvjor3
l0niceojverzynB6NCjOJ3WS+B360cbMURmaK3PuPfBH/x+zdF7mpTI4MRG7
2LwmiVH5LUevpCiDoGbFiO+dSWJ1as3szntlOJHy67S/1SQxHbN3+8ZvylDn
x6YWpDNJzCcV37s0qgyVOmbjoQyThBxDbGQ1RoOGhRJ9qckJYuVt0ZeY3TTg
v9qaJ/17gjBXjVjUx2kQosf0VPbrBNH9U9Lw4FEa+DGbHFF2nSCWj6r61dnQ
oMz+6hfa1Qkihuvcu5TbNGDpcZenn5ogcKk+wsqFBl7kG1YVVdT+wsfYkAc0
cLs3/1V9apy4wWM/Fh9Lg7xRLiXNrnGiQDPkdWoCDebPSkZr1Y4T2Uuj2lGp
NHDUPOysnTFOXGqtY6V/oMGN+WiazrVxQvz95n6jKhpY3NZ+adQ9Ruw8lWP9
fpYGuqT5JYf6MSJ+j5u16CINFPi8ZZ8VjhFeokqNt1doMJtenNkZN0bs3a3O
PMOKQcDgIfKG5Rhxd3OSpp4wBu/MT3QH9Y4S92pu8V3ehcGzt45vMhtHiftR
sTCxGwP3lafXGotHCVtjloc3tTA4+LxlSjRhlFCJrFLX349BR/N5ptTLo8Rl
Ez7pu0YYsB69KlXeP0LwKghxDVtjMBwTMDDSNEKUSCjrVNlgUDeSmsZXNkK4
pX7Vf3MDg+iAMZVTiSPENfKu4R4HDGil9jp/rEaI1ryGeUYPDMz23LvCMjhM
yEmrtXGEY7A3KFZermWYkF789sL6CQbb2ogxg/Jh4trF7RgRgcHoHSbnx8nD
RPnpM9tOP8fA+72f77ZrwwS30AZxrQQMUhXCk2B4iKhZyxWqzsHgc4/2PWrr
EBE2vFtn/AMG36NHjnd9GyLC4z2LOT6h9jh1Vz3fDBEc346JKnzFQHlk3oSw
GCLEs4d+SJZikJV2nkn75yDxmoW+c6YRA/ISZwtP2SDx+9CF2JwmDOrFPmb8
yhkkOGsWKm79xGA6iHr6XvggcXiLWFprGwYqtsWZ+UcGiX+nLR/bdWPwQUn+
vFbJAKGhcvjplzEMyvqadnK9HyCiqhnO7pjA4GeMD0d73AAhVWs0/XoSgwXu
jvdungOE0YNPja4zGGiMhXB+1hwgfFKwifkFDPIzZj+qZ/8hsptuR7xipEMx
jRRQi+0nynRln2Zw0uHYbLys6cN+gp7m7oRx0aHzk98eZ/d+4kPdLtYs5H86
RlYfzvQTWZHiBzK46bDzbOcnNZF+Qj5/OjWSlw6v/ZYtdof2EdXZDr5qAnSg
H+lyOuXZR7Rc7Ka/QS4QKAm8c7OPeC7yr0xgAx3aXgTlfDTsIwQsMoqGkQVy
RDnUKX2EWTejYYgQHXy61DPVfXqJnQEbdRM30oGaKF5idruXSA9dFGDdRIfY
6wytLha9RDMhv2SJ/PnvN6ZP2r2EyaOT0uKidJjmPmWqsdRDeFeMbrkvRoeL
Gk4rGo49RHsBrUVpCx0gPNtAy6qbKHlyzHpyGx2cdr/+cM+0m7gu4qOwU4oO
qR3hW0m9bsINDlg4IG+QdZzXke0mjrYsyM0i//miFn90sIswzv9+ckKaDsH9
X/5dtOki/GX+qFfL0KEwMP1KwpkuYsj8D8kmS4e/2Iu6P/pdhKXKiVoc2dzN
I/G6YhfRYsV3Pwv50hafhOGW34TJecYbwXJ0eHs7+AT/r04iXumgJKZAh435
N+QjvnYSn20/hVxE9mYzWhON7SS8N/99/BjZ5Dl/mrR5J3FP6q3VX+R/JRFM
6t2/iMHGVr2PinTQ2xiXfaG/gxAQEU2TUabDr4JcvvSxNmLyy57AQowOMe0Z
HAHf24hm85b0EeRzC28YrVLaCL2ayltCdDp07IiYkbjSRkjMSHZZrzvB+efj
jlZCzm3FgWMHcuDul3e/txAD35f5NXai9pKwSLOUFsJxm0HieeRzJbJhqn4t
hOynrAFv5I4Vkf8m9rcQseb3HSuQ228tWF36/JOocH1WYaKCfh+mn2gGKc2E
9I7NI+d20SHaIVtWzq+ZCPdweuGOfCY0RZL1SjPBP/uULQa5rSJKgJBsJrYe
tVlrRW7d4/Z3Z2QTkeaxEn1clQ4t27QKRP1+ENnXisfV1Ojwczz/yPDlBsLH
RVmjdjcd+iprprl0GwhjHVDoR55O7HqmvL2BENFSG/yHzG3O0nOrv54wqPn3
fbs6HfbXGjjPX6knXgbTtVyR32a2xbJY1xFJlM3/hDXokB80ekDmYB3Bz2/Z
IY9cYb06eFC2jtgyuvZoD3I5rmMlXFtLHD+rYXsRWUWyMUSqroa4Vn94LRmZ
s3vy996GKsJfUqgU06TD9ihBBe/wKqLi4tlWHBmM1R1LjlcR09szi4yQnQs9
OQwavxPLu0DIDrk7jneH2Y9Kot/ciEhDzrNU8rFvLie6XE4bb9aiQ6Posarc
iHLCL12oWgF5vMFBeNG0nBA42yupjix14Euq589vREWJu/Fx5BAp/cbgljIi
xqKx7T7ylT5r6aS2EuKa66GMHmTnBuvrijElhIrx3P0xZH/S+l3m+RLikqaH
+gJyaow15HUVE6t5qSo8e1B/JtbnKv4UEaczxTxUkdf2W8cfSS4iHp0xVceR
qTush+uvFRFa7G61h5BVeKxd2kYLibUWpqdnkV1KrZ6MTJPEHKh5eSIHvLdq
t8shiYg/fdL+yNFxVttmnUii8uSRpFBkt6Uqi8UpgigSTdCNQ2a2rYoUW/1K
fGduGiaRhY9857AQ/kzQXV8PLyKry3+PuBr1idj6+4gTw146nGX9Ln1b/BOx
pir0mw351ddK8NmWR5yCY8c2IMvTKl0SaB8I/9UfaQrIhpyVbBnZucQeu9Qd
dOSbfyqe5O7KJXIw2jNV5HexFVllmjnEfYbbjIC8h69icFDvHeHxQM3kBPKF
kXLnqYpsYu/G+pZTyN7fyln+GWYTnV/c9p5DLvMsl+Q6kUUci1BMuoxc/zH0
vGx6JnF1RT/9KrLwrVBX9XdviYmmlDBb5Jddj7LPFKQTP7VMVxyQ+yIfVV8v
SSM8F7/8dwdZzvjRkHtlKiEdEDbstj6+wpCtL5uTiUmP/NPeyPOuIXuzOpKI
C0IKlvfXx7sz5HRhTyJxqnO3gd/6eF4/DOsdTyCcrl4mgpELxg6U5f6OJwJE
Hng9Qv6o/u+fX91rQtjkj3g4ctZ/WdiZwjii6GvQkyfIyTVWl5XevSK4Z1wG
IpBBRXPniu5Lwj48WygKeUdF4vM42RfEbU0NiefIAnOeN4eHIwnVLTolscjM
QaM/Q6oiiLmIGvNXyLOSp/epvH1C6IV/aI5D7v9QmvrzUTiR9HZNLh652XCn
oPvtUOJpYIZpAnJI6d4lSAwmHpYUm79BtpsSrgm45k9Ql3R1EpGPbZ581aB0
n4iq2s2ShHw5PHxArcuTSPoZ83LdssM6D8ut7hB5n12Ek5Gb/hu/ktN2g9AX
rL267o9WiZaZtaeJNp/4iHW7OEryCCoBPpiw+HLdz270fuxeuYxPbmy6v24O
c1zNfMEev3VPQ3fduuwPQ6tv38UHbil0r/dXeOrG3Is5b7wxLM1s3V2KT7ad
3OmLN9YQaevjXV37bMRtF4gbb7vUtj4f8R/d7sVpIbhR9MO+9fluNmE5udcx
DP+qubtyfT2UCp6NRIY/xv3YzYJer++vnKLPbNZT/AXLoOz6+hmEF2w8VvsM
H1P9/fIl8pll48y0sSjc6qXqzAtkG6t+XXbuGHxOp3drDLJrnUuHpUIsHqDQ
pRiNrLPZV8Nc+hXObyLNH7n+fTTUsjxUicPvlibVP0U28dtU93n/azzXx/LG
4/Xvbc+l54PG8fjbR4Z9oevtJ/7doXPrDf40OeRSELL9WVi57ZmIX8xvvu6/
3h81sPxlSBKegNGMHiD7u202X0pPwY/qjCR6ICce1Ql+N5SB408KouyQM5hD
TnUtvMXjKuNcr6/Pp+M6PztLFl4Yd2SXNbJlWG7Hrg3Z+KR6psaF9f6WDjmE
7niPJx629tFH/ts0Zib76T1+jjivpovslhWuXQA5uBjdvQRf/16vdFBGjXLx
4RddN3chh9bavTp48yPuMCT4Twy5Mz2j6fvoR/z+0K0xofX1DxzhPHY9D0c7
RPAhf9OxdjK7+glnijVeZVrfz08X9K9ZfsHd5+MHBtD5ZPgsxnOs6wvu4Ha4
umv9vHNsy7ltno9r84yHtiKrYqYSbue+4o996rIrkW0TjswGmhJ46UmGU2nI
n72D5PmaCDxpwyf5eOT7mZczK+RJ3FUwujUauSH4dd+RZBLfNm9dF4B84+AW
I9M3hTjDsLqIFXJCvpC09cti/Hl9x5QIskFajnZKZzFOPjENXD/fp6NOnB7Z
XIKnLumsMiHDnbAQu5gSnDdZx2X9fmjfwbN4J6oUN+gbeUciCySx1Pg//ob7
GhiIWSB/eho/WNnwDe/c8vzsCWSL+/uZeQTK8esS4456yBkXvdTDQsvxpey+
HUrIh8SXX0c9rMAXL7LWzaH7zjNs5k6q33fcW+ilozeyS/tlwz1V3/HFwuP9
t5DttzdL1lCr8D3HqqUtkK0+5VVMRVXh5z0V+bSRj3bfE9NIr8b9pcWC5tF9
vGUHB/GtrhZPvomPWiAHf82vSOesw0+ylCkfQfa3nHs/p1SHi/Wbamog+6Rb
+fvdrsPTEnrfUZGd4fCOtH91+EVGLpGvKC9cuMr73zR3A653ctCUC/ksz8Eb
WlgDLp72WXQW5Q2zd56n7hs34As73OI7kI8vTyoKRzTgrTV7mTKQ9UIbf2hI
NOLF8vuH9ZFpeZEy3jt+4Bf9I/juonyzwi5VyWfajHsaaBMpKA+tho2p5t1p
xuPfsQ4EIjOI58VZRDXjd5uSvl1HZqEfcc3uaMZtjc9lKyFzm92RO3HpJ26k
niiShvKYaPJ334hbLThmX5AXhfKa+M6Iae3wFrxn+jbNGXlLvsWFgfcteLuW
l8lx5K11c6rq8y1438D5TAqy3IJEf+u9Vvy0NHuQI8qLuw85Htgc1IZvMjxE
10R5Ur1BO7M0vQ03+ehuwo+seY4idrOmDf+Pg7Z5EOVR7Vux0wX87fjEeYao
J8h6keVxFpHtuMOvnduHaOj8GBRnSHjTgT+sONHnifLtbf/SfAWyE0/It79+
HuVhmRPO7iG/O/ER7a0bFZHbNsvumV7txK0VTp9dkEd57r3/l097f+MFzbyv
w5AFOw0+H/ryG78QKbCRQHm8fdPQWZWzXfjN5rxcFpTX1TwLtfptunB+pj0m
31HeD+2LEnvm1oW78Pq6hCHrZOq3/4vqwjfvmjkijpyuk36mqKULT4ip41ba
Tod7dnanjU278U6MpWO93mj5cVCD2aobl338z3AK1SM7NSU35Tp140pGnPRM
5D8s9S0bn3bjoqbhevLIR6N3mnU1duM7gTtYeCsdJEvnTO2Me/CRwD7aD1Tf
FIm6mzw07MWf/wjNqkP10ZRwxbbH53txeQN3RgdkyQ3CU5E3e/GNlmevCyJ7
cGU9TAjtxfnvTnuaoHpLY7m37MuPXvzxk3tWFcLovv5loDF8rg/fcHNL8n+o
XvvdGsk+eaMP14rr0xRG5m3ub5rz6MNrc4M/JKF6z7bG054xrg/nVGM5+40f
7T/xPm1jfx9+0Fn83wIfyiOvxLYcvNGPexbsergN1ZM1MVdHDT368X2VX7le
o3pzOTL38/FH/fiYB223JPKZMKNTF7L7cX72Pz4bUb0q7PNfqNNcPz4S4ndr
gR3d35dGmBLu/cH3Xo/Pvs1MB3eZLwMMIQO4ecT714emMWA5sGTe92IAT2os
fTiP6uVgc62WbxkDOPM499xrVE/HRH4pD6kewK1ie9kmRjH4ypmfIs4ziFOV
zTrPDGCwOp5/XT0YeU7Uz7kdA1+ulV6xmEF8ran37EArBrxye8+tpQ3iZofv
tp1owWDLxa+GZd8H8eBX8FQC1f9441dlE64hfHXrsf1eNRh4fSyYsAscwg+r
BpqbkRhw/Fi1PhE9hKvXf8LcCzAIndTuUksdwre/634anY/BK3mibqViCA9Q
rW0oy8Og8DmRHUQZxi/0bWhuy8KAyYt0SPIfxie/Hn7b+RKDwBiG0cDIYXxH
bdffuBcYCHyCyzeTh/GK8J7rF55jIDVNmqiWIxeF2xdFYKBzuVC1mH0Ejy16
IbzrIQYPDhXNd/qO4BsK0w68ccGgZ8n5gnDkCC6/Zl3+3gkD7UzF0iMpI/jO
xisb8uwxWBB6Gp7/fQTfVH3RKM4WA9tea+Vo6iheSpt4NWWOgYkHz6WT0aP4
vMy2p+d1MMjeUVQRnDaKn7rzcj4b0Pr1O9NL8kfx4+xPpxb2YFBu0LWy8/co
/u1PZ9Z5VQz2bHofSZUew0NEBn+5bUfjzzGr+Z4xhqeozu79xoTW05pHlZkY
w5U2KRLSqzToEC16rlk3hhfIaO27tUiDCG/FaynTYzjLBZeJ2gkacBqtMvvt
Hset5WJ8kttpYM303qbg0Dh+BBO+Z9tMg5Jc6/q50+O4Q3nsU7F6GniI18de
dh/HFaWd7TTKaDA9FK+xv3AcpyY4j1pn0sDohdkr14ZxPNc8dsUlhQbpx3jY
s3vH8a+so+W342lg9dH5hwTbBC56bjZo4zMatN0/bLeiP4Ez/f7brniPBoUS
Ewl5PybwLTzKbyYP0OBVqW3Vy/4JXGqXYp3FHhp4XR+e8f07gRdEJ1Vl7aLB
y3b7OAXuSZyqMVI0Jk2DC7I3JxeUJ3GpmeHHFcw0OPpP6b6t2iSeEaGyXWZJ
GfZWj4h0aU/i5X6e4uenlUHc4Rr+zWgSH9+63+xUlzK0F1wOeXp7El9JHhy0
/qwMlWFS2yhuk/gGIfcwnyxl+Hy5J9fdZxLv9nK3uZ2oDNGcFr8uPZ7EFQaJ
c+VhymBmelZpZ+4k3v6L0rXfShmax4wraxYm8R81EX/iWJWhjKRe2M84hcf9
fffp6YISfHhcO5VLmcKlDugaGY0owVONI5teiE7hNpyVq3x1SmDy4NDV63um
cMEwB9+MCCXQMWNf7tSZwiu3JDvl+imBimLZo+NHpvBmJ5+fd12UQKD+wEeN
C1P4tOq4L5xWgnpxnI3Dawo/l71YFy6iBOTEStRd/ylc88VZlztsSpBVlK88
ETqF+03ePCk4pwihVzVPNsdN4awNA/sd6xXhaI5qQkLxFF7lXHX5q68iVBko
7d/HPo1nzD06JtWrAINv+1Kl+KbxsedWofU1CsAi8GIDm8g07mR3M37vZwXY
28LTXykzjUcZJc0YhSrA28sTfiZ603hMYf3kFQ0FCL33rtr6wTQuKlY+XuIp
Dycz1U+HMM/glyvuw1SPLNgLTBXe4prBpc+5Pn76TRZCnFIUTmyYwX1Tq3/y
p8tCmZbosojUDP6SI7I5wlEW1MuXYuP2z+CahsoZ08yyINpd0JfjPYM7Owzt
GxSXgU4B3VvtazO47v6Hxn7a0hCQM2k7s+0v/vxp6Uh3pgicu8iQTG5dwJOG
j2FpiWu4+wXa8gPhf/hFOclTG1VXCVW1iS0Vqsu4977B3I0mG0mhTYJehfRV
3OH0Yn/LjBTJudBgdkpjFc+O5c9iFpImGX6G7Rjbt4rn9Q05bVWTJkef8PVu
PLGK84n1iqq4SJMlVC69W06ruDav7WrkkjTpyMHELfF5FU9K3d8et7qdtBkg
+3KKVvF2Hz/XJ1tkSIsyz6/631fxUib3LBttGdLw/spN545V3GnclOnrPRlS
imGxvnp1FT8663jhxz8ZsmF+4pn7gTXcYIfw8NMxWbK8+e0tAcM1PGhrio0E
lxxZkHvjcLLJGq5QRWd2lpMjUx1G/jVeWcN1jo3437eUI30m/pxX9Efvnxf4
ttIoR+4Y+CXVVrWGj2bYPFNMkydlymKW7ZrW8Guc7K6dJfKk+JuzTaydazjM
jTw43ClPclxq9d0xsYa/b9/3RIeqQN6yG3Ys4WCAQ6HllR9vKZCHRvp/iiky
gKnHfktRKUXy8rM7OccxBnhjxDgev1uR9DxACQtQYQA5zX3x3QaK5IfnSvrz
WgxwcHMQn5uDIilt6JDfYMgA3SFcX2QIRRIWWKIoxgywIfLoY7N6RfJsQoQT
nGSAtVNbNff1KpLhy59ob88zQEzqcdBgUyIZMxjiAm4ygHqdokrzISVS/HT4
PdKeAdTun9atM1Mi1Vmlz8w7M0ALx55o36tK5K3zBzdc8WSA1oEtFop+SmQn
T8gDCGWAbQwH1G8UKpGfb4rZzGczgOHvr0wxCspks2iGHu0DA1StHR4tVlMm
p8q0pa58ZgBdfMnjw35lUk7CsqOhiAGeX7pvsHZamYyoTT76tpEBLpx06FT3
VSbf3dVU7P/JAJ7lcbdqQ5XJatkqdvEOBvANjv6x+7kyyeI1QQb0McCJ5As3
vDOVSXu6msqVObQ+FeOKfM3KZEjHN76YRQaQpc+5GfxWJlP8T482rDBAc/jQ
RotBZbKry/0NsDHCeKezsdA/ZfJoWLGIuAgjmDzZM1gsRiMVp48tN6gzQuBT
oYOVZjTynJX5gcI9jDB25uluK3MaGdJ2IzATGCGsZKBh8AqNnC4K3Bh8iBEG
WBdr4+1p5OfHJbt0zRhBfLs5y0ogjTykqn7j4x1G+PZOhvPZRxrplqKX8+Yu
IzzJTjxem08j0zefXHrsiZ6r1T2cLaSRVDb7gFt+jNB7pE+dvYpG/mxOeyP/
jBHMtzApmv6mkVYuEp3PPzCCvse8QwcTRkaOKm8P/MwIXd3/XeBgx8hKiz22
LgWMUJ3A8mM7F0bSDp/+Z1LGCMUjvcZqGzBybtNjYd5mRpAcmpDL2YaR97+w
GXnNMcIvF3PLEzhGfsCEIm4uMkL4ofT/3u3HyMF4qV/nVtB8mhsC2fQw0jAY
rmuwMkGNghc1xBAjN5x385sWZILLC8WhEqcx8vXqGHF5FxPsln7y7uYtjAyI
jGJKVmcCrsJPbTYOGHlrp67uyB4mYFxNHzznjJHaVjGVt3WZwG3bMyMpd4xs
q9Zv8jBlApM6Y4+9fqj9F0nDkS5McGGJq6/8OUb+Uzuh3OHOBB8ltbRVYzGy
p27VTsKbCZ5EM5RFvcLILBbTuTcB6Pl/Sa0Gb9B4bVkY3kczgYHqx1un3qL5
al0Uqs5H7eVn7dxOYOT1Jm4zaiETpK9xMm4rxMjjdnnRJ0qZoEDe/ePGYoyU
jOeTbKtmArmfpPpsGUbmcxYoDHSi5/xN3VdqMHK2VRQYGZnhhWnHHr0OjGx3
KPPRYWWG5lcjXiO/MLKIx77Uj8IMG3wOTgX9xsjQfRX6vALM0LprV2xBD0Yq
pdw5KSbFDGY/coTGBjHyissPG1VdZriwJ22n+yxGWrYti9APM8PkNa3kkjmM
tNizvVThCDPsspEoosxj5BkGZwnJk8wwz6fIHbiIkcf8RX5wXmEGeyV90cur
GKkZeWZv131mOK63z72YmU6q//MZbvNnhuu/9dWMWOik6rm0Z03BzMDfM/Co
FZkuuTxV+YQZ2oYsVYZZ6eT25BeJuQnMsGUGcpbY6SQ1r4svqIQZjslZz/dw
0UleUcrXB+XM8NUr7eEZbjrJ5b7DxquKGW5f92CsR2YDnxKnH8ywNks8+sxD
J5e+Sbla9DHDfgr1hRcfnfzz06pHlYUFvr65LNMuQCfz50dzug6wwI+GivRf
G+nkmYiDx78dZIF6eXrPrk10cmHX64kMAxZgjZcyCULeZX9K4e4JFhhu/zqn
Kkon00cLXwpdYoHXvgJXfcToZEx3RKC+Dwvwr/78tLiZTmp6Tcnu8GUBr8Oh
r3S30MmWLYalIoEsoCV+rzsUWfAcI0N/GAtYh31x2S5BJ4Obrzt5xrHAAeY1
xYOSdPLud7DIIVng1J5N/25so5MbbZ6vRJewAOdszL4s5A8cf6O9y1nAc+nV
EqrnyGndtKajdSxQRO+rcpCikzakkMHQbxYIPMtOuS2N5pc7rLpljQXUdfcv
HpdB43v5hMt/LytIR99syJenkw8vBScU72MF1jBZ3lnkLtn7e9d0WeGRPmeN
ggKd9M1ysHM+ygoMrwR/RyA3Fh5vvGzOCgEbf1+6pkgnbfuoz/d5s4K3/1jv
ghKdJJI5dt17wAov1x72yinTSYEbDNV5AazQHHnRxQz509zEKhbOCn/Kw658
QGZjr7XcEs8KBJ+F1Q0anXwp/1BhqYQVzkXbFpVjaH5j94vVKljhdRTmOY2s
9879nH01K5SpbPwtRqeTo5q2IUNNrLB9KDroBrK6ocH0zz+s4Gxrlca9g042
3KR8zuFgA9ai4wmaO+kkS86DwzcN2cCLd1X1zC46eRP+GV48xgYZIUFP7iD/
rLp5zMSEDY5k2+U8QU7tP3VK8xwbPDnMr1mDfExE4QqbLRu8Txy01lZF++9W
4xUbhNr7LfZmg9r6fA7cD3vEBuJMHoeVke0ef/S7/5gNKidDcvWQ96e/CrF5
zgY7SIM/LsiDv+xj1NLY4GKKbE4bsso+kbyaSjbovxF3+Mlu1H510JfCGjao
clkKS0VmO8NA5DSwAVXFJIlEbrEfKo1uY4NiLn3NUWSPhC+NVsNs0PNsN+c+
dTpZyW4xsUphh1ozlkfdyJY1yTLYYXZ48ebizJoGnfT2+rz9zhF2SDwrV8Sv
SSdf7aySJozZ4eOfyAtSyL8iJrYZnWEHwwP2jHrIZuZqEnbX2aEqoHvOH/nI
ZLFI5kN20B58WMeqhX4Pr5uE58PYIdTg5DNB5ECTASE8gh3OxmVjUsjleZyC
tbHswHiLqxlH3u9tTJ3IRO9/MF91RlYX+M2BNbADb+9Ifweyackk+51mdrB9
6dsxiOzkzMROtLHD5/6kpFnkd23bWY162YEvSS2faw+dVI63ZbSbZYdvqaG9
u5ENT3owfFxgB5E5y//2I9uwh66tLrODcorwoiFy8vX3KyGsHPBm4bXVReRt
u/4tvhXmgMdtjUf8kff94Vr8K8oB/RvVXoUhW0RuXtCW4IAJwbsV0cgvluFv
jSwHyEwqx6Ujbyz1mx5XR89bvlytQeYxFRqhneUAAWcLR869aL518SY0cw7Q
Ou5UT0V21t9ZoHyJA04E6nCLIHdpG4UpXecA787jYlLIObIBuxXucoBa+ewr
DeShOJE4eU8O2KX6ekwbeYt4Iqf8fxzwIDZoow6yP7X4l2wQBxxTO0E5inxu
cfm/7c85YFTxrpkFcphD0Jj0Sw74pVQTeRm5bGzTKel49H5l58eryPQeNQWp
NA6Yi3MNv4V85Vzp422ZHHB5VfKoI3J084mVre854H3358E7yCzfb9VJfuGA
Rfeezx7IGrprGpIEB0ybeEx7I98kHsZLFHNA3Ywc5QFyy/tU5y3fOQDKyhoD
kXloGl2bazmgaVO538P19Un+dnhzI1oPx1nRUOT0mD5x8XYOoHoMdz5B7hZ2
8BX7zQHHjxTxPUMWDmOcFO3lAJ9L3RJRyAZcoadFBzggru4o33NkrwdbijeN
cEBWAn9nDHLuWrrSpgkOyJ6gB8ciD7tqRWyc4YCEwvebXiFLzFasicxzQKBC
nG8csslNs2siSxxgpcnQ+Bo5YPBPg/AaB+xmbFmNRy6wdNojzEyBtRCM8w3y
TAdzohA7BYJHeebWLXcqnE+IiwIcB+4Qicjn6yVdBfkoEHnD5loScrhBZs+G
DRRgyO2fXve30r2GG0QowG45cDYZeRmvyhUQo4Dj1xsJ697x+YyEgAQFeKl3
qtZttWvIn1+KAs9fM/5Y9/O3d6apshTo/sr1Zd11cmznqIoUSE597L1u1vgn
pXwYBXKzn8muW3OzFManQoEaMeGM9f7tnmVH8u6mQP4OHoF1J/ADE68WBQ7s
uWu6Pv7WoJrrPDgFFO9fcFufHy/b+SbuAxTQPJ57LwH5gNeINvdBCuyeuGex
vj4u/1yTuQwoMBD/Ydv6+mU4cghwGVFgw6fzJevr3TMecZfzBAU879zWfbm+
f73vj1LOUkB1Q0v/+v5JRjsmz16ggN1sL2808t9jqkxdlhQQN43eGIn8uuBD
7gcbCpid3lTzeL0/pzt8r29SgGe21jUM+YiS+rWH9hRYuiHG9gh5IeqT+GU3
CrBe30cGINccc3M28qBAjxTLuC9yPLtWnaYPBdxklZb/Qz7qlP8ffyAFzri5
f7q3vh7HiOGCKApY4fUf7JDd2L10Ul9Q4KX27T/XkY0KIPZpHAWemov8tUb+
p1hkbJtCAQ17vVxzZGP20rxNnyjQW9mTfQRZpuCBAOtXCgSUW3UdWt9vRz3b
SZIC4wVh4weQk3u+SXwrR/vPmJGy/v2vfq30dWyhwHJ1WtT6+fDDMajLvIMC
Ej6iJZuRUxQNNQ26KMDEVl+9fp6YRFWPbR2kwMl9fzy4kFMd60xq5ymQXkCc
nELnk5di2NvPS6h/PNhlGPlkjzFH4hoa3+KSay8yw7HGL+7snMAOFhubkE8p
Nm9TEOGESkE38gOyUk+Eu5AYJxhfjm16i8wUdaqZQYIT9u+OKU9EfsvWGvBT
hhNOBxMHI5BZeton76txgujfniQH5KzI7oLfJzmh6FdwqyyylhMuKHmGE+Kz
f/eKI5cZv7hmcYETmOmyJfzI7ZynBbutOOGw0wa2JXT+s92ru9ZzhxNUP4cH
fUc+d5EQ7I/ihAINBvvLyAN7N9tsj+UE9d6z30yR7UXvEldecwKHde7EIWS/
RjWbP6mcoNMbkqe0fp/oviUGvnDChTmh7dPofuNQeGEz/IsTvD/paTkiP2Zb
IhR6OOHIZFHSJeQtvWZC1/9wQuOzyd7jyCoxguTIOCeMGT+spCNf4A0WGltD
89lO1x9G923OtBs5sZULskX+1pxAvvjFTHjuChfsMzcsXEX3N5OFSvPoNS6o
//5o6xByAgtvRN8NLvi1zcqoEfnPkWKhH05csEirEkhCtulSFnr/gAsy2Zsw
Q2R7VmbB22+4oGuH+61glCc2pP5qvJrCBS3v570dkHOO5j22yOCC4BSbs2eQ
/z67seFYLhdML325LIt8V6FFACvlAr5HmWUFKN/cN8rgH+vjggjGOccelH+2
z/rV9w1ywU1Jz9ZS5LJIy7COUS4Q6hFkSEHm6BHhr5rlgsjTg2E3kYMdfahp
LNyAX6F//atCJ59GneK7Js0NSvxTBf9QHkvsZeTpv8QNTLcnUqpRflvOcC3f
cZUbdAJ6Vd8gH3eZ+s/Dlhvi2SOuuCOvcXf/E3HihmMaLhnyyGZq5KC+LzfE
MdpWeqJ8yBngUZKVzA1tPQHWm1CetDjx13MlnRsy1dMqhlHe/LD5ppZ+NjcQ
Z6QKvyBfenf+Xe8nbrAI2mN7Djm/fc8r4e/ccPOkQGQkyrN2tKW77mPcIKUb
fGMJ5d+yBfvdFVPc0B4ynFmKLF48PC30lxv0xpnuPEIuP9V2LXOVG8pbZUK2
Im/z/nSqh48Hgn+8+IKjfP2j8Y7KoZ08ENh9dtxSFuUd19nhDXd4IGNZR1IL
5XfMKzbC8C4PxKwSr2dRvpfxO7T/gScPRF5p9MpAFnwaE/XXjwd0Qrce3ow8
kaVzqDWSB0yfjbfPovohcfDJm9jPPMBcXXnXB9UbLya0jX8W8IB73kIPHfnJ
38FlvmL0fq28XyeqV3xY9pp4f+cBW62ue7uRz0v2M13u4IHvaikDKGCTgmaq
FvKrPPAs4VURB6qHuMx/c1ky8cL0g5nJFFQ/MVkFfIxm4wXLzYSaPvKkwy9e
bj5e2Dovt+InQie/P3rwdVyCF+4KSEkvCKH+vjWJ5uzjBd/vIcbJqB6bVHNu
0n7AC8q3WOt3oHpvhfXFCC2AFw5+NX+dx4n2s6mYUeIhL4jtwgy0kbc78NPW
nvDCEVZPYT0Kqm8y032JBF7oZitXO4jqx2LZ3t1QwgtHm0lBblSP1v2lHKWX
88KBDM8XHkx0srOUflmyihf2/8ktmGBE98Elj1CGH7xgfq/oUzUDOs9ebRoi
e3lh4cmi+uQyRkZsPBa9j5kPbvK9CmSZwcj4AeesHex8sMzSpJs3hZFZH16U
beXig7QLAeFXJzHyu8nINOMGPujepZhbMIaRDGG+BkXb+CDvqNMkjurva5Sv
y/v380G1HnYnCNXzzi29Aip6fMD8y+kdUztG3k/ilJfS54O3vwveObViZKyu
2Unm46j9peaKo80Y2eA9k1F8kQ9OHXxW9r0WI/f8kzfX8eaDmqvf1XsLMXJ1
fOxWwAM+0NVe6hsgMLKwN9unJoAPDmV+s/jzFSP1qjUSzcL5gG3YzKbuE0Ya
vTo8ZhvPB6w1m3aaZmOkpd61u09L+eD1lWBT6kuMlNZSfthWwQf1k0lf3sRg
5AA2FStRwwdfiv12q0RjpO0m16KUZj749bBzSfUpRjqN+lMKBvig/Ed0bXMg
Ruoc/mEww0KF4CNqzy87YuSbAx9+CLFTIZon/onNbYxk0448r06hwr2An/pW
NzGyYuc5u3s8VHhQoKygfRUjj4r3hbMLU4HFMuWczVmMNJuYaRWTpcKGsMUr
AThGfhpqstSWp8Lr04caGrUwUrTv44iFIhUsFeYzqeoY+avl7sobjApu2orf
LOhofkXMW+nqVLCp1og6IYmR159uuKpzmArVtRPP9FZoZMuMSuJ+Ayrkl2y5
P7hAI3WOm/TBESpYRKUTbrM0UpzvqcVeYyosKoiy2o3QyBp/4dNqp9H4B+12
h7TQSM0BtWe7zlLh2tLgwdRGGpmoe6pp53kqCPOx7c2poZGeTJHG2EUqnPx4
6nloCY2ku2/Sl7uGxvNuRswyk0bGtGn4y1ynwtiAjlJfCo2kaJwpk75BBRlt
RzPjBBrZMxe9f+ttKjAatN8diaSRj+3EtURdqcBQ3bpT0JtG/rWUUOIOoIKp
Z1hpiyGNtCzEbTiDqOCYlP+vTZdG1kpYJHM8pILrxaf6hdo0MrnjlTRrGBo/
nz0qF2nkadNtm1cjqTCc/t93gp9GluXsP7scTQVqi2hGI4VG7txwKepfDFof
X0W1b4w0krMuXmj+FRVidrdO6U8pk/mHt/NOJlPBxfLQtfc1yqRcsq7heCoV
yo407H1fqkw+ZbMKHE1H88OvJjzMVyZvFieyDWVR4Sq+8l9tijIpsVdurTuP
CofoxaUOPsqkD11xsrGcChp+7CNRisqkdsZlmfJKKrywMu6XlVQml+Rjz+VX
USE7Xj3QV1CZdJTir0ioo8Jf3qn2d8tKpLXwfJxTCxVmSr43vatUIqUf01uu
tVFh78bii9lflcguPhveCx1U4HEyfO+WpUSeofxy0+tC61voW2rzVIk0XC46
ITJIBXub5Zr0c0okxXU5gGuYCuPbVhrGjiiRZXOq5NoIFW6r6cjOaiuR+ESy
0uAEFTwT9WlHJZXInT0hrJ/mqdATbESV61IkRcrPfDzDzg8+S4I2XCaK5A+d
J2NHKfwg7t8QcWWfIhlaWC11gIsfvGYvvvKgKZKcXyBUkY8fDtZVjI+yK6L7
UebasjA/vHpQpPr5owLZ83haNFaGHxbrC/0PcCmQ6eaBHt26/HBsPPlPywM5
8oBd+E6GQ/ywM5MaHHRNjmzziP6zRZ8fFL9LtrMfkSMpsalHzx3lh6jQALFL
G+RIq47KLT9N+SEw6MvBqheypORpLqLKmh+0Td5XpqTKkE+OB699DOCH0/nH
LPIypEl33RCvkGp+CJofS5YOkiSFaYoNcoYCIGj8sUbGiZ80rbZ9ZtkkAMzb
p+Sl1Eiiy21o1R7ZSTX3TsQwQdjIWVn9h7yX5v/8z1WC8PzPXDUB+SXQen2v
FBDJGscb+5F/C961/3Yhn1h6s5vvWrMAOLiKhB0yziNeeTD52f0UgDC/czX6
almEgpLnuCcyT69ln+q1TCK3delkKHJMFbdS85W3ROWuOelsZHzrxS/C5unE
zPBA0TTyw1SutmfGyYTeqepVpxYB8Ne4KhKt9oqoY9G38kXmFZUvcLSKJc68
K6uOQP4g7HMk1zyGsOMhYz4iC8zuslU7HklEFr/TXEQenYhNUd8dSmy7jb2m
tAoA99vZ29MWwUTGlnSKKLLQTFqowwl/osj1TYsmMlOfeI2TuhdhKLsNDJAV
t2e0jp10IZp/xCadRdZc3CoyqXmLsPAR47NFLn5IT+nDLYgRLNLZHfmZ8WFt
dAIW/A/ry/zK
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {193.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Xc8VX8YB3Dbvfa87rllpKEkWlbJeSpECKVIg2Q0rBQlW8NMpITslURS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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {580.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4FW8bB3DOOXOcY6dIUrRKu0QS5q5oQ9aQFiprlKwVIrKLUAmhUH4S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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {967.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8ld8fAHAV7r1GRhmVkGy+SiEk5zSUjIyMNil7ZWdENKQkK1nZSaWQ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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {193.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3k8lc8Xx2W991qTtbIkJRQtEoqZFi0oS0qRyFYiohApol0U9RWlZE0i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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {580.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k0Vd8XAHAZ3zPPlVIoMqVS5nJOJJVM8UVSJGQWGYoKIU2UBiGpkGSI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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {967.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->{640., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.405706964608183*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 2", "Section"],

Cell[TextData[{
 "Extract order 2 terms from the general expansion, use formal solution to \
order 0 and 1 equations and perform algebraic simplication.\nNeed to be put \
under the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]2", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}, {
  3.405685906475298*^9, 3.405685933174532*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2", " ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"NS2", ",", "\[Epsilon]", ",", "2"}], "]"}], "   ", "//.", " ", 
     
     RowBox[{"{", 
      RowBox[{"Rule0", ",", "Rule1"}], "}"}]}], " ", "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{
  3.405707115570497*^9, {3.424926363485377*^9, 3.424926371786062*^9}}],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection",
 CellChangeTimes->{{3.405689902151525*^9, 3.405689906517454*^9}}],

Cell["\<\
Here we extract the terms of the second member, factor per factor, and we \
test the solvability condition\
\>", "Text",
 CellChangeTimes->{{3.40568617718019*^9, 3.4056862579374123`*^9}, {
  3.40568991337463*^9, 3.4056899311116037`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"]}], ":", " ", 
  "a2a"}]], "Subsubsection",
 CellChangeTimes->{{3.405686378322873*^9, 3.405686385538538*^9}, {
  3.405690025024864*^9, 3.405690026158256*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Coefficient", "[", 
        RowBox[{"a2", " ", ",", 
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], ",", "2"}], "]"}], " ", "]"}]}], 
     " ", ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.441628753475881*^9}],

Cell["\<\
Check that this simplification can be somewhat improved for the term which is \
not in factor of C\
\>", "Text",
 CellChangeTimes->{{3.4056862817471857`*^9, 3.405686293409556*^9}, {
  3.405687379626865*^9, 3.405687409487836*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a2a", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["f1", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.405686477381343*^9, 3.405687312568282*^9, 
  3.405703482887491*^9, 3.405707747595942*^9, 3.4057533625583067`*^9, 
  3.424926488136475*^9, 3.425025850464573*^9, 3.441628762140351*^9}]
}, Open  ]],

Cell["\<\
This term integrates twice in y and satisfies the solvability condition\
\>", "Text",
 CellChangeTimes->{{3.405690121361199*^9, 3.4056901296072617`*^9}, {
  3.405707882353025*^9, 3.405707885483936*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2a1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a2a", ",", "C"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.424926607228583*^9, 3.424926634977579*^9}}],

Cell["\<\
a2a1I = Integrate[a2a1, y];
a2a1I2 = Integrate[a2aI, y]\
\>", "Text",
 CellChangeTimes->{{3.405707182438018*^9, 3.405707185668837*^9}, {
   3.405707762365654*^9, 3.405707771439313*^9}, {3.424926643571176*^9, 
   3.424926660934103*^9}, 3.42492777657156*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2a1I2", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "+", 
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
        "+", 
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}]}],
        ")"}], "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a2a1I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a2a1"}], "]"}]}], "Input",\

 CellChangeTimes->{
  3.405687843186754*^9, 3.40570370366247*^9, 3.405707986290822*^9, 
   3.4057534646847973`*^9, {3.424927330678644*^9, 3.424927416115737*^9}, {
   3.424927459529038*^9, 3.424927463719118*^9}, 3.424927520791685*^9, {
   3.42492765145127*^9, 3.424927676614168*^9}, 3.424927735853069*^9, {
   3.424927804687892*^9, 3.424927824487294*^9}, {3.424928181962433*^9, 
   3.42492819009591*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424927562677067*^9, 3.424927685622425*^9, 
  3.424927740031589*^9, 3.424928193644864*^9, 3.425025861538531*^9, 
  3.441628767810623*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a2b"}]], "Subsubsection",
 CellChangeTimes->{{3.405690035550551*^9, 3.405690037683858*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2b", "=", 
  RowBox[{"-", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"a2", "  ", ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], ",", "1"}], "]"}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], " ", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{3.424927966672739*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Mu]", "2"]}], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "5"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{
       RowBox[{"U", "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"f1", "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "4"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       RowBox[{"f1", "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       RowBox[{"f1", "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"5", "/", "2"}]]}]}], "-", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"5", "/", "2"}]]], 
   RowBox[{"C", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"]}], "-", 
      RowBox[{
       SuperscriptBox["\[Mu]", "3"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "5"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "4"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{"5", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], "-", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"5", "/", "2"}]]], 
   RowBox[{"D", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["\[Mu]", "2"]}], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]}]], "Output",\

 CellChangeTimes->{3.405687481063635*^9, 3.405703789087614*^9, 
  3.405708459749359*^9, 3.405753503847404*^9, 3.42492796884631*^9, 
  3.425025869855567*^9, 3.441628776131934*^9}]
}, Closed]],

Cell["\<\
Split it in several part for integration. First isolate the part that does \
not depend on C and D and integrate it once.\
\>", "Text",
 CellChangeTimes->{{3.405745492990153*^9, 3.405745570156051*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2b0", "=", " ", 
   RowBox[{"a2b", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"D", "\[Rule]", "0"}], " ", ",", 
      RowBox[{"C", "\[Rule]", "0"}]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{"a2b1I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a2b0", ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405745451200237*^9, 3.405745483222468*^9}, 
   3.405745655293355*^9, 3.4249282887167*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4056881282704763`*^9, 3.405703789576619*^9, 
  3.405708461015973*^9, 3.4057535044806767`*^9, 3.424927981655608*^9, 
  3.425025873639796*^9, 3.441628783591239*^9}]
}, Open  ]],

Cell["Then isolate the factor of C and checks it integrates twice", "Text",
 CellChangeTimes->{{3.405745589367653*^9, 3.405745618950581*^9}, {
  3.424928004713627*^9, 3.424928004941129*^9}, {3.424928039808253*^9, 
  3.424928049751544*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2b1", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a2b", ",", "C"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.405745623012708*^9, 3.405745659658623*^9}, {
  3.405753432891119*^9, 3.405753433760559*^9}, {3.424928007928128*^9, 
  3.424928008089905*^9}}],

Cell["a2b2I2 = Integrate[Integrate[a2b1, y], y]", "Text",
 CellChangeTimes->{
  3.405708443762661*^9, {3.405745672954757*^9, 3.405745674746818*^9}, {
   3.4057534375848083`*^9, 3.40575343789323*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2b2I2", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"2", "  ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a2b2I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a2b1"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424928116960062*^9, 3.424928158972341*^9}, {
  3.424928199823647*^9, 3.424928238527601*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424928239521296*^9, 3.425025878392403*^9, 
  3.441628787052989*^9}]
}, Open  ]],

Cell["Isolate the factor of D and integrate it once", "Text",
 CellChangeTimes->{{3.405745754960486*^9, 3.405745759642454*^9}, {
  3.405745791092037*^9, 3.405745808312101*^9}, {3.424928249341529*^9, 
  3.424928249507365*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2b2", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a2b", "  ", ",", "D"}], "]"}]}], ";"}], "\n", 
 RowBox[{"a2b0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a2b2", ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405745812649135*^9, 3.405745828351323*^9}, {
   3.405753440570002*^9, 3.4057534411203814`*^9}, 3.405753527993288*^9, {
   3.424928250920753*^9, 3.424928269004994*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.4056881642759657`*^9, 3.405703812606026*^9, 3.405708511034817*^9, 
   3.405753517211644*^9, {3.424928262256887*^9, 3.424928273164765*^9}, 
   3.425025884030258*^9, 3.441628792007794*^9}]
}, Open  ]],

Cell["\<\
Complete the solvability proof for a2b by check that nothing has been \
forgotten in a2b\
\>", "Text",
 CellChangeTimes->{{3.405745389447373*^9, 3.405745403146656*^9}, {
  3.405745764672007*^9, 3.405745784943751*^9}, {3.405745896667426*^9, 
  3.405745935471117*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a2b", " ", "-", " ", "a2b0", " ", "-", " ", 
   RowBox[{"C", " ", "a2b1"}], " ", "-", 
   RowBox[{"D", " ", "a2b2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.40574540948459*^9, 3.405745437037369*^9}, {
   3.405745841759482*^9, 3.405745865636389*^9}, 3.405745940805416*^9, {
   3.4057534480064774`*^9, 3.405753452172996*^9}, {3.424928309033918*^9, 
   3.424928310444633*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057535175270147`*^9, 3.424928313070743*^9, 
  3.425025891344839*^9, 3.441628794624962*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a2d"}]], "Subsubsection",
 CellChangeTimes->{{3.405690035550551*^9, 3.405690037683858*^9}, {
  3.441628884030012*^9, 3.441628942169037*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2d", "=", 
  RowBox[{"-", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a2", "  ", ",", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], ",", "1"}], "]"}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.405690035550551*^9, 3.405690037683858*^9}, {
   3.441628884030012*^9, 3.441628917112034*^9}, {3.441628947298827*^9, 
   3.441628976648047*^9}, 3.441629029097339*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f1", "\[Prime]\[Prime]",
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{3.441628977569552*^9, 3.441629030240339*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reconstruction of the second order equation ", "Subsection",
 CellChangeTimes->{{3.425025955054413*^9, 3.42502596256308*^9}, 
   3.441629010397268*^9}],

Cell["\<\
Check that nothing has been forgotten in the extraction of the components of \
a2\
\>", "Text",
 CellChangeTimes->{{3.405687499347293*^9, 3.405687519117462*^9}, {
  3.405687570045809*^9, 3.4056875715644836`*^9}, {3.405745942937049*^9, 
  3.405745950226455*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2N", " ", "=", " ", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]2", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "-", " ", 
    RowBox[{"a2b", "  ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "-", " ", 
    RowBox[{"a2a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}], "-", " ", 
    RowBox[{"a2d", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a2N", " ", "-", " ", "a2"}], " ", "]"}]}], "Input",
 CellChangeTimes->{
  3.405687585410922*^9, 3.405689971668638*^9, 3.441628811059948*^9, {
   3.441628990615522*^9, 3.441629006826898*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.405708612492112*^9, 3.405753537981843*^9, 3.424928319770715*^9, 
   3.425025898542524*^9, {3.441628803833969*^9, 3.441628821095726*^9}, {
   3.441629022734927*^9, 3.441629032692938*^9}, 3.441629799135573*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule2", " ", "=", "  ", 
  RowBox[{"\[Psi]2", "  ", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f2a", "[", "#3", "]"}], "  ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"#1", ",", "#2"}], "]"}], "2"]}], "+", " ", 
      RowBox[{
       RowBox[{"f2b", "[", "#3", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}]}], "+", 
      RowBox[{"f2d", "  ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}]}], "&"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.42502599142893*^9, 3.425026017409225*^9}, {
  3.441629045241194*^9, 3.441629050686321*^9}}],

Cell[BoxData[
 RowBox[{"\[Psi]2", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f2a", "[", "#3", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"f2b", "[", "#3", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"#1", ",", "#2"}], "]"}]}], "+", 
     RowBox[{"f2d", " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.4056881724009247`*^9, 3.405703814113815*^9, 
  3.405708621168304*^9, 3.4057535424394903`*^9, 3.424928323469436*^9, 
  3.42502598238046*^9, 3.425026019706363*^9, 3.441629053672639*^9}]
}, Open  ]],

Cell["\<\
f2a has CosI symmetry
f2b has CosP symmetry
f2d has SinI symmetry\
\>", "Text",
 CellChangeTimes->{{3.425026028377749*^9, 3.42502605168865*^9}, {
  3.441629061265755*^9, 3.441629063246728*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 3", "Section"],

Cell[TextData[{
 "Extract order 3 terms from the general expansion, use formal solution to \
order 0, 1 and 2 equations and perform algebraic simplication.\nNeed to be \
put under the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]3", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member\nNo attemps to simplify here"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}, {
  3.405685906475298*^9, 3.405685933174532*^9}, {3.405688214542055*^9, 
  3.405688233724618*^9}, {3.405688414807213*^9, 3.405688425967601*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3", " ", "=", "  ", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"NS2", ",", "\[Epsilon]", ",", "3"}], "]"}], "   ", "//.", " ", 
    RowBox[{"{", 
     RowBox[{"Rule0", ",", "Rule1", ",", "Rule2"}], "}"}]}]}], " ", 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection"],

Cell["\<\
First reorganize a3 in order to make further extraction easier\
\>", "Text",
 CellChangeTimes->{{3.405688359831512*^9, 3.4056883786622953`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a31", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a3", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.441629078402705*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "3"]}], ":", " ", 
  "a3a"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a31", " ", ",", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], "3"]}], "]"}], " ", ",", "C"}], 
    "]"}]}], "  ", ";"}]], "Input",
 CellChangeTimes->{{3.424928406687376*^9, 3.424928409639603*^9}, 
   3.441629384954184*^9}],

Cell["Term excluding factor C, which can be integrated in y", "Text",
 CellChangeTimes->{{3.405690303565764*^9, 3.405690323803512*^9}, {
  3.405690427766193*^9, 3.405690440196372*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3a", " ", "/.", " ", 
  RowBox[{"C", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f2a", 
   TagBox[
    RowBox[{"(", "3", ")"}],
    Derivative],
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{3.4056884479239197`*^9, 3.405703816650679*^9, 
  3.405708654607628*^9, 3.4057535963939047`*^9, 3.424928418934583*^9, 
  3.42502608866803*^9, 3.441629388003782*^9}]
}, Open  ]],

Cell["\<\
Get term in factor of C and check that the combination, adding previous \
contribution, reconstructs a3a\
\>", "Text",
 CellChangeTimes->{{3.405688495447377*^9, 3.405688524661201*^9}, {
  3.405690464708074*^9, 3.405690509076673*^9}, {3.424929839719086*^9, 
  3.424929850849363*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3a1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a3a", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"a3a", "-", 
  RowBox[{"C", " ", "a3a1"}], " ", "-", " ", 
  RowBox[{"(", 
   RowBox[{"a3a", " ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.424929175820322*^9, 3.424929198990442*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4056885308606787`*^9, 3.40570381692071*^9, 
  3.405708667588608*^9, 3.4057535986938543`*^9, 3.424929200397949*^9, 
  3.425026090893405*^9, 3.441629391394275*^9}]
}, Open  ]],

Cell["\<\
a3a1I = Integrate[a3a1, y];
a3a1I2 = Integrate[a3a1I, y];\
\>", "Text",
 CellChangeTimes->{
  3.4057537709319763`*^9, {3.424929276730252*^9, 3.424929279715138*^9}, {
   3.424929750425013*^9, 3.424929751340458*^9}, 3.424929792164733*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3a1I2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"U", "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], " ", 
          
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}]}], 
        ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["f2a", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f2a", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f2a", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             RowBox[{"2", "  ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["U", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["f2a", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
     "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a3a1I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a3a1"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424929592119862*^9, 3.424929655697013*^9}, {
  3.424929691130295*^9, 3.424929723245533*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424929725753221*^9, 3.425026095319715*^9, 
  3.441629397619807*^9}]
}, Open  ]],

Cell["\<\
Solvability is satisfied since all components of a3a integrate twice in y. \
Notice that it would be sufficient to check that the solvability condition is \
satisfied on the first integral but more compact expressions are obtained \
when a second primitive can be obtained. \
\>", "Text",
 CellChangeTimes->{{3.405690369471695*^9, 3.405690390351179*^9}, {
  3.405746127058013*^9, 3.405746150970755*^9}, {3.405771248852193*^9, 
  3.405771249117156*^9}, {3.405771324636036*^9, 3.405771476043433*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", "factor", " ", "of", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{"Group", " ", "of", " ", "all", " ", "terms", " ", "containing", " ",
   
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}], " ", "in", " ", "factor"}]], "Text",
 CellChangeTimes->{{3.405690572298355*^9, 3.405690599510146*^9}, {
  3.4057574744603233`*^9, 3.405757483084566*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a33", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a31", "]"}], ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.424929880269172*^9, 3.42492988634174*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", "a3b"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3b", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a33", " ", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.405690674595083*^9, {3.424929900639438*^9, 3.424929917984903*^9}, 
   3.441629934227534*^9}],

Cell["Term not in factor of C within a3b", "Text",
 CellChangeTimes->{{3.405690618705862*^9, 3.405690622111414*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3b0", "=", 
  RowBox[{"a3b", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f2b", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{"D", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f2a", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.40569067849599*^9, 3.405709767863743*^9, 
  3.405753898377462*^9, 3.424929942838567*^9, 3.425026134998223*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3b0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a3b0", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.424929947335741*^9, 3.424929970060273*^9}, {
  3.424930018945308*^9, 3.424930079287381*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"D", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f1", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f2a", "[", "y", "]"}], "-", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{"2", " ", "D", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.424929964188506*^9, 3.424929971547486*^9}, {
   3.424930065414791*^9, 3.424930084462213*^9}, 3.425026139229703*^9}]
}, Open  ]],

Cell["\<\
Term in factor of C within a3b, checking that it combines with a3b0 to \
reconstruct a3b\
\>", "Text",
 CellChangeTimes->{{3.4056908582981787`*^9, 3.405690913088511*^9}, {
  3.405709381407221*^9, 3.405709386605586*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3b2", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a3b", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"a3b", " ", "-", 
  RowBox[{"C", " ", "a3b2"}], " ", "-", " ", "a3b0"}]}], "Input",
 CellChangeTimes->{{3.405709392793869*^9, 3.405709394330489*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405690920055438*^9, 3.405709772691623*^9, 
  3.405753971191379*^9, 3.424930100996744*^9, 3.42493089345565*^9, 
  3.425026143952413*^9}]
}, Open  ]],

Cell["\<\
Integrate twice a3b2, completing the proof of solvability for a3b\
\>", "Text",
 CellChangeTimes->{{3.405690998215687*^9, 3.405691050436213*^9}}],

Cell["\<\
a3b2I = Integrate[a3b2, y]
a3b2I2 = Integrate[a3b2I, y]\
\>", "Text",
 CellChangeTimes->{
  3.405691071157219*^9, {3.424930120655591*^9, 3.424930135243004*^9}, 
   3.424930688343996*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3b2I2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{"f1", "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], ")"}]}],
       "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a3b2I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a3b2"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424931101510121*^9, 3.424931132601686*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.424931087387912*^9, {3.424931118306033*^9, 3.424931141390351*^9}, 
   3.425026151727788*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  RowBox[{"a3d", "  ", "[", "S", "]"}]}]], "Subsubsection",
 CellChangeTimes->{{3.424954851109949*^9, 3.424954855093057*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3d", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a31", " ", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.424931455143082*^9, 3.424931460423517*^9}, 
   3.441629965942022*^9}],

Cell["Extract the contribution that does not contain C", "Text",
 CellChangeTimes->{{3.405709452831823*^9, 3.405709487758203*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3d0", "=", 
  RowBox[{"a3d", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"U", "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["f2b", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.405710513092377*^9, 3.405754662837373*^9, 
  3.424931470954106*^9, 3.425026205116525*^9, 3.441629976306626*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"a3d0", "+", 
    RowBox[{"U", "[", "y", "]"}]}], ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.424931515159451*^9, 3.424931558149137*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"U", "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f2b", "[", "y", "]"}], "-", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.424931532360037*^9, 3.42493156002175*^9}, 
   3.425026208086114*^9, 3.441629979158128*^9}]
}, Open  ]],

Cell["Coefficient in front of C in a3d", "Text",
 CellChangeTimes->{{3.405710925928004*^9, 3.405710928733447*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3d2", " ", "=", 
   RowBox[{"Improve", "[", " ", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a3d", ",", "C"}], "]"}], " ", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.405711887382365*^9, {3.4057547683618507`*^9, 3.4057547689028893`*^9}, {
   3.424931591495112*^9, 3.424931621829126*^9}}],

Cell["\<\
Mathematica does not integrate this expression but after a few manipulations \
we get an expression for a3d2 as the sum of two derivatives plus a residual \
term.
The residual term does not vanish in general in the absence of symmetry but \
we notice that it
is in factor of \[Mu] and hence disappears in the \[Mu]\[Rule]0 limit\
\>", "Text",
 CellChangeTimes->{{3.405712617213736*^9, 3.405712705533528*^9}, {
  3.405712750084974*^9, 3.405712913677759*^9}, {3.424932435975783*^9, 
  3.424932443803413*^9}, {3.42502059648781*^9, 3.425020597382921*^9}, {
  3.441629606860168*^9, 3.441629684910538*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3d2P", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"U", "[", "y", "]"}], "3"]}], "+", 
            RowBox[{
             RowBox[{"U", "[", "y", "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]], 
       RowBox[{
        RowBox[{"f1", "'"}], "[", "y", "]"}]}], ",", "y"}], "]"}], "-", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
        SqrtBox[
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]]], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "2"}], "}"}]}], "]"}], 
     RowBox[{"f1", "[", "y", "]"}]}], "-", "  ", 
    FractionBox[
     RowBox[{"\[Mu]", " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}]}], 
  ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a3d2P", "-", "a3d2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.424931997109471*^9, 3.424932037599298*^9}, {
  3.424932154922573*^9, 3.424932239276746*^9}, {3.424932297225535*^9, 
  3.424932297525247*^9}, {3.424932350838209*^9, 3.424932406520563*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.424932255969011*^9, 3.424932305594875*^9}, {
   3.424932400090653*^9, 3.424932419109431*^9}, 3.425026250476829*^9, 
   3.441629982874287*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a3g"}]], "Subsubsection",
 CellChangeTimes->{3.441630056142039*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3g", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"a33", ",", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4416300629317*^9, 3.441630063521332*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", 
  RowBox[{
   SuperscriptBox["f2a", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.4057135888749*^9, 3.405754999269525*^9, 
  3.42493271991169*^9, 3.425026300965645*^9, 3.441629726659322*^9, 
  3.441630064678808*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a3h"}]], "Subsubsection",
 CellChangeTimes->{{3.441630114953963*^9, 3.441630119193349*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3h", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"a31", ",", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.44163012379247*^9, 3.441630137239009*^9}, {
  3.441630440680862*^9, 3.441630443724631*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "-", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.441630446675639*^9}]
}, Open  ]],

Cell["This term generates a contribution to the amplitude equation", "Text",
 CellChangeTimes->{{3.441630481080249*^9, 3.441630501708004*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Amplitude equation", "Subsubsection",
 CellChangeTimes->{{3.441630528139813*^9, 3.441630534191501*^9}}],

Cell["The amplitude equation at this stage is ", "Text",
 CellChangeTimes->{{3.441630563327747*^9, 3.441630574141701*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "T"], " ", "\[CurlyPhi]0"}], " ", "+"}], "<",
    
   FractionBox[
    RowBox[{"\[Mu]", " ", 
     RowBox[{"U", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]]], ">", 
   RowBox[{
    SubscriptBox["\[PartialD]", "X"], " ", "\[CurlyPhi]0"}]}], "=", 
  "0"}]], "Text",
 CellChangeTimes->{{3.441630657541711*^9, 3.441630662259605*^9}, {
  3.441630746431664*^9, 3.44163078049764*^9}}],

Cell["\<\
It is purely propagative and hence cannot produce an instability per se. It \
is still necessary to go to higer order. Also we see that the propagtive \
effect is proportional to \[Mu] that we want to be small.\
\>", "Text",
 CellChangeTimes->{{3.441630783600802*^9, 3.441630878839818*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification", "Subsubsection"],

Cell["\<\
Assemble all the contribution found at order 3 plus the linear term in \
\[Psi]3, and check the sum against a3\
\>", "Text",
 CellChangeTimes->{{3.405713595570601*^9, 3.40571365848319*^9}, {
  3.40571370802528*^9, 3.405713764152111*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3N", "=", 
   RowBox[{
    RowBox[{"a3g", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "  ", "+", "  ", 
    RowBox[{"a3d", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{"a3b", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{"a3a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "3"]}], "+", "  ", 
    RowBox[{"a3h", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "+", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]3", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{"a3N", "-", "a3"}], " ", "]"}], "]"}], " ", "]"}]}], "Input",
 CellChangeTimes->{
  3.40571373382877*^9, {3.4416298217753*^9, 3.441629852051294*^9}, 
   3.441630093994667*^9, {3.441630457812817*^9, 3.441630468246709*^9}, {
   3.441630978694568*^9, 3.441630987160262*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.40571369948894*^9, 3.405713782318974*^9, {3.405754986385345*^9, 
   3.4057550042718554`*^9}, 3.424932704983323*^9, 3.424932745821245*^9, 
   3.425026315013511*^9, {3.441629862442383*^9, 3.441629864487338*^9}, 
   3.44162998907241*^9, 3.441630097184854*^9, 3.44163046976404*^9, 
   3.441630989891302*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection",
 CellChangeTimes->{{3.40569149000653*^9, 3.405691494113007*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rule3", "=", 
   RowBox[{"\[Psi]3", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f3g", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "  ", "+", "  ", 
       RowBox[{
        RowBox[{"f3d", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"f3b", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"f3a", "[", "#3", "]"}], "  ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], "3"]}], "+", " ", 
       RowBox[{"f3h", " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}]}], "&"}], ")"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.441630912231553*^9, 3.441630969216191*^9}, {
  3.441631013370587*^9, 3.441631035788219*^9}}],

Cell["\<\
f3a has SinI symmetry
f3b has SinP symmetry
f3d has SinI symmetry
f3g has SinI symmetry
f3h has CosP symmetry\
\>", "Text",
 CellChangeTimes->{{3.441631075178601*^9, 3.441631147834075*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 4", "Section"],

Cell[TextData[{
 "Extract order 4 terms from the general expansion, use formal solution to \
order 0, 1, 2 and 3 equations and perform algebraic simplication.\nNeed to be \
put under the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]4", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member\nNo attemps to simplify here"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}, {
  3.405685906475298*^9, 3.405685933174532*^9}, {3.405688214542055*^9, 
  3.405688233724618*^9}, {3.405688414807213*^9, 3.405688425967601*^9}, {
  3.405713897641922*^9, 3.405713898274895*^9}, {3.40575505879291*^9, 
  3.4057550692681227`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4", " ", "=", " ", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", ">", "0"}], " ", "&&", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", ">", "0"}]}], ",", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"NS2", ",", "\[Epsilon]", ",", "4"}], "]"}], "   ", "//.", " ",
       
      RowBox[{"{", 
       RowBox[{"Rule0", ",", "Rule1", ",", "Rule2", ",", "Rule3"}], "}"}]}]}],
     "  ", "]"}]}], ";"}]], "Input"],

Cell["Rearrange a4 to prepair extraction", "Text",
 CellChangeTimes->{{3.4057550866309853`*^9, 3.4057550996880407`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a41", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a4", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "4"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]1", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.441631174526098*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "4"]}], ":", " ", 
  "a4a"}]], "Subsubsection",
 CellChangeTimes->{{3.424947516757441*^9, 3.424947541815585*^9}, {
  3.441631232352543*^9, 3.441631233242527*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a41", ",", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], "4"]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.42493282770303*^9, 3.424932829754728*^9}}],

Cell["\<\
Contribution that does not contain C.
Can be integrated and satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.4057551808796577`*^9, 3.405755253445551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4a0", "=", 
  RowBox[{"a4a", "  ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f3a", 
   TagBox[
    RowBox[{"(", "3", ")"}],
    Derivative],
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{3.405755374229994*^9, 3.424932836096854*^9, 
  3.441631213316615*^9}]
}, Open  ]],

Cell["Get the rest of a4a", "Text",
 CellChangeTimes->{{3.40575533835573*^9, 3.405755363289391*^9}, {
  3.424933018921989*^9, 3.424933022363526*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4a1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a4a", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4a", " ", "-", " ", 
   RowBox[{"C", " ", "a4a1"}], "-", "a4a0"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.424932850961348*^9, {3.424932938032786*^9, 3.424933005871961*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424933007178779*^9, 3.441631215542135*^9}]
}, Open  ]],

Cell["Integrate  and check ", "Text",
 CellChangeTimes->{{3.4057554086968327`*^9, 3.405755430519291*^9}, 
   3.4057555228684273`*^9, {3.405760252086955*^9, 3.405760259206244*^9}, {
   3.424949444243932*^9, 3.424949450415943*^9}}],

Cell["\<\
a4a1I = Integrate[a4a1, y];
a4a1I2 = Integrate[a4a1I, y]\
\>", "Text",
 CellChangeTimes->{{3.405755545525198*^9, 3.4057555760568113`*^9}, {
  3.4057557082657213`*^9, 3.405755742490711*^9}, {3.424933495827059*^9, 
  3.424933504301467*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4a1I2a", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], " ", 
          
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], " ", 
          
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
         RowBox[{"4", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"6", " ", 
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]", "-", 
            RowBox[{"4", " ", "\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["f1", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["f1", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
           ")"}]}]}], ")"}]}], ")"}]}], "/", 
    RowBox[{"(", 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"7", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4a1I2b", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
         " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"U", "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}]}],
        ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         RowBox[{"U", "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2a", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], "/",
     
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4a1I2c", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["f3a", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"3", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
      RowBox[{"6", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f3a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f3a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["f3a", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f3a", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"a4a1I2a", "+", "a4a1I2b", "+", "a4a1I2c"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a4a1"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.424943994305324*^9, 3.424944025193213*^9}, {
  3.42494405673797*^9, 3.424944077870964*^9}, {3.424949392022278*^9, 
  3.424949417011726*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4249493413115*^9, 3.424949421537894*^9, 
  3.441631220213774*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], "2"]}]], "Subsubsection",
 CellChangeTimes->{{3.441631248133919*^9, 3.441631249617428*^9}}],

Cell[BoxData[
 RowBox[{"Group", " ", "of", " ", "all", " ", "terms", " ", "containing", "  ",
   "a", " ", "factor", " ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], "2"]}]], "Text",
 CellChangeTimes->{{3.4057575270756073`*^9, 3.405757546269353*^9}, {
  3.4057576059926167`*^9, 3.405757612014574*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a42", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a41", ",", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}], "]"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4c"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4c", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a42", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.4057590454196167`*^9, {3.424949501917177*^9, 3.424949503592385*^9}}],

Cell["\<\
Contribution that does not contain C.
Can be integrated and satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.4057551808796577`*^9, 3.405755253445551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c0", "=", 
   RowBox[{"a4c", "  ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}]}], ";"}], "\n", 
 RowBox[{"a4c0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4c0", ",", "y"}], "]"}]}], "\n", 
 RowBox[{"Solva", "[", "a4c0I", "]"}]}], "Input",
 CellChangeTimes->{{3.4057627942562113`*^9, 3.405762820166201*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], "-", 
     RowBox[{"3", " ", "D", " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f3b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", "D", " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405762828468363*^9, 3.424949511758758*^9, 
  3.441631274911592*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405762828468363*^9, 3.424949511758758*^9, 
  3.441631274949413*^9}]
}, Open  ]],

Cell["Get the rest of a4c in powers of A", "Text",
 CellChangeTimes->{{3.40575533835573*^9, 3.405755363289391*^9}, {
  3.405762994029332*^9, 3.4057629944598637`*^9}, {3.424949538418483*^9, 
  3.424949539128171*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a4c", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4c", "-", "a4c0", " ", "-", " ", 
   RowBox[{"C", " ", "a4c1"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4249495471513*^9, 3.424949579679052*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424949580187758*^9, 3.441631277375094*^9}]
}, Open  ]],

Cell["Integrate and check ", "Text",
 CellChangeTimes->{{3.4057554086968327`*^9, 3.405755430519291*^9}, 
   3.4057555228684273`*^9, {3.405760225057373*^9, 3.405760236790447*^9}, {
   3.424949586864693*^9, 3.424949589494624*^9}}],

Cell["\<\
a4c1I = Improve[Integrate[a4c1, y]];
a4c1I2 = Integrate[a4c1I, y]\
\>", "Text",
 CellChangeTimes->{{3.405762871324792*^9, 3.4057629051957693`*^9}, {
  3.424950288561341*^9, 3.424950291186582*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c1I2a", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"f1", "[", "y", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["f1", "\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}],
              " ", 
             RowBox[{
              SuperscriptBox["f2b", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "3"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Mu]", " ", 
            RowBox[{"f1", "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Mu]", "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["f1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
             ")"}]}], "+", 
           RowBox[{"6", " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["f2b", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Mu]", " ", 
            RowBox[{"f1", "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Mu]", "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["f1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
            " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["f2b", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         RowBox[{"U", "[", "y", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"f1", "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{"6", " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["f2b", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], ")"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4c1I2b", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["f3b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f3b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{"f2a", "[", "y", "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f3b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f3b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{"f2a", "[", "y", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["f2a", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SuperscriptBox["f2b", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f3b", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]], ")"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"a4c1I2a", "+", "a4c1I2b"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a4c1"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424949609118788*^9, 3.424949631646508*^9}, {
   3.42494966254823*^9, 3.424949710384385*^9}, 3.424950198872686*^9, 
   3.424950278130341*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424950214290304*^9, 3.441631282386633*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{"Group", " ", "of", " ", "all", " ", "terms", " ", "containing", "  ",
   "a", " ", "factor", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Text",
 CellChangeTimes->{{3.4057575270756073`*^9, 3.405757546269353*^9}, {
  3.405757599066083*^9, 3.405757622894477*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a43", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a41", ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", 
  RowBox[{"a4g", " ", "[", "S", "]"}]}]], "Subsubsection",
 CellChangeTimes->{{3.424954739225724*^9, 3.424954743173667*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4g", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a43", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.4057688735777407`*^9, {3.42495166536996*^9, 3.424951667940716*^9}}],

Cell["\<\
Contribution that does not contain C.
Can be integrated and satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.4057551808796577`*^9, 3.405755253445551*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4g0", "=", 
   RowBox[{"a4g", " ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{3.405767457084242*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4gOI", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4g0", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4gOI", "]"}]}], "Input",
 CellChangeTimes->{{3.4057674653494883`*^9, 3.405767485721105*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f3d", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.405768885960895*^9, 3.424951678290629*^9, 
  3.441631686962468*^9, 3.44163176044278*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405768885960895*^9, 3.424951678290629*^9, 
  3.441631686962468*^9, 3.441631760479928*^9}]
}, Open  ]],

Cell["Get  the rest of a4g ", "Text",
 CellChangeTimes->{{3.40575533835573*^9, 3.405755363289391*^9}, {
  3.405762994029332*^9, 3.4057629944598637`*^9}, {3.405768933023402*^9, 
  3.405768940484323*^9}, {3.4057707003752127`*^9, 3.4057707137701807`*^9}, {
  3.405770941336204*^9, 3.40577094511432*^9}, {3.424951690735821*^9, 
  3.424951695210219*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4g1", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a4g", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4gl", " ", "=", 
   RowBox[{"CoefficientList", "[", " ", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a4g", ",", "C"}], "]"}], ",", "A"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4g", "-", "a4g0", "-", 
   RowBox[{"C", " ", "a4g1"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.424951779031792*^9, 3.424951838346196*^9}, {
  3.441632830949864*^9, 3.441632856683024*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.42495183580442*^9, 3.424951839213915*^9}, 
   3.441631689673038*^9, 3.441631764143766*^9, 3.441632858821181*^9}]
}, Open  ]],

Cell["\<\
This contribution cannot be integrated but, after some manipulations, it is \
possible to extract an integrable part on which the solvability condition can \
be tested and a non integrable part for which the solvability condition is \
obtained due to the symmetries\
\>", "Text",
 CellChangeTimes->{{3.4057691019715643`*^9, 3.4057691027106447`*^9}, {
   3.405769245709103*^9, 3.405769281169829*^9}, {3.405769829880949*^9, 
   3.405769943488309*^9}, {3.424951703685236*^9, 3.424951704200429*^9}, 
   3.42495176614767*^9, {3.424951852497225*^9, 3.424951866615901*^9}, 
   3.424951916576213*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4g1", "=", 
   RowBox[{"Improve", "[", "a4g1", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.4057698240388317`*^9, {3.441632871343733*^9, 3.441632874940593*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4g1Pa", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]], "-", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], "+", 
       RowBox[{"3", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Mu]", " ", 
           RowBox[{"U", "[", "y", "]"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{
            SuperscriptBox["U", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]], " ", 
     RowBox[{
      RowBox[{"f2a", "'"}], "[", "y", "]"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"6", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       RowBox[{"4", "  ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]], " ", 
     RowBox[{
      RowBox[{"f2a", "''"}], "[", "y", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4g1Pb", "=", 
   FractionBox[
    RowBox[{"\[Mu]", " ", 
     RowBox[{"U", "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"U", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4g1Pc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"f2b", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}], "+", 
       
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}], "-", 
       
       RowBox[{
        RowBox[{"f1", "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["U", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["f3d", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f3d", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f3d", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["U", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["f3d", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
     "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]], 
     RowBox[{"f2a", "[", "y", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4g1P", "=", 
   RowBox[{"a4g1Pa", " ", "+", " ", 
    RowBox[{"D", "[", 
     RowBox[{"a4g1Pb", ",", "y"}], "]"}], "+", " ", 
    RowBox[{"D", "[", 
     RowBox[{"a4g1Pc", ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4g1", "-", "a4g1P"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4057693100629683`*^9, 3.405769575467018*^9}, 
   3.405770014013647*^9, {3.424952028827952*^9, 3.424952057789126*^9}, {
   3.424952094810216*^9, 3.424952096787772*^9}, {3.424953031514696*^9, 
   3.424953114492045*^9}, {3.424953161642638*^9, 3.424953185494167*^9}, {
   3.42495354035074*^9, 3.424953546727444*^9}, {3.424953639928789*^9, 
   3.424953654359181*^9}, 3.42495369830531*^9, {3.424954213445778*^9, 
   3.424954222035034*^9}, {3.424954271758819*^9, 3.42495428675451*^9}, {
   3.424954321126616*^9, 3.424954361793249*^9}, {3.42495442002086*^9, 
   3.424954435460361*^9}, {3.424954486107351*^9, 3.42495451160027*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057700938079567`*^9, 3.424953674577627*^9, 
  3.42495372340194*^9, 3.42495423134469*^9, 3.424954444063457*^9, 
  3.424954520047071*^9, 3.441631700420083*^9, 3.441632889443626*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "In", " ", "general", " ", "and", " ", "in", " ", "the", " ", "absence", 
   " ", "of", " ", "symmetries"}], ",", " ", 
  RowBox[{
  "the", " ", "term", " ", "a4g1Pa", " ", "does", " ", "not", " ", 
   "integrate", " ", "to", " ", "zero", " ", 
   RowBox[{"over", " ", "[", 
    RowBox[{"0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "]"}]}], ",", " ", 
  RowBox[{
   RowBox[{
   "hence", " ", "it", " ", "contributes", " ", "to", " ", "the", " ", 
    "amplitude", " ", 
    RowBox[{"equation", ".", " ", "In"}], " ", "the", " ", "limit", " ", 
    "\[Mu]"}], "\[Rule]", "0"}], ",", " ", 
  RowBox[{"this", " ", "term", " ", "is"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], 
    SuperscriptBox[
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"], ")"}], 
     RowBox[{"3", "/", "2"}]]]}], "+", 
  RowBox[{"4", " ", 
   SqrtBox[
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], "2"]], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  FractionBox[
   RowBox[{"8", " ", 
    RowBox[{
     SuperscriptBox["f2a", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], " ", 
    RowBox[{
     SuperscriptBox["U", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], " ", 
    RowBox[{
     SuperscriptBox["U", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], 
   SqrtBox[
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], "2"]]]}]}], "Text",
 CellChangeTimes->{{3.424954642147134*^9, 3.424954652996735*^9}, {
  3.441633196350238*^9, 3.441633261218423*^9}, {3.441633340140405*^9, 
  3.441633364561588*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4h"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4h", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a43", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.40577097598291*^9, {3.424955147550365*^9, 3.424955150748665*^9}}],

Cell["\<\
Contribution that does not contain C.
  Can be integrated and satisfies the solvability condition.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4h0", "=", 
  RowBox[{"a4h", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.405772134095028*^9, 3.405772134487248*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f3g", 
   TagBox[
    RowBox[{"(", "3", ")"}],
    Derivative],
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{3.405771315175596*^9, 3.405772135947776*^9, 
  3.424955155471661*^9, 3.441631339678275*^9}]
}, Open  ]],

Cell["Get contribution in C, integrate it and check solvability", "Text",
 CellChangeTimes->{{3.405771165093082*^9, 3.405771184911344*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4h1", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a4h", ",", "C"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4h", "-", "a4h0", " ", "-", 
   RowBox[{"C", " ", "a4h1"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.4057709903100767`*^9, 3.4057710867285633`*^9, {3.424955211573497*^9, 
   3.424955232007339*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424955243946653*^9, 3.441631348165966*^9}]
}, Open  ]],

Cell["\<\
a4h1I = Improve[Integrate[a4h1, y]];
a4h1I2 = Integrate[a4h1I, y]\
\>", "Text",
 CellChangeTimes->{
  3.4057709903100767`*^9, 3.4057710867285633`*^9, {3.424955211573497*^9, 
   3.424955232007339*^9}}],

Cell["Integrate and check", "Text",
 CellChangeTimes->{{3.42495536847847*^9, 3.424955371977152*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4h1I2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["f3g", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f3g", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f3g", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          " ", 
          RowBox[{
           SuperscriptBox["f3g", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a4h1I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a4h1"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424955306576038*^9, 3.424955358843573*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.424955360147597*^9, {3.441631354319637*^9, 3.441631355460235*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  "a4l"}], "\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{
  "contributes", " ", "to", " ", "the", " ", "amplitude", " ", "equation"}], 
  ")"}]}], "Subsubsection",
 CellChangeTimes->{{3.40577326685183*^9, 3.405773276842127*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4l", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a41", ",", "  ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "4"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.405778535921381*^9, {3.424963677386166*^9, 3.424963678790344*^9}}],

Cell["\<\
Contribution independent of C.
  The two terms of a4l0 are of symmetry CosP, they have no primitive and \
provide a contribution to the amplitude equation.\
\>", "Text",
 CellChangeTimes->{{3.405773297999565*^9, 3.405773446969352*^9}, {
  3.405774550179636*^9, 3.405774566382914*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4l0", "=", 
  RowBox[{"a4l", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.405773449821535*^9, 3.4057734506448717`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"f1", "[", "y", "]"}]}], " ", 
   RowBox[{"U", "[", "y", "]"}]}], "-", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4057791487556553`*^9, 3.424963685674487*^9, 
  3.441631399295672*^9}]
}, Open  ]],

Cell["\<\
Now get the coefficient of C. It has no primitive but can be described as a \
sum of derivatives and residual terms.\
\>", "Text",
 CellChangeTimes->{{3.4057785839594183`*^9, 3.405778601640111*^9}, {
  3.4057786442864113`*^9, 3.40577874277704*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4l1", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a4l", ",", "C"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.424955660610357*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4l1Pa", " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"2", "  ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4l1Pb", " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]]], 
    RowBox[{"f2b", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4l1Pc", " ", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"\[Mu]", " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"U", "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]], " ", 
    RowBox[{"f2b", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4l1Pd", "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Mu]"}], " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
     RowBox[{"3", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4l1P", "=", " ", 
   RowBox[{"a4l1Pa", "+", " ", 
    RowBox[{"D", "[", 
     RowBox[{"a4l1Pb", ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], " ", "-", "  ", 
    RowBox[{"D", "[", 
     RowBox[{"a4l1Pc", ",", "y"}], "]"}], " ", "-", " ", 
    RowBox[{
     RowBox[{"f2b", "[", "y", "]"}], 
     RowBox[{"D", "[", 
      RowBox[{"a4l1Pd", ",", "y"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4l1", "-", "a4l1P"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405778804231544*^9, 3.405778954165442*^9}, {
   3.405779001962867*^9, 3.405779023790101*^9}, 3.405779106948366*^9, {
   3.405779311513914*^9, 3.405779330755417*^9}, {3.4057795204768047`*^9, 
   3.4057795345895157`*^9}, {3.405779690178726*^9, 3.405779700074843*^9}, {
   3.405780014437278*^9, 3.405780016437257*^9}, {3.424963720257463*^9, 
   3.424963766269344*^9}, {3.424963897130382*^9, 3.424963904720321*^9}, {
   3.424964135129139*^9, 3.424964156524633*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.405779125968079*^9, 3.405779172163254*^9, {3.405779337151836*^9, 
   3.405779364789768*^9}, 3.405779399805955*^9, 3.4057794547113457`*^9, 
   3.405779503702523*^9, 3.4057795368013783`*^9, 3.4057797019355297`*^9, 
   3.405780017913056*^9, 3.424964162043495*^9, 3.441631402836311*^9}]
}, Open  ]],

Cell["\<\
The first and the fourth term contribute as they are product of trig \
functions with same symmetry.\
\>", "Text"],

Cell["Check that nothing has been forgotten", "Text",
 CellChangeTimes->{{3.405780081706346*^9, 3.40578009218684*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4l", " ", "-", " ", "a4l0", " ", "-", " ", 
   RowBox[{"C", " ", "a4l1"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.405780096973837*^9, 3.405780145849922*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.405780130925108*^9, 3.405780147243774*^9}, 
   3.424964690311702*^9, 3.441631407885822*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4n"}]], "Subsubsection",\

 CellChangeTimes->{{3.40577306274051*^9, 3.405773131776634*^9}, {
  3.4057801891531677`*^9, 3.40578019344256*^9}, {3.441631419204432*^9, 
  3.441631421019398*^9}, {3.441634042900321*^9, 3.441634043969129*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4n", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a41", ",", "  ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"{", "D", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.424956024281265*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.40578474080618*^9, 3.424956026518311*^9, 
  3.441631424389339*^9}]
}, Open  ]],

Cell["No contribution of that sort", "Text",
 CellChangeTimes->{{3.405773034258717*^9, 3.405773056972809*^9}, {
  3.405773140256077*^9, 3.405773177236987*^9}, {3.441639202855288*^9, 
  3.44163921022142*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], ":", " ", 
  RowBox[{"a4o", " ", "[", "S", "]"}]}]], "Subsubsection",
 CellChangeTimes->{{3.4057811527477016`*^9, 3.405781154299303*^9}, {
   3.424956161535799*^9, 3.424956171454131*^9}, 3.424963619929375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4o", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a41", ",", "  ", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], " ", "]"}], " ", ",",
      
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.405774813424066*^9, 3.405774821561133*^9}, {
  3.424956041204938*^9, 3.424956043033507*^9}}],

Cell["\<\
The contribution independent of C has a primitive and satisfies the \
solvability condition\
\>", "Text",
 CellChangeTimes->{{3.405775267257039*^9, 3.405775312793243*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o0", "=", 
   RowBox[{"a4o", " ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}]}], ";"}], "\n", 
 RowBox[{"a4o0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4o0", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4oI0", "]"}]}], "Input",
 CellChangeTimes->{{3.405775332191866*^9, 3.4057753823561068`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], "-", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405775386767068*^9, 3.424956072983493*^9, 
  3.441631481502306*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405775386767068*^9, 3.424956072983493*^9, 
  3.441631481527662*^9}]
}, Open  ]],

Cell["Expand the rest of a4o in power of A", "Text",
 CellChangeTimes->{{3.405775392778092*^9, 3.405775408735867*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o1", " ", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a4o", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4o", "-", "a4o0", "-", 
   RowBox[{"C", " ", "a4o1"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.424962367748235*^9, 3.424962393352097*^9}, {
  3.424962619181573*^9, 3.424962654431784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.424962648176953*^9, 3.424962655365897*^9}, 
   3.44163148658319*^9}]
}, Open  ]],

Cell["\<\
The term in C cannot be integrated but it can be sorted in several parts\
\>", "Text",
 CellChangeTimes->{{3.405776170244063*^9, 3.40577618342692*^9}, {
  3.4057764251543837`*^9, 3.405776436923333*^9}, {3.42496267632612*^9, 
  3.424962685185026*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o1aP", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["\[Mu]", "2"], 
           SuperscriptBox[
            RowBox[{"f1", "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"4", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        FractionBox[
         RowBox[{" ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], 
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", "  ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
         
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]]], 
        RowBox[{"f2a", "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SuperscriptBox["f2b", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["U", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{
              SuperscriptBox["f2b", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "+", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{"U", "[", "y", "]"}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"U", "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              RowBox[{"U", "[", "y", "]"}]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox["U", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
         ")"}], "/", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]}], 
       SuperscriptBox[
        RowBox[{
         RowBox[{"f1", "'"}], "[", "y", "]"}], "2"]}], ",", "y"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4o1bP", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]", " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["U", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "4"], "+", 
           RowBox[{"3", " ", "\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "3"], " ", 
            RowBox[{
             SuperscriptBox["U", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
       "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]}], 
     SuperscriptBox[
      RowBox[{
       RowBox[{"f1", "'"}], "[", "y", "]"}], "2"]}], "-", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "4"]}], "+", 
        RowBox[{"5", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "4"]}]}], ")"}], "/", 
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]], ")"}]}], 
     SuperscriptBox[
      RowBox[{
       RowBox[{"f1", "''"}], "[", "y", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"U", "'"}], "[", "y", "]"}], "2"], 
           RowBox[{
            RowBox[{"f2a", "'"}], "[", "y", "]"}]}], ",", "y"}], "]"}]}], "+",
        
       RowBox[{"6", "\[Mu]", " ", 
        RowBox[{"U", "[", "y", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"U", "[", "y", "]"}], 
           RowBox[{
            RowBox[{"f2a", "'"}], "[", "y", "]"}]}], ",", "y"}], "]"}]}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]], ")"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.424958983886849*^9, 3.424958990096006*^9}, {
   3.424959031534348*^9, 3.424959096097489*^9}, {3.424959160517371*^9, 
   3.424959171594864*^9}, 3.424960894429665*^9, {3.424961178254939*^9, 
   3.424961214583041*^9}, {3.424961558994031*^9, 3.424961637377953*^9}, {
   3.424961694012289*^9, 3.424961746518656*^9}, {3.42496204848552*^9, 
   3.424962060541673*^9}, 3.424962176961875*^9, {3.424962721833822*^9, 
   3.424962738888405*^9}, {3.424963155679005*^9, 3.424963254583392*^9}, 
   3.4249632953605*^9, {3.424963482587645*^9, 3.424963492103314*^9}, 
   3.424963523930197*^9}],

Cell["\<\
It is easy to check that all the terms which are not under the derivative in \
a4o1bP are with CosI symmetry and integrate to zero\
\>", "Text",
 CellChangeTimes->{{3.405777459366008*^9, 3.4057774700174217`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4o1c", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "7"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Mu]", "2"], 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "5"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"]}], "+", 
         RowBox[{"7", " ", 
          RowBox[{"U", "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "5"], " ", 
       SuperscriptBox["\[Mu]", "3"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", 
       SuperscriptBox["\[Mu]", "4"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "6"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"7", "/", "2"}]]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.424960147410371*^9, 3.424960163040725*^9}, {
   3.424960665300648*^9, 3.424960705316272*^9}, {3.424960789191353*^9, 
   3.424960789640733*^9}, 3.424962483700739*^9}],

Cell["\<\
The numerator is a sum of terms with CosI symmetry, which is preserved by the \
division by the denominator in CosP, integrating a4o1c to zero. Let us check \
it numerically for some examples.\
\>", "Text",
 CellChangeTimes->{{3.405777517685257*^9, 3.405777657205868*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"a4o1c", "  ", "/.", 
     RowBox[{"{", " ", 
      RowBox[{"Flow1", ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"a4o1c", "  ", "/.", 
     RowBox[{"{", " ", 
      RowBox[{"Flow2", ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"a4o1c", "  ", "/.", 
     RowBox[{"{", " ", 
      RowBox[{"Flow3", ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData["0``12.205890367704667"], "Output",
 CellChangeTimes->{
  3.405778469935143*^9, 3.424960735462923*^9, 3.424960796192548*^9, {
   3.44163151066857*^9, 3.441631527694854*^9}}],

Cell[BoxData["0``14.090905755020245"], "Output",
 CellChangeTimes->{
  3.405778469935143*^9, 3.424960735462923*^9, 3.424960796192548*^9, {
   3.44163151066857*^9, 3.441631528016809*^9}}],

Cell[BoxData["0``14.549782725157412"], "Output",
 CellChangeTimes->{
  3.405778469935143*^9, 3.424960735462923*^9, 3.424960796192548*^9, {
   3.44163151066857*^9, 3.441631528320897*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Chek", " ", "that", " ", "a4o1", " ", "is", " ", 
  "reconstructed"}]], "Input",
 CellChangeTimes->{{3.424962537328735*^9, 3.424962565235955*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4o1", "-", "a4o1aP", "-", "a4o1bP", "-", "a4o1c"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.42496333131156*^9, 3.424963334104093*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424962597555139*^9, 3.424963336176897*^9, 
  3.424963510431146*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4p", 
  " "}]], "Subsubsection",
 CellChangeTimes->{{3.4057811527477016`*^9, 3.405781154299303*^9}, {
   3.424956161535799*^9, 3.424956171454131*^9}, 3.424963619929375*^9, {
   3.441632664596869*^9, 3.441632694224462*^9}, {3.441632726993073*^9, 
   3.441632727588368*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4p", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"a41", ",", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.44163269768788*^9, 3.441632733421643*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"f1", "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.441632737066486*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification", "Subsubsection",
 CellChangeTimes->{3.405783109694642*^9, 3.424787620444553*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4NN", "=", " ", 
   RowBox[{
    RowBox[{"a4p", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "+", 
    RowBox[{"a4o", " ", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], " ", "+", "   ", 
    RowBox[{"a4l", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a4g", "  ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "+", 
       RowBox[{"a4h", " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], " ", "+", 
    "\[IndentingNewLine]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"], 
     RowBox[{"(", 
      RowBox[{"a4c", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], " ", ")"}]}], "+", " ", 
    RowBox[{"a4a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "4"]}], "+", "  ", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]4", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{"a4NN", "-", "a41"}], "]"}], " ", "]"}]}], "Input",
 CellChangeTimes->{
  3.4057566039740477`*^9, {3.405785280810128*^9, 3.405785289698398*^9}, {
   3.441631557280837*^9, 3.441631608962376*^9}, {3.441632746805498*^9, 
   3.441632755785443*^9}, {3.441634065209081*^9, 3.441634072736946*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.405780644817511*^9, 3.405785296758334*^9, {3.441631610747546*^9, 
   3.44163161237636*^9}, 3.441632587029216*^9, 3.441632757349504*^9, 
   3.441634067982116*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Analysis", " ", "of", " ", "the", " ", "contributions", " ", "to", 
  " ", "the", " ", "amplitude", " ", "equation"}]], "Input",
 CellChangeTimes->{{3.441636881007975*^9, 3.441636897890881*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "The", " ", "contribution", " ", "to", " ", "the", " ", "amplitude", " ", 
   "equation", " ", "which", " ", "have", " ", "been", " ", "identified", " ",
    "at", " ", "order", " ", "4", " ", "are"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"C", "<", " ", 
  RowBox[{"a4o1c", " ", "+", "a4o1bP"}], ">", 
  RowBox[{
   SuperscriptBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], " "}], "2"], "+", " ", "C"}], " ", "<", 
  "a4g1Pa", ">", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "3"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}]}], " ", "+"}], "<", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"f1", "[", "y", "]"}]}], " ", 
    RowBox[{"U", "[", "y", "]"}]}], "-", 
   RowBox[{"D", " ", 
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], " ", 
    RowBox[{
     SuperscriptBox["U", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], " ", "+", 
   RowBox[{"(", 
    RowBox[{"a4l1Pa", "-", " ", 
     RowBox[{
      RowBox[{"f2b", "[", "y", "]"}], 
      RowBox[{"D", "[", 
       RowBox[{"a4l1Pd", ",", "y"}], "]"}]}]}], ")"}]}], ">", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "4"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]}], "Text",
 CellChangeTimes->{{3.441636936269791*^9, 3.441636962790728*^9}, {
  3.441637260638914*^9, 3.441637458898952*^9}, {3.441637510963794*^9, 
  3.441637552991693*^9}, {3.441637631535221*^9, 3.441637649700882*^9}}],

Cell[BoxData[
 RowBox[{"It", " ", "is", " ", "interesting", " ", "to", " ", "see", " ", 
  "how", " ", "the", " ", "first", " ", "terms", " ", 
  RowBox[{"combine", ".", " ", "Actually"}], " ", "we", " ", 
  RowBox[{"find", ":"}]}]], "Input",
 CellChangeTimes->{{3.441637676175659*^9, 3.441637685991219*^9}, {
  3.441638410792653*^9, 3.441638415578588*^9}, {3.441638653414203*^9, 
  3.441638659523071*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"D", "[", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]}]], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], " ", "-", " ", "a4g1Pa", 
   " ", "+", " ", "a4o1c", " ", "+", "a4o1bP"}], "]"}]], "Input",
 CellChangeTimes->{{3.44163853051957*^9, 3.441638647579379*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.441638649339785*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"This", " ", "means", " ", "that"}], "<", " ", 
   RowBox[{"a4o1c", " ", "+", "a4o1bP"}], ">"}], " ", "=", 
  RowBox[{"<", "a4g1Pa", ">", " ", 
   RowBox[{
   "and", " ", "hence", " ", "that", " ", "the", " ", "nonlinear", " ", 
    "terms", " ", "are", " ", "of", " ", "the", " ", "form", " ", "Constant", 
    " ", "\[Times]", 
    RowBox[{
     RowBox[{"(", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[PartialD]", "X"], " ", "\[CurlyPhi]0"}], ")"}], "2"],
       ")"}], "''"}]}]}]}]], "Text",
 CellChangeTimes->{{3.441639270364581*^9, 3.441639321014465*^9}, {
  3.441647049693726*^9, 3.441647086345684*^9}, {3.441647146365992*^9, 
  3.441647178763756*^9}, {3.441647279524953*^9, 3.441647304047908*^9}}],

Cell[BoxData[{
 RowBox[{"The", " ", "ful", " ", "amplitude", " ", "equation", " ", "is", " ",
   "then", " ", 
  RowBox[{"(", 
   RowBox[{"after", " ", "2", " ", "integrations", " ", "in", " ", "y"}], 
   ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "T"], " ", "\[CurlyPhi]0"}], " ", "+", 
   RowBox[{"P", 
    RowBox[{
     SubscriptBox["\[PartialD]", "X"], " ", "\[CurlyPhi]0"}]}], " ", "+", " ",
    
   RowBox[{"\[Epsilon]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Q", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "X"], " ", "\[CurlyPhi]0"}], ")"}], 
        "2"]}], " ", "-", " ", 
      RowBox[{"\[Nu]T", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         SuperscriptBox["X", "2"]], " ", "\[CurlyPhi]0"}]}]}], ")"}]}]}], "=",
   "0"}]}], "Text",
 CellChangeTimes->{{3.441647202627583*^9, 3.441647271198866*^9}, {
  3.441647310296837*^9, 3.441647408858547*^9}, {3.44164747503761*^9, 
  3.441647528269971*^9}, {3.441647934884388*^9, 3.441647938147081*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"where", " ", "P"}], " ", "=", " ", 
   RowBox[{"<", 
    FractionBox[
     RowBox[{"\[Mu]", " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]]], ">"}]}], ",", 
  " ", 
  RowBox[{"Q", "=", " ", 
   RowBox[{"<", "a4g1Pa", ">"}]}], ",", " ", 
  RowBox[{"\[Nu]T", " ", "=", " ", 
   RowBox[{"-", 
    RowBox[{"<", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"f1", "[", "y", "]"}]}], " ", 
       RowBox[{"U", "[", "y", "]"}]}], "-", 
      RowBox[{"D", " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], " ", "+", 
      RowBox[{"(", 
       RowBox[{"a4l1Pa", "-", " ", 
        RowBox[{
         RowBox[{"f2b", "[", "y", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"a4l1Pd", ",", "y"}], "]"}]}]}], ")"}]}], 
     ">"}]}]}]}]], "Text",
 CellChangeTimes->{{3.441647540027976*^9, 3.441647619449003*^9}, {
  3.441647941438148*^9, 3.44164794542944*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dump / Recover", "Subsection",
 CellChangeTimes->{{3.4057803757773247`*^9, 3.405780388865893*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DumpSave", "[", 
  RowBox[{"\"\<CH-eff1-nu-8.m6.mx\>\"", ",", "\"\<Global`\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.405707255571572*^9, 3.405707269590346*^9}, {
  3.405707365657104*^9, 3.405707399428372*^9}, {3.405708293588033*^9, 
  3.405708330550449*^9}, {3.40575679967369*^9, 3.405756808002439*^9}}],

Cell[BoxData[
 RowBox[{"{", "\<\"Global`\"\>", "}"}]], "Output",
 CellChangeTimes->{{3.40570830006631*^9, 3.405708331989448*^9}, 
   3.405713795903619*^9, 3.405753555714876*^9, 3.405754634680348*^9, 
   3.4057550220528812`*^9, 3.405756959529352*^9, 3.405758134973331*^9, 
   3.405761818912491*^9, 3.405766506606394*^9, 3.405768825483378*^9, 
   3.405772491723752*^9, 3.405774122117296*^9, 3.405774384697494*^9, 
   3.405776566513393*^9, 3.405780205698803*^9, 3.405784783431664*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "CH-eff1-nu-8.m6.mx"}]], "Input",
 CellChangeTimes->{{3.4057529715345097`*^9, 3.405752973934311*^9}, {
  3.405756812713182*^9, 3.405756814598175*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Tools", "Subsection",
 CellChangeTimes->{{3.424964651440337*^9, 3.424964652621289*^9}, {
  3.424965736704426*^9, 3.424965748340623*^9}}],

Cell["\<\
Used for the translation from Sin[\[Theta][y]] to U[y] \
\>", "Text",
 CellChangeTimes->{{3.42496486454377*^9, 3.424964932483436*^9}}],

Cell[BoxData[{
 RowBox[{"Recode0", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], "\[Rule]", 
     RowBox[{"1", "-", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], "->", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], ")"}], "2"]}], 
    ",", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], "->", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], ")"}], "3"]}]}],
    "}"}]}], "\n", 
 RowBox[{"Recode1", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "\[Rule]", 
     RowBox[{"U", "[", "y", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"U", "'"}], "[", "y", "]"}], 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]]}]}], "}"}]}], "\n", 
 RowBox[{"Recode2", "=", 
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], "\[Rule]", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "2"]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Recode3", " ", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}]}], 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Recode4", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Theta]", 
      TagBox[
       RowBox[{"(", "3", ")"}],
       Derivative],
      MultilineFunction->None], "[", "y", "]"}], "->", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}], "+", 
       RowBox[{"3", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}]}], 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"]}]}], 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.424937585752509*^9, 3.424937594265153*^9}, 
   3.424938264593386*^9, {3.424938532334188*^9, 3.424938533488309*^9}, 
   3.424938570807581*^9, {3.424952243388058*^9, 3.424952266613115*^9}, {
   3.424952313564542*^9, 3.424952359645446*^9}, {3.424952427542885*^9, 
   3.424952446513098*^9}, {3.424952746585351*^9, 3.42495284158733*^9}, {
   3.424952923253182*^9, 3.424952926780795*^9}, {3.424959449088426*^9, 
   3.424959546597484*^9}, {3.424959585231411*^9, 3.424959625076684*^9}, {
   3.424959817590693*^9, 3.42495983257623*^9}}],

Cell["Example of usage", "Text",
 CellChangeTimes->{{3.424965717368748*^9, 3.42496572069955*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"TrigExpand", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"TrigExpand", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "86"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"3", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"5", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], 
                " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}], "5"]}], "-", 
               RowBox[{"16", " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", " ", "\[Mu]", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"3", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
                  RowBox[{"6", " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
                   RowBox[{
                    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"8", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], 
                   " ", 
                   RowBox[{
                    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"32", " ", "\[Mu]", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
                RowBox[{
                 SuperscriptBox["\[Theta]", 
                  TagBox[
                   RowBox[{"(", "3", ")"}],
                   Derivative],
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{"32", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox["\[Theta]", 
                  TagBox[
                   RowBox[{"(", "3", ")"}],
                   Derivative],
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
            ")"}]}], " ", "/.", "Recode4"}], " ", "/.", "Recode3"}], "]"}], 
       "]"}], " ", "/.", "Recode1"}], "]"}], " ", "/.", "Recode2"}], " ", "/.",
    "Recode1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "16"}], " ", "\[Mu]", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "5"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "5"]}], "-", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"10", " ", 
     RowBox[{"U", "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "4"], " ", 
     RowBox[{
      SuperscriptBox["U", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["U", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.424965805501355*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{897, 912},
WindowMargins->{{Automatic, 265}, {48, Automatic}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>"CH-eff.nb.ps",
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {72, 72}}},
Magnification->1.25,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Report"}, "StandardReport.nb", CharacterEncoding -> 
       "iso8859-1"]]], 
   Cell[
    StyleData["Output"], FontSize -> 12], 
   Cell[
    StyleData["Input"], FontFamily -> "Utopia", FontSize -> 12, FontWeight -> 
    "Bold", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], FontSize -> 14]}, Visible -> False, 
  FrontEndVersion -> "6.0 for Linux x86 (32-bit) (June 19, 2007)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 104, 3, 241, "Title"],
Cell[697, 28, 290, 12, 297, "Author"],
Cell[CellGroupData[{
Cell[1012, 44, 406, 9, 237, "Subtitle"],
Cell[1421, 55, 24, 0, 37, "Text"],
Cell[CellGroupData[{
Cell[1470, 59, 33, 0, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[1528, 63, 83, 2, 48, "Input",
 InitializationCell->True],
Cell[1614, 67, 530, 10, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2193, 83, 32, 0, 33, "Subsubsection"],
Cell[2228, 85, 118, 3, 48, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2383, 93, 34, 0, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[2442, 97, 437, 14, 52, "Input",
 InitializationCell->True],
Cell[2882, 113, 553, 15, 52, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3484, 134, 101, 2, 33, "Subsubsection"],
Cell[3588, 138, 169, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[3782, 146, 1158, 38, 56, "Input",
 InitializationCell->True],
Cell[4943, 186, 1181, 36, 60, "Output"]
}, Open  ]],
Cell[6139, 225, 414, 13, 61, "Text"],
Cell[CellGroupData[{
Cell[6578, 242, 3458, 103, 162, "Input",
 InitializationCell->True],
Cell[10039, 347, 3382, 101, 102, "Output"],
Cell[13424, 450, 196, 5, 58, "Reference"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13669, 461, 61, 0, 94, "Section"],
Cell[CellGroupData[{
Cell[13755, 465, 49, 0, 33, "Subsection"],
Cell[13807, 467, 70, 1, 37, "Text",
 InitializationCell->True],
Cell[13880, 470, 270, 8, 48, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[14187, 483, 40, 0, 33, "Subsection"],
Cell[14230, 485, 177, 4, 37, "Text"],
Cell[14410, 491, 994, 32, 181, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15441, 528, 39, 0, 33, "Subsection"],
Cell[CellGroupData[{
Cell[15505, 532, 1761, 53, 118, "Input"],
Cell[17269, 587, 90078, 1498, 217, 69052, 1152, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[107396, 2091, 49, 0, 33, "Subsection"],
Cell[CellGroupData[{
Cell[107470, 2095, 1815, 58, 101, "Input"],
Cell[109288, 2155, 19953, 1146, 184, 15269, 1067, "GraphicsData", \
"PostScript", "Graphics"],
Cell[129244, 3303, 139, 4, 55, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[129432, 3313, 59, 0, 32, "Subsection"],
Cell[129494, 3315, 307, 6, 85, "Text"],
Cell[CellGroupData[{
Cell[129826, 3325, 468, 14, 48, "Input"],
Cell[130297, 3341, 2999, 90, 120, "Output"]
}, Open  ]],
Cell[133311, 3434, 207, 4, 61, "Text"],
Cell[CellGroupData[{
Cell[133543, 3442, 2212, 60, 187, "Input"],
Cell[135758, 3504, 144544, 2385, 248, 105133, 1737, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[280317, 5892, 274, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[280616, 5901, 2215, 60, 187, "Input"],
Cell[282834, 5963, 130419, 2155, 250, 95578, 1582, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[413314, 8125, 56, 0, 94, "Section"],
Cell[CellGroupData[{
Cell[413395, 8129, 51, 0, 33, "Subsection"],
Cell[413449, 8131, 637, 18, 87, "Text"],
Cell[414089, 8151, 1374, 37, 74, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[415500, 8193, 31, 0, 33, "Subsection"],
Cell[415534, 8195, 159, 3, 37, "Text"],
Cell[415696, 8200, 865, 23, 72, "Input",
 InitializationCell->True],
Cell[416564, 8225, 361, 11, 48, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[416974, 8242, 26, 0, 94, "Section"],
Cell[417003, 8244, 263, 6, 61, "Text"],
Cell[CellGroupData[{
Cell[417291, 8254, 250, 6, 48, "Input"],
Cell[417544, 8262, 15971, 467, 653, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[433552, 8734, 39, 0, 32, "Subsection"],
Cell[433594, 8736, 190, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[433809, 8744, 218, 6, 48, "Input"],
Cell[434030, 8752, 373, 8, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[434452, 8766, 102, 1, 33, "Subsection"],
Cell[434557, 8769, 201, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[434783, 8777, 215, 5, 48, "Input"],
Cell[435001, 8784, 232, 3, 68, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[435294, 8794, 51, 0, 94, "Section"],
Cell[CellGroupData[{
Cell[435370, 8798, 216, 6, 48, "Input",
 InitializationCell->True],
Cell[435589, 8806, 372, 8, 68, "Output"]
}, Open  ]],
Cell[435976, 8817, 104, 1, 37, "Text"],
Cell[436083, 8820, 579, 17, 48, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[436699, 8842, 26, 0, 94, "Section"],
Cell[436728, 8844, 531, 11, 85, "Text"],
Cell[437262, 8857, 384, 10, 48, "Input"],
Cell[CellGroupData[{
Cell[437671, 8871, 72, 0, 33, "Subsection"],
Cell[437746, 8873, 116, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[437887, 8878, 541, 15, 54, "Input"],
Cell[438431, 8895, 2642, 79, 145, "Output"]
}, Open  ]],
Cell[441088, 8977, 117, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[441230, 8982, 476, 14, 54, "Input"],
Cell[441709, 8998, 3144, 94, 145, "Output"]
}, Open  ]],
Cell[444868, 9095, 163, 2, 37, "Text"],
Cell[CellGroupData[{
Cell[445056, 9101, 449, 14, 54, "Input"],
Cell[445508, 9117, 1568, 45, 95, "Output"]
}, Open  ]],
Cell[447091, 9165, 166, 2, 37, "Text"],
Cell[CellGroupData[{
Cell[447282, 9171, 439, 14, 54, "Input"],
Cell[447724, 9187, 793, 24, 98, "Output"]
}, Open  ]],
Cell[448532, 9214, 179, 4, 37, "Text"],
Cell[448714, 9220, 1696, 53, 115, "Input"],
Cell[CellGroupData[{
Cell[450435, 9277, 1022, 34, 81, "Input"],
Cell[451460, 9313, 206, 3, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[451715, 9322, 120, 1, 33, "Subsection"],
Cell[451838, 9325, 181, 4, 30, "Commentary"],
Cell[CellGroupData[{
Cell[452044, 9333, 404, 13, 54, "Input"],
Cell[452451, 9348, 323, 7, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[452823, 9361, 65, 0, 33, "Subsection"],
Cell[452891, 9363, 781, 22, 30, "Commentary"],
Cell[453675, 9387, 474, 15, 50, "Input"],
Cell[CellGroupData[{
Cell[454174, 9406, 97, 2, 48, "Input"],
Cell[454274, 9410, 208, 3, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[454531, 9419, 39, 0, 33, "Subsection"],
Cell[454573, 9421, 193, 4, 30, "Commentary"],
Cell[454769, 9427, 590, 18, 54, "Input"],
Cell[455362, 9447, 122, 1, 30, "Commentary"]
}, Open  ]],
Cell[CellGroupData[{
Cell[455521, 9453, 170, 2, 33, "Subsection"],
Cell[455694, 9457, 247, 5, 29, "Commentary"],
Cell[CellGroupData[{
Cell[455966, 9466, 2160, 60, 189, "Input"],
Cell[458129, 9528, 1828, 54, 137, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[459994, 9587, 101, 1, 31, "Subsubsection"],
Cell[460098, 9590, 218, 3, 30, "Commentary"],
Cell[CellGroupData[{
Cell[460341, 9597, 932, 21, 71, "Input"],
Cell[461276, 9620, 227, 4, 45, "Output"]
}, Open  ]],
Cell[461518, 9627, 120, 1, 30, "Commentary"],
Cell[CellGroupData[{
Cell[461663, 9632, 1020, 23, 71, "Input"],
Cell[462686, 9657, 410, 10, 45, "Output"]
}, Open  ]],
Cell[463111, 9670, 1031, 22, 86, "Commentary"],
Cell[CellGroupData[{
Cell[464167, 9696, 4247, 124, 528, "Input"],
Cell[468417, 9822, 667, 17, 45, "Output"],
Cell[469087, 9841, 667, 17, 45, "Output"],
Cell[469757, 9860, 667, 17, 45, "Output"],
Cell[470427, 9879, 667, 17, 45, "Output"],
Cell[471097, 9898, 666, 17, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[471800, 9920, 3682, 106, 395, "Input"],
Cell[475485, 10028, 99789, 1663, 348, 80132, 1339, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[575323, 11697, 149, 2, 29, "Subsubsection"],
Cell[575475, 11701, 212, 3, 38, "Text"],
Cell[575690, 11706, 902, 19, 76, "Text"],
Cell[CellGroupData[{
Cell[576617, 11729, 5002, 148, 516, "Input"],
Cell[581622, 11879, 667, 17, 45, "Output"],
Cell[582292, 11898, 667, 17, 45, "Output"],
Cell[582962, 11917, 667, 17, 45, "Output"],
Cell[583632, 11936, 667, 17, 45, "Output"],
Cell[584302, 11955, 667, 17, 45, "Output"],
Cell[584972, 11974, 667, 17, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[585676, 11996, 3682, 106, 425, "Input"],
Cell[589361, 12104, 97635, 1629, 354, 77087, 1290, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[687069, 13741, 26, 0, 94, "Section"],
Cell[687098, 13743, 587, 12, 85, "Text"],
Cell[687688, 13757, 402, 12, 48, "Input"],
Cell[CellGroupData[{
Cell[688115, 13773, 131, 1, 33, "Subsection"],
Cell[688249, 13776, 247, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[688521, 13785, 486, 14, 34, "Subsubsection"],
Cell[689010, 13801, 654, 20, 54, "Input"],
Cell[689667, 13823, 239, 5, 37, "Text"],
Cell[CellGroupData[{
Cell[689931, 13832, 127, 3, 48, "Input"],
Cell[690061, 13837, 388, 10, 71, "Output"]
}, Open  ]],
Cell[690464, 13850, 212, 4, 37, "Text"],
Cell[690679, 13856, 202, 5, 48, "Input"],
Cell[690884, 13863, 266, 6, 61, "Text"],
Cell[CellGroupData[{
Cell[691175, 13873, 2755, 76, 187, "Input"],
Cell[693933, 13951, 186, 3, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[694168, 13960, 401, 11, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[694594, 13975, 617, 18, 54, "Input"],
Cell[695214, 13995, 12365, 368, 461, "Output"]
}, Closed]],
Cell[707594, 14366, 211, 4, 56, "Text"],
Cell[CellGroupData[{
Cell[707830, 14374, 448, 12, 72, "Input"],
Cell[708281, 14388, 524, 14, 68, "Output"]
}, Open  ]],
Cell[708820, 14405, 239, 3, 37, "Text"],
Cell[709062, 14410, 305, 7, 48, "Input"],
Cell[709370, 14419, 199, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[709594, 14426, 962, 31, 131, "Input"],
Cell[710559, 14459, 117, 2, 68, "Output"]
}, Open  ]],
Cell[710691, 14464, 225, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[710941, 14471, 439, 10, 72, "Input"],
Cell[711383, 14483, 693, 19, 68, "Output"]
}, Open  ]],
Cell[712091, 14505, 276, 6, 37, "Text"],
Cell[CellGroupData[{
Cell[712392, 14515, 427, 8, 48, "Input"],
Cell[712822, 14525, 141, 2, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[713012, 14533, 450, 12, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[713487, 14549, 610, 17, 54, "Input"],
Cell[714100, 14568, 187, 4, 68, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[714348, 14579, 157, 2, 33, "Subsection"],
Cell[714508, 14583, 271, 6, 37, "Text"],
Cell[CellGroupData[{
Cell[714804, 14593, 1279, 39, 75, "Input"],
Cell[716086, 14634, 261, 4, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[716396, 14644, 39, 0, 33, "Subsection"],
Cell[CellGroupData[{
Cell[716460, 14648, 1222, 37, 78, "Input"],
Cell[717685, 14687, 1230, 37, 75, "Output"]
}, Open  ]],
Cell[718930, 14727, 203, 6, 85, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[719182, 14739, 26, 0, 94, "Section"],
Cell[719211, 14741, 714, 13, 109, "Text"],
Cell[719928, 14756, 285, 8, 48, "Input"],
Cell[CellGroupData[{
Cell[720238, 14768, 65, 0, 33, "Subsection"],
Cell[720306, 14770, 154, 3, 37, "Text"],
Cell[720463, 14775, 1246, 40, 81, "Input"],
Cell[CellGroupData[{
Cell[721734, 14819, 346, 12, 34, "Subsubsection"],
Cell[722083, 14833, 589, 18, 54, "Input"],
Cell[722675, 14853, 184, 2, 37, "Text"],
Cell[CellGroupData[{
Cell[722884, 14859, 91, 2, 47, "Input"],
Cell[722978, 14863, 345, 9, 70, "Output"]
}, Open  ]],
Cell[723338, 14875, 292, 6, 61, "Text"],
Cell[CellGroupData[{
Cell[723655, 14885, 393, 10, 71, "Input"],
Cell[724051, 14897, 211, 3, 67, "Output"]
}, Open  ]],
Cell[724277, 14903, 246, 6, 61, "Text"],
Cell[CellGroupData[{
Cell[724548, 14913, 5139, 146, 241, "Input"],
Cell[729690, 15061, 117, 2, 67, "Output"]
}, Open  ]],
Cell[729822, 15066, 508, 8, 85, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[730367, 15079, 299, 9, 31, "Subsubsection"],
Cell[730669, 15090, 454, 12, 37, "Text"],
Cell[731126, 15104, 460, 14, 53, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[731623, 15123, 527, 18, 31, "Subsubsection"],
Cell[732153, 15143, 624, 19, 53, "Input"],
Cell[732780, 15164, 116, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[732921, 15169, 118, 3, 47, "Input"],
Cell[733042, 15174, 2436, 79, 75, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[735515, 15258, 231, 5, 47, "Input"],
Cell[735749, 15265, 1800, 54, 72, "Output"]
}, Open  ]],
Cell[737564, 15322, 229, 5, 37, "Text"],
Cell[CellGroupData[{
Cell[737818, 15331, 310, 7, 71, "Input"],
Cell[738131, 15340, 185, 3, 46, "Output"]
}, Open  ]],
Cell[738331, 15346, 155, 3, 37, "Text"],
Cell[738489, 15351, 196, 6, 61, "Text"],
Cell[CellGroupData[{
Cell[738710, 15361, 3305, 97, 183, "Input"],
Cell[742018, 15460, 145, 3, 46, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[742212, 15469, 414, 12, 31, "Subsubsection"],
Cell[742629, 15483, 599, 18, 54, "Input"],
Cell[743231, 15503, 130, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[743386, 15508, 118, 3, 48, "Input"],
Cell[743507, 15513, 1237, 39, 74, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[744781, 15557, 208, 5, 48, "Input"],
Cell[744992, 15564, 900, 27, 68, "Output"]
}, Open  ]],
Cell[745907, 15594, 114, 1, 37, "Text"],
Cell[746024, 15597, 333, 8, 48, "Input"],
Cell[746360, 15607, 610, 11, 109, "Text"],
Cell[CellGroupData[{
Cell[746995, 15622, 2825, 83, 206, "Input"],
Cell[749823, 15707, 192, 3, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[750064, 15716, 564, 19, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[750653, 15739, 395, 12, 54, "Input"],
Cell[751051, 15753, 322, 8, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[751422, 15767, 375, 11, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[751822, 15782, 445, 13, 54, "Input"],
Cell[752270, 15797, 209, 6, 68, "Output"]
}, Open  ]],
Cell[752494, 15806, 142, 1, 37, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[752673, 15812, 109, 1, 33, "Subsubsection"],
Cell[752785, 15815, 122, 1, 37, "Text"],
Cell[752910, 15818, 931, 29, 62, "Text"],
Cell[753844, 15849, 300, 5, 61, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[754181, 15859, 37, 0, 33, "Subsubsection"],
Cell[754221, 15861, 247, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[754493, 15870, 2398, 76, 122, "Input"],
Cell[756894, 15948, 356, 6, 68, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[757311, 15961, 104, 1, 33, "Subsection"],
Cell[757418, 15964, 2191, 67, 152, "Input"],
Cell[759612, 16033, 199, 7, 132, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[759860, 16046, 26, 0, 94, "Section"],
Cell[759889, 16048, 816, 15, 109, "Text"],
Cell[760708, 16065, 586, 17, 72, "Input"],
Cell[761297, 16084, 120, 1, 37, "Text"],
Cell[761420, 16087, 2001, 64, 81, "Input"],
Cell[CellGroupData[{
Cell[763446, 16155, 461, 14, 34, "Subsubsection"],
Cell[763910, 16171, 599, 18, 75, "Input"],
Cell[764512, 16191, 188, 4, 61, "Text"],
Cell[CellGroupData[{
Cell[764725, 16199, 119, 3, 68, "Input"],
Cell[764847, 16204, 251, 8, 70, "Output"]
}, Open  ]],
Cell[765113, 16215, 149, 2, 37, "Text"],
Cell[CellGroupData[{
Cell[765287, 16221, 366, 9, 92, "Input"],
Cell[765656, 16232, 92, 1, 67, "Output"]
}, Open  ]],
Cell[765763, 16236, 229, 3, 37, "Text"],
Cell[765995, 16241, 248, 6, 61, "Text"],
Cell[CellGroupData[{
Cell[766268, 16251, 10811, 304, 414, "Input"],
Cell[777082, 16557, 115, 2, 67, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[777246, 16565, 371, 11, 33, "Subsubsection"],
Cell[777620, 16578, 488, 13, 38, "Text"],
Cell[778111, 16593, 394, 13, 75, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[778542, 16611, 566, 19, 33, "Subsubsection"],
Cell[779111, 16632, 595, 18, 74, "Input"],
Cell[779709, 16652, 188, 4, 61, "Text"],
Cell[CellGroupData[{
Cell[779922, 16660, 355, 9, 115, "Input"],
Cell[780280, 16671, 1572, 50, 93, "Output"],
Cell[781855, 16723, 117, 2, 67, "Output"]
}, Open  ]],
Cell[781987, 16728, 215, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[782227, 16735, 339, 8, 92, "Input"],
Cell[782569, 16745, 92, 1, 67, "Output"]
}, Open  ]],
Cell[782676, 16749, 228, 3, 37, "Text"],
Cell[782907, 16754, 206, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[783138, 16763, 10646, 288, 433, "Input"],
Cell[793787, 17053, 92, 1, 67, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[793928, 17060, 273, 9, 31, "Subsubsection"],
Cell[794204, 17071, 454, 12, 37, "Text"],
Cell[794661, 17085, 359, 12, 74, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[795057, 17102, 627, 20, 31, "Subsubsection"],
Cell[795687, 17124, 589, 18, 75, "Input"],
Cell[796279, 17144, 188, 4, 61, "Text"],
Cell[796470, 17150, 180, 5, 69, "Input"],
Cell[CellGroupData[{
Cell[796675, 17159, 249, 5, 93, "Input"],
Cell[796927, 17166, 1148, 35, 74, "Output"],
Cell[798078, 17203, 139, 2, 68, "Output"]
}, Open  ]],
Cell[798232, 17208, 349, 5, 37, "Text"],
Cell[CellGroupData[{
Cell[798606, 17217, 607, 16, 116, "Input"],
Cell[799216, 17235, 163, 2, 68, "Output"]
}, Open  ]],
Cell[799394, 17240, 602, 10, 85, "Text"],
Cell[799999, 17252, 201, 5, 69, "Input"],
Cell[CellGroupData[{
Cell[800225, 17261, 12147, 348, 623, "Input"],
Cell[812375, 17611, 230, 3, 68, "Output"]
}, Open  ]],
Cell[812620, 17617, 2221, 64, 132, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[814878, 17686, 533, 18, 32, "Subsubsection"],
Cell[815414, 17706, 587, 18, 74, "Input"],
Cell[816004, 17726, 122, 3, 61, "Text"],
Cell[CellGroupData[{
Cell[816151, 17733, 184, 4, 68, "Input"],
Cell[816338, 17739, 273, 8, 70, "Output"]
}, Open  ]],
Cell[816626, 17750, 139, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[816790, 17755, 411, 11, 92, "Input"],
Cell[817204, 17768, 92, 1, 67, "Output"]
}, Open  ]],
Cell[817311, 17772, 210, 6, 61, "Text"],
Cell[817524, 17780, 100, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[817649, 17785, 2614, 76, 177, "Input"],
Cell[820266, 17863, 119, 2, 67, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[820434, 17871, 522, 16, 57, "Subsubsection"],
Cell[820959, 17889, 599, 18, 75, "Input"],
Cell[821561, 17909, 294, 6, 85, "Text"],
Cell[CellGroupData[{
Cell[821880, 17919, 186, 4, 69, "Input"],
Cell[822069, 17925, 461, 14, 68, "Output"]
}, Open  ]],
Cell[822545, 17942, 258, 5, 61, "Text"],
Cell[822806, 17949, 215, 6, 69, "Input"],
Cell[CellGroupData[{
Cell[823046, 17959, 4711, 136, 405, "Input"],
Cell[827760, 18097, 335, 5, 68, "Output"]
}, Open  ]],
Cell[828110, 18105, 124, 3, 37, "Text"],
Cell[828237, 18110, 118, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[828380, 18115, 217, 4, 69, "Input"],
Cell[828600, 18121, 142, 2, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[828791, 18129, 527, 14, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[829343, 18147, 487, 15, 75, "Input"],
Cell[829833, 18164, 116, 2, 68, "Output"]
}, Open  ]],
Cell[829964, 18169, 207, 3, 37, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[830208, 18177, 544, 15, 34, "Subsubsection"],
Cell[830755, 18194, 703, 21, 76, "Input"],
Cell[831461, 18217, 181, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[831667, 18225, 371, 9, 116, "Input"],
Cell[832041, 18236, 1129, 36, 71, "Output"],
Cell[833173, 18274, 117, 2, 68, "Output"]
}, Open  ]],
Cell[833305, 18279, 118, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[833448, 18284, 385, 9, 93, "Input"],
Cell[833836, 18295, 119, 2, 68, "Output"]
}, Open  ]],
Cell[833970, 18300, 260, 5, 37, "Text"],
Cell[834233, 18307, 9998, 284, 488, "Input"],
Cell[844234, 18593, 222, 4, 61, "Text"],
Cell[844459, 18599, 3520, 99, 181, "Input"],
Cell[847982, 18700, 282, 5, 61, "Text"],
Cell[CellGroupData[{
Cell[848289, 18709, 1077, 31, 139, "Input"],
Cell[849369, 18742, 186, 3, 70, "Output"],
Cell[849558, 18747, 186, 3, 70, "Output"],
Cell[849747, 18752, 186, 3, 70, "Output"]
}, Open  ]],
Cell[849948, 18758, 170, 3, 48, "Input"],
Cell[CellGroupData[{
Cell[850143, 18765, 189, 4, 48, "Input"],
Cell[850335, 18771, 117, 2, 47, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[850501, 18779, 563, 15, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[851089, 18798, 396, 12, 75, "Input"],
Cell[851488, 18812, 116, 3, 68, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[851653, 18821, 101, 1, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[851779, 18826, 3220, 102, 132, "Input"],
Cell[855002, 18930, 214, 4, 68, "Output"]
}, Open  ]],
Cell[855231, 18937, 218, 3, 48, "Input"],
Cell[855452, 18942, 2153, 67, 83, "Text"],
Cell[857608, 19011, 406, 7, 48, "Input"],
Cell[CellGroupData[{
Cell[858039, 19022, 1270, 36, 110, "Input"],
Cell[859312, 19060, 70, 1, 68, "Output"]
}, Open  ]],
Cell[859397, 19064, 793, 19, 60, "Text"],
Cell[860193, 19085, 1100, 30, 60, "Text"],
Cell[861296, 19117, 1600, 49, 86, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[862933, 19171, 104, 1, 33, "Subsection"],
Cell[CellGroupData[{
Cell[863062, 19176, 335, 6, 46, "Input"],
Cell[863400, 19184, 481, 7, 45, "Output"]
}, Open  ]],
Cell[863896, 19194, 179, 3, 46, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[864112, 19202, 142, 2, 32, "Subsection"],
Cell[864257, 19206, 144, 3, 36, "Text"],
Cell[864404, 19211, 4139, 122, 302, "Input"],
Cell[868546, 19335, 97, 1, 36, "Text"],
Cell[CellGroupData[{
Cell[868668, 19340, 5136, 119, 311, "Input"],
Cell[873807, 19461, 2199, 67, 118, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
