(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    620806,      15046]
NotebookOptionsPosition[    600944,      14414]
NotebookOutlinePosition[    602629,      14470]
CellTagsIndexPosition[    602586,      14467]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Large-scale linear instability of the generalized Kolmogorov flow with \
modified viscosity\
\>", "Title",
 CellChangeTimes->{{3.426488624721015*^9, 3.426488641967429*^9}}],

Cell["\<\
Bernard Legras
Laboratoire de Meteorologie Dynamique
Ecole Normale Superieure
24 rue Lhomond 
F-75231 PARIS Cedex 05
E-mail: legras@lmd.ens.fr
Barbara Villone
Istituto di Fisica dello Spazio Interplanetario
Corso Fiume, 4
I-10137 TORINO
E-mail: villone@to.infn.it \
\>", "Author"],

Cell[CellGroupData[{

Cell[TextData[{
 "Smagorinsky-Clark mixed model + friction\nU = A Sin[\[Theta][y]] where \
\[Theta][y] = \[CapitalSigma] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Theta]", "^"], "p"], TraditionalForm]]],
 "Sin[2 p y]\nStreamfunction defined as u=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", "\[Psi]"}], ",", " ", 
    RowBox[{"v", "=", 
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", "\[Psi]"}]}]}]}], 
   TraditionalForm]]],
 "\nCalculation are done in terms of U, not expanding in \[Theta][y]"
}], "Subtitle",
 CellChangeTimes->{{3.424787302076682*^9, 3.4247873135143347`*^9}, {
  3.424925305512432*^9, 3.424925344925313*^9}, {3.426488715370364*^9, 
  3.426488720705675*^9}}],

Cell["Settings", "Text"],

Cell[CellGroupData[{

Cell["Last use", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateList", "[", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.435142938876382*^9, 3.435142940064369*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2009", ",", "1", ",", "14", ",", "16", ",", "32", ",", 
   "21.058743`8.076007427942763"}], "}"}]], "Output",
 CellChangeTimes->{
  3.405677748643395*^9, 3.405686657448234*^9, 3.4056866994312477`*^9, 
   3.405686742241375*^9, 3.405702624881482*^9, 3.405702770362739*^9, 
   3.405705708691693*^9, 3.405705842636776*^9, 3.4057532634380817`*^9, {
   3.424925507282484*^9, 3.424925519976899*^9}, {3.435142942553712*^9, 
   3.43514294828263*^9}, {3.440935935668371*^9, 3.440935941076385*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["General", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laplacian", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]", " ", "=", 
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "X"}]], " ", "#"}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], "#"}]}], ")"}]}], "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Epsilon]", "2"], " ", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"X", ",", "X"}]], "#1"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], "#1"}]}], ")"}]}], "&"}]], "Output",
 CellChangeTimes->{3.40567775505799*^9, 3.4056866581610813`*^9, 
  3.405686699606001*^9, 3.405702625144552*^9, 3.405705709097206*^9, 
  3.424925508353436*^9, 3.435142942723406*^9, 3.440935935860435*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Definition of the turbulent viscosity, Smagorinsky-Clark mixed model\
\>", "Subsubsection"],

Cell["\<\
Standard version with a heuristic component accounting for the vertical shear\
\
\>", "Text",
 CellChangeTimes->{{3.405677175227804*^9, 3.405677198572053*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["S", "_"], "=", " ", 
  RowBox[{
   RowBox[{"\[Sqrt]", " ", 
    RowBox[{
     RowBox[{"4", "  ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"X", ",", "y"}]], "#"}]}], " ", ")"}], "2"]}], " ", "+", 
     " ", 
     SuperscriptBox[
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Epsilon]", "2"], " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"X", ",", "X"}]], "#"}]}], "-", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"y", ",", "y"}]], "#"}]}], ")"}], "2"], "+", " ", 
     RowBox[{"\[Mu]", "  ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", "X"], "#"}]}], " ", ")"}], "2"]}], " ", 
     "+", 
     RowBox[{"\[Mu]", "  ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], "#"}], " ", ")"}], "2"]}]}]}], 
   "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], "#1"}]}], ")"}], "2"]}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Epsilon]", "2"], " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "X"}]], "#1"}]}], "-", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], "#1"}]}], ")"}], "2"], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "X"], "#1"}]}], ")"}], "2"]}], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "#1"}], ")"}], "2"]}]}]], 
  "&"}]], "Output",
 CellChangeTimes->{3.4056777606307793`*^9, 3.405686658761257*^9, 
  3.405686699718836*^9, 3.405702625178161*^9, 3.405705709307059*^9, 
  3.424925508676807*^9, 3.43514294281516*^9, 3.440935935961832*^9}]
}, Open  ]],

Cell[TextData[{
 "Dissipation: C in front of the Smagorinsky component, D in front of the \
Clark component\nIn standard notations D=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[CapitalGamma]", "2"], TraditionalForm]]],
 "/12 and C = C",
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "S"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[CapitalGamma]", "2"], TraditionalForm]]],
 " \nNote that K=-DS in the paper"
}], "Text",
 CellChangeTimes->{{3.428922904874752*^9, 3.428922909124525*^9}, {
  3.428923528582487*^9, 3.428923532461954*^9}, {3.42892472353675*^9, 
  3.428924736332754*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DS", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"C", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#", "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"y", ",", "y"}]], " ", "#"}]}], " ", "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}], ")"}]}], 
       "-", " ", 
       RowBox[{
        SuperscriptBox["\[Epsilon]", "2"], 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "X"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            OverscriptBox["S", "_"], "[", "#", "]"}], 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"-", " ", 
              RowBox[{
               SubscriptBox["\[PartialD]", 
                RowBox[{"y", ",", "y"}]], " ", "#"}]}], " ", "+", " ", 
             RowBox[{
              SuperscriptBox["\[Epsilon]", "2"], 
              RowBox[{
               SubscriptBox["\[PartialD]", 
                RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}], ")"}]}]}], 
       " ", "-", " ", 
       RowBox[{"4", "  ", 
        SuperscriptBox["\[Epsilon]", "2"], 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            OverscriptBox["S", "_"], "[", "#", "]"}], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "y"}]], " ", "#"}]}], ")"}]}]}]}], ")"}]}], 
    " ", "+", " ", "\[IndentingNewLine]", 
    RowBox[{"D", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], " ", "#"}], " ", 
        RowBox[{"(", "  ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]", "4"], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X", ",", "X", ",", "X"}]], "#"}]}], " ", "-", 
          " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], "#"}]}], ")"}]}], 
       " ", "+", " ", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"\[Epsilon]", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "y", ",", "y", ",", "y"}]], "#"}]}], " ", "+", 
          
          RowBox[{
           SuperscriptBox["\[Epsilon]", "3"], " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X", ",", "X", ",", "y"}]], "#"}]}]}], ")"}], 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y"}]], " ", "#"}], " ", "-", " ", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}]}], " ", 
      ")"}]}]}], " ", "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"C", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"y", ",", "y"}]], "#1"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "X"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"y", ",", "y"}]], "#1"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], " ", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}], ")"}]}]}], "-", 
      
      RowBox[{"4", " ", 
       SuperscriptBox["\[Epsilon]", "2"], " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "y"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y"}]], "#1"}]}], ")"}]}]}]}], ")"}]}], "+", 
   RowBox[{"D", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "y"}]], "#1"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Epsilon]", "4"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X", ",", "X", ",", "X"}]], "#1"}]}], "-", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], "#1"}]}], ")"}]}], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y", ",", "y", ",", "y"}]], "#1"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "3"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X", ",", "X", ",", "y"}]], "#1"}]}]}], ")"}], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y"}]], "#1"}], "-", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}]}], ")"}]}]}], 
  "&"}]], "Output",
 CellChangeTimes->{3.4056777628958063`*^9, 3.4056866596465693`*^9, 
  3.405686699838736*^9, 3.405702625649367*^9, 3.405705709731844*^9, 
  3.42492550945588*^9, 3.435142942912438*^9, 3.440935936184273*^9}],

Cell["\<\
Reference
Pope, S.B. Turbulent flows, C.U.P., 2000\
\>", "Reference",
 CellChangeTimes->{{3.405677233198999*^9, 3.405677274407757*^9}, {
  3.4056773690199203`*^9, 3.405677391583219*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the generalized Kolmogorov Flow", "Section",
 CellChangeTimes->{{3.426488677906436*^9, 3.426488686529616*^9}}],

Cell[CellGroupData[{

Cell["Velocity and streamfunction", "Subsection"],

Cell["U[y_] := A Sin[\[Theta][y]]", "Text",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "y_", "]"}], ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0.", ",", "y"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exemples of flows ", "Subsection"],

Cell["\<\
Standard Kolmogorov flow in Flow1, \"flat\" flow in Flow2, intermediate case \
in Flow3\
\>", "Text",
 CellChangeTimes->{{3.405677494754274*^9, 3.405677541094836*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Flow2", "=", 
   RowBox[{"U", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"#", " ", "+", " ", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"Sin", "[", " ", 
          RowBox[{"2", " ", "#"}], "]"}]}]}], "]"}], "&"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow1", " ", "=", 
   RowBox[{"U", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Sin", "[", "#", " ", "]"}], "&"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow3", "=", 
   RowBox[{"U", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"#", " ", "+", " ", 
        RowBox[{
         FractionBox["1", "4"], 
         RowBox[{"Sin", "[", " ", 
          RowBox[{"2", " ", "#"}], "]"}]}]}], "]"}], "&"}], "]"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.424925402751207*^9, 3.424925448951906*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the flow", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405677785746386*^9, 3.405677789463428*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtmnk8VN//x61F1pmxU6JI0p4+JTmXUNmVUJFShESLpJSyZEtlKdkiIlmy
L6k4105SlC37voyZOXZjbL/7fTx+/8w8no/7uPe836/3633Ouedx5Wxdz9hx
sLGxlRE///vXOy14YllOEm94q/trSDVM41jhoymeLZJ4n768jGSEK1CRm3wn
JiWJb9DUHa0KfwIEl2qZ+8mSeLPuGrtd+CvQ/Mk7y4FDEn8rN0u3DksAljzz
km2DErh12UVerxfZ4Hpt11TOBwlcL+PwdVkvCPx00uLtFSTwqIdW5f3Yb3C7
hUWOoIjjqv8Kcm949IHIM8YXXguJ434vC/25cvrA96YPiW/4xHEb3Vn4eKwP
bGg02BfFKY6P/beI8ezqB3HV8YbvZsVw/e17Ezqi+kFdkVZg6l+CpfloFrcH
wJbo4NVvEWL4HXdvDVHRIaAt3qdd+koMX7Xc8zp/zxBwfHMwpOy5GN5d41Sr
cWoIFIR1S5X7iuHpiyWXpT2HwOngPUdq7orh9ID1aGrfEHDz/HOn6awY3n9/
RLMhZRj8sJYaH6aI4WNTt69Q5UaBcYI6YAmJ4YYFvMLeR0ZBS/+lSCF+MZyP
q/IWh/Eo6Ln6QVuNSwwvbLeZqfIcBVOOKomv5kRxMYpygm7LKBB317ig1iqK
351OVFb2HgPXXtr+fBUpisvtxKsH68fBxG+/bSnhonjY9Uyf1J5x4EJKffj1
pShexfJ2MJseB/dfTyqN+IvizMfPr9pLTIDgGLdnavdFcZMbofyOdhMg56O/
xoiFKF4kbi7/jzUBVsvSc9QkRXF/X8/5cfIk+Nm5l39ZRBT/+6xGmbl9EsQt
FFz/JiyKk34+wccPTwL1PXCLOo8ofovvxvebFybBw3d/Q44viuDfTq3Vcr2f
BAueKw5Yqwi+71PFXnMFGqh5613F1iyCL1ulHrujSgNv8jdsLf8pgqtffe3m
okMDhyaF2zWrRPDA6ECFjXY0cPeCgs6JfBGcGVwdUZxEA1NHjOR0w0RwbRY5
iluCDnCzv482vBDBo5wyjWUU6eDVLcuOmkAR/CGzYTv5EB3s+WT76uRTEVxO
vnI8xpgOborfXz3lKoIfnCjbIfuMDqjzCf/0DUVw/fCjXiMTdPCVpKDKf1oE
V2sXWBudp4Og3emhP7VFcOGF5ZwadgZQsis4aagugut1FD3cKskA9i11hUa7
RPCJmpW96roMMJQ3HWbKK4IfLXt1gDeGAeI2sHwucIvgWZ+Cr2EfGMD8Aofb
VXYR/MJoquf5TAaoY6eY31ui4PS4ZNX9ZQyQZXJIKnqCgqfJJo3c62eA68nq
fEkjFPzGbJfBt3EG2MrUXkkfoODRj2fMBqcYICLhXO/3fxR8IL5uRysbAh4M
96T+egquuFlp3UAWgf1aTyImqik41+KziHhFBKhvAvxmyin4Ipx63rwbAevj
UfZcXyn43UAY0nUMAa2QEmWldAr+a3uM0BNzBJb7yqX3f6TgWnojXF1WCBQc
/MGvlkTB+61mlCSuIrCjq5OhH0PBn2+ZHFZ1RYBfeSXPNZiC39faEbj2DIHq
x1zJHv4UfEjFy+jqcwS8mvnfePtQcKW+HtG0UASmPTbfj3hIwY06ZSLaYxBo
q9U4VuxEwSUzecvgZwRCpU+q4PZEPlpaHCp5CJx2Nd5cb0vB/cKvyz0oQuC7
2OX1zgsUnFs6u6+wDIFEO+/KNT0K/szhGv1LIwIXSoIKNp4k4jO0id7VjICI
QHiK8AkKHni2mf1JCwL+BUkB8scoeKTIjuXaTgQwngyPXf9R8PKmnmelPQgs
Xcx3PHSQgu8rysUj+hFw5qzS191FwXdbpR0bHEFAweKnuvEOCi6nGel+YRyB
3vSW3ZbbKDh4d8Ain4pA1Fr3liuyFLyCY18XjYaA6ZkRISdpCk5tucS2ESGw
6SOd7a44Bd+sl1XFPo1A1dL8tCeFgs/eVFHsmUHgcOKGlhd8FPywQkCJ6gIC
ar9v12tupOBrb7bZNS8ioLHaXTbPQcFtZy6pnFoi6rfrVEHaGhmnfwkUiGEh
oHs+P82aRcYPr0ptrF1GQC9gSwJpgYynOn4V/72CgFFh0OvqaTLOp3lYI28V
gTNDc0EP6GScahP44NYaAhaky092T5Bx/HhrHe86AlagwW1gmIzP0W/s8iL4
8s3DTm/6yXjy1pr3jQRfi020Od1NxrW3BSoxCXao5z+32k7GuQaeVqwS7Lx4
Xy/3LzHeUJpLL8G3FIaA3W8y/sRkx+4Ygt3OGqlKNpBxS8bJtX0Ee3iXKDfW
kPGNss8Gk4h4HmVv3+pdQcYnB3w6ERHv055XoqplZPz1H6ExcYL9+JY3TZSQ
8aYdCrzSRH6BR+3Z3hWS8bC8Uc0lQo+Q683zJrlkPKY7KTyP0Cv0jfok12cy
vvLxz4ouE4HXlan9Xz6RcbtPkj5FhN5R0+Q252QyfpRPdzv7PAJxsl4NW9+T
ce/nJiOKswi8N5zAW2LJeIKbVe0Oon7JnmZFgW/JeHd88U9Oor6f0mCGegQZ
/+bcufiVqH9mu3Li1EsyLld3Xd+Q8EcOd2RkcjAZ15Pd/ePrGAIlV5y9+X3I
+NSy47kdgwiUvWp3xx+T8YBWEwfFPgQqSrWc3R6Q8U/6Rvls3Qj8kJS06L5F
xudLNNhOtiLw66SfQagzGd/8do43n/D7n3tIU9uB0KNZ9yKL6IfO5mqVTBsy
fsFFYlSqhvDr+j75yxfJeFnRZ6W5cgQGd8eJi1iQcRNZvupPpcR8EXSH45ER
GTf0lpZNLkCApSnboX+cjPPUfqcPvUdgzTW4cf0IGY8UehMeFYsAR/x8Rf4h
Mh4d8aBUKZLwN6vhs7QKGV88nl7WFYyAdJ6H76QUGT9WnqP04g4CW/uHPBLE
yHhfyo+iLc4IbBc0djlLJuPV+V/ZQ+wQUHFSOP+Nl4zfy42nLVkgoC7/Z89z
Jglni9w2v42Yr95T+A6dnSPh4k17x4oPIsDJrX1UeoqEvwk33b5ThdBnrPBE
xhgJnwiLS/wgg4Dl52jLhjYSvmK9593SMgO4Hbniw1dIcJFq6f4CBujYGRPw
N4eEayZ5psSnM8Ax6b8hsZkk3C3Y/PbEewbgWNN+uyuZhOvHyPdJvGCA0Eql
TP0IEl65q0yv/yoDZBpNtT6/TcL3nuSIleZjAGFsZ9fZmyT8dw19i/M6Hdzd
b9sv7UjC9z3s0o6dpQM1kRZqxmUSbrbslvGmiw7q/hWvNxiT8N7e71YraXQw
fO3JTv49JDx1s0HYO4wOZDwFH4dQhfGzrf21UedowDH5h/i7UWGcvY89Z0KX
Booa/fM+DwrjQvvF1WSP0IDp1vWxX53CePQ3z5tHpGjAvxqdITUI4/lzj8a3
90wCJNSsFJkhjG9J6Qaz1pOgIjmiJcFZGG+A37X/6lOB0C9j1xwHYXy5ukO2
7SgVWC3ybSq/JoybBkhEwx1UsHjaDwxaCeOITT5Tl5MKVJBb+nZDYVzjboj2
jpIJ8Oao+dO03cL47/A8Ia2tE6Apbr+lfY8QHmWcdv9K9xhgS3aN7GkRwuWY
KnWvq8fAvozPLWY/hfCmmxp8n7PGQGjJTtMT34TwW5duNoc8HQMmbXJ6W6OF
8MEPVoB/2xhoEiKrd5oJ4T1ur4Tkr46CJp8ZWaOfgvjZfTjLqWkY/HbIH1P9
JoALTDKO/rMbAB93Nh8xKeXDDwZLnMt61AL2xTTdulPPi7+1v6QzOV4A5PYd
7xTL2IhvoV7VbzOohdSvOtwbcrnxwQBFnbM5nTAjrPjH3U/ceELF3uhIRid0
dtgZOpDAjSu4T3F8U+mCdFEB6dKX3Pg/xeuslE9dcOpWyz43Z25cs+tLwUp8
N1xQvGo1uIMbn72v+9n1WS/kiHiaXxbPhavzeR2olB6AlY4zHiqRXDhHz92X
eUcGoB92TSPmBReemfxZ4eW5AcjNOFl/7xEXbrnV15v31QDkOS3Up3KBCze8
3W4mwD4IBdffbYoV5cI7nqiMqwwMQukb367cD+HEX159mkMLHYYxdXW6An6c
eFoM28v09GEopdi264MnJ+6w4vLStIrggan5X06ceIpFhv+FxWEoYaEYrHia
E5c4boCdsxqBIifC8lq5OXE9sVfBrXKjkF/6OuehJxy4aH/nM+2YMRji4TZe
786B7yw3qJjOGYN8bd6NNi4cOElGvN6vdgxuCot7+9yaA7/NojVfnBuDPBv/
7Bo6xoHb6wTINBiMQ+5ZdbNwJjuuUf7tXDRzHK79IKdM3WbHbb9ffm5yjApN
oxQLxZ3Y8dPrL7Q1DKkw2U6tWsOWHadWjmaRbahQj812JOQMO37PNeKMqw8V
RqrmKuw8yI6f9Hq6PF9LhbvfG3+8MseGj7L3myobTcKnN68WBdLY8FnPsVOe
lybhH7X7NdnDbDjn3X3UXJdJ6NEaP7rawoavbzpK//1yElZtYijGFLLhlh1v
dBsbJ6HVvZDUP+5s+KLQDkVclwaztd4XL7mw4b4MhbRr52iQQ7igdut1NrxW
s3mcfpUGP6V3jblYsOEPVs3ss57S4FyfshLfETZ8JHuiY+QLDYoRE1fAzDoU
U+Ciym+nw7uA38xxcQ2mb1JMezxCh9on4LOro2swqHLoVeg0HYqdvFNs3boG
u3Nbw7xX6fCLUYfUmfw1WOxxI3dVhAFXrJMH1FzXoHHtJYaVFgP6PVJ35R9b
hbKXdcwzIxnw3FP0fkPbKhTs+MqIec+Ain5Jf9iqV6HiX61u+3QGrHvOc3g+
aRXKBJoHR5YyoEBsy0rPpVXoY1LKbTbIgJElzsHZbSvQzSfutYYCgtdLZb+n
Va9Ad+XWxFUVBI+U/6F/KFiBjJQjdtGHEOysO2IaFb4Ch4+p0uxPILilg0vC
22gF0qdKKOdtEERdxac9j69An6HRiRU7BPE+J897Kisw1O+r6mNnBG3Hmnod
N63A9BxBEuUBgqkLcSlnapbh5O7T5IhQBD1Yxu0GhcuQP/1Wk2QkgnprHLwn
k5dhmWR946NYBGncjs7HfJahbGHzzfYUBEt5ZeJVby9Dzsh6rt/pCL4U+P17
7+VlqDDoXZmUjeA+UdWD2zWW4cRJ76TeLwiyS45f27J7GTZlmH3RLUXwj0xs
pITMMjwrzT4QXI6g23Z2Fj+LBa27v1uk1iP45WAjPl/IguOlL6z3dRDPE39x
ivyRBU+G/MvR7ELwE8ugaU8kC6pTZWIO9iIYVf6z77o7Cx5/zretZAhB4ZSQ
6372LGg6ol1qMIpgYKABem/OgnYc4YP4OIL3jX+u/TvMggKdHVV6dAQZB0L8
FxRZcPiv5ePLCEF7MQNBijgL5lCWis2nEexd4ovcu5EF/1r8uLN7FkHznobN
BotLMMRlJWN4DsFf+PMUh7El+P2/3iuPFhDUTdbf/ax9Cb752BM+t4hgWQBf
YWLtElSoDDhuuITg4RsN6mXFS7AqI/CyPwvBLKPnVZ2pS9A2MoOVsIyg4gF9
g8W3S/Bbc+emmBUE40X5WiiBS/BajWyo2yqCYks/Lu7zWILli0lBe9cI/buD
hwwclmAnV+bCD4I34Ho3HC2XoFBaYpvuOoJeHzbNPju1BHO/8+78QPC8/4+H
SUeWoIdqEL2PYGenYA6otAT7FIe3EftNOGyoF9wlsQQvV6w2sAi22r+JzOQh
8rXoGOkguEXkR7TIEhMKmL25/ZZgA2aQ3P4JJvQ9cc/1MMFVXafTDP8xoc7v
9r5CIh51yLvfqZ4JOcuOVYoSXJBU/8W/hAlPz2pImRP5qPgHYR/SmLDfJX7E
ncg32fF0HYxmQmmDw4oehB4yhrwm3UFMOIez95wn9Hq9r76d+YAJt2yW5pMh
9OQXCbIRdWLCibpvuWWE3n6Lp8b2X2BCQW31P5pEPe6W1S04qTGhlkin/8QM
gtTEQK8AZSbUbT6xRZCor+2zUxuSpZjQSFnxMIWo/xmDOtEe1iJk/XcClVER
/LE38N0SdRF6NVW8tiP8o0U5pSDWtQhf1GlX0kYQPNBZe8j42yJ0Wd1THdeP
YHppwPcbGYswy7zlXXUPgvKJJ7UDYxfhzhMLvL87ESQ51J4t91yE5Wten3xb
CH/qB3T13FiEB5qkBvY0I8i29+RV1sVFeP3gu5KvjQhOzdfcOahOjLdVxNKt
BkGHf/4sY5VFWLdPVSGpAsH+77o+zjKL0KjjzfucMgSbfGvCUlYW4MlfFbmu
RQhmk2pyxEsXoJmRTp57MpHfJZJef8YCdLU5ZaaVgOBCutXQp5gFaHPS+vxE
NFEv7VlRNY8FmLgjI6X+JYJ17ls9rQ4uQOkvCWt/3RG8UXlDREGeeJ5Ys6vn
LQQFhYs/04UXYNPu4w/XHBE0SzPs92LMw5+UFY+3VkR8XQ91EtMIHqxhiWII
+irV9DpGzUPXUUtS7BHC7/dIHgcC5uHvT+3sK/sIPwp+Sq+8Ng+zVUmvTeUQ
ZGKtQqOy83CvcZOXARuh38e9ncqRc3Dr5RW24GIGLJh5eHfWbw5W+Tofav7M
gJaghv/73TlYSns4OPeBAeM7rICh6Rwkhep2N79iQGW+4GRX/jkY53IpdMiO
AbVuDbsU+MzCo3eqft3iY8CR73t5Ht+ehVe/RNk8W6fDQF7PRJ3Ls7DZ+d+h
+7N0+CuJ1NJ2fBaWG7wbnumkwwutGkeXmDMwkb1/Qv8Tsf6oRXNquM7A2pS8
iDB1Onz9Wrrb/NIM/Px0q1LlHjosYLwrcDWcgV/Hfyq3bKXDhaQku8RdM1DU
9WjJay469ODLrOUan4bpHwqLwn7QoFd32fOGy9OwxG42JMiEBgO9hinnz0xB
ld1/Cqnak/BThz3ttuYU1FxiH1c+OAnrD0xUBe+bgtM/p8oM5CbhpjH6ve+C
U/CD2XS66ioVSiUwsgExz+f3KOTF51OhgqbIkcYABqQr67zvk6JCtWc2p8ad
aPC75oHfBX/HYT3zccolfRo0FegfqYDj0NI5jqN1Fw3WhIbOfMkYh/fO/vte
TpuElzfTjln7jsMcubP7Y4l9wMVtmoWB+8fhjjJdKaM7VKLvLCsfBY1BkcXd
tPwH45DKZTbtqDQKkcPKqyeBwzAtYvnw9h1DsCVrv7CR/TDc6a7aVcA3BL/O
2YfKaA/D+bnb+N6pQej3tDm0ZH0IFpl/axj+Mgiloj6GzboPQRc9p4vGpweh
dq1JxHW7QZgeu9lay34ARimkRBpr9cO36jqHebf1Qd+qWDXAbIe7v6iZNji2
w7Zv6lXpnDj8236/cX4aQhsV3VWzsDIQf2iaH/cqAwOnLM+5xHcAE/YnFQpc
HUBj5NGVxp4OsNH4glu7RgeI8U68qbL5H8C+lly+/aADnPlKfUaN/QciN+px
WjM6QMWux0X20Z2gXrpGRaD9H0gSTBK3ed0NrvcK6SV86AIHqPO0HTr9IOfX
ehm7Uh+YywbZEseGQYXjZDZ1fBD83HWMfMt6GJQ8zl+K4BoCH1IP36t9Mgzu
WzhY7dg6BM4k7D7mXjUMLNAnOp/FEMh9KV3713AEcOq+/FlXOQRcbi72vrw8
Ch7oXjq6EDUMxpSzBbn9x8GpLcNq+vtHQdnH9NtWn8ZBgo6S5MrpURAp/7El
/8c44JCf1I+wHQW6Uu9ibIUmwFm9iuNuEaMgmfe5Ih41AS5akDRXZ0fB5XF7
Dc8MKtgfdCCOkjMGOlO2uEw30YCVMMqKpEyAog2ZZz7N0IBm244rD5UmQMT1
o//ZiNBBxi8TRa3jE8BgpxlbowUdNB01evHYfgKUZQaFf+qlA6ZGjXFi8QRI
zJ8rsqExQN9AsEyQGRUUXB5ZH/WdAqMxpZLaHpNAnqRyp+L1FEj14xl4EjQJ
QsvvDL9LmQISE+ri72ImwU15tnqz2imgrxrg5/l9EigOS4VXbJoGLxOkLGrW
JkHUdZPt8WHTQP9QyZTvYxrwdPl26lzCDJA9frRM8SodaIH5a4LZM8BrtNMn
2JUONgnv9a4tmwEDEYGdzZ50EJWbVHK0dwYUhxVS+F7TQdFckPKWzbNgzlHa
QbGSDmYeWvKPxcyCyU3kHwvSDPBVP1zpffos8GvZcPOlIgN4y/zUPv91Frx8
qD/Ds594/y0Djxv+zYIPyfaeH3UYYA/7Dka2xBygqT6563OTAZwC5n97RM6B
rYWzBYXFDHDAci9t/8c5YNd2f8UdZ4AlJUeeycI5YGiWESZVzwCBP7ox69Y5
cN6y15enkwE+ClTlaorMg42vULIXiwFcelcbWdvmwbhEorspBwKq2f9R8w/O
AyMeJ/MNmxCoMsmQVzw7D0QtY+TFJBGRd3jEpvB5ULd0aHujKgKfrv3Mrkyc
B/XZb+Oy1RG4pbrh56PcefDdroB69wQCa20PuFDTPCgIFGUkmiAgI3Xl3l+h
BZCSlTkQ7ojAMDUmLER2AQR+PG3h64pAxreWzzp7F8AHu+e3z91DQM361Gix
0QJoyY5/HP8UAcv3ey3iXiyA+cxO68o3CMxt7L2SFr8A6jO6W5RjEQh1DXEu
yl4AQsxBe5f3CNRrTHg3NS+A5oRjVUHpCNh/fBvSM7gAil5R/K5kI8AhqPuW
OrsARjmWT4oWEOP1JGVyiS2CssWqGuFSBNq0TYtJOxaB4fLd+5blCNzJXC/f
cmQRBIU1iD+qJuL1tGo/cmERhP37LWLR+L/8xDhuxi+CPpdk/4tdCHzxruJ/
mL0IYninj/r0ImA2cUc8AF8EpV613/wGEHjx5bdK4uAiMB16uXnzGALKW73+
y5pdBGoSCot5EwjUBKhofeNigpySV+HbaYSe5kEWrYpMAD2mOWOnEIgp+892
8D8m4NnW3pLwv/NPxVFndIoJ2M67WD+dQ+DPi9f3V84zgYjNm1j1BQRc5rV8
eG8wwaecsy9aFhHYZD0dIvaICSw4Ovf97zz0Y1XC220viPu1ffzeshDQUjFK
2hfPBClJv/0rlhHoi1jJPJ7NBDLBLofrVxB4tJxerIczQdjHQ+EZqwhIXD1f
YdHMBO0jW6Md1xAo+LGx8dogE7z0uKjHuY6AyYGi9tuzTCDxVzXFg2Ba9LVB
L64lYJ2lnFZPcCA7hf5cdAnY8fSeWyB4u2P5YpTiEoDbN2esEYw3uXJ8/G8J
fAvp/TT4v/PVI1sE8k8tgXtCWsZJBDMTforj55dAbnlo/HGCX2/0lG90WgIB
q+pvC4h49rvu3N3puQQGrgwe3Ujwr7b2/8ZClkBjs06AKhG/k4a/1ty7JRBz
99xTQOS34eMhQ/bsJdCQraSoQOSfJDBkIYgvgc69bA9HCb007oXZSjcvgZ/d
Oo99mQh0doObSoNLILInZP8Kobe7NuO+6uwSMH4TFmUyjwAlM85Hi4sFsMSj
BU9nEcih6L8wFmWB/LYI/5BpBAw8l95aKbJACtZBckMI+OmZf3Y/xQICXY1W
bVQEtuZxffE9zwKGYqVypuMIfJfMrwh1YoH0N+T01BEE5seFOtJDWOCC+n7S
eB8C4SZlg8XvWMA51XuhuRuBPV+c6VVZLJDTppv59h/RDwH1HH1NLHB+P0dU
0R9CT6EbxfX9LOB/IlrO+DcCpm/5nQumWMD6rMW+ugYE1FONW4OEl8F4r/Xk
xSoEyLWtqYdMloHy3yVsE9E/PMb3rWQvL4NzTWetUon+Wm2TIG26tQwMfJVk
FDIQGB+9+LDv1TIgq6jFViQiULph0CD49zKgnH4l7f8CgbyXvuz3+pbBrLl7
r1IgMb+IKRTZoGUg+Y3unOlD5KPoIKsqtALA8FUO8/sIOOgypvuMVkA3xpt9
0AYBEX9WpOqvFfA2d+PtLTsJfwvG6W/tXQFSy43fmuQQWH9znI2PsQJoa87/
XZNCgJry1LFfYBUIDxf17uEj/FW9Qf254SrI3pxVcXaSAZy5KQP9P1dBp7oZ
fTCFAWxfFLxp6F4F6y/yljLiGMBC1FyviLYKslozv5pHMICWQnT+c/410CL2
7InpUwaQ0JH1P2ywBh72lW7psWSASr9du0Ia1gD7cue1c1wMoLb+5r1i1xpI
a/bzdV+ig7wHbGLl1DXQ1Ht/qyeDDpJcWtkWeNfBzjDp9T0ddOBj+aTN5tQ6
cP9366FWOrE+qfz1Pli9DgxNzKXkT9NBv+Nx55s2bJhLfeuq2B0akEmd+ah2
nQ1rBrlKZVdpwHI4dWCjKxs2ZZpzVu8cDTRdIlskebFhNS93D5CO0AB+dkyz
/R0bpvBE74rNyiRIOB4mrtnNhp3Ki/NhezoJLpFGKkTOs2P+T7A/VXepgCum
Ze75FXZMOLHxa+plKkiXr1LkdGLHxK43S940pILFgx+Cpx+yYw/4noQlKFJB
qPmVM7/i2LFQn7s/UtonQGVsz0BAP3Fd//OI3qEJoKTYxrZ8nQOz4+uwj+kY
A7NqtRoD7pzY2kYJ67o/w6DmbI5OrRcnRlO+1IV/HQZRztEGn/05sYmM5O0p
ScNAI/7GhQeRnNh97pPu++8Mg2B2YXdSEScGG/IzLwoPA/k6y8+a85xY7amu
i3ynh4DpOap00l0ubE+kpbZv5gDIdhVYsr3FjfWMbtdu9ekGXE9GvW1fb8Q8
a4ovpOfWAe/obafFX/NiEaNrfId9M6E+15OdVUF8WEKXn6zt3B+YdfpmByNN
ADsaRh/O3jUAp8LlLXtzBbC8BL7AW7oD8EB3e3tjiQAW0luwa+uVAVjkotWe
WS+APf2Vy2cQOQBhhHib04QA9tn75Nm/6wOwqaf876iSIPYglPdK0O9BOHtb
7HdvqiA2+ThdbvDyMDz8rcHoV7YgphCno2f6YBh6cHn/Ki0WxEImsg0zw4bh
SuRkY1ytIHZLXfmZQsUw5PqO/7wwJoiJaiTIyMuPQLENN360KQphp+dcbfb2
jsAjMbD6V4oQlvzDZxNLZwwO78lWd8gSwirFOU4HWo/BsMr4fPZiIaxEdj5g
2W0MUmmPEw/VCWH122djQj+MwTig/jiGKoQJcZ1XvLM+Bp/esZLKFxfGCkoD
K5dzx+GI+L9mLythTL3YRO8+OxWqD5q8aLgsjBnqrvnfFaXC8My6UxJ2whgM
YntvupMKNTS/wNybwphuyBm+fBMqjHJ6+3nYSxhb7GI35ImnQr3Sc0F6icIY
I+aY7MSBSZhl+wcTGxXGcsyT3Ka0aTDF8RHNiCqMKZIT2vLNaDDulmJUAEMY
sxmZSre4RoPBXg8Rc0EYe8S/yQ7zpUG7GPn4ro0kzPD8Buw1pEGZP3eW3+8k
YXy/Lgj8d4AOKf9kUv/tJmEP4meLlwAdbuqvOUM+QMLCyjp+xRrSIZMule6r
RsJuryAuLwc6/MtbaWmvT8LG1+VmvsTRYbAmpWjXTRJWHfXfyZU1OvQ+VXrl
2m0SdvG/R+NZmxjQw/i6wLt7JIxpeloEE2NAe+tv1wS9SJjTOamOVRUG1Hxw
lTL9koSViJNzRywZkJmTf6soh4S1ZF3eYZXOgKjYWgYVkDDO9BMl0/kMOFq2
sW5HCQlLi9slaVfKgC0/L8pGl5Ow6BNikiO/GTB7nPOX5x8SZu/IuXJqlhhv
q9kuzTkSpph+ceDtQQTvooea+5kkjPszFzlADcGnZYkWciskrEKucM1CE8FY
K+TLzkXGSvR7puONEGyKCu4up5Axd6eXL/DrCPZcz53JFSdju2MmJr/fRJB6
uIMnSZqMzeelt8TcRZCrVUHVZxsZo/4q3bPsheBRUvkLrYNk7L8HR28avkZQ
t3/sw4H/yJjhkY3+56IRNMsW/Cp/jIzlPWCtacQj6GJoNcpxgoydu3NtrTAV
QU8Z35UZXTKGDWd5nshEMHAyjTykR8aKzGt083IQTApa1Kg8Q8Y+/dErPFiC
YLbllnP55sT4rx+Y/O988vsOnRsfLpAxzWamklo5gu3V4W99bclY1kq+T3Ud
gvwce6ZO3CFjEZsO3nNqQ1Cy2WzDIXcyto6UI/3/Iaj43lNm+0MypihG/ufb
jaCmRv0pLh8y1nJTtURuEEEjgalLc8/I2HNxNtOKYQStusXuDQeRsczFtvUT
Ywi6P7yWWBVGxqagUDR1EkHf08+LC96QsZEa5CXEQDBUIq8xOZqMAd2OO6JT
CL4b6xh6/Y6M3Tzx987KNILpRetLfolkzKWS53HVLILFzxSF76WQsdc/y17d
nEewysxQ0S6NjKk6nE9bXEDwzzY39XOfydjh5At1tkwE+2ZizujkkjHf17aT
WUsI0srLHVQLyZi12V5SNwtBVui4l0IJGYva+O4IdRnBjZeF3oiWkrGCrpTL
/1YQFNl7OIO7nIy189gGpq0iKLdmVT5fRVz/szH7whqCexp920fqyJh+0ORf
GsHH4tLprT/J2MugJws26wieutHMWdNExhjHzcQKCD6nxpQsaiFjVVskDk4Q
bMsru+9jBxlLzHtrsE7wrQ4d3chuMubzstSW2C/Cx6nOVv79ZKzvXPi9XwQH
u0fccR8mYxlf1Z8FEByl8zXQfpyM7XjMHi5HcIrIQLw5jYwl3zgRF0fEkze0
sVB3ioxttfVNZhLxu3U01DyfI2OW34abthH8X+OrjiYmGTtwQzlYmciXVX6W
KrpKxow9bzXzE3p8LxJfucBOwa48Wkn9QejnldEl8J6bghX6HRe6RuiLvU+Q
HeGlYBF7fvL8I/TneHN1v7IgBXOIdIrcSdSnOmjHCVcyBWuw5Pp6jqhfoNek
WYEYBTsdmnXPmqiv3t1s+yUpCsbzN7UBQwj+svov2HcbBdPbbWoSQyX8Yboc
W7eDgslUGvoJjyN4Vhd+FlChYJUXDljbjiDYsfdk89tDFEzbVGRTdB+CMdv5
hrqPULC112nDjwm/Wkv+npM7TsEa48xvaxB+HuSwkMjUoWA2Y4zsM38QTF6U
Up4+TcGurn53/PgLQXta77HDRsT9bg4jrT8QnGy1t8HNKdhwxNDBugoEs34o
3+a+SMR7s1/oeRlRL8jw0bOhYBzsovjOrwjOfXL/2HKdgn3GdHJZRH+uefrT
xz0o2AxKcp6MQxC/pbe++zEFm4Obn7x4S/SDnSDprjcFk689Hs4XjiCPceSh
1SAKdi4h52+sP4Ik+Y+epFgK9ld992MBFwRbxJxemCdQMPODXoahxHwUybcn
IfYDBbP/Jn8OXUZQar6wQiGTgt3NrlbSOovg9rpqXrVSCvZrfq7s2GEER78H
ST8pp2CRUbqKiXsQTMs13F1VTcEE7zRwDykSfo5tNTH6RcHyrQZMVsQIf7iM
vLXto2Bnmg5L+M8zoJ4It+JzdhFM1PbO4loGA25r1kkK4BbBnDd8VupIYsCV
F/5b/HhFMF68iRYezYCfN/KIPyaJYC+fVp/57M+AwsubeFzlRDD3rzHx7jYM
2DogTD2jKYKp9e0evMrHgFnxpvbGOiLYwvKrlgtsDOh/MXxQn1g6nO2PLR+c
p8MjrZQuotbYk+YO0oteOoypE/t5+IoIJs/xIrErmw4vZ8tkSXmLYGTpXZFz
BnR41NlaWfwZMZ6cl4YIRofknfEfKUEi2LNMoU6xg3RYmSSbwB9GLE1+KVuq
JehQMVI+dO29CJb6ftywdpAGJx8p3RnERbAD86ztLrdp0F3v0OF0NlFsx/Co
d/qDSYhOpCaFc4lisdljzyIdJ6HDcSkhTx5R7OR53Mbh/CS8uI9tXF9YFFOL
6/hTemQSYmI/o+myolg02Hdz/wIV8g1eXd0HRDGvM/X3TztT4fsHEVXFj0Wx
gH0Om/J0JqDk3Q3733uLYvpuLa88DkzAcOcH7wKfiWLaQvY8O2Qn4DMbG/fz
L0SxqbZmGXXmOHTS2aW0HCeKxZ0u7D6VNg4PkSqfa3wXxUSPS59Z3TAO6z/N
nKlmiWKKlnmOF3NHIbOW4xvHuih21sPk8bXoUag4Rt6GcYphKtv6Vcy8R6GP
wsHZr3ximEmm6M8xk1GonnQ3IkdGDLtU17JhiDECc2Ln/sZqiGHKFvxpmooj
MOrlgtkdHzHMTDWG/7rvEHRwY5nLbhLHTmembK5c7oOxOodYZzdKYLaVeang
djOU8iv2q5WUxJz55GMirj+Fe/tyzo4T/G3l2N4FhadQWy1dnldKEmPfvPdp
bt0TeHMqDtcjuEwmN/1YhRfErXxWGgl+F1ifYFz4CNqrGrq1SEtiMWIPlNxj
PWDe6ODVgc2S2AbSsZSy67dgrWb3AY4tktjzchPuDfWusDuulX0bwUd5motf
VrhA7rN1CdcIfuXRxvW+0Blaws9dYwRHcT7VrYh1gGtvPc4yZCWxPzKfkrkd
LkPK7G15oa2SGFnl2px05SWoZHRjei/B1GjbtypFVtCU69Kr2wT7V+rWGsZZ
wuRbJxrmCD4XWtHzysEEljSox4jKEfH1e2dhxQbwl+Jhx8MEK1XPRF95dwou
ditt9CDY6cvTSx8cMch/RL4tiuDq4eC7gQlH4NYI6ZQSgpMpcdt+3NgHVRki
bp0EJ4R/iRe/tRX+//e82P9/z1v2f9aBJEY=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{(-2) Pi, 2 Pi}, {-0.9999996658276197, 
         0.9999993650500513}}, {{-6.283185307179586, 
        6.283185307179586}, {-0.9999996658276197, 0.9999993650500513}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwk23k8VF8bAHC7ss8YSyQqSqUoqUjOJClLESqpJJUSUZSlTZaflCVLaSFK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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{(-2) Pi, 2 Pi}, {-0.9999999999999937, 
         0.9999999999999951}}, {{-6.283185307179586, 
        6.283185307179586}, {-0.9999999999999937, 0.9999999999999951}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtm3c0198fx21lfpYRiZRVkiRJct+EzMxKUaGSJKkkpRQJScNIiqyQjCi7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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{(-2) Pi, 2 Pi}, {-0.999999916456827, 
         0.9999998412622314}}, {{-6.283185307179586, 
        6.283185307179586}, {-0.999999916456827, 0.9999998412622314}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{579., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.4056777764286547`*^9, 3.4056777910360394`*^9}, 
   3.4056867426154213`*^9, 3.405702771154598*^9, 3.424925522564547*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the streamfunction", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.294302 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .16187 -18 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-6)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-4)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-2)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(2)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(4)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(6)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.08317 .01472 m
.08317 .01847 L
s
.12106 .01472 m
.12106 .01847 L
s
.15895 .01472 m
.15895 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.31053 .01472 m
.31053 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.68947 .01472 m
.68947 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.87894 .01472 m
.87894 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .16187 m
.50625 .16187 L
s
[(0.5)] .4875 .16187 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(1.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(2)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01475 L
.02605 .01484 L
.02729 .01503 L
.02846 .01527 L
.03053 .01587 L
.03279 .01678 L
.03527 .01807 L
.0379 .01979 L
.04262 .02373 L
.05205 .03491 L
.06244 .05214 L
.0842 .10331 L
.10458 .16662 L
.14335 .31094 L
.18458 .46296 L
.20517 .52463 L
.21519 .54917 L
.22428 .5678 L
.2338 .58332 L
.24277 .59399 L
.2477 .59817 L
.25224 .60093 L
.25461 .60196 L
.25597 .60242 L
.25722 .60276 L
.25853 .60303 L
.25925 .60314 L
.25994 .60322 L
.26115 .6033 L
.26184 .60332 L
.26248 .60331 L
.26365 .60324 L
.26489 .60309 L
.26595 .6029 L
.26711 .60263 L
.2697 .60176 L
.2721 .60066 L
.27647 .5979 L
.28114 .59389 L
.28669 .58772 L
.29194 .58051 L
.30174 .56359 L
.32176 .51621 L
.34021 .45972 L
.37961 .31422 L
.4175 .17253 L
.43858 .10619 L
.45784 .05909 L
.46737 .04157 L
Mistroke
.4724 .03402 L
.47776 .0273 L
.48291 .02217 L
.48757 .01867 L
.48982 .01737 L
.49225 .01625 L
.49337 .01584 L
.49455 .01547 L
.49565 .0152 L
.49666 .015 L
.49789 .01483 L
.49854 .01477 L
.49922 .01473 L
.50037 .01472 L
.50164 .01478 L
.50276 .01491 L
.50398 .01512 L
.50512 .01539 L
.50617 .01569 L
.50854 .01658 L
.51113 .01788 L
.51634 .02153 L
.52094 .02588 L
.52585 .03167 L
.53469 .04501 L
.54496 .06499 L
.55607 .09166 L
.57624 .15148 L
.61721 .30188 L
.65666 .44917 L
.6765 .51136 L
.6946 .55618 L
.70461 .57505 L
.71409 .58868 L
.71929 .5943 L
.7241 .59831 L
.72661 .59995 L
.72938 .60138 L
.73077 .60195 L
.73228 .60245 L
.73369 .60282 L
.735 .60307 L
.73627 .60323 L
.73747 .60331 L
.73855 .60331 L
.73973 .60325 L
.741 .6031 L
.74165 .603 L
.74236 .60285 L
.74362 .60254 L
Mistroke
.74478 .60217 L
.74705 .60127 L
.74949 .6 L
.7539 .59695 L
.75897 .59223 L
.76451 .58563 L
.77459 .56986 L
.79428 .52609 L
.81525 .46353 L
.85686 .31013 L
.89694 .16147 L
.91533 .1046 L
.92577 .07747 L
.93551 .0561 L
.94506 .03919 L
.94997 .03216 L
.9553 .02583 L
.95822 .02295 L
.96091 .02067 L
.96344 .01887 L
.96623 .01725 L
.96872 .01614 L
.97106 .01539 L
.97235 .01509 L
.97353 .0149 L
.97483 .01476 L
.97548 .01473 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.233891 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .13166 -18 -4.5 ]
[.4875 .13166 0 4.5 ]
[.4875 .24861 -6 -4.5 ]
[.4875 .24861 0 4.5 ]
[.4875 .36555 -18 -4.5 ]
[.4875 .36555 0 4.5 ]
[.4875 .4825 -6 -4.5 ]
[.4875 .4825 0 4.5 ]
[.4875 .59944 -18 -4.5 ]
[.4875 .59944 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-6)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-4)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-2)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(2)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(4)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(6)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.08317 .01472 m
.08317 .01847 L
s
.12106 .01472 m
.12106 .01847 L
s
.15895 .01472 m
.15895 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.31053 .01472 m
.31053 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.68947 .01472 m
.68947 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.87894 .01472 m
.87894 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13166 m
.50625 .13166 L
s
[(0.5)] .4875 .13166 1 0 Mshowa
.5 .24861 m
.50625 .24861 L
s
[(1)] .4875 .24861 1 0 Mshowa
.5 .36555 m
.50625 .36555 L
s
[(1.5)] .4875 .36555 1 0 Mshowa
.5 .4825 m
.50625 .4825 L
s
[(2)] .4875 .4825 1 0 Mshowa
.5 .59944 m
.50625 .59944 L
s
[(2.5)] .4875 .59944 1 0 Mshowa
.125 Mabswid
.5 .0381 m
.50375 .0381 L
s
.5 .06149 m
.50375 .06149 L
s
.5 .08488 m
.50375 .08488 L
s
.5 .10827 m
.50375 .10827 L
s
.5 .15505 m
.50375 .15505 L
s
.5 .17844 m
.50375 .17844 L
s
.5 .20183 m
.50375 .20183 L
s
.5 .22522 m
.50375 .22522 L
s
.5 .27199 m
.50375 .27199 L
s
.5 .29538 m
.50375 .29538 L
s
.5 .31877 m
.50375 .31877 L
s
.5 .34216 m
.50375 .34216 L
s
.5 .38894 m
.50375 .38894 L
s
.5 .41233 m
.50375 .41233 L
s
.5 .43572 m
.50375 .43572 L
s
.5 .45911 m
.50375 .45911 L
s
.5 .50589 m
.50375 .50589 L
s
.5 .52927 m
.50375 .52927 L
s
.5 .55266 m
.50375 .55266 L
s
.5 .57605 m
.50375 .57605 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01477 L
.02605 .01492 L
.02729 .01521 L
.02846 .01559 L
.03053 .01655 L
.03279 .01797 L
.03527 .02 L
.0379 .02266 L
.04262 .02869 L
.05205 .04511 L
.06244 .06864 L
.10458 .19095 L
.14487 .31522 L
.18364 .43479 L
.20335 .49445 L
.21376 .52432 L
.22486 .5533 L
.23566 .57685 L
.24076 .5858 L
.24546 .59255 L
.25018 .59779 L
.25267 .59987 L
.25394 .60075 L
.2553 .60155 L
.25649 .60213 L
.25759 .60256 L
.25868 .6029 L
.25972 .60313 L
.26093 .60328 L
.26204 .60332 L
.26327 .60324 L
.26457 .60303 L
.26571 .60273 L
.26695 .60228 L
.26946 .60101 L
.27178 .59938 L
.27394 .59749 L
.27883 .59194 L
.28404 .58417 L
.29362 .56561 L
.30232 .5449 L
.3423 .42823 L
.38077 .30958 L
.42169 .18338 L
.44205 .12181 L
.46109 .06932 L
.47046 .04776 L
.47936 .03145 L
.48426 .02459 L
Mistroke
.48685 .02165 L
.48961 .01907 L
.49216 .0172 L
.49447 .01596 L
.49559 .01551 L
.4968 .01513 L
.49793 .01489 L
.49898 .01476 L
.50025 .01472 L
.50145 .0148 L
.50252 .01497 L
.50369 .01527 L
.50497 .01572 L
.50632 .01633 L
.50874 .01781 L
.51098 .01957 L
.51307 .02157 L
.51784 .02733 L
.5278 .04422 L
.53852 .06836 L
.57971 .18769 L
.61939 .31007 L
.65755 .42778 L
.67884 .49239 L
.69816 .54614 L
.70783 .56873 L
.71291 .57883 L
.71829 .58787 L
.72299 .59421 L
.72549 .59694 L
.72816 .59934 L
.73062 .60106 L
.73287 .60221 L
.73395 .60262 L
.73512 .60296 L
.73623 .60318 L
.73726 .60329 L
.73843 .60332 L
.73967 .60322 L
.74073 .60304 L
.74188 .60274 L
.74313 .60229 L
.74447 .60167 L
.74687 .6002 L
.7493 .59826 L
.7516 .59601 L
.7559 .59076 L
.76578 .57405 L
.77649 .54998 L
.81738 .43165 L
Mistroke
.85675 .31023 L
.89461 .19345 L
.91566 .12943 L
.93491 .07533 L
.94443 .05253 L
.94945 .04214 L
.95481 .03263 L
.95995 .02522 L
.96461 .02011 L
.96686 .01823 L
.96929 .01664 L
.97041 .01607 L
.97159 .01557 L
.9726 .01524 L
.97371 .01497 L
.97491 .01478 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.256165 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .1428 -18 -4.5 ]
[.4875 .1428 0 4.5 ]
[.4875 .27088 -6 -4.5 ]
[.4875 .27088 0 4.5 ]
[.4875 .39896 -18 -4.5 ]
[.4875 .39896 0 4.5 ]
[.4875 .52704 -6 -4.5 ]
[.4875 .52704 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-6)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-4)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-2)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(2)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(4)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(6)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.08317 .01472 m
.08317 .01847 L
s
.12106 .01472 m
.12106 .01847 L
s
.15895 .01472 m
.15895 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.31053 .01472 m
.31053 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.68947 .01472 m
.68947 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.87894 .01472 m
.87894 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .1428 m
.50625 .1428 L
s
[(0.5)] .4875 .1428 1 0 Mshowa
.5 .27088 m
.50625 .27088 L
s
[(1)] .4875 .27088 1 0 Mshowa
.5 .39896 m
.50625 .39896 L
s
[(1.5)] .4875 .39896 1 0 Mshowa
.5 .52704 m
.50625 .52704 L
s
[(2)] .4875 .52704 1 0 Mshowa
.125 Mabswid
.5 .04033 m
.50375 .04033 L
s
.5 .06595 m
.50375 .06595 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11718 m
.50375 .11718 L
s
.5 .16841 m
.50375 .16841 L
s
.5 .19403 m
.50375 .19403 L
s
.5 .21965 m
.50375 .21965 L
s
.5 .24526 m
.50375 .24526 L
s
.5 .2965 m
.50375 .2965 L
s
.5 .32211 m
.50375 .32211 L
s
.5 .34773 m
.50375 .34773 L
s
.5 .37335 m
.50375 .37335 L
s
.5 .42458 m
.50375 .42458 L
s
.5 .4502 m
.50375 .4502 L
s
.5 .47581 m
.50375 .47581 L
s
.5 .50143 m
.50375 .50143 L
s
.5 .55266 m
.50375 .55266 L
s
.5 .57828 m
.50375 .57828 L
s
.5 .60389 m
.50375 .60389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01476 L
.02605 .01488 L
.02729 .01512 L
.02846 .01544 L
.03053 .01622 L
.03279 .0174 L
.03527 .01908 L
.0379 .02129 L
.04262 .02633 L
.05205 .04034 L
.06244 .06112 L
.0842 .11807 L
.10458 .18129 L
.14335 .31069 L
.18458 .44782 L
.20517 .51051 L
.21519 .53758 L
.22428 .55917 L
.23316 .57682 L
.24277 .5913 L
.24534 .59427 L
.24806 .59697 L
.25057 .59905 L
.25292 .60063 L
.25512 .60178 L
.25625 .60225 L
.25748 .60266 L
.25817 .60285 L
.25882 .603 L
.26009 .60321 L
.26125 .60331 L
.26248 .60331 L
.26361 .60322 L
.26486 .60303 L
.26616 .60272 L
.26737 .60232 L
.26953 .60138 L
.27185 .60003 L
.27714 .59565 L
.28195 .59015 L
.29135 .57555 L
.30023 .55761 L
.33869 .44954 L
.37961 .31354 L
.41902 .18198 L
.43881 .1204 L
.4569 .07149 L
.46621 .0508 L
.47635 .0329 L
Mistroke
.48191 .02548 L
.48462 .02253 L
.48707 .02026 L
.48944 .01843 L
.492 .01685 L
.49341 .01617 L
.4947 .01565 L
.49594 .01527 L
.49724 .01497 L
.49847 .01479 L
.49916 .01474 L
.4998 .01472 L
.50097 .01475 L
.50222 .01488 L
.50333 .01509 L
.50437 .01535 L
.50552 .01573 L
.50675 .01623 L
.50934 .01762 L
.51206 .01954 L
.51692 .02415 L
.52147 .02977 L
.52569 .03606 L
.53527 .05383 L
.55576 .10478 L
.57436 .16078 L
.6144 .29331 L
.65292 .42239 L
.67244 .48428 L
.69389 .54384 L
.70373 .56607 L
.70915 .57645 L
.71429 .5849 L
.71906 .59142 L
.72425 .59697 L
.72654 .59888 L
.72897 .60055 L
.73105 .60166 L
.73334 .60257 L
.73456 .6029 L
.73569 .60313 L
.73693 .60327 L
.73762 .60331 L
.73825 .60332 L
.73953 .60325 L
.74024 .60317 L
.74091 .60306 L
.74213 .60278 L
.74342 .60237 L
.74569 .60139 L
Mistroke
.74782 .60017 L
.75267 .59629 L
.75791 .59044 L
.76271 .58366 L
.77351 .56389 L
.79251 .51702 L
.81324 .45477 L
.85391 .31995 L
.89306 .18896 L
.91305 .1262 L
.92356 .09609 L
.93466 .06776 L
.94462 .04644 L
.94989 .03705 L
.95554 .02867 L
.96074 .0226 L
.96548 .01853 L
.96776 .01708 L
.96896 .01646 L
.97024 .0159 L
.97135 .0155 L
.97258 .01515 L
.9737 .01492 L
.97475 .01478 L
.9755 .01473 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{679, 130.875},
 ImageMargins->{{34, 0}, {0, 1}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 678}, {129.875, 0}} -> {-0.0880394, -0.0144882, \
0.00468449, 0.00468449}, {{18.75, 218.875}, {126.75, 3.0625}} -> {-8.55224, \
-0.267221, 0.071981, 0.0185364}, {{238.875, 439.062}, {126.75, 3.0625}} -> \
{-24.2418, -0.334415, 0.0715163, 0.0231736}, {{459.062, 659.188}, {126.75, \
3.0625}} -> {-39.6135, -0.302944, 0.070849, 0.0209612}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "GraphicsArray", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots of the forcing (or dissipation)", "Subsection"],

Cell["\<\
Forcing is calculated to equilibrate the dissipation since there is no \
advection for a flow that depends only on y
Some arbitrary values are assumed for the parameters\
\>", "Text",
 CellChangeTimes->{{3.405677580537345*^9, 3.405677646827773*^9}, {
  3.40567768158708*^9, 3.405677702176744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Forcing", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", ">", "0"}], " ", "&&", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], ">", "0"}]}], ",", 
     RowBox[{"Simplify", "[", " ", 
      RowBox[{"DS", "[", "  ", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "]"}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   FractionBox["1", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]], 
   RowBox[{"C", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "5"]}], "+", 
      RowBox[{"3", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"3", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]}]], "Output",\

 CellChangeTimes->{3.405677810825055*^9, 3.424925537180129*^9}]
}, Open  ]],

Cell["\<\
Setting \[Mu] -> 0. shows that Flow1 requires a forcing with discontinuities \
that disappear in Flow2 and Flow3.\
\>", "Text",
 CellChangeTimes->{{3.4056778880865917`*^9, 3.4056779589082003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", 
        RowBox[{"\[Mu]", "\[Rule]", "0."}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0."}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0."}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405677815714443*^9, 3.40567781989952*^9}, {
  3.405677852460116*^9, 3.405677854705751*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3k8VN8bx+37OoMZEhGSVL7aJedUlOxJpWhRWRIqSZYkS0IqS0kkWSJb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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {193.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c8Vf8bt/e691opRSgk+9ruOTJutmj4aqOSlMhsJyEUskfKlko2kft5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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {580.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUW3c8lt8btvd8X168r1FCNonylZwnlQgRTQ1SGaU0JQ0poVBIklVJmUVZ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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {967.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{674., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.405677858203236*^9, 3.424925600449761*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
Setting \[Mu] -> 0.5 shows that the discontinuities disappear in Flow1, while \
the forcings in Flow2 and Flow3 are hardly modified\
\>", "Text",
 CellChangeTimes->{{3.4056778880865917`*^9, 3.405678010764269*^9}, {
  3.4056783216133003`*^9, 3.405678349750502*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", 
        RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405677815714443*^9, 3.40567781989952*^9}, {
  3.405678299741843*^9, 3.405678312368596*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c81e8Xt/e6dtS3ooEkUSrr+SRKKBIlqWxCyhZlJSoNKwkhK0SEUMbz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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {193.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3k4VV8Xx83zeC+usUjm+d6LkpxjujJFUmn4SUKDQlKkFJGhVEKlSMmU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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {580.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmnk8lN8XxzGDGftgFlvWrDO2lEKeS9qV9VuSVLK00iKVJEkSZSkkW4st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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {967.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{679., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.405677822668429*^9, 3.405678026726883*^9, {3.405678305770659*^9, 
   3.405678317322577*^9}, 3.424925609309808*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the pertubation problem", "Section"],

Cell[CellGroupData[{

Cell["2D Navier-Stokes with scaling", "Subsection"],

Cell[TextData[{
 StyleBox["We have taken u = ", "Text"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", "\[Psi]"}], " ", "and", " ", 
     "v"}], " ", "=", " ", 
    RowBox[{"-", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", "\[Psi]"}]}]}], 
   TraditionalForm]]],
 " (definition used in fluid mechanics, opposite to the convention in GFD)"
}], "Text",
 CellChangeTimes->{{3.4056784807764606`*^9, 3.405678508854782*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Epsilon]", "2"], 
     RowBox[{
      SubscriptBox["\[PartialD]", "T"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], "-", " ", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "+", "\n", 
    "      ", 
    RowBox[{"\[Epsilon]", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "-", " ", 
    RowBox[{"DS", "[", 
     RowBox[{"\[Psi]", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "+", " ", 
    RowBox[{"DS", "[", 
     RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}]}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expansion", "Subsection"],

Cell["\<\
The streamfunction is expanded up to the fourth order in \[Epsilon]\
\>", "Text",
 CellChangeTimes->{{3.405678519006564*^9, 3.4056785401302223`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Psi]", "[", 
   RowBox[{"T_", ",", "X_", ",", "y_"}], "]"}], " ", ":=", "  ", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "+", " ", 
   RowBox[{"\[Psi]0", "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"\[Psi]1", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], " ", 
    RowBox[{"\[Psi]2", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "3"], " ", 
    RowBox[{"\[Psi]3", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "4"], " ", 
    RowBox[{"\[Psi]4", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS2", " ", "=", " ", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{"NS", ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], 
     ",", "\[Epsilon]"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 0", "Section"],

Cell["\<\
Extract order 0 terms from the general expansion and perform algebraic \
simplication.
Fairly lengthy expression anyway.\
\>", "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.4056799005414543`*^9, 3.405679948493458*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a0", " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"NS2", ",", "\[Epsilon]", ",", "0"}], "]"}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.424925731289408*^9, 3.424925734445738*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "C", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"8", " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], ")"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]], "-", 
    RowBox[{"4", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
     RowBox[{
      SuperscriptBox["U", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            RowBox[{"U", "[", "y", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["U", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]]], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "3"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "3"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"U", "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}]], 
      ")"}]}], "-", 
    FractionBox[
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"U", "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "3"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"U", "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], ")"}], 
      
      RowBox[{"3", "/", "2"}]]], "+", 
    RowBox[{"4", " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"U", "[", "y", "]"}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "+", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}], "+", 
       RowBox[{
        SuperscriptBox["\[Psi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "4"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}], "2"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"U", "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["U", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "3"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["U", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "3"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["U", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "4"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"U", "[", "y", "]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}]], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.405680437302593*^9, 3.405686782110867*^9, 3.405702863564118*^9, 
   3.405705927313441*^9, 3.4249256236271772`*^9, 3.424925742004727*^9, {
   3.435142956906522*^9, 3.43514297053171*^9}, 3.44093595240999*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell["\<\
The 0 th order solution satisfies a0 = 0 as soon as it does not depend on the \
fast variable y \
\>", "Text",
 CellChangeTimes->{{3.4056787688339157`*^9, 3.4056788439856663`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule0", "=", " ", 
  RowBox[{"\[Psi]0", " ", "\[Rule]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[CurlyPhi]0", "[", 
      RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Psi]0", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[CurlyPhi]0", "[", 
     RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.405680437709983*^9, 3.40568678273033*^9, 3.405702864034481*^9, 
   3.40570592823939*^9, 3.424925637923162*^9, 3.435142957243918*^9, {
   3.440935952839862*^9, 3.440935961830074*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification", "Subsection",
 CellChangeTimes->{{3.4056812924802628`*^9, 3.405681294988698*^9}}],

Cell["\<\
Check that \[CurlyPhi]0[X, T] satisfies the 0 th order solution\
\>", "Text",
 CellChangeTimes->{{3.405678887077858*^9, 3.405678911528989*^9}, {
  3.405678944352785*^9, 3.40567896841066*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"a0", "  ", "/.", " ", 
    RowBox[{"{", "Rule0", "}"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.424925771536065*^9, 3.424925774695413*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4056804405524597`*^9, 3.405686785513888*^9, 
  3.405702870471019*^9, 3.405705933507183*^9, 3.424925675950719*^9, 
  3.424925776360183*^9, 3.435142982319079*^9, 3.44093596418991*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Useful rules for simplifications", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rulea", "=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "2"], " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox["A", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], "n_"], 
   "\[Rule]", 
   RowBox[{
    SuperscriptBox["A", 
     RowBox[{"2", " ", "n"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     "n"]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["A", "2"], " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["A", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], "n_"], 
  "\[Rule]", 
  RowBox[{
   SuperscriptBox["A", 
    RowBox[{"2", " ", "n"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
    "n"]}]}]], "Output",
 CellChangeTimes->{3.4056804409028177`*^9, 3.405686741897224*^9, 
  3.405702769751576*^9, 3.405702870934696*^9, 3.405705842326382*^9, 
  3.405705934446885*^9, 3.42492551938101*^9, 3.435142948096967*^9, 
  3.440935940712518*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Improve", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"Together", "[", "#1", "]"}], "]"}], "&"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.424926465800952*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"Together", "[", "#1", "]"}], "]"}], "&"}]], "Output",
 CellChangeTimes->{3.40568044119874*^9, 3.405686742026483*^9, 
  3.405702770031386*^9, 3.405705842353067*^9, 3.405705935121743*^9, 
  3.42492551941725*^9, 3.424926467598072*^9, 3.435142948118767*^9, 
  3.435143711900085*^9, 3.440935940807461*^9}]
}, Open  ]],

Cell["Periodicity in space", "Text",
 CellChangeTimes->{{3.405679044282816*^9, 3.4056790705350523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solva", "[", "expr_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"expr", " ", "/.", " ", 
       RowBox[{"y", " ", "\[Rule]", " ", 
        RowBox[{"2", " ", "\[Pi]"}]}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"expr", " ", "/.", " ", 
       RowBox[{"y", " ", "\[Rule]", "0"}]}], ")"}]}], ")"}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"g___", "[", 
     RowBox[{"2", " ", "\[Pi]"}], "]"}], "\[Rule]", 
    RowBox[{"g", "[", "0", "]"}]}]}]}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 1", "Section"],

Cell[TextData[{
 "Extract order 1 terms from the general expansion, use formal solution to \
order 0 equation and perform algebraic simplication.\nNeed to be put under \
the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]1", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"NS2", ",", "\[Epsilon]", ",", "1"}], "]"}], "]"}], " ", "/.", 
    " ", "Rule0"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{{3.424925802872702*^9, 3.424925804984272*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"C", " ", "\[Mu]", " ", 
     RowBox[{"U", "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", "\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Psi]1", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}], "+", 
    RowBox[{"C", " ", 
     SuperscriptBox["\[Mu]", "3"], " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["U", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"C", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "3"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "-", 
       RowBox[{"3", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["U", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "3"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{"C", " ", 
     SuperscriptBox["\[Mu]", "3"], " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "6"], " ", 
     RowBox[{
      SuperscriptBox["\[Psi]1", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[Mu]", "2"], " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "C", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
           RowBox[{
            SuperscriptBox["\[CurlyPhi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X"}], "]"}]}], "+", 
          RowBox[{"6", " ", "C", " ", 
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "3"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"C", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{
            SuperscriptBox["U", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "4"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
           RowBox[{
            SuperscriptBox["\[CurlyPhi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X"}], "]"}]}], "+", 
          RowBox[{"C", " ", 
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "3"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"2", " ", "C", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["U", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["\[Psi]1", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "0", ",", "4"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]], " ", 
           RowBox[{
            SuperscriptBox["\[CurlyPhi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X"}], "]"}]}], "+", 
          RowBox[{"C", " ", 
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", " ", "\[Mu]", " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
             RowBox[{"10", " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "3"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"5", " ", "C", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["U", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              SuperscriptBox["\[Psi]1", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "0", ",", "4"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405680469323229*^9, 3.40568681210163*^9, 
  3.405702935985776*^9, 3.405706173972464*^9, 3.424925810288159*^9, 
  3.435142989979582*^9, 3.440935983394296*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Extraction of the linear operator and verification", "Subsection"],

Cell["First derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680267654934*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]], 
  RowBox[{"C", " ", "\[Mu]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", "\[Mu]", " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "5"]}], "+", 
     RowBox[{"7", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "5"], " ", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "3"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.405680475064075*^9, 3.405686818017201*^9, 
  3.405702947644118*^9, 3.405706187599757*^9, 3.424925846890108*^9, 
  3.435142998243316*^9, 3.440935989255141*^9}]
}, Open  ]],

Cell["Second derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680284810182*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
    RowBox[{"5", "/", "2"}]]], 
  RowBox[{"C", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["\[Mu]", "3"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "5"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["\[Mu]", "2"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"5", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["U", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["U", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["\[Mu]", "2"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.405680481735201*^9, 3.405686824150296*^9, 
  3.405702959741571*^9, 3.405706201606166*^9, 3.424925856595809*^9, 
  3.435142999331812*^9, 3.440935991367051*^9}]
}, Open  ]],

Cell["Third derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680267654934*^9}, {
  3.405680300316112*^9, 3.4056803028255*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F3", "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", "]"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"C", " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["\[Mu]", "2"], " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "3"]}], "+", 
     RowBox[{"\[Mu]", " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"6", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
   RowBox[{"3", "/", "2"}]]]], "Output",
 CellChangeTimes->{3.405680482456992*^9, 3.405686824898526*^9, 
  3.405702961055523*^9, 3.405706202731677*^9, 3.424925861072515*^9, 
  3.43514300188898*^9, 3.440935994412179*^9}]
}, Open  ]],

Cell["Fourth derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680267654934*^9}, {
  3.405680306086762*^9, 3.405680308433175*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F4", "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"C", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
  SqrtBox[
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], "2"]}]]]], "Output",
 CellChangeTimes->{3.40568048286045*^9, 3.405686825095542*^9, 
  3.4057029616301*^9, 3.405706203451018*^9, 3.424925864293939*^9, 
  3.435143002978347*^9, 3.44093599726542*^9}]
}, Open  ]],

Cell["\<\
Complete form of \[ScriptCapitalL] and verification against the terms \
extracted from a1\
\>", "Text",
 CellChangeTimes->{{3.405680327200042*^9, 3.405680367142193*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalL]", "[", "f_", "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"C", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"y", ",", "y"}]], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"U", "'"}], "[", "y", "]"}], "2"]}]}], " ", ")"}], 
        SqrtBox[
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            RowBox[{"U", "'"}], "[", "y", "]"}], "2"]}]]], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], "f"}]}], "  ", ")"}]}]}], " ", "+", " ", 
   RowBox[{"C", "  ", "\[Mu]", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"y", ",", "y"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"U", "[", "y", "]"}], 
         RowBox[{
          RowBox[{"U", "'"}], "[", "y", "]"}]}], 
        RowBox[{" ", 
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             RowBox[{"U", "'"}], "[", "y", "]"}], "2"]}]]}]], 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "f"}]}], ")"}]}]}]}]}]], "Input",
 CellChangeTimes->{{3.42492587478068*^9, 3.424926003497318*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"f", "[", "y", "]"}], "]"}], " ", "-", "  ", 
    RowBox[{"a1F1", "  ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "1", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"a1F2", "  ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "2", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{"a1F3", "   ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{"a1F4", " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}]}], ",", " ", 
   RowBox[{"Trig", "->", "True"}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405680483359929*^9, 3.405686825436984*^9, 
  3.405702962363421*^9, 3.405706205041713*^9, 3.424926035010647*^9, 
  3.435143022601645*^9, 3.440936001734053*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extraction of second member: a1a", "Subsection",
 CellChangeTimes->{{3.405745203832325*^9, 3.405745206527741*^9}}],

Cell["\<\
The second member contains only the first derivative in X of the Oth order \
solution\
\>", "Commentary",
 CellChangeTimes->{{3.405680924835505*^9, 3.405680976013473*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1a", "=", 
  RowBox[{"-", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["U", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.4056811907123632`*^9, 3.405686825639031*^9, 
  3.40570296285511*^9, 3.405706205562864*^9, 3.424926045671801*^9, 
  3.435143009709649*^9, 3.44093600469738*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reconstruction of the first order equation ", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "We", " ", "check", " ", "here", " ", "that", " ", "the", " ", "first", " ",
    "order", " ", "equation", " ", "is", " ", 
   RowBox[{"\[ScriptCapitalL]", "[", 
    RowBox[{"\[Psi]1", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}], "=", " ", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     RowBox[{"U", "''"}], "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}]}]], "Commentary",
 CellChangeTimes->{{3.405680993611363*^9, 3.405680997989916*^9}, {
  3.405681035330802*^9, 3.405681097427763*^9}, {3.424926076232111*^9, 
  3.424926079243314*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a1N", "=", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]1", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "-", " ", 
    RowBox[{"a1a", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a1N", " ", "-", " ", "a1"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.405681196602668*^9, 3.405686826350112*^9, 3.405702963578828*^9, 
   3.405706207010185*^9, 3.424926299012313*^9, {3.435143013180671*^9, 
   3.435143026633357*^9}, 3.440936012425011*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solvability condition", "Subsection"],

Cell["\<\
The solvability condition is that the integral in y from 0 to 2\[Pi] of the \
second member vanishes. It is obviously satisfied with the second member of \
the first order equation which is proportional to the second derivative of \
Sin[\[Theta][y]] , as checked here\
\>", "Commentary",
 CellChangeTimes->{{3.40568122874508*^9, 3.405681235935019*^9}, {
  3.40568130878643*^9, 3.405681371971428*^9}, {3.405706217329728*^9, 
  3.405706234207999*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a1a", "+", 
   RowBox[{"A", " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "A"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
  RowBox[{
   SuperscriptBox["U", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{"A", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405681201315318*^9, 3.40568682657369*^9, 
  3.405702964009238*^9, 3.405706207093014*^9, 3.424926301291671*^9, 
  3.435143031805012*^9, 3.44093601583793*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell["\<\
This solution is meant to replace \[Psi]1 in further formal steps of the \
perturbative expansion\
\>", "Commentary",
 CellChangeTimes->{{3.405682181618347*^9, 3.405682241109109*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule1", " ", "=", 
  RowBox[{"\[Psi]1", " ", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"f1", "[", "#3", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"#1", ",", "#2"}], "]"}]}], " ", "&"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.435143053851826*^9, 3.435143054284893*^9}}],

Cell[BoxData[
 RowBox[{"\[Psi]1", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "#3", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"#1", ",", "#2"}], "]"}]}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.405685988576124*^9, 3.405686826795513*^9, 3.405702964250146*^9, 
   3.405706207409132*^9, 3.424926307211843*^9, {3.435143033747106*^9, 
   3.435143059201007*^9}, 3.440936017732856*^9}]
}, Open  ]],

Cell["Notice that f1 has SinI symmetry", "Commentary",
 CellChangeTimes->{{3.4056822559201202`*^9, 3.405682257900504*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 2", "Section"],

Cell[TextData[{
 "Extract order 2 terms from the general expansion, use formal solution to \
order 0 and 1 equations and perform algebraic simplication.\nNeed to be put \
under the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]2", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}, {
  3.405685906475298*^9, 3.405685933174532*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2", " ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"NS2", ",", "\[Epsilon]", ",", "2"}], "]"}], "   ", "//.", " ", 
     
     RowBox[{"{", 
      RowBox[{"Rule0", ",", "Rule1"}], "}"}]}], " ", "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{
  3.405707115570497*^9, {3.424926363485377*^9, 3.424926371786062*^9}, {
   3.435143042628649*^9, 3.435143044758897*^9}}],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection",
 CellChangeTimes->{{3.405689902151525*^9, 3.405689906517454*^9}}],

Cell["\<\
Here we extract the terms of the second member, factor per factor, and we \
test the solvability condition\
\>", "Text",
 CellChangeTimes->{{3.40568617718019*^9, 3.4056862579374123`*^9}, {
  3.40568991337463*^9, 3.4056899311116037`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"]}], ":", " ", 
  "a2a"}]], "Subsubsection",
 CellChangeTimes->{{3.405686378322873*^9, 3.405686385538538*^9}, {
  3.405690025024864*^9, 3.405690026158256*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Coefficient", "[", 
        RowBox[{"a2", " ", ",", 
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], ",", "2"}], "]"}], " ", "]"}]}], 
     " ", ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.440936031210367*^9}],

Cell["\<\
Check that this simplification can be somewhat improved for the term which is \
not in factor of C\
\>", "Text",
 CellChangeTimes->{{3.4056862817471857`*^9, 3.405686293409556*^9}, {
  3.405687379626865*^9, 3.405687409487836*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a2a", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["f1", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.405686477381343*^9, 3.405687312568282*^9, 
  3.405703482887491*^9, 3.405707747595942*^9, 3.4057533625583067`*^9, 
  3.424926488136475*^9, 3.43514311976088*^9, 3.440936037159426*^9}]
}, Open  ]],

Cell["\<\
This term integrates twice in y and satisfies the solvability condition\
\>", "Text",
 CellChangeTimes->{{3.405690121361199*^9, 3.4056901296072617`*^9}, {
  3.405707882353025*^9, 3.405707885483936*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2a1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a2a", ",", "C"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.424926607228583*^9, 3.424926634977579*^9}}],

Cell["\<\
a2a1I = Integrate[a2a1, y];
a2a1I2 = Integrate[a2aI, y]\
\>", "Text",
 CellChangeTimes->{{3.405707182438018*^9, 3.405707185668837*^9}, {
   3.405707762365654*^9, 3.405707771439313*^9}, {3.424926643571176*^9, 
   3.424926660934103*^9}, 3.42492777657156*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2a1I2", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", " ", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "+", 
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
        "+", 
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}]}],
        ")"}], "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a2a1I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a2a1"}], "]"}]}], "Input",\

 CellChangeTimes->{
  3.405687843186754*^9, 3.40570370366247*^9, 3.405707986290822*^9, 
   3.4057534646847973`*^9, {3.424927330678644*^9, 3.424927416115737*^9}, {
   3.424927459529038*^9, 3.424927463719118*^9}, 3.424927520791685*^9, {
   3.42492765145127*^9, 3.424927676614168*^9}, 3.424927735853069*^9, {
   3.424927804687892*^9, 3.424927824487294*^9}, {3.424928181962433*^9, 
   3.42492819009591*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424927562677067*^9, 3.424927685622425*^9, 
  3.424927740031589*^9, 3.424928193644864*^9, 3.435143125044422*^9, 
  3.440936055125678*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a2b"}]], "Subsubsection",
 CellChangeTimes->{{3.405690035550551*^9, 3.405690037683858*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2b", "=", 
   RowBox[{"-", 
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"Coefficient", "[", 
        RowBox[{"a2", "  ", ",", 
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], ",", "1"}], "]"}], "]"}], " ", ",", 
      
      RowBox[{"{", 
       RowBox[{"A", ",", "D", ",", "C"}], " ", "}"}]}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.424927966672739*^9, 3.440936075179006*^9}],

Cell["\<\
Split it in several part for integration. First isolate the part that does \
not depend on C and D and integrate it once.\
\>", "Text",
 CellChangeTimes->{{3.405745492990153*^9, 3.405745570156051*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2b0", "=", " ", 
   RowBox[{"a2b", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"D", "\[Rule]", "0"}], " ", ",", 
      RowBox[{"C", "\[Rule]", "0"}]}], "}"}]}]}], ";"}], "\n", 
 RowBox[{"a2b1I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a2b0", ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405745451200237*^9, 3.405745483222468*^9}, 
   3.405745655293355*^9, 3.4249282887167*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4056881282704763`*^9, 3.405703789576619*^9, 
  3.405708461015973*^9, 3.4057535044806767`*^9, 3.424927981655608*^9, 
  3.435143139903084*^9, 3.440936080570174*^9}]
}, Open  ]],

Cell["Then isolate the factor of C and checks it integrates twice", "Text",
 CellChangeTimes->{{3.405745589367653*^9, 3.405745618950581*^9}, {
  3.424928004713627*^9, 3.424928004941129*^9}, {3.424928039808253*^9, 
  3.424928049751544*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2b1", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a2b", ",", "C"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.405745623012708*^9, 3.405745659658623*^9}, {
  3.405753432891119*^9, 3.405753433760559*^9}, {3.424928007928128*^9, 
  3.424928008089905*^9}}],

Cell["a2b2I2 = Integrate[Integrate[a2b1, y], y]", "Text",
 CellChangeTimes->{
  3.405708443762661*^9, {3.405745672954757*^9, 3.405745674746818*^9}, {
   3.4057534375848083`*^9, 3.40575343789323*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2b2I2", "=", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"2", "  ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a2b2I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a2b1"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424928116960062*^9, 3.424928158972341*^9}, {
  3.424928199823647*^9, 3.424928238527601*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424928239521296*^9, 3.435143145936007*^9, 
  3.440936089183262*^9}]
}, Open  ]],

Cell["Isolate the factor of D and integrate it once", "Text",
 CellChangeTimes->{{3.405745754960486*^9, 3.405745759642454*^9}, {
  3.405745791092037*^9, 3.405745808312101*^9}, {3.424928249341529*^9, 
  3.424928249507365*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2b2", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a2b", "  ", ",", "D"}], "]"}]}], ";"}], "\n", 
 RowBox[{"a2b0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a2b2", ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405745812649135*^9, 3.405745828351323*^9}, {
   3.405753440570002*^9, 3.4057534411203814`*^9}, 3.405753527993288*^9, {
   3.424928250920753*^9, 3.424928269004994*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.4056881642759657`*^9, 3.405703812606026*^9, 3.405708511034817*^9, 
   3.405753517211644*^9, {3.424928262256887*^9, 3.424928273164765*^9}, 
   3.435143154540552*^9, 3.440936092135942*^9}]
}, Open  ]],

Cell["\<\
Complete the solvability proof for a2b by check that nothing has been \
forgotten in a2b\
\>", "Text",
 CellChangeTimes->{{3.405745389447373*^9, 3.405745403146656*^9}, {
  3.405745764672007*^9, 3.405745784943751*^9}, {3.405745896667426*^9, 
  3.405745935471117*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a2b", " ", "-", " ", "a2b0", " ", "-", " ", 
   RowBox[{"C", " ", "a2b1"}], " ", "-", 
   RowBox[{"D", " ", "a2b2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.40574540948459*^9, 3.405745437037369*^9}, {
   3.405745841759482*^9, 3.405745865636389*^9}, 3.405745940805416*^9, {
   3.4057534480064774`*^9, 3.405753452172996*^9}, {3.424928309033918*^9, 
   3.424928310444633*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057535175270147`*^9, 3.424928313070743*^9, 
  3.435143157719455*^9, 3.440936095296737*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reconstruction and verification of the second order equation", \
"Subsection",
 CellChangeTimes->{{3.426489032258686*^9, 3.426489038510984*^9}}],

Cell["\<\
Check that nothing has been forgotten in the extraction of the components of \
a2\
\>", "Text",
 CellChangeTimes->{{3.405687499347293*^9, 3.405687519117462*^9}, {
  3.405687570045809*^9, 3.4056875715644836`*^9}, {3.405745942937049*^9, 
  3.405745950226455*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2N", " ", "=", " ", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]2", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "-", " ", 
    RowBox[{"a2b", "  ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "-", " ", 
    RowBox[{"a2a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a2N", " ", "-", " ", "a2"}], " ", "]"}]}], "Input",
 CellChangeTimes->{3.405687585410922*^9, 3.405689971668638*^9, 
  3.440936102890523*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405708612492112*^9, 3.405753537981843*^9, 
  3.424928319770715*^9, 3.435143166124051*^9, 3.440936126376157*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule2", " ", "=", "  ", 
  RowBox[{"\[Psi]2", "  ", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f2a", "[", "#3", "]"}], "  ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"#1", ",", "#2"}], "]"}], "2"]}], "+", " ", 
      RowBox[{
       RowBox[{"f2b", "[", "#3", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}]}]}], "&"}], ")"}]}]}]], "Input",
 CellChangeTimes->{3.435143183535072*^9}],

Cell[BoxData[
 RowBox[{"\[Psi]2", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f2a", "[", "#3", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"f2b", "[", "#3", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"#1", ",", "#2"}], "]"}]}]}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.4056881724009247`*^9, 3.405703814113815*^9, 
  3.405708621168304*^9, 3.4057535424394903`*^9, 3.424928323469436*^9, 
  3.43514319347511*^9, 3.44093612904985*^9}]
}, Open  ]],

Cell["\<\
f2a has CosI symmetry
f2b has CosP symmetry\
\>", "Text",
 CellChangeTimes->{{3.435143209480846*^9, 3.435143210233665*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 3", "Section"],

Cell[TextData[{
 "Extract order 3 terms from the general expansion, use formal solution to \
order 0, 1 and 2 equations and perform algebraic simplication.\nNeed to be \
put under the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]3", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member\nNo attemps to simplify here\nNOTICE THAT, FOR HISTORICAL \
REASONS,  THE axx TERMS AT THIS ORDER AND THE NEXT ONE IN THIS NOTEBOOK ARE \
DEFINED AS THE NEGATIVE OF THOSE USED IN THE PAPER AND OTHER NOTEBOOK (SEE \
THE VERIFICATION STEP)\nThe terms marked as [S] require the symmetry \
assumption to satisfy the solvability condition. Only term 3d is involved at \
this order.\nPre-defined integrals at this order and the next one in this \
notebook have been derived from the calculation of primitives obtained with \
",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " with U=Sin[ \[Theta][y]]. For some unknown reasons, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is more able to find the primitive under this form than using U alone."
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}, {
  3.405685906475298*^9, 3.405685933174532*^9}, {3.405688214542055*^9, 
  3.405688233724618*^9}, {3.405688414807213*^9, 3.405688425967601*^9}, {
  3.426488870735977*^9, 3.426489013827247*^9}, {3.426489127818313*^9, 
  3.426489205240738*^9}, {3.42648935546798*^9, 3.426489404983214*^9}, {
  3.426489439810365*^9, 3.426489538630949*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3", " ", "=", "  ", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"NS2", ",", "\[Epsilon]", ",", "3"}], "]"}], "   ", "//.", " ", 
    RowBox[{"{", 
     RowBox[{"Rule0", ",", "Rule1", ",", "Rule2"}], "}"}]}]}], " ", 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection"],

Cell["\<\
First reorganize a3 in order to make further extraction easier\
\>", "Text",
 CellChangeTimes->{{3.405688359831512*^9, 3.4056883786622953`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a31", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a3", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.44093614574836*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "3"]}], ":", " ", 
  "a3a"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"a31", " ", "/.", " ", "Rulea"}], " ", ",", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], "3"]}], "]"}], " ", ",", "C"}], 
    "]"}]}], "  ", ";"}]], "Input",
 CellChangeTimes->{{3.424928406687376*^9, 3.424928409639603*^9}}],

Cell["Term excluding factor C, which can be integrated in y", "Text",
 CellChangeTimes->{{3.405690303565764*^9, 3.405690323803512*^9}, {
  3.405690427766193*^9, 3.405690440196372*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3a", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0."}]}], ";"}]], "Input",
 CellChangeTimes->{{3.440936154513973*^9, 3.440936174035672*^9}}],

Cell["\<\
Get term in factor of C and check that the combination, adding previous \
contribution, reconstructs a3a\
\>", "Text",
 CellChangeTimes->{{3.405688495447377*^9, 3.405688524661201*^9}, {
  3.405690464708074*^9, 3.405690509076673*^9}, {3.424929839719086*^9, 
  3.424929850849363*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3a1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a3a", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"a3a", "-", 
  RowBox[{"C", " ", "a3a1"}], " ", "-", " ", 
  RowBox[{"(", 
   RowBox[{"a3a", " ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.424929175820322*^9, 3.424929198990442*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4056885308606787`*^9, 3.40570381692071*^9, 
  3.405708667588608*^9, 3.4057535986938543`*^9, 3.424929200397949*^9, 
  3.435143230683322*^9, 3.440936179415065*^9}]
}, Open  ]],

Cell["\<\
a3a1I = Integrate[a3a1, y];
a3a1I2 = Integrate[a3a1I, y];\
\>", "Text",
 CellChangeTimes->{
  3.4057537709319763`*^9, {3.424929276730252*^9, 3.424929279715138*^9}, {
   3.424929750425013*^9, 3.424929751340458*^9}, 3.424929792164733*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3a1I2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"U", "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], " ", 
          
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}]}], 
        ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["f2a", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f2a", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f2a", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             RowBox[{"2", "  ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["U", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["f2a", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
     "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a3a1I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a3a1"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424929592119862*^9, 3.424929655697013*^9}, {
  3.424929691130295*^9, 3.424929723245533*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424929725753221*^9, 3.435143247955101*^9, 
  3.440936185810449*^9}]
}, Open  ]],

Cell["\<\
Solvability is satisfied since all components of a3a integrate twice in y. \
Notice that it would be sufficient to check that the solvability condition is \
satisfied on the first integral but more compact expressions are obtained \
when a second primitive can be obtained. \
\>", "Text",
 CellChangeTimes->{{3.405690369471695*^9, 3.405690390351179*^9}, {
  3.405746127058013*^9, 3.405746150970755*^9}, {3.405771248852193*^9, 
  3.405771249117156*^9}, {3.405771324636036*^9, 3.405771476043433*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", "factor", " ", "of", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{"Group", " ", "of", " ", "all", " ", "terms", " ", "containing", " ",
   
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}], " ", "in", " ", "factor"}]], "Text",
 CellChangeTimes->{{3.405690572298355*^9, 3.405690599510146*^9}, {
  3.4057574744603233`*^9, 3.405757483084566*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a33", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a31", "]"}], ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.424929880269172*^9, 3.42492988634174*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", "a3b"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3b", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"a33", " ", "/.", " ", "Rulea"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.405690674595083*^9, {3.424929900639438*^9, 3.424929917984903*^9}}],

Cell["Term not in factor of C within a3b", "Text",
 CellChangeTimes->{{3.405690618705862*^9, 3.405690622111414*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3b0", "=", 
  RowBox[{"a3b", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f2b", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{"D", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f2a", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.40569067849599*^9, 3.405709767863743*^9, 
  3.405753898377462*^9, 3.424929942838567*^9, 3.435143283823585*^9, 
  3.44093622233104*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3b0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a3b0", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.424929947335741*^9, 3.424929970060273*^9}, {
  3.424930018945308*^9, 3.424930079287381*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"D", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f1", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f2a", "[", "y", "]"}], "-", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{"2", " ", "D", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.424929964188506*^9, 3.424929971547486*^9}, {
   3.424930065414791*^9, 3.424930084462213*^9}, 3.435143284823285*^9, 
   3.440936225207638*^9}]
}, Open  ]],

Cell["\<\
Term in factor of C within a3b, checking that it combines with a3b0 to \
reconstruct a3b\
\>", "Text",
 CellChangeTimes->{{3.4056908582981787`*^9, 3.405690913088511*^9}, {
  3.405709381407221*^9, 3.405709386605586*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3b2", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a3b", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"a3b", " ", "-", 
  RowBox[{"C", " ", "a3b2"}], " ", "-", " ", "a3b0"}]}], "Input",
 CellChangeTimes->{{3.405709392793869*^9, 3.405709394330489*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405690920055438*^9, 3.405709772691623*^9, 
  3.405753971191379*^9, 3.424930100996744*^9, 3.42493089345565*^9, 
  3.435143287947878*^9, 3.440936228571939*^9}]
}, Open  ]],

Cell["\<\
Integrate twice a3b2, completing the proof of solvability for a3b\
\>", "Text",
 CellChangeTimes->{{3.405690998215687*^9, 3.405691050436213*^9}}],

Cell["\<\
a3b2I = Integrate[a3b2, y]
a3b2I2 = Integrate[a3b2I, y]\
\>", "Text",
 CellChangeTimes->{
  3.405691071157219*^9, {3.424930120655591*^9, 3.424930135243004*^9}, 
   3.424930688343996*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3b2I2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{"f1", "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], ")"}]}],
       "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a3b2I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a3b2"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424931101510121*^9, 3.424931132601686*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.424931087387912*^9, {3.424931118306033*^9, 3.424931141390351*^9}, 
   3.43514329269075*^9, 3.440936231469362*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  RowBox[{"a3d", "  ", "[", "S", "]"}]}]], "Subsubsection",
 CellChangeTimes->{{3.424954851109949*^9, 3.424954855093057*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3d", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"a31", " ", "/.", " ", "Rulea"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.424931455143082*^9, 3.424931460423517*^9}}],

Cell["Extract the contribution that does not contain C", "Text",
 CellChangeTimes->{{3.405709452831823*^9, 3.405709487758203*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3d0", "=", 
  RowBox[{"a3d", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"U", "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["f2b", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.405710513092377*^9, 3.405754662837373*^9, 
  3.424931470954106*^9, 3.435143332292131*^9, 3.440936238699262*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"a3d0", "+", 
    RowBox[{"U", "[", "y", "]"}]}], ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.424931515159451*^9, 3.424931558149137*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"U", "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f2b", "[", "y", "]"}], "-", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.424931532360037*^9, 3.42493156002175*^9}, 
   3.435143333470945*^9, 3.440936244856887*^9}]
}, Open  ]],

Cell["Coefficient in front of C in a3d", "Text",
 CellChangeTimes->{{3.405710925928004*^9, 3.405710928733447*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3d2", " ", "=", 
   RowBox[{"Improve", "[", " ", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a3d", ",", "C"}], "]"}], " ", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.405711887382365*^9, {3.4057547683618507`*^9, 3.4057547689028893`*^9}, {
   3.424931591495112*^9, 3.424931621829126*^9}}],

Cell["\<\
Mathematica does not integrate this expression but after a few manipulations \
we get an expression for a3d2 as the sum of two derivatives plus a residual \
term.
In the residual term, f1'[y] has CosI symmetry. Its product with U[y]U'[y] \
has SinI symmetry with zero mean.
Hence the solvability condition is satisfied for all the terms contributing \
to a3d\
\>", "Text",
 CellChangeTimes->{{3.405712617213736*^9, 3.405712705533528*^9}, {
  3.405712750084974*^9, 3.405712913677759*^9}, {3.424932435975783*^9, 
  3.424932443803413*^9}, {3.42502059648781*^9, 3.425020597382921*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3d2P", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"U", "[", "y", "]"}], "3"]}], "+", 
            RowBox[{
             RowBox[{"U", "[", "y", "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
         RowBox[{"5", "/", "2"}]]], 
       RowBox[{
        RowBox[{"f1", "'"}], "[", "y", "]"}]}], ",", "y"}], "]"}], "-", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
        SqrtBox[
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]]], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "2"}], "}"}]}], "]"}], 
     RowBox[{"f1", "[", "y", "]"}]}], "-", "  ", 
    FractionBox[
     RowBox[{"\[Mu]", " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}]}], 
  ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a3d2P", "-", "a3d2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.424931997109471*^9, 3.424932037599298*^9}, {
  3.424932154922573*^9, 3.424932239276746*^9}, {3.424932297225535*^9, 
  3.424932297525247*^9}, {3.424932350838209*^9, 3.424932406520563*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.424932255969011*^9, 3.424932305594875*^9}, {
   3.424932400090653*^9, 3.424932419109431*^9}, 3.435143341753889*^9, 
   3.440936250375472*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a3g"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3g", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"a31", ",", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["f1", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.4057135888749*^9, 3.405754999269525*^9, 
  3.42493271991169*^9, 3.435143355387602*^9, 3.440936256033495*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification", "Subsubsection"],

Cell["\<\
Assemble all the contribution found at order 3 plus the linear term in \
\[Psi]3, and check the sum against a3\
\>", "Text",
 CellChangeTimes->{{3.405713595570601*^9, 3.40571365848319*^9}, {
  3.40571370802528*^9, 3.405713764152111*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3N", "=", 
   RowBox[{
    RowBox[{"a3g", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", "  ", 
    RowBox[{"a3d", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], 
     RowBox[{"(", 
      RowBox[{"a3b", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], " ", ")"}]}], "+", " ", 
    RowBox[{"a3a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "3"]}], "+", "  ", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]3", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"a3N", "-", "a3"}], " ", "/.", " ", "Rulea"}], "]"}], "]"}], " ",
   "]"}]}], "Input",
 CellChangeTimes->{
  3.40571373382877*^9, {3.435143388193505*^9, 3.43514339956117*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.40571369948894*^9, 3.405713782318974*^9, {3.405754986385345*^9, 
   3.4057550042718554`*^9}, 3.424932704983323*^9, 3.424932745821245*^9, 
   3.435143403317091*^9, 3.440936264958264*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection",
 CellChangeTimes->{{3.40569149000653*^9, 3.405691494113007*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rule3", "=", 
   RowBox[{"\[Psi]3", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f3g", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", "  ", 
       RowBox[{
        RowBox[{"f3d", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"f3b", "[", "#3", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[CurlyPhi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", 
          RowBox[{"f3h", "   ", 
           OverscriptBox["r", "~"]}]}], ")"}]}], "+", " ", 
       RowBox[{
        RowBox[{"f3a", "[", "#3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], "3"]}]}], " ", "&"}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.435143412992421*^9, 3.435143443289178*^9}}],

Cell["\<\
f3a has SinI symmetry
f3b has SinP symmetry
f3d has SinI symmetry
f3g has SinI symmetry
f3h has SinI symmetry\
\>", "Text",
 CellChangeTimes->{{3.435143465080358*^9, 3.435143481132388*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 4", "Section"],

Cell[TextData[{
 "Extract order 4 terms from the general expansion, use formal solution to \
order 0, 1, 2 and 3 equations and perform algebraic simplication.\nNeed to be \
put under the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]4", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member\nNo attemps to simplify here.\nThe terms a4g, a4\[AGrave] \
and a4r require the symmetry assumption to satisfy the solvability condition.\
\nThe terms a4l and a4l provide the amplitude equation. "
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}, {
  3.405685906475298*^9, 3.405685933174532*^9}, {3.405688214542055*^9, 
  3.405688233724618*^9}, {3.405688414807213*^9, 3.405688425967601*^9}, {
  3.405713897641922*^9, 3.405713898274895*^9}, {3.40575505879291*^9, 
  3.4057550692681227`*^9}, {3.426489210888645*^9, 3.426489316460619*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4", " ", "=", " ", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", ">", "0"}], " ", "&&", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", ">", "0"}]}], ",", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"NS2", ",", "\[Epsilon]", ",", "4"}], "]"}], "   ", "//.", " ",
       
      RowBox[{"{", 
       RowBox[{"Rule0", ",", "Rule1", ",", "Rule2", ",", "Rule3"}], "}"}]}]}],
     "  ", "]"}]}], ";"}]], "Input"],

Cell["Rearrange a4 to prepair extraction", "Text",
 CellChangeTimes->{{3.4057550866309853`*^9, 3.4057550996880407`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a41", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a4", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "4"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.435143564869027*^9, 3.435143570373898*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "4"]}], ":", " ", 
  "a4a"}]], "Subsubsection",
 CellChangeTimes->{{3.424947516757441*^9, 3.424947541815585*^9}, {
  3.426489087366361*^9, 3.426489088394109*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a41", ",", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], "4"]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.42493282770303*^9, 3.424932829754728*^9}}],

Cell["\<\
Contribution that does not contain C.
Can be integrated and satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.4057551808796577`*^9, 3.405755253445551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4a0", "=", 
  RowBox[{"a4a", "  ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f3a", 
   TagBox[
    RowBox[{"(", "3", ")"}],
    Derivative],
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{3.405755374229994*^9, 3.424932836096854*^9, 
  3.435143581897046*^9, 3.440936280933719*^9}]
}, Open  ]],

Cell["Get the rest of a4a", "Text",
 CellChangeTimes->{{3.40575533835573*^9, 3.405755363289391*^9}, {
  3.424933018921989*^9, 3.424933022363526*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4a1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a4a", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4a", " ", "-", " ", 
   RowBox[{"C", " ", "a4a1"}], "-", "a4a0"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.424932850961348*^9, {3.424932938032786*^9, 3.424933005871961*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424933007178779*^9, 3.435143585887935*^9, 
  3.44093628342932*^9}]
}, Open  ]],

Cell["Integrate  and check ", "Text",
 CellChangeTimes->{{3.4057554086968327`*^9, 3.405755430519291*^9}, 
   3.4057555228684273`*^9, {3.405760252086955*^9, 3.405760259206244*^9}, {
   3.424949444243932*^9, 3.424949450415943*^9}}],

Cell["\<\
a4a1I = Integrate[a4a1, y];
a4a1I2 = Integrate[a4a1I, y]\
\>", "Text",
 CellChangeTimes->{{3.405755545525198*^9, 3.4057555760568113`*^9}, {
  3.4057557082657213`*^9, 3.405755742490711*^9}, {3.424933495827059*^9, 
  3.424933504301467*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4a1I2a", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], " ", 
          
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}]}], 
        ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], " ", 
          
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
         RowBox[{"4", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"6", " ", 
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]", "-", 
            RowBox[{"4", " ", "\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["f1", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["f1", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
           ")"}]}]}], ")"}]}], ")"}]}], "/", 
    RowBox[{"(", 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"7", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4a1I2b", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
         " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"U", "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"\[Mu]", "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}]}],
        ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         RowBox[{"U", "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2a", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], "/",
     
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4a1I2c", "=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["f3a", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"3", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
      RowBox[{"6", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f3a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f3a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["f3a", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f3a", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"a4a1I2a", "+", "a4a1I2b", "+", "a4a1I2c"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a4a1"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.424943994305324*^9, 3.424944025193213*^9}, {
  3.42494405673797*^9, 3.424944077870964*^9}, {3.424949392022278*^9, 
  3.424949417011726*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4249493413115*^9, 3.424949421537894*^9, 
  3.435143595998731*^9, 3.440936286797624*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], "2"]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{"Group", " ", "of", " ", "all", " ", "terms", " ", "containing", "  ",
   "a", " ", "factor", " ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], "2"]}]], "Text",
 CellChangeTimes->{{3.4057575270756073`*^9, 3.405757546269353*^9}, {
  3.4057576059926167`*^9, 3.405757612014574*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a42", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a41", ",", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}], "]"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4c"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4c", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a42", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.4057590454196167`*^9, {3.424949501917177*^9, 3.424949503592385*^9}}],

Cell["\<\
Contribution that does not contain C.
Can be integrated and satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.4057551808796577`*^9, 3.405755253445551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c0", "=", 
   RowBox[{"a4c", "  ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}]}], ";"}], "\n", 
 RowBox[{"a4c0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4c0", ",", "y"}], "]"}]}], "\n", 
 RowBox[{"Solva", "[", "a4c0I", "]"}]}], "Input",
 CellChangeTimes->{{3.4057627942562113`*^9, 3.405762820166201*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], "-", 
     RowBox[{"3", " ", "D", " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f3b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", "D", " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405762828468363*^9, 3.424949511758758*^9, 
  3.435143621108506*^9, 3.440936303173456*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405762828468363*^9, 3.424949511758758*^9, 
  3.435143621108506*^9, 3.440936303190255*^9}]
}, Open  ]],

Cell["Get the rest of a4c in powers of A", "Text",
 CellChangeTimes->{{3.40575533835573*^9, 3.405755363289391*^9}, {
  3.405762994029332*^9, 3.4057629944598637`*^9}, {3.424949538418483*^9, 
  3.424949539128171*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a4c", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4c", "-", "a4c0", " ", "-", " ", 
   RowBox[{"C", " ", "a4c1"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4249495471513*^9, 3.424949579679052*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424949580187758*^9, 3.435143627435417*^9, 
  3.440936307749233*^9}]
}, Open  ]],

Cell["Integrate and check ", "Text",
 CellChangeTimes->{{3.4057554086968327`*^9, 3.405755430519291*^9}, 
   3.4057555228684273`*^9, {3.405760225057373*^9, 3.405760236790447*^9}, {
   3.424949586864693*^9, 3.424949589494624*^9}}],

Cell["\<\
a4c1I = Improve[Integrate[a4c1, y]];
a4c1I2 = Integrate[a4c1I, y]\
\>", "Text",
 CellChangeTimes->{{3.405762871324792*^9, 3.4057629051957693`*^9}, {
  3.424950288561341*^9, 3.424950291186582*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c1I2a", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"f1", "[", "y", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["f1", "\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}],
              " ", 
             RowBox[{
              SuperscriptBox["f2b", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "3"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Mu]", " ", 
            RowBox[{"f1", "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{"\[Mu]", "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["f1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
             ")"}]}], "+", 
           RowBox[{"6", " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["f2b", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Mu]", " ", 
            RowBox[{"f1", "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Mu]", "+", 
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{
                 SuperscriptBox["f1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
            " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["f2b", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         RowBox[{"U", "[", "y", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"f1", "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{"6", " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               SuperscriptBox["f2b", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], ")"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4c1I2b", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["f3b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f3b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{"f2a", "[", "y", "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f3b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["f2a", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f3b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{"f2a", "[", "y", "]"}]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{
              SuperscriptBox["f2a", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{
                SuperscriptBox["f2b", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
            RowBox[{
             RowBox[{
              SuperscriptBox["f1", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], " ", 
             RowBox[{
              SuperscriptBox["f3b", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]], ")"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"a4c1I2a", "+", "a4c1I2b"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a4c1"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424949609118788*^9, 3.424949631646508*^9}, {
   3.42494966254823*^9, 3.424949710384385*^9}, 3.424950198872686*^9, 
   3.424950278130341*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424950214290304*^9, 3.435143631454321*^9, 
  3.440936310372881*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{"Group", " ", "of", " ", "all", " ", "terms", " ", "containing", "  ",
   "a", " ", "factor", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Text",
 CellChangeTimes->{{3.4057575270756073`*^9, 3.405757546269353*^9}, {
  3.405757599066083*^9, 3.405757622894477*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a43", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a41", ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", 
  RowBox[{"a4g", " ", "[", "S", "]"}]}]], "Subsubsection",
 CellChangeTimes->{{3.424954739225724*^9, 3.424954743173667*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4g", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a43", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.4057688735777407`*^9, {3.42495166536996*^9, 3.424951667940716*^9}}],

Cell["\<\
Contribution that does not contain C.
Can be integrated and satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.4057551808796577`*^9, 3.405755253445551*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4g0", "=", 
   RowBox[{"a4g", " ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{3.405767457084242*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4gOI", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4g0", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4gOI", "]"}]}], "Input",
 CellChangeTimes->{{3.4057674653494883`*^9, 3.405767485721105*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f3d", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.435144264181355*^9, 3.440936324037871*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.435144264181355*^9, 3.440936324093194*^9}]
}, Open  ]],

Cell["Get  the rest of a4g ", "Text",
 CellChangeTimes->{{3.40575533835573*^9, 3.405755363289391*^9}, {
  3.405762994029332*^9, 3.4057629944598637`*^9}, {3.405768933023402*^9, 
  3.405768940484323*^9}, {3.4057707003752127`*^9, 3.4057707137701807`*^9}, {
  3.405770941336204*^9, 3.40577094511432*^9}, {3.424951690735821*^9, 
  3.424951695210219*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4g1", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a4g", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4gl", " ", "=", 
   RowBox[{"CoefficientList", "[", " ", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a4g", ",", "C"}], "]"}], ",", "A"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4g", "-", "a4g0", "-", " ", 
   RowBox[{"C", " ", "a4g1"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.424951779031792*^9, 3.424951838346196*^9}, {
  3.435145211716375*^9, 3.435145251475447*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.42495183580442*^9, 3.424951839213915*^9}, 
   3.435143667995585*^9, 3.435144272544712*^9, 3.435145169433803*^9, {
   3.43514523610472*^9, 3.435145252663873*^9}, 3.440936327035112*^9}]
}, Open  ]],

Cell["\<\
This contribution cannot be integrated but, after some manipulations, it is \
possible to extract an integrable part on which the solvability condition can \
be tested and a non integrable part for which the solvability condition is \
obtained due to the symmetries\
\>", "Text",
 CellChangeTimes->{{3.4057691019715643`*^9, 3.4057691027106447`*^9}, {
   3.405769245709103*^9, 3.405769281169829*^9}, {3.405769829880949*^9, 
   3.405769943488309*^9}, {3.424951703685236*^9, 3.424951704200429*^9}, 
   3.42495176614767*^9, {3.424951852497225*^9, 3.424951866615901*^9}, 
   3.424951916576213*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4g1", "=", 
   RowBox[{"Improve", "[", "a4gl", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.4057698240388317`*^9, 3.435143759430593*^9, 3.435144322203866*^9, {
   3.435144980974272*^9, 3.435144988850668*^9}, {3.435145173623255*^9, 
   3.435145177510557*^9}, 3.435145270667494*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4g1Pa", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]], "-", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"5", "/", "2"}]]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], "+", 
       RowBox[{"3", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Mu]", " ", 
           RowBox[{"U", "[", "y", "]"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{
            SuperscriptBox["U", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]], " ", 
     RowBox[{
      RowBox[{"f2a", "'"}], "[", "y", "]"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"6", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       RowBox[{"4", "  ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]], " ", 
     RowBox[{
      RowBox[{"f2a", "''"}], "[", "y", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4g1Pb", "=", 
   FractionBox[
    RowBox[{"\[Mu]", " ", 
     RowBox[{"U", "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"U", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4g1Pc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"f2b", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}], "+", 
       
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}], "-", 
       
       RowBox[{
        RowBox[{"f1", "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["U", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{
            SuperscriptBox["f3d", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f3d", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f3d", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["U", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["f3d", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
     "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]]], 
     RowBox[{"f2a", "[", "y", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4g1P", "=", 
   RowBox[{"a4g1Pa", " ", "+", " ", 
    RowBox[{"D", "[", 
     RowBox[{"a4g1Pb", ",", "y"}], "]"}], "+", " ", 
    RowBox[{"D", "[", 
     RowBox[{"a4g1Pc", ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4g1", "-", "a4g1P"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4057693100629683`*^9, 3.405769575467018*^9}, 
   3.405770014013647*^9, {3.424952028827952*^9, 3.424952057789126*^9}, {
   3.424952094810216*^9, 3.424952096787772*^9}, {3.424953031514696*^9, 
   3.424953114492045*^9}, {3.424953161642638*^9, 3.424953185494167*^9}, {
   3.42495354035074*^9, 3.424953546727444*^9}, {3.424953639928789*^9, 
   3.424953654359181*^9}, 3.42495369830531*^9, {3.424954213445778*^9, 
   3.424954222035034*^9}, {3.424954271758819*^9, 3.42495428675451*^9}, {
   3.424954321126616*^9, 3.424954361793249*^9}, {3.42495442002086*^9, 
   3.424954435460361*^9}, {3.424954486107351*^9, 3.42495451160027*^9}}],

Cell[BoxData[
 RowBox[{"{", "0", "}"}]], "Output",
 CellChangeTimes->{3.4057700938079567`*^9, 3.424953674577627*^9, 
  3.42495372340194*^9, 3.42495423134469*^9, 3.424954444063457*^9, 
  3.424954520047071*^9, 3.435143693803852*^9, 3.43514377011624*^9, 
  3.435144330120016*^9, 3.435144994660621*^9, 3.43514518606759*^9, 
  3.435145274245078*^9, 3.440936331434083*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"All", " ", "the", " ", "non", " ", "integrated", " ", "terms", " ", 
  "in", " ", "a4g1Pa", "  ", "have", " ", "CosI", " ", "symmetry", " ", "and",
   " ", "hence", " ", "sum", " ", "to", " ", 
  RowBox[{"zero", "."}]}]], "Text",
 CellChangeTimes->{{3.405769981363545*^9, 3.4057700059682217`*^9}, {
   3.405770043009708*^9, 3.405770053187258*^9}, {3.405774628443433*^9, 
   3.405774643689392*^9}, {3.405774740191969*^9, 3.405774740901881*^9}, 
   3.424954559785905*^9, 3.424954693409757*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f2a", "''"}], "[", "y", "]"}], " ", "has", " ", "symmetry", " ", 
   "CosI"}], ",", " ", 
  RowBox[{
  "its", " ", "product", " ", "with", " ", "a", " ", "CosP", " ", "term", " ",
    "is", " ", "CosI", " ", "and", " ", "integrates", " ", "to", " ", 
   RowBox[{"zero", ".", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f2a", "'"}], "[", "y", "]"}]}], " ", "has", " ", "SinI", " ", 
   "symmetry"}], ",", " ", 
  RowBox[{"and", " ", 
   RowBox[{
    RowBox[{"U", "'"}], "[", "y", "]"}], 
   RowBox[{"U", "[", "y", "]"}], " ", "has", " ", "SinP", " ", "symmetry"}], 
  ",", " ", 
  RowBox[{
  "hence", " ", "there", " ", "are", " ", "two", " ", "products", " ", "CosI",
    " ", "SinI", " ", "SinI", " ", "and", " ", "CosI", " ", "CosI", " ", 
   "SinP", " ", "SinI", " ", "which", " ", "have", " ", "CosI", " ", 
   "symmetry", " ", "and", " ", "integrate", " ", "to", " ", 
   RowBox[{"zero", "."}]}]}]], "Text",
 CellChangeTimes->{{3.424954642147134*^9, 3.424954652996735*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4h"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4h", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a43", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.40577097598291*^9, {3.424955147550365*^9, 3.424955150748665*^9}}],

Cell["\<\
Contribution that does not contain C.
  Can be integrated and satisfies the solvability condition.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4h0", "=", 
  RowBox[{"a4h", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.405772134095028*^9, 3.405772134487248*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f3g", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.405771315175596*^9, 3.405772135947776*^9, 
  3.424955155471661*^9, 3.435144411476402*^9, 3.440936341874182*^9}]
}, Open  ]],

Cell["Get contribution in C, integrate it and check solvability", "Text",
 CellChangeTimes->{{3.405771165093082*^9, 3.405771184911344*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4h1", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a4h", ",", "C"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"a4h", "-", "a4h0", " ", "-", 
    RowBox[{"C", " ", "a4h1"}]}], "]"}], "3"}]}], "Input",
 CellChangeTimes->{
  3.4057709903100767`*^9, 3.4057710867285633`*^9, {3.424955211573497*^9, 
   3.424955232007339*^9}, 3.440936343217289*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424955243946653*^9, 3.435144414037404*^9, 
  3.440936347037867*^9}]
}, Open  ]],

Cell["\<\
a4h1I = Improve[Integrate[a4h1, y]];
a4h1I2 = Integrate[a4h1I, y]\
\>", "Text",
 CellChangeTimes->{
  3.4057709903100767`*^9, 3.4057710867285633`*^9, {3.424955211573497*^9, 
   3.424955232007339*^9}}],

Cell["Integrate and check", "Text",
 CellChangeTimes->{{3.42495536847847*^9, 3.424955371977152*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4h1I2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["f3g", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f3g", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f3g", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          " ", 
          RowBox[{
           SuperscriptBox["f3g", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a4h1I2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a4h1"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.424955306576038*^9, 3.424955358843573*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424955360147597*^9, 3.435144415392318*^9, 
  3.440936348411884*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  "a4l"}], "\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{
  "contributes", " ", "to", " ", "the", " ", "amplitude", " ", "equation"}], 
  ")"}]}], "Subsubsection",
 CellChangeTimes->{{3.40577326685183*^9, 3.405773276842127*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4l", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a41", ",", "  ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "4"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.405778535921381*^9, {3.424963677386166*^9, 3.424963678790344*^9}}],

Cell["\<\
Contribution independent of C.
  The two terms of a4l0 are of symmetry CosP, they have no primitive and \
provide a contribution to the amplitude equation.\
\>", "Text",
 CellChangeTimes->{{3.405773297999565*^9, 3.405773446969352*^9}, {
  3.405774550179636*^9, 3.405774566382914*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4l0", "=", 
  RowBox[{"a4l", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.405773449821535*^9, 3.4057734506448717`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"f1", "[", "y", "]"}]}], " ", 
   RowBox[{"U", "[", "y", "]"}]}], "-", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4057791487556553`*^9, 3.424963685674487*^9, 
  3.435144431567607*^9, 3.440936353654334*^9}]
}, Open  ]],

Cell["\<\
Now get the coefficient of C. It has no primitive but can be described as a \
sum of derivatives and residual terms.\
\>", "Text",
 CellChangeTimes->{{3.4057785839594183`*^9, 3.405778601640111*^9}, {
  3.4057786442864113`*^9, 3.40577874277704*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4l1", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a4l", ",", "C"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.424955660610357*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4l1Pa", " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"2", "  ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4l1Pb", " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]]], 
    RowBox[{"f2b", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4l1Pc", " ", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"\[Mu]", " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"U", "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
      RowBox[{"3", "/", "2"}]]], " ", 
    RowBox[{"f2b", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4l1Pd", "=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", "\[Mu]"}], " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
     RowBox[{"3", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"U", "[", "y", "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
     RowBox[{"3", "/", "2"}]]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4l1P", "=", " ", 
   RowBox[{"a4l1Pa", "+", " ", 
    RowBox[{"D", "[", 
     RowBox[{"a4l1Pb", ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], " ", "-", "  ", 
    RowBox[{"D", "[", 
     RowBox[{"a4l1Pc", ",", "y"}], "]"}], " ", "-", " ", 
    RowBox[{
     RowBox[{"f2b", "[", "y", "]"}], 
     RowBox[{"D", "[", 
      RowBox[{"a4l1Pd", ",", "y"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4l1", "-", "a4l1P"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405778804231544*^9, 3.405778954165442*^9}, {
   3.405779001962867*^9, 3.405779023790101*^9}, 3.405779106948366*^9, {
   3.405779311513914*^9, 3.405779330755417*^9}, {3.4057795204768047`*^9, 
   3.4057795345895157`*^9}, {3.405779690178726*^9, 3.405779700074843*^9}, {
   3.405780014437278*^9, 3.405780016437257*^9}, {3.424963720257463*^9, 
   3.424963766269344*^9}, {3.424963897130382*^9, 3.424963904720321*^9}, {
   3.424964135129139*^9, 3.424964156524633*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.405779125968079*^9, 3.405779172163254*^9, {3.405779337151836*^9, 
   3.405779364789768*^9}, 3.405779399805955*^9, 3.4057794547113457`*^9, 
   3.405779503702523*^9, 3.4057795368013783`*^9, 3.4057797019355297`*^9, 
   3.405780017913056*^9, 3.424964162043495*^9, 3.4351444357378*^9, 
   3.440936357781356*^9}]
}, Open  ]],

Cell["\<\
The first and the fourth term contribute as they are product of trig \
functions with same symmetry.\
\>", "Text"],

Cell["Check that nothing has been forgotten", "Text",
 CellChangeTimes->{{3.405780081706346*^9, 3.40578009218684*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4l", " ", "-", " ", "a4l0", " ", "-", " ", 
   RowBox[{"C", " ", "a4l1"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.405780096973837*^9, 3.405780145849922*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.405780130925108*^9, 3.405780147243774*^9}, 
   3.424964690311702*^9, 3.435144446282556*^9, 3.440936361204736*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  "a4n"}], "\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{
  "contributes", " ", "to", " ", "the", " ", "amplitude", " ", "equation"}], 
  ")"}]}], "Subsubsection",
 CellChangeTimes->{{3.40577306274051*^9, 3.405773131776634*^9}, {
  3.4057801891531677`*^9, 3.40578019344256*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4n", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a41", ",", "  ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"{", "D", "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.424956024281265*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "-", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.40578474080618*^9, 3.424956026518311*^9, 
  3.43514446372433*^9, 3.440936365266061*^9}]
}, Open  ]],

Cell["\<\
The first term makes a contribution to the amplitude equation and the \
secondone satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.405773034258717*^9, 3.405773056972809*^9}, {
  3.405773140256077*^9, 3.405773177236987*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], ":", " ", 
  RowBox[{"a4o", " ", "[", "S", "]"}]}]], "Subsubsection",
 CellChangeTimes->{{3.4057811527477016`*^9, 3.405781154299303*^9}, {
   3.424956161535799*^9, 3.424956171454131*^9}, 3.424963619929375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4o", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a41", ",", "  ", 
       SuperscriptBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], " ", "]"}], " ", ",",
      
     RowBox[{"{", 
      RowBox[{"D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.405774813424066*^9, 3.405774821561133*^9}, {
  3.424956041204938*^9, 3.424956043033507*^9}}],

Cell["\<\
The contribution independent of C has a primitive and satisfies the \
solvability condition\
\>", "Text",
 CellChangeTimes->{{3.405775267257039*^9, 3.405775312793243*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o0", "=", 
   RowBox[{"a4o", " ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}]}], ";"}], "\n", 
 RowBox[{"a4o0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4o0", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4oI0", "]"}]}], "Input",
 CellChangeTimes->{{3.405775332191866*^9, 3.4057753823561068`*^9}, {
  3.44093637133883*^9, 3.440936372524555*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], "-", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405775386767068*^9, 3.424956072983493*^9, 
  3.435144468454048*^9, 3.440936373131855*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405775386767068*^9, 3.424956072983493*^9, 
  3.435144468454048*^9, 3.440936373190627*^9}]
}, Open  ]],

Cell["Expand the rest of a4o in power of A", "Text",
 CellChangeTimes->{{3.405775392778092*^9, 3.405775408735867*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o1", " ", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a4o", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4o", "-", "a4o0", "-", 
   RowBox[{"C", " ", "a4o1"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.424962367748235*^9, 3.424962393352097*^9}, {
  3.424962619181573*^9, 3.424962654431784*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.424962648176953*^9, 3.424962655365897*^9}, 
   3.435144470511613*^9, 3.44093637602655*^9}]
}, Open  ]],

Cell["\<\
The term in C cannot be integrated but it can be sorted in several parts\
\>", "Text",
 CellChangeTimes->{{3.405776170244063*^9, 3.40577618342692*^9}, {
  3.4057764251543837`*^9, 3.405776436923333*^9}, {3.42496267632612*^9, 
  3.424962685185026*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o1aP", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["\[Mu]", "2"], 
           SuperscriptBox[
            RowBox[{"f1", "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"4", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        FractionBox[
         RowBox[{" ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], 
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]]]}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", "  ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
         
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]]], 
        RowBox[{"f2a", "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SuperscriptBox["f2b", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["U", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{
              SuperscriptBox["f2b", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["U", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
           RowBox[{"3", "/", "2"}]]}], ")"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "+", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{"U", "[", "y", "]"}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"U", "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              RowBox[{"U", "[", "y", "]"}]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{
               SuperscriptBox["U", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
         ")"}], "/", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
         RowBox[{"3", "/", "2"}]]}], 
       SuperscriptBox[
        RowBox[{
         RowBox[{"f1", "'"}], "[", "y", "]"}], "2"]}], ",", "y"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4o1bP", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\[Mu]", " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["U", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["U", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "4"], "+", 
           RowBox[{"3", " ", "\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"U", "[", "y", "]"}], "3"], " ", 
            RowBox[{
             SuperscriptBox["U", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
       "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}]}], 
     SuperscriptBox[
      RowBox[{
       RowBox[{"f1", "'"}], "[", "y", "]"}], "2"]}], "-", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "4"]}], "+", 
        RowBox[{"5", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "4"]}]}], ")"}], "/", 
      RowBox[{"(", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
        RowBox[{"5", "/", "2"}]], ")"}]}], 
     SuperscriptBox[
      RowBox[{
       RowBox[{"f1", "''"}], "[", "y", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{
             RowBox[{"U", "'"}], "[", "y", "]"}], "2"], 
           RowBox[{
            RowBox[{"f2a", "'"}], "[", "y", "]"}]}], ",", "y"}], "]"}]}], "+",
        
       RowBox[{"6", "\[Mu]", " ", 
        RowBox[{"U", "[", "y", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"U", "[", "y", "]"}], 
           RowBox[{
            RowBox[{"f2a", "'"}], "[", "y", "]"}]}], ",", "y"}], "]"}]}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"U", "[", "y", "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]], ")"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.424958983886849*^9, 3.424958990096006*^9}, {
   3.424959031534348*^9, 3.424959096097489*^9}, {3.424959160517371*^9, 
   3.424959171594864*^9}, 3.424960894429665*^9, {3.424961178254939*^9, 
   3.424961214583041*^9}, {3.424961558994031*^9, 3.424961637377953*^9}, {
   3.424961694012289*^9, 3.424961746518656*^9}, {3.42496204848552*^9, 
   3.424962060541673*^9}, 3.424962176961875*^9, {3.424962721833822*^9, 
   3.424962738888405*^9}, {3.424963155679005*^9, 3.424963254583392*^9}, 
   3.4249632953605*^9, {3.424963482587645*^9, 3.424963492103314*^9}, 
   3.424963523930197*^9}],

Cell["\<\
It is easy to check that all the terms which are not under the derivative in \
a4o1bP are with CosI symmetry and integrate to zero\
\>", "Text",
 CellChangeTimes->{{3.405777459366008*^9, 3.4057774700174217`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4o1c", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "7"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Mu]", "2"], 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "5"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"]}], "+", 
         RowBox[{"7", " ", 
          RowBox[{"U", "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"5", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["U", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "5"], " ", 
       SuperscriptBox["\[Mu]", "3"], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["U", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", 
       SuperscriptBox["\[Mu]", "4"], " ", 
       SuperscriptBox[
        RowBox[{"U", "[", "y", "]"}], "6"], " ", 
       RowBox[{
        SuperscriptBox["U", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"U", "[", "y", "]"}], "2"]}], "+", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["U", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], 
       RowBox[{"7", "/", "2"}]]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.424960147410371*^9, 3.424960163040725*^9}, {
   3.424960665300648*^9, 3.424960705316272*^9}, {3.424960789191353*^9, 
   3.424960789640733*^9}, 3.424962483700739*^9}],

Cell["\<\
The numerator is a sum of terms with CosI symmetry, which is preserved by the \
division by the denominator in CosP, integrating a4o1c to zero. Let us check \
it numerically for some examples.\
\>", "Text",
 CellChangeTimes->{{3.405777517685257*^9, 3.405777657205868*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"a4o1c", "  ", "/.", 
     RowBox[{"{", " ", 
      RowBox[{"Flow1", ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"a4o1c", "  ", "/.", 
     RowBox[{"{", " ", 
      RowBox[{"Flow2", ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"a4o1c", "  ", "/.", 
     RowBox[{"{", " ", 
      RowBox[{"Flow3", ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData["0``12.205890367704667"], "Output",
 CellChangeTimes->{
  3.405778469935143*^9, 3.424960735462923*^9, 3.424960796192548*^9, 
   3.435144480352278*^9, 3.43514452237787*^9, {3.440936381885632*^9, 
   3.440936400713407*^9}}],

Cell[BoxData["0``14.090905755020245"], "Output",
 CellChangeTimes->{
  3.405778469935143*^9, 3.424960735462923*^9, 3.424960796192548*^9, 
   3.435144480352278*^9, 3.43514452237787*^9, {3.440936381885632*^9, 
   3.440936401039231*^9}}],

Cell[BoxData["0``14.549782725157412"], "Output",
 CellChangeTimes->{
  3.405778469935143*^9, 3.424960735462923*^9, 3.424960796192548*^9, 
   3.435144480352278*^9, 3.43514452237787*^9, {3.440936381885632*^9, 
   3.440936401293532*^9}}]
}, Open  ]],

Cell["Chek that a4o1 is reconstructed", "Text",
 CellChangeTimes->{{3.424962537328735*^9, 3.424962565235955*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4o1", "-", "a4o1aP", "-", "a4o1bP", "-", "a4o1c"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.42496333131156*^9, 3.424963334104093*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.424962597555139*^9, 3.424963336176897*^9, 
  3.424963510431146*^9, 3.435144539913996*^9, 3.440936415253761*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Verification", "Subsubsection",
 CellChangeTimes->{3.405783109694642*^9, 3.424787620444553*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Expand", "[", "a4", "]"}], "-", "a41"}], "]"}]], "Input",
 CellChangeTimes->{{3.4057824851749697`*^9, 3.405782490104938*^9}, {
  3.405782524941266*^9, 3.405782532191402*^9}, {3.405782631775648*^9, 
  3.405782636736158*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.40578534016892*^9, 3.424963654910413*^9, 
  3.440936435768527*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4NN", "=", 
   RowBox[{
    RowBox[{"a4o", " ", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], "+", 
    RowBox[{"a4n", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{"a4l", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a4g", "  ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "+", 
       RowBox[{"a4h", " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], " ", "+", 
    "\[IndentingNewLine]", 
    RowBox[{"a4c", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "+", " ", 
    RowBox[{"a4a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "4"]}], "+", "  ", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]4", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{"a4NN", "-", "a41"}], "]"}], " ", "/.", " ", "Rulea"}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.4057566039740477`*^9, {3.405785280810128*^9, 3.405785289698398*^9}, {
   3.435144556354406*^9, 3.435144626950073*^9}, {3.440936836311755*^9, 
   3.440936859805665*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.405780644817511*^9, 3.405785296758334*^9, {3.435144619568892*^9, 
   3.435144629153667*^9}, 3.440936437556314*^9, {3.440936856215377*^9, 
   3.440936862772393*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dump / Recover", "Subsection",
 CellChangeTimes->{{3.4057803757773247`*^9, 3.405780388865893*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DumpSave", "[", 
  RowBox[{"\"\<CH-eff1-nu-12.m6.mx\>\"", ",", "\"\<Global`\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.405707255571572*^9, 3.405707269590346*^9}, {
  3.405707365657104*^9, 3.405707399428372*^9}, {3.405708293588033*^9, 
  3.405708330550449*^9}, {3.40575679967369*^9, 3.405756808002439*^9}, {
  3.435144640929328*^9, 3.435144642387434*^9}}],

Cell[BoxData[
 RowBox[{"{", "\<\"Global`\"\>", "}"}]], "Output",
 CellChangeTimes->{{3.40570830006631*^9, 3.405708331989448*^9}, 
   3.405713795903619*^9, 3.405753555714876*^9, 3.405754634680348*^9, 
   3.4057550220528812`*^9, 3.405756959529352*^9, 3.405758134973331*^9, 
   3.405761818912491*^9, 3.405766506606394*^9, 3.405768825483378*^9, 
   3.405772491723752*^9, 3.405774122117296*^9, 3.405774384697494*^9, 
   3.405776566513393*^9, 3.405780205698803*^9, 3.405784783431664*^9, 
   3.43514464733951*^9, 3.435145297026515*^9, 3.440936443685497*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "CH-eff1-nu-12.m6.mx"}]], "Input",
 CellChangeTimes->{{3.4057529715345097`*^9, 3.405752973934311*^9}, {
  3.405756812713182*^9, 3.405756814598175*^9}, {3.435144652437927*^9, 
  3.435144653833208*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Translation tools", "Subsection",
 CellChangeTimes->{{3.424964651440337*^9, 3.424964652621289*^9}, {
  3.424965736704426*^9, 3.424965748340623*^9}, {3.426489583039664*^9, 
  3.426489586863857*^9}}],

Cell["\<\
Used for the translation from Sin[\[Theta][y]] to U[y] \
\>", "Text",
 CellChangeTimes->{{3.42496486454377*^9, 3.424964932483436*^9}}],

Cell[BoxData[{
 RowBox[{"Recode0", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], "\[Rule]", 
     RowBox[{"1", "-", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}]}], ",", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], "->", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], ")"}], "2"]}], 
    ",", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], "->", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], ")"}], "3"]}]}],
    "}"}]}], "\n", 
 RowBox[{"Recode1", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "\[Rule]", 
     RowBox[{"U", "[", "y", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"U", "'"}], "[", "y", "]"}], 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]]}]}], "}"}]}], "\n", 
 RowBox[{"Recode2", "=", 
  RowBox[{"{", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], "\[Rule]", 
    RowBox[{"1", "-", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "2"]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Recode3", " ", "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}]}], 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"Recode4", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Theta]", 
      TagBox[
       RowBox[{"(", "3", ")"}],
       Derivative],
      MultilineFunction->None], "[", "y", "]"}], "->", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["U", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}], "+", 
       RowBox[{"3", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}]}], 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]], "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"]}]}], 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.424937585752509*^9, 3.424937594265153*^9}, 
   3.424938264593386*^9, {3.424938532334188*^9, 3.424938533488309*^9}, 
   3.424938570807581*^9, {3.424952243388058*^9, 3.424952266613115*^9}, {
   3.424952313564542*^9, 3.424952359645446*^9}, {3.424952427542885*^9, 
   3.424952446513098*^9}, {3.424952746585351*^9, 3.42495284158733*^9}, {
   3.424952923253182*^9, 3.424952926780795*^9}, {3.424959449088426*^9, 
   3.424959546597484*^9}, {3.424959585231411*^9, 3.424959625076684*^9}, {
   3.424959817590693*^9, 3.42495983257623*^9}}],

Cell["Example of usage", "Text",
 CellChangeTimes->{{3.424965717368748*^9, 3.42496572069955*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"TrigExpand", "[", 
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"TrigExpand", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "86"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                  RowBox[{"5", " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"3", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"5", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], 
                " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}], "5"]}], "-", 
               RowBox[{"16", " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "y", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"5", " ", "\[Mu]", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"3", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
                  RowBox[{"6", " ", 
                   SuperscriptBox[
                    RowBox[{"Cos", "[", 
                    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
                   RowBox[{
                    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"8", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"\[Mu]", " ", 
                   RowBox[{"Sin", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
                  RowBox[{"4", " ", 
                   RowBox[{"(", 
                    RowBox[{"4", "+", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], 
                   " ", 
                   RowBox[{
                    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"32", " ", "\[Mu]", " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
                RowBox[{
                 SuperscriptBox["\[Theta]", 
                  TagBox[
                   RowBox[{"(", "3", ")"}],
                   Derivative],
                  MultilineFunction->None], "[", "y", "]"}]}], "+", 
               RowBox[{"32", " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
                SuperscriptBox[
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
                RowBox[{
                 SuperscriptBox["\[Theta]", 
                  TagBox[
                   RowBox[{"(", "3", ")"}],
                   Derivative],
                  MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
            ")"}]}], " ", "/.", "Recode4"}], " ", "/.", "Recode3"}], "]"}], 
       "]"}], " ", "/.", "Recode1"}], "]"}], " ", "/.", "Recode2"}], " ", "/.",
    "Recode1"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "16"}], " ", "\[Mu]", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "5"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "5"]}], "-", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"10", " ", 
     RowBox[{"U", "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["U", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "4"], " ", 
     RowBox[{
      SuperscriptBox["U", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"U", "[", "y", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["U", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["U", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["U", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.424965805501355*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{897, 738},
WindowMargins->{{115, Automatic}, {Automatic, 16}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>"CH-eff.nb.ps",
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {72, 72}}},
Magnification->1.,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Report"}, "StandardReport.nb", CharacterEncoding -> 
       "iso8859-1"]]], 
   Cell[
    StyleData["Output"], FontSize -> 12], 
   Cell[
    StyleData["Input"], FontFamily -> "Utopia", FontSize -> 12, FontWeight -> 
    "Bold", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], FontSize -> 14]}, Visible -> False, 
  FrontEndVersion -> "6.0 for Linux x86 (32-bit) (June 19, 2007)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 182, 4, 192, "Title"],
Cell[775, 29, 290, 12, 244, "Author"],
Cell[CellGroupData[{
Cell[1090, 45, 788, 22, 139, "Subtitle"],
Cell[1881, 69, 24, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[1930, 73, 33, 0, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[1988, 77, 149, 3, 37, "Input",
 InitializationCell->True],
Cell[2140, 82, 530, 10, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2719, 98, 32, 0, 27, "Subsubsection"],
Cell[2754, 100, 118, 3, 37, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2909, 108, 34, 0, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[2968, 112, 437, 14, 42, "Input",
 InitializationCell->True],
Cell[3408, 128, 553, 15, 43, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4010, 149, 101, 2, 27, "Subsubsection"],
Cell[4114, 153, 169, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[4308, 161, 1158, 38, 44, "Input",
 InitializationCell->True],
Cell[5469, 201, 1180, 36, 50, "Output"]
}, Open  ]],
Cell[6664, 240, 613, 17, 73, "Text"],
Cell[CellGroupData[{
Cell[7302, 261, 3458, 103, 81, "Input",
 InitializationCell->True],
Cell[10763, 366, 3382, 101, 65, "Output"],
Cell[14148, 469, 196, 5, 48, "Reference"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14393, 480, 130, 1, 75, "Section"],
Cell[CellGroupData[{
Cell[14548, 485, 49, 0, 27, "Subsection"],
Cell[14600, 487, 70, 1, 31, "Text",
 InitializationCell->True],
Cell[14673, 490, 270, 8, 39, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[14980, 503, 40, 0, 27, "Subsection"],
Cell[15023, 505, 177, 4, 31, "Text"],
Cell[15203, 511, 994, 32, 117, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16234, 548, 39, 0, 27, "Subsection"],
Cell[CellGroupData[{
Cell[16298, 552, 1761, 53, 89, "Input"],
Cell[18062, 607, 81871, 1363, 149, 69052, 1152, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[99982, 1976, 49, 0, 27, "Subsection"],
Cell[CellGroupData[{
Cell[100056, 1980, 1815, 58, 81, "Input"],
Cell[101874, 2040, 19953, 1146, 147, 15269, 1067, "GraphicsData", \
"PostScript", "Graphics"],
Cell[121830, 3188, 139, 4, 44, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[122018, 3198, 59, 0, 27, "Subsection"],
Cell[122080, 3200, 307, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[122412, 3210, 468, 14, 37, "Input"],
Cell[122883, 3226, 2999, 90, 86, "Output"]
}, Open  ]],
Cell[125897, 3319, 207, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[126129, 3327, 2212, 60, 140, "Input"],
Cell[128344, 3389, 127716, 2109, 170, 105133, 1737, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[256075, 5501, 274, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[256374, 5510, 2215, 60, 140, "Input"],
Cell[258592, 5572, 115885, 1917, 171, 95578, 1582, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[374538, 7496, 56, 0, 75, "Section"],
Cell[CellGroupData[{
Cell[374619, 7500, 51, 0, 27, "Subsection"],
Cell[374673, 7502, 502, 15, 31, "Text"],
Cell[375178, 7519, 1336, 37, 59, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[376551, 7561, 31, 0, 27, "Subsection"],
Cell[376585, 7563, 159, 3, 31, "Text"],
Cell[376747, 7568, 865, 23, 41, "Input",
 InitializationCell->True],
Cell[377615, 7593, 361, 11, 37, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[378025, 7610, 26, 0, 75, "Section"],
Cell[378054, 7612, 263, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[378342, 7622, 250, 6, 37, "Input"],
Cell[378595, 7630, 15924, 466, 463, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[394556, 8101, 39, 0, 27, "Subsection"],
Cell[394598, 8103, 190, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[394813, 8111, 218, 6, 37, "Input"],
Cell[395034, 8119, 380, 9, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[395463, 8134, 102, 1, 27, "Subsection"],
Cell[395568, 8137, 201, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[395794, 8145, 215, 5, 37, "Input"],
Cell[396012, 8152, 231, 3, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[396304, 8162, 51, 0, 75, "Section"],
Cell[CellGroupData[{
Cell[396380, 8166, 1266, 40, 42, "Input",
 InitializationCell->True],
Cell[397649, 8208, 1409, 42, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[399095, 8255, 216, 6, 37, "Input",
 InitializationCell->True],
Cell[399314, 8263, 364, 7, 37, "Output"]
}, Open  ]],
Cell[399693, 8273, 104, 1, 31, "Text"],
Cell[399800, 8276, 579, 17, 39, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[400416, 8298, 26, 0, 75, "Section"],
Cell[400445, 8300, 531, 11, 51, "Text"],
Cell[CellGroupData[{
Cell[401001, 8315, 334, 8, 37, "Input"],
Cell[401338, 8325, 16190, 466, 360, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[417565, 8796, 72, 0, 27, "Subsection"],
Cell[417640, 8798, 116, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[417781, 8803, 476, 14, 43, "Input"],
Cell[418260, 8819, 2642, 79, 86, "Output"]
}, Open  ]],
Cell[420917, 8901, 117, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[421059, 8906, 476, 14, 43, "Input"],
Cell[421538, 8922, 3144, 94, 86, "Output"]
}, Open  ]],
Cell[424697, 9019, 163, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[424885, 9025, 449, 14, 43, "Input"],
Cell[425337, 9041, 1567, 45, 70, "Output"]
}, Open  ]],
Cell[426919, 9089, 166, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[427110, 9095, 439, 14, 43, "Input"],
Cell[427552, 9111, 793, 24, 73, "Output"]
}, Open  ]],
Cell[428360, 9138, 179, 4, 31, "Text"],
Cell[428542, 9144, 1696, 53, 76, "Input"],
Cell[CellGroupData[{
Cell[430263, 9201, 1022, 34, 43, "Input"],
Cell[431288, 9237, 208, 3, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[431545, 9246, 120, 1, 27, "Subsection"],
Cell[431668, 9249, 181, 4, 25, "Commentary"],
Cell[CellGroupData[{
Cell[431874, 9257, 404, 13, 43, "Input"],
Cell[432281, 9272, 322, 7, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[432652, 9285, 65, 0, 27, "Subsection"],
Cell[432720, 9287, 781, 22, 24, "Commentary"],
Cell[433504, 9311, 474, 15, 40, "Input"],
Cell[CellGroupData[{
Cell[434003, 9330, 97, 2, 37, "Input"],
Cell[434103, 9334, 237, 4, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[434389, 9344, 43, 0, 27, "Subsection"],
Cell[434435, 9346, 459, 8, 43, "Commentary"],
Cell[CellGroupData[{
Cell[434919, 9358, 295, 9, 37, "Input"],
Cell[435217, 9369, 790, 21, 39, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[436056, 9396, 39, 0, 27, "Subsection"],
Cell[436098, 9398, 193, 4, 25, "Commentary"],
Cell[CellGroupData[{
Cell[436316, 9406, 507, 15, 43, "Input"],
Cell[436826, 9423, 597, 17, 43, "Output"]
}, Open  ]],
Cell[437438, 9443, 122, 1, 25, "Commentary"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[437609, 9450, 26, 0, 75, "Section"],
Cell[437638, 9452, 587, 12, 71, "Text"],
Cell[438228, 9466, 452, 13, 37, "Input"],
Cell[CellGroupData[{
Cell[438705, 9483, 131, 1, 27, "Subsection"],
Cell[438839, 9486, 247, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[439111, 9495, 486, 14, 27, "Subsubsection"],
Cell[439600, 9511, 654, 20, 43, "Input"],
Cell[440257, 9533, 239, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[440521, 9542, 127, 3, 37, "Input"],
Cell[440651, 9547, 387, 10, 40, "Output"]
}, Open  ]],
Cell[441053, 9560, 212, 4, 31, "Text"],
Cell[441268, 9566, 202, 5, 37, "Input"],
Cell[441473, 9573, 266, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[441764, 9583, 2755, 76, 119, "Input"],
Cell[444522, 9661, 186, 3, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[444757, 9670, 401, 11, 25, "Subsubsection"],
Cell[445161, 9683, 683, 21, 43, "Input"],
Cell[445847, 9706, 211, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[446083, 9714, 448, 12, 55, "Input"],
Cell[446534, 9728, 524, 14, 37, "Output"]
}, Open  ]],
Cell[447073, 9745, 239, 3, 31, "Text"],
Cell[447315, 9750, 305, 7, 37, "Input"],
Cell[447623, 9759, 199, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[447847, 9766, 962, 31, 94, "Input"],
Cell[448812, 9799, 117, 2, 37, "Output"]
}, Open  ]],
Cell[448944, 9804, 225, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[449194, 9811, 439, 10, 55, "Input"],
Cell[449636, 9823, 693, 19, 37, "Output"]
}, Open  ]],
Cell[450344, 9845, 276, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[450645, 9855, 427, 8, 37, "Input"],
Cell[451075, 9865, 141, 2, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[451277, 9874, 150, 2, 27, "Subsection"],
Cell[451430, 9878, 271, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[451726, 9888, 963, 29, 59, "Input"],
Cell[452692, 9919, 161, 2, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[452902, 9927, 39, 0, 27, "Subsection"],
Cell[CellGroupData[{
Cell[452966, 9931, 870, 27, 44, "Input"],
Cell[453839, 9960, 937, 28, 44, "Output"]
}, Open  ]],
Cell[454791, 9991, 133, 4, 51, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[454973, 10001, 26, 0, 75, "Section"],
Cell[455002, 10003, 1629, 29, 231, "Text"],
Cell[456634, 10034, 285, 8, 37, "Input"],
Cell[CellGroupData[{
Cell[456944, 10046, 65, 0, 27, "Subsection"],
Cell[457012, 10048, 154, 3, 31, "Text"],
Cell[457169, 10053, 1245, 40, 43, "Input"],
Cell[CellGroupData[{
Cell[458439, 10097, 346, 12, 27, "Subsubsection"],
Cell[458788, 10111, 606, 18, 44, "Input"],
Cell[459397, 10131, 184, 2, 31, "Text"],
Cell[459584, 10135, 177, 4, 37, "Input"],
Cell[459764, 10141, 292, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[460081, 10151, 393, 10, 55, "Input"],
Cell[460477, 10163, 211, 3, 37, "Output"]
}, Open  ]],
Cell[460703, 10169, 246, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[460974, 10179, 5139, 146, 142, "Input"],
Cell[466116, 10327, 117, 2, 37, "Output"]
}, Open  ]],
Cell[466248, 10332, 508, 8, 71, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[466793, 10345, 299, 9, 25, "Subsubsection"],
Cell[467095, 10356, 454, 12, 30, "Text"],
Cell[467552, 10370, 460, 14, 43, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[468049, 10389, 527, 18, 25, "Subsubsection"],
Cell[468579, 10409, 636, 19, 43, "Input"],
Cell[469218, 10430, 116, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[469359, 10435, 118, 3, 37, "Input"],
Cell[469480, 10440, 2460, 80, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[471977, 10525, 231, 5, 37, "Input"],
Cell[472211, 10532, 1826, 55, 58, "Output"]
}, Open  ]],
Cell[474052, 10590, 229, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[474306, 10599, 310, 7, 55, "Input"],
Cell[474619, 10608, 207, 3, 37, "Output"]
}, Open  ]],
Cell[474841, 10614, 155, 3, 31, "Text"],
Cell[474999, 10619, 196, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[475220, 10629, 3305, 97, 98, "Input"],
Cell[478528, 10728, 166, 3, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[478743, 10737, 414, 12, 25, "Subsubsection"],
Cell[479160, 10751, 611, 18, 43, "Input"],
Cell[479774, 10771, 130, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[479929, 10776, 118, 3, 37, "Input"],
Cell[480050, 10781, 1237, 39, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[481324, 10825, 208, 5, 37, "Input"],
Cell[481535, 10832, 900, 27, 37, "Output"]
}, Open  ]],
Cell[482450, 10862, 114, 1, 31, "Text"],
Cell[482567, 10865, 333, 8, 37, "Input"],
Cell[482903, 10875, 591, 11, 91, "Text"],
Cell[CellGroupData[{
Cell[483519, 10890, 2825, 83, 152, "Input"],
Cell[486347, 10975, 192, 3, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[486588, 10984, 309, 10, 25, "Subsubsection"],
Cell[CellGroupData[{
Cell[486922, 10998, 331, 11, 43, "Input"],
Cell[487256, 11011, 273, 6, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[487578, 11023, 37, 0, 27, "Subsubsection"],
Cell[487618, 11025, 247, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[487890, 11034, 1889, 61, 78, "Input"],
Cell[489782, 11097, 238, 4, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[490081, 11108, 104, 1, 27, "Subsection"],
Cell[490188, 11111, 2022, 62, 99, "Input"],
Cell[492213, 11175, 199, 7, 111, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[492461, 11188, 26, 0, 75, "Section"],
Cell[492490, 11190, 1029, 17, 131, "Text"],
Cell[493522, 11209, 586, 17, 37, "Input"],
Cell[494111, 11228, 120, 1, 31, "Text"],
Cell[494234, 11231, 1770, 56, 64, "Input"],
Cell[CellGroupData[{
Cell[496029, 11291, 461, 14, 27, "Subsubsection"],
Cell[496493, 11307, 599, 18, 44, "Input"],
Cell[497095, 11327, 188, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[497308, 11335, 119, 3, 37, "Input"],
Cell[497430, 11340, 273, 8, 40, "Output"]
}, Open  ]],
Cell[497718, 11351, 149, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[497892, 11357, 366, 9, 55, "Input"],
Cell[498261, 11368, 116, 2, 37, "Output"]
}, Open  ]],
Cell[498392, 11373, 229, 3, 31, "Text"],
Cell[498624, 11378, 248, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[498897, 11388, 10811, 304, 256, "Input"],
Cell[509711, 11694, 137, 2, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[509897, 11702, 305, 10, 27, "Subsubsection"],
Cell[510205, 11714, 488, 13, 31, "Text"],
Cell[510696, 11729, 394, 13, 44, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[511127, 11747, 566, 19, 27, "Subsubsection"],
Cell[511696, 11768, 595, 18, 43, "Input"],
Cell[512294, 11788, 188, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[512507, 11796, 355, 9, 72, "Input"],
Cell[512865, 11807, 1594, 50, 43, "Output"],
Cell[514462, 11859, 139, 2, 37, "Output"]
}, Open  ]],
Cell[514616, 11864, 215, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[514856, 11871, 339, 8, 55, "Input"],
Cell[515198, 11881, 117, 2, 37, "Output"]
}, Open  ]],
Cell[515330, 11886, 228, 3, 31, "Text"],
Cell[515561, 11891, 206, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[515792, 11900, 10646, 288, 259, "Input"],
Cell[526441, 12190, 117, 2, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[526607, 12198, 273, 9, 25, "Subsubsection"],
Cell[526883, 12209, 454, 12, 30, "Text"],
Cell[527340, 12223, 359, 12, 43, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[527736, 12240, 627, 20, 25, "Subsubsection"],
Cell[528366, 12262, 589, 18, 43, "Input"],
Cell[528958, 12282, 188, 4, 51, "Text"],
Cell[529149, 12288, 180, 5, 37, "Input"],
Cell[CellGroupData[{
Cell[529354, 12297, 249, 5, 55, "Input"],
Cell[529606, 12304, 1102, 34, 43, "Output"],
Cell[530711, 12340, 92, 1, 37, "Output"]
}, Open  ]],
Cell[530818, 12344, 349, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[531192, 12353, 612, 16, 72, "Input"],
Cell[531807, 12371, 234, 3, 37, "Output"]
}, Open  ]],
Cell[532056, 12377, 602, 10, 71, "Text"],
Cell[532661, 12389, 321, 7, 37, "Input"],
Cell[CellGroupData[{
Cell[533007, 12400, 12147, 348, 434, "Input"],
Cell[545157, 12750, 366, 6, 37, "Output"]
}, Open  ]],
Cell[545538, 12759, 515, 8, 27, "Text"],
Cell[546056, 12769, 1045, 24, 62, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[547138, 12798, 533, 18, 25, "Subsubsection"],
Cell[547674, 12818, 587, 18, 43, "Input"],
Cell[548264, 12838, 122, 3, 51, "Text"],
Cell[CellGroupData[{
Cell[548411, 12845, 184, 4, 37, "Input"],
Cell[548598, 12851, 467, 14, 40, "Output"]
}, Open  ]],
Cell[549080, 12868, 139, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[549244, 12873, 453, 12, 55, "Input"],
Cell[549700, 12887, 117, 2, 37, "Output"]
}, Open  ]],
Cell[549832, 12892, 210, 6, 51, "Text"],
Cell[550045, 12900, 100, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[550170, 12905, 2614, 76, 98, "Input"],
Cell[552787, 12983, 117, 2, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[552953, 12991, 522, 16, 45, "Subsubsection"],
Cell[553478, 13009, 599, 18, 43, "Input"],
Cell[554080, 13029, 294, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[554399, 13039, 186, 4, 37, "Input"],
Cell[554588, 13045, 483, 14, 37, "Output"]
}, Open  ]],
Cell[555086, 13062, 258, 5, 31, "Text"],
Cell[555347, 13069, 215, 6, 37, "Input"],
Cell[CellGroupData[{
Cell[555587, 13079, 4711, 136, 275, "Input"],
Cell[560301, 13217, 359, 6, 37, "Output"]
}, Open  ]],
Cell[560675, 13226, 124, 3, 31, "Text"],
Cell[560802, 13231, 118, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[560945, 13236, 217, 4, 37, "Input"],
Cell[561165, 13242, 164, 2, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[561378, 13250, 572, 17, 45, "Subsubsection"],
Cell[CellGroupData[{
Cell[561975, 13271, 487, 15, 43, "Input"],
Cell[562465, 13288, 276, 7, 37, "Output"]
}, Open  ]],
Cell[562756, 13298, 257, 5, 31, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[563050, 13308, 544, 15, 27, "Subsubsection"],
Cell[563597, 13325, 703, 21, 44, "Input"],
Cell[564303, 13348, 181, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[564509, 13356, 419, 10, 72, "Input"],
Cell[564931, 13368, 1151, 36, 40, "Output"],
Cell[566085, 13406, 139, 2, 37, "Output"]
}, Open  ]],
Cell[566239, 13411, 118, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[566382, 13416, 385, 9, 55, "Input"],
Cell[566770, 13427, 141, 2, 37, "Output"]
}, Open  ]],
Cell[566926, 13432, 260, 5, 31, "Text"],
Cell[567189, 13439, 9998, 284, 257, "Input"],
Cell[577190, 13725, 222, 4, 31, "Text"],
Cell[577415, 13731, 3520, 99, 82, "Input"],
Cell[580938, 13832, 282, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[581245, 13841, 1077, 31, 89, "Input"],
Cell[582325, 13874, 234, 4, 39, "Output"],
Cell[582562, 13880, 234, 4, 39, "Output"],
Cell[582799, 13886, 234, 4, 39, "Output"]
}, Open  ]],
Cell[583048, 13893, 113, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[583186, 13898, 189, 4, 37, "Input"],
Cell[583378, 13904, 161, 2, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[583588, 13912, 101, 1, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[583714, 13917, 287, 6, 37, "Input"],
Cell[584004, 13925, 116, 2, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[584157, 13932, 3151, 102, 100, "Input"],
Cell[587311, 14036, 217, 4, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[587577, 14046, 104, 1, 27, "Subsection"],
Cell[CellGroupData[{
Cell[587706, 14051, 385, 7, 37, "Input"],
Cell[588094, 14060, 550, 8, 37, "Output"]
}, Open  ]],
Cell[588659, 14071, 229, 4, 37, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[588925, 14080, 203, 3, 27, "Subsection"],
Cell[589131, 14085, 144, 3, 31, "Text"],
Cell[589278, 14090, 4139, 122, 214, "Input"],
Cell[593420, 14214, 97, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[593542, 14219, 5136, 119, 206, "Input"],
Cell[598681, 14340, 2199, 67, 65, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
