(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1037580,      24386]
NotebookOptionsPosition[   1012049,      23581]
NotebookOutlinePosition[   1013687,      23635]
CellTagsIndexPosition[   1013644,      23632]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Large-scale linear instability of the Kolmogorov flow with modified viscosity\
\
\>", "Title"],

Cell["\<\
Bernard Legras
Laboratoire de Meteorologie Dynamique
Ecole Normale Superieure
24 rue Lhomond 
F-75231 PARIS Cedex 05
E-mail: legras@lmd.ens.fr
Barbara Villone
Istituto di Fisica dello Spazio Interplanetario
Corso Fiume, 4
I-10137 TORINO
E-mail: villone@to.infn.it \
\>", "Author"],

Cell[CellGroupData[{

Cell[TextData[{
 "Smagorinsky-Clark mixed model + friction\nU = A Sin[\[Theta][y]] where \
\[Theta][y] = \[CapitalSigma] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Theta]", "^"], "p"], TraditionalForm]]],
 "Sin[2 p y]\nStreamfunction defined as u=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", "\[Psi]"}], ",", " ", 
    RowBox[{"v", "=", 
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", "\[Psi]"}]}]}]}], 
   TraditionalForm]]]
}], "Subtitle",
 CellChangeTimes->{{3.424787302076682*^9, 3.4247873135143347`*^9}, {
  3.426489667143157*^9, 3.426489679518512*^9}}],

Cell["Settings", "Text"],

Cell[CellGroupData[{

Cell["Last use", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateList", "[", "]"}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2009", ",", "1", ",", "14", ",", "17", ",", "50", ",", 
   "27.843983`8.1973063417282"}], "}"}]], "Output",
 CellChangeTimes->{3.405677748643395*^9, 3.405686657448234*^9, 
  3.4056866994312477`*^9, 3.405686742241375*^9, 3.405702624881482*^9, 
  3.405702770362739*^9, 3.405705708691693*^9, 3.405705842636776*^9, 
  3.4057532634380817`*^9, 3.4409405690857077`*^9, 3.440940627984439*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["General", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laplacian", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]", " ", "=", 
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "X"}]], " ", "#"}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], "#"}]}], ")"}]}], "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Epsilon]", "2"], " ", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"X", ",", "X"}]], "#1"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], "#1"}]}], ")"}]}], "&"}]], "Output",
 CellChangeTimes->{3.40567775505799*^9, 3.4056866581610813`*^9, 
  3.405686699606001*^9, 3.405702625144552*^9, 3.405705709097206*^9, 
  3.4409405693158607`*^9}]
}, Open  ]],

Cell["\<\
beware of the sign, such that vorticity = Laplacian(streamfunction)\
\>", "Text",
 CellChangeTimes->{{3.425065448975732*^9, 3.425065491679688*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Definition of the turbulent viscosity, Smagorinsky-Clark mixed model\
\>", "Subsubsection"],

Cell["\<\
Standard version with a heuristic component accounting for the vertical shear\
\
\>", "Text",
 CellChangeTimes->{{3.405677175227804*^9, 3.405677198572053*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["S", "_"], "=", " ", 
  RowBox[{
   SqrtBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"4", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y"}]], "#"}]}], " ", ")"}], "2"]}], " ", "+", 
      " ", 
      SuperscriptBox[
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X"}]], "#"}]}], "-", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y"}]], "#"}]}], ")"}], "2"], "+", " ", 
      RowBox[{"\[Mu]", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", "X"], "#"}]}], " ", ")"}], "2"]}], " ",
       "+", 
      RowBox[{"\[Mu]", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["\[PartialD]", "y"], "#"}], " ", ")"}], "2"]}]}]}]], 
   "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], "#1"}]}], ")"}], "2"]}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Epsilon]", "2"], " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "X"}]], "#1"}]}], "-", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], "#1"}]}], ")"}], "2"], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "X"], "#1"}]}], ")"}], "2"]}], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "#1"}], ")"}], "2"]}]}]], 
  "&"}]], "Output",
 CellChangeTimes->{3.4056777606307793`*^9, 3.405686658761257*^9, 
  3.405686699718836*^9, 3.405702625178161*^9, 3.405705709307059*^9, 
  3.440940569393372*^9}]
}, Open  ]],

Cell[TextData[{
 "Dissipation: C in front of the Smagorinsky component, D in front of the \
Clark component\nIn standard notations D=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[CapitalGamma]", "2"], TraditionalForm]]],
 "/12 and C = C",
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "S"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[CapitalGamma]", "2"], TraditionalForm]]],
 "\nNote that K=-DS in the paper"
}], "Text",
 CellChangeTimes->{{3.42892470572445*^9, 3.428924752650701*^9}, {
  3.441627184522395*^9, 3.441627189496221*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DS", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"C", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#", "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"y", ",", "y"}]], " ", "#"}]}], " ", "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}], ")"}]}], 
       "-", " ", 
       RowBox[{
        SuperscriptBox["\[Epsilon]", "2"], 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "X"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            OverscriptBox["S", "_"], "[", "#", "]"}], 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"-", " ", 
              RowBox[{
               SubscriptBox["\[PartialD]", 
                RowBox[{"y", ",", "y"}]], " ", "#"}]}], " ", "+", " ", 
             RowBox[{
              SuperscriptBox["\[Epsilon]", "2"], 
              RowBox[{
               SubscriptBox["\[PartialD]", 
                RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}], ")"}]}]}], 
       " ", "-", " ", 
       RowBox[{"4", "  ", 
        SuperscriptBox["\[Epsilon]", "2"], 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            OverscriptBox["S", "_"], "[", "#", "]"}], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "y"}]], " ", "#"}]}], ")"}]}]}]}], ")"}]}], 
    " ", "+", " ", "\[IndentingNewLine]", 
    RowBox[{"D", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], " ", "#"}], " ", 
        RowBox[{"(", "  ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]", "4"], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X", ",", "X", ",", "X"}]], "#"}]}], " ", "-", 
          " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], "#"}]}], ")"}]}], 
       " ", "+", " ", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"\[Epsilon]", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "y", ",", "y", ",", "y"}]], "#"}]}], " ", "+", 
          
          RowBox[{
           SuperscriptBox["\[Epsilon]", "3"], " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X", ",", "X", ",", "y"}]], "#"}]}]}], ")"}], 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y"}]], " ", "#"}], " ", "-", " ", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}]}], " ", 
      ")"}]}]}], " ", "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"C", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"y", ",", "y"}]], "#1"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "X"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"y", ",", "y"}]], "#1"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], " ", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}], ")"}]}]}], "-", 
      
      RowBox[{"4", " ", 
       SuperscriptBox["\[Epsilon]", "2"], " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "y"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y"}]], "#1"}]}], ")"}]}]}]}], ")"}]}], "+", 
   RowBox[{"D", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "y"}]], "#1"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Epsilon]", "4"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X", ",", "X", ",", "X"}]], "#1"}]}], "-", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], "#1"}]}], ")"}]}], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y", ",", "y", ",", "y"}]], "#1"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "3"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X", ",", "X", ",", "y"}]], "#1"}]}]}], ")"}], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y"}]], "#1"}], "-", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}]}], ")"}]}]}], 
  "&"}]], "Output",
 CellChangeTimes->{3.4056777628958063`*^9, 3.4056866596465693`*^9, 
  3.405686699838736*^9, 3.405702625649367*^9, 3.405705709731844*^9, 
  3.4409405700357323`*^9}],

Cell["\<\
Reference
Pope, S.B. Turbulent flows, C.U.P., 2000\
\>", "Reference",
 CellChangeTimes->{{3.405677233198999*^9, 3.405677274407757*^9}, {
  3.4056773690199203`*^9, 3.405677391583219*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the modified Kolmogorov Flow", "Section"],

Cell[CellGroupData[{

Cell["Velocity and streamfunction", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"U", "[", "y_", "]"}], " ", ":=", 
  RowBox[{"A", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "y_", "]"}], ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0.", ",", "y"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exemples of flows ", "Subsection"],

Cell["\<\
Standard Kolmogorov flow in Flow1, \"flat\" flow in Flow2, intermediate case \
in Flow3\
\>", "Text",
 CellChangeTimes->{{3.405677494754274*^9, 3.405677541094836*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Flow2", "=", 
   RowBox[{"\[Theta]", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"#", " ", "+", " ", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"Sin", "[", " ", 
         RowBox[{"2", " ", "#"}], "]"}]}]}], "&"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow1", " ", "=", 
   RowBox[{"\[Theta]", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{"#", " ", "&"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow3", "=", 
   RowBox[{"\[Theta]", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"#", " ", "+", " ", 
       RowBox[{
        FractionBox["1", "4"], 
        RowBox[{"Sin", "[", " ", 
         RowBox[{"2", " ", "#"}], "]"}]}]}], "&"}], "]"}]}]}], 
  ";"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the flow", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405677785746386*^9, 3.405677789463428*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtmnk8VN//x61F1pmxU6JI0p4+JTmXUNmVUJFShESLpJSyZEtlKdkiIlmy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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{(-2) Pi, 2 Pi}, {-0.9999996658276197, 
         0.9999993650500513}}, {{-6.283185307179586, 
        6.283185307179586}, {-0.9999996658276197, 0.9999993650500513}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwk23k8VF8bAHC7ss8YSyQqSqUoqUjOJClLESqpJJUSUZSlTZaflCVLaSFK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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{(-2) Pi, 2 Pi}, {-0.9999999999999937, 
         0.9999999999999951}}, {{-6.283185307179586, 
        6.283185307179586}, {-0.9999999999999937, 0.9999999999999951}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtm3c0198fx21lfpYRiZRVkiRJct+EzMxKUaGSJKkkpRQJScNIiqyQjCi7
cN+yZ/bI3uMz3vYev/f3nN9fzuO4577vfb2ez9fr3nPPZ7f9bfNrLExMTMxs
TEz//TXQ5zu5tnsHavxBN6et8aPG8ZzH09t27UAV5AbH9b4/APK7qZ8FRXag
k28UVqjp/oBvpXL5EGkHShyeW5VP/wCakr2/O7LsQPlssrNfpXwFVtsWdrQP
CaPn+U1Ej8XmgeuV3dOZX4TRUtaD/ucfVAKrwwbRxTHC6GBnX8jLg1VALybf
sC5SGC2KyF13GK8C+x68TxoPFUYdHMeDJM7WAIa0ic0uX2G02zGny/hgPXD3
+1P56qowumeTDzO83gR8db5FO0gJowrhN6zZutoB+uqRqfhuYfTRowb+eeUO
sN5kyNK5UxhlO/eILehdB7h3iXFNn4LPX5KpmanbCewfHD4gz4rPfzZ9MfV7
FwDfin7PDAihC8/F3F4794BVnubOx1FCqOFgdPNw3QBQsfgSeCRCCM14rF17
f34A3P3ops4IFULltV5aNogOgkkpodjLr4TQCvXUzaYbg6BTw+a61iMh9MEd
lUc7WYdAruvYAqeVEJp9tqXj1b5hcKd1lRRKFkL1zuc9yTccBeHmJhfC+IXQ
clGGatyNUVDY+CXuPbcQ+sLsw6SF/yjgqDdSjGAVQktb9WWF/oyCqPJo489z
gqhb3Np5gSNjoCpXK+BriyCqcfXhqSXCOGAof/ib/FcQPZLaxOGzfxyQs6iC
KbWC6NuT82c7dMbBpYywxLRSQXRMV49p6OE4mPs69udHliC6A4ztfNQ/DnZ9
DNz4HSqIsjhpf2uInQDaQv3aRW8FUcXVNFn+/Alw4/3hoOJXguiZ7w/Ed/6d
ANnBPSIlzwVRvZ3MlKj1CaAfqKBacU8QbW2rylU9MwncPJvvNloIogNzT6Z5
NiZBzUWRiRGyIMr5LnvytSwVmMSog1V+QZSISZ9yOEYFrQOXwvl5BNG06gtP
yAZU0Hvli7YamyAa0Xrcge5EBdM35OPezgug7c+1BxNTqEDIXeOCWpsAuv7E
44GtJA1E5dn+MGkSQLv38Id+UaQBiRWfbdfqBVCl7U6eUIMG9j2uzH1bLoCO
72wu8LlAAxo+puTRHAG0YSRaXuMdDVx9Y1/3NlwAvcT10rl0ngYm//ruSQwR
QHd7DL3+yUQHLsSvj369EUBvCkemevHQwYMwquyonwB6bkuJ+n0PHQR+cnuh
9kAAVROpHHE3pYPMJD+N0XMC6O9THav9X+jgyETy+1ULAbSzwC2qOJ0OfsnV
0vhNBVCrS2t3vfLooDSNP1JNTwCt2T1ZHV9DB+0/I5beqgqgdjU9V19gdLBR
nJKptkMAnWpzH6MeZoC6fwd51igCaKXgQkiKOgNELWZf/00QQB/OaP7T12EA
dQW4S32bAPqx/OST/WcZ4NHnlqATSxT0ctGV7ufuDGBQYDWxMUtBLyQbyph6
McCOtt6TxQwKmucIX229YIB8nolVjTEKKvlNuW3bewZY9Fx3RNooqNRtrab6
HwxQ8cG7jKmJgtI+PjT8nc8A77M4JErqKGjvxS3wBjKAMpXQoVlGQSNn4+Bo
HQPcuyClczKLghYx7SVdGWOAadXTu3WDKejPS+e42igYQC1bHnO8pqC75Njz
jotg4K2rVWdFAAVN3LDWCBLHgEKy/dtTzygor4XhIFUOA7eEHmzo3aagmY6p
bmknMKB+eN1q+00Ker1aZclRCwM8Jt7Z1Q4U1DjF0ph4CgNpfq9uGlyioKKs
ktekTTEwtRDTZWhMQX2FibmOdhj4RZQ6wqNPQTdqXhsFXsPAywMp7+q0Kajy
720BH29gQPZa9iljdQrKsEup8b6DAYfWqpzT+yno2PLbK0+fYWD450yw2XZ8
vlUxunUkBqI4Vn0usFPQQ1I5KurRGDh7gcXtCjO+fwcfhD8OA1XM5LP3V8jo
WdXP0m+SMPDdVFnk4yQZNWNw7prLxMD1BHXu+FEyWvxm0/hWFgYklrXXUwbJ
6OXKBcvuHAyExpzpK+wio+fetN4I/YUBD4Z7/EA1Gb3yZEHiQSkGDmk9DZ0s
J6P2YgSv0HJ8v+/9fWdLyOidJMFvCZUYuHgiwoHtFxn1mp78l1iLAa2ggn2y
KWRUQmM6Q7oFA2v9JaKHkshoyn55H1orBrIP1/CoxZNRmpfbytd2DMh0/2MY
fiKjH6IsjjH9w+O9b/3n7UAy+vPl32DVAQyUP2FL8PAjo2sxjnu+D2LAq4nn
vbcPGX10OIQoMoyBGQ+xB6GPyKipPevZtlEMpNRJOUa5k9FGJr3WveMYuCqh
cD7xLhklOQhtOU1goL1S43ieE85MMwndUxh4J3pKHnUgo5gXQZuDhgH92yZi
1fZk1DJqtEOGjoFCQdutfxfIKNNLbwlTDANx17xLNw3IaPYiN0NlDgMXCl5m
c54io6576hgi8xig8IYkEk7i438ZXFzE2S873l/yOBlVOdaVG7qIAWRbqsf+
o2T06erlX2eWMLBinXVD+TAZ5SKE2vAvY8CZtcxQdz8Z3Tgen3xjBQNS5+rU
TWTIqPcRsetcqxjoS2k9YLWHjBIf+9DjcY7Y7NllJ47Ho5mhfXgNA2bmo/xO
ovj4h2zuv3HmSqIz3RMio7U61IDj6xgoW1mY8SST0eps0xdZOKvEcbS+5iaj
L5Smzr7awIDa3zvVmpxk1OWz6fAszhobPcULLGTUJ3mLz2wTz+9+vexvmyR0
STd2IBFn3fNZ3y6uklCC+uFLMzgb+O+KIS6SUG4F4uvDWxg4nfMyrHyGhArk
Td1xxtl8eP7lQzoJVXKrIkThfI5o+/TAJAmVJXHf+oOzDah1Gxwhoaesbr7s
x9n2lorT+wF8/KHV63M4X42Mu6zfQ0If/5Dg2sTZsZrnzEYHCVXfGeu6hbPz
0gODHy0k9P5ocOQSzq5Sw+DaXxLq8vN64BjObhanj+yoJaGj56jH63D28C7Y
V19BQqXaNb4n4/w4Y6+E9x8Sym7R0+eJ87PetwJHikloLTG8RgdnX+41rskC
ErriGH6LA+eAYw5Mn3NIKF/u5dIifP9B15sWTH+Q0EMmdRU3cX73Xp3Klk5C
h+/y3SXgHFb6dSA/mYR+OZJZnIrHN2KG1O6cQELjb4UmnsA5StyrViKWhPpH
zeyqwPMTazyJtkaSUIMOa0kdnBM8LXMDPpBQlbRfSb/w/CZ/g6nqoSSUyHk6
XhrntI59cdNvSGggOZ3rJa6PTPbw8IRAEjoiVtE6iOupwM7Zm8eHhKarhlxy
x/VW/LbDHX1CQr9atLL9xPX4p0jL2e0hCa08yugaxvVas2PHuR5XEros+bRd
bgEDDad8jd45k9ADr1X7T+D6br6PaWo7ktA9Sqe7TuF++NdULp92mYRGPy+1
OTGD63VLUdLWmoRuTyD/kZ3GwNCBKCHKORI6+TK2cTvup6mXd1kenyaht4+v
fkzD/beqKd5peIKEtrfOv7qL+3fzdmD9lioeT5FdjG1jGGCJXviTpUxCZVz2
6YeN4PperU0XlSehfT4rvi/x+iD60+M5VYSEPm9b3UfF64nEwLBHjCCuR/vH
rtJdGNjLZ+JiQSKhfyeutZzpwIC8k9T539tJaIVYo/s7vF6pSzYrvFomohQl
96w7eD2LJXMrW8wT0eH4klDLagywsmsfE50moi/qgln24/WvZjznZOo4EeWd
EWP9+QcDVukfrWrbiajir9qMvQV4/YhuvhjaTETZQsNlY3MxIP6O+4p1AxEl
uxD4+LIxMHb3yS1qORH9Wcrpg37H9alq58OdQ0Sj9rHGeH7BQKfcJ/+WTCJa
G1FI8ovFwHHRlqDINCIa9/NhsvdnPB6b2h/2JxDR5E+BAYYfcL2VyqYZhhLR
ps/KYlKBuB5OT7e9ukNEP8pqvy93xgABkeu2uEVEH6cr8tY5YuDeIfsB0RtE
9HNY6wf0Ku5/SutUqi0Rzbz2gPueDd5fuvK2ak2IaMMr7jNLBni8aqfZwgyJ
6BDLnImjLt5fC+W4bE4R0Xp/pk/lmnh/iomk0DSI6GFhFQVtVQyMXH0qx6NA
RLFTR/IN9mJA72y+QqscESXJ5QYL4f049dTM4Sgp/P8ToLFhBwbu7ruiIS9G
ROeddB6v8WGAaVrXwoiHiMZXSt/WXWaAnZ58T4KmCKjxiM349QoGuJFQI/R5
jIAmK7E/PYgyQG6938/0IQKqve1s5EABA5hJbI03/COgeVfuuG+mMYBfOWZO
rCWgjO2JhyRDGADjb5INTyWgwRfMXFvP4eedY69Lk74S0Btnt28JmTJAoL3+
pbwv+PjbT9Q19Rhgb05JaGckAaUVSZeeVGUAqws/N0WCCKhZkDqdWYgB/iSE
tsY4E9DUjEALub90wN9gcjvTkYBe2xI5/q2cDmyWuLlKrhLQy7ZJWVyFdLCk
7wuGbAgoW5WR/p1kOpDH3FL2GhPQhp92n8qf0sH7Y2effTtAQK1rpigmsnQw
ZE8S/SVHQD2cH4lX7aQDxaCGnBopAppSn31/F5EOavp0qVQxAnor5fCs3QoN
bD4/elaBj4CuhBxOVq+igcaoQ1YOvfwoK5onzX6ZBpgSbof3tvKjw0d+BHGY
0oBianqrZR0/eqf4psg/hAbeFciZnfzNjw5MlZ9b3E0Dpu27DSQ+8qOCLpGC
q4NU0MhPUv9nyY9GJco1jVpRAZOQ6SMzI360ar3YY0iXChR3vcmvOsmPPvr+
YneaMhW8k+c6kqfEj0pYq4BEfiow1WdRCCPg41fzjaRLp0Cjz6z46To+lDmI
qLhHYgowBSpeKi/lQ2e4xuh1XFNAMdglSv03H3o63FsGLEyCdzFTwvtT+NDG
zhLux9WTwLRwiLgtgA+tvLyr1PT2JGhcaGb9c5IPLSgwXFDKnAB/HbPGj/zm
Rdt8G/xfsI+D5v4lU40sXpQgcZP7z9QYaD+r/ks3lRdNkRgF1X/HQI92edC5
SF5USXzp4dGPY2BKouPQQ09e9E9Calaw3Bhg61r1LDzOi9o0jLYfQUaBmr4W
4WQhD9ot86D7tM4w0ED9Hhpm86BW1Ql1PXuGgebR2iGLNB60H7IfUGEZBnpS
ljlXo3jQwwlcRYbFQ+AMs8MFv8c8qLLMNjYO5SHgWvAyoVqdBz2yay+xR2AQ
JMk1qZoWcaNPfuwREb/RCxxlfpQ8y+FGk0Cm6DXRXrBPKtjgRzo3Wv2Cbbdl
fQ/4LmFmQ4rmRv/+vFd1ULEH5Ak1PW314kbHksWUpmf+gSr2pgorhBvVnpHM
VXboBNTBRku7Ui60vePnbTuhFqD4qdH1bvV21FqabfCCLgS7FU/8E0zlRMse
/yNYqzVBI/PJcIUvnGjjwlxBZGgT9HB7b6EbyYlyfRB/E0drgg359Lr7rzjR
U0fMXyx/boaPNKNh601OdO9MUFfuRgtsNd9KCJHnRC28Exnhme3Q737Jbb7v
HKhHbVj5i95u+OPDLXnpJA6Ud/75sfADPbCnYMfkiWgO9ClX/SuTJz1QafOO
/a03HChffijvL9Fe2O8neabOhQOdtxDlsbHsg6oRz9UCD+LzOSp6SV0YgFO/
dNg5frCjKM9zsej3QzA1OK/mXjI7qsfg5Hr+awg6O8q9G4xhR5l3uHzc3z8E
6QK8okVv2NHavzdmK2SG4bRrq6KbMzu6jvzRkcwdhovSV2yGZHCWMfI0rRyB
eRutu03F2VEi+++iyxMj0KNVd7xIkB0d3SM8qbh9FK5477v7kZ0d7Ung7BA2
GIXrPTP+psNsKGvwcsBm1ShkCX2WVRzNhjbtGQ7d83sMlt6Y9ZAPZ0PvaNpe
NOscg77IVY1Pr9lQ7TgPB82FMcjOOFV9/zEb6qZQ8sZRYRxu0+fvl7/Ahra+
G1hr+zwO+bY+c0UKsKE/J2WG9O5MQNGbv+0eBLGiNULN5b+pk/BTVZUury8r
+qc37D2FeQqKSLfv/+LJivqCx6ZHBXEenF5ocGJF5e6cft4NpqDwOelAaX1W
tHNEaSbx3RSknAz+2cbOiq7YhZt7yVJhWGz0h5sbLGhTuLHQezUqJG+mPmZe
YEFjit8IPDKiQlJBhe6BERa0W/MANeM2FRIOrv/z/cOCTl6aNmvJokIe0eus
yk9Z0Du+y44nDtNgkIfbRLU7C+qp3cJro0WD3O3e9ZddWNDzPz60G5vRIFdw
1IdXF1nQ1ykFomkuNLiNs3n/8HEWVJiu8dDmKw2yz6lbhiwzo7c7hE61EejQ
19TgmOw0M3r+siCLsRgdsn0/t6t4nBmdmJcT+CyH8427E5PtzKhWV1xopSYd
svR/fayZw4zKpk1JmLjS4WYNKXH6DjP6mzco/04FHZpFSOcIOTHj583bZhN/
6TDhmlq5hj0zytXSOI100aEBk/1okDkzmiNxw/gjlQ7Dj/yQkjvMjEZcPFtI
52PAA7EmSXbzTGgaSSDnkikDPrt1JTeAxoT+edjuTbFiwGa1BxUZI0xoKlv/
tczLDOjRFj220cqE5u0Xux3pwoBlXAzpTzlM6N+UKUudVwxocz/oa7M7E6ob
stQuhjJghlZs3ooLE5rNzjZmVsGALITsSonrTKhKv13r7ToGTE7pHnc5h8+f
0ajs1MmA8/37ZLlVmVArUa2jlzEGPJWuoaqkyIQ+PXjMfWKeAT89Mtc7L8uE
qvZRz1xcZUBE4JHjV2EmdIvrWyMXOwYF34eY+c9uQUe1a0GPdmCw8OCvO21D
W/C0FyPNYRcG7WsGg/e0bMGQY8kCyB4Mpm8pNsOsLThjcObVb3kMajv9NV92
24Jei+izfxoYvAd4LG8sbcIYrhcTQ5fx/5+EL66MbUJV/4gNnqv4907dzbvY
tglLdxSG7nXEYP7pThHzrE341JC2W8wVg+sXEwbVbm/CQqax/GNPMVhvd458
5NIm5HScrG/zwWD0NS6dg8abML49hmDnh0Hklmvynv2b8F2W6KTOawz6Pla/
zTO+Advszpw6/QmDZ55hsRztGzCpMODgjc8YlPaNb2Yq34BhdgZVbrEYrHq1
TWUhfgPus7qKXkrCIG9k63rvpQ14b80pwucHBvui/RU6jXH+Lt0hk43BzHg1
22b1DVhlLyoOczFonhJbWiGyAUdN3Z3KfmMwvMA5MKN9HdItL8kqlGPwepF4
4bfydXjGE2Ncr8Sgakkz/Uv2OszmEqGHVWPwX5WqWUTIOtzpMyRSXY/BXZ1s
wt6n12GG3vLg5zYMYt15+p4n1qGkdgr//Q4Mov1Onvfl1+Fq4f6HSBeen/HG
vhtc6zA4QfN+dg8Gvy5GJZpXrEH3h/F7KcMY9Fg16TDKWYNPtpvqvRvBoMEm
y/ZTCWswunyXD/MYBmnsN5yP+6xB0hA1onQCg0Xbd0YfubMG9739kUCZwuAb
3r9/D9quQXV7mb3WVAwqChw5vFdjDQYefN9aRccg846Jq7sOrMFfu+UOTjMw
2LwzMlx45xqsCEg05Z3GoNte5lWe1VU4ij1SlpvF8324Hl3IWYWl81Gukwv4
fEKv9UhJq/B4jM7kz0UMJq8aNSqEr8KG05rYvSUMRpTU9V93X4WnTH809ixj
kJAYdN3XYRU6DmeU+K5gMCDACIs9uwpjlQRv7l3F4AOTus0uFXz+0j4ewzUM
MpSC/BalV+G1doZgM84OgkZ8ZKFV6Hnvz7rpOp7fFe7wg5yrcL/Venklzmd7
a8WMllZg/+6yhyobGGxAXyU6jq9AJruKXZ9x1k0wPPCiYwUGpij/XsO52J87
J65yBXokl1uab2JQ5WatenEePl4uZzoW5++nX5X9+7oCo+XLQsdxllYyNFr6
sAIHZ1W1pLdwPQtwt5ID8PEc/Vs2OAuu1FgreqzA/Tqcja9wftMTOGzkuAJD
6P45P3HmQA1u3rBagQfiC3824ez1hWvuhd4KVLjrVz2B84JfzaN41RWo2Ge4
ht+nobNTIAuUXYF8Pct6+H0bjhgbBHYLr0DXrs2f+H0c2hziIi1vW4HMRZbH
FnFupdR8pKwsw/Nj7t2jOBstv9x9aHIZvpO/HlGPc1m3/jfjrmXo3Z3mko6z
Otx+yKl6GZZkWNq8wDk7vjrfr2AZajRNXzqDs7zfS+TLt2UYVRdxTwznhBv6
VfDjMjzxajK8F4/HTuPtpj0vlyGHAXv5e5zDFKs7lh8uw4E3oSs6OPNQXl4W
cFqGSztLDjLwePsu6Y0furAMC8aB/Ruc7xVXLTqpLcPyyJCEXDx/U3EBXv77
lqFxx5WvGjjbv9DjSBBZhklNz4KK8fybG1UJ9K4uQc/U032JuF5qDgZ8Xpla
gtUle9R4cdYi60kJdi/Bi11BZ51xfSn9q1Q2+b0EBccFUoi4/lKK/Atvpi5B
8imvunO4PiXjTmkHRC5BZn1uv/e4fomOlRYlnkvwsXzz26V5XJ+G/t29N5cg
8vh+pSjOTAdPXVm1XoKlBMK1o3MYnF6ouHtYfQl6HfgaaTmDQccuv1UT+SU4
9Xaf8FncPwOFuj7OO5dgStrPktMYBhufVwQnri9CvmKfi1K4/zKIFZlCRYtQ
kz9+4hruX/NLRIOB1EWYdWxai3Ucg4spNsPJnxbhJlvF5/ejeL605wTUPBZh
zol7MxFDeP1zl/C0ObwIyR1Zh4Tw+nGz9CZFSnIRIpvdOef/YZCPkJdOJyxC
T7cfdu86MWj5zXjAi7EAX71jyutqxdfX/Ugn7tsCzGsVGOisw+Bz2Yq+GxEL
cFrlnEJBDa73+0QPJf8F+DkqOSaoCtcjX3JK6dUFiNjutOEpw+Ay0sY/Jr4A
c4z59t38hccv6eC/feHzkH6eS/t5Aq6n2Uf35nznoaDq4YDncRi0AhU8hffm
Yb7wXzu3aNw/nTbA2GweNitV7pCJwOA+7sCE2zzzkP8u1bI2EO8f59pOqK7N
QbsHucyG/hh0TZDoYJqag+GErl8FzzGYeyJve0jlHDy2M/DZlcd4/l1HXLJ9
5mDcopTHkDMGRwsPbntyZw6eTONIbcX7VcB2zzgd2zlYue3MkWy8nzXEE1vb
T8xByeQpRzUbDF5o0zi2sjwLw3rPtdgY4PpU+8iqcXsWhptYlJdK4voOE+05
e2kWBqZ/ZA4Qw/fH+Jx923gWxqF2T1SE8XzFx1+L2z8Ll29ZHjLjxes3d1ol
28QMfF3UYe2+yIAfrynEinXMwJrYszdeTDPgL5jpoVIxA6U6rb88nmLAtXs5
co4JM3BtZDlAso8BvXqKX9XazkCFf9mu2mUMGK2ieXXEZAaS395Xf13EgPBd
qfqGxgykLQps/c5lQCadKrqC2Axs3/DQrklmwOfpTSYhXdOQQ+5WThx+Xgnw
GiGfN5+G3fv1elcM8fNIpwPtjuY05CUf6/Y6yYDVSpNlgYrTUPbZr+2jagzI
NU6/X8g3DV3t4vMt5BhQJIaRAcIxOLj7VNAPNgaU0qSo1vszoL1kySOZHDp0
WBCe3LzGgJ7lUbYfU+gw+ZvYJ0VtBlz1FzkzHkOH+0gy66FMDGimcmKHYCAd
Kg4fQy88pMO7DyIbc2zoUO3FZb0JJxp0aF4vyFqlwerlJ4mXDPFzaPW579EM
GrRyjmJp20+DF77x/7k2RIP3LboKS2hUGD6Vc9i/mgYzd1scinShwp5Eej5/
OA3KFOuKnL47BeU6j7qtydBg7qFrD8rMp2B0JkUrYAcNaic+b1U7PAWBtySD
xkWD9kHoG5n5SbiWZNShTqfC6AtqrMzuk7DX0uQ3lkGFlKUDtKyHEzCwIsz4
xgEq/OJkpL/vwgTM/Vf76sxOKlTqc0qKVZuATy+OfBPgpkLT8q+2r9fGYZgE
LYwwMQVfhe5uc3gyDvftPPR9KmYKsigKFO/wHoMBi8WETY4piDmuv30aMAKf
SvbsVfkxAVu/HyKcdhiBzluUuycjJuCveYd3O7VH4NVKDj+BpxPQ91nTu4Kt
Ybjy+oARp9EEFIlICp5zH4ZyLvnJO4fHoXalaej1a0PQzBczY7CPwwipxHAT
rQGo0Gjt6C02Cp/c/Ce4S2IAqu1RNKOvj8Bye3GFrrV+aH3w9R3RnhF44dG8
AvlePzRuO/e8+OMIfPEtWtHfrg/+YncL2E0agf845w7f1uiBf6JC5l2WhuDz
skg1sNwBralHmY69H4ATDcdCr+V3wMuamrtabg/A010d1FceHZDyNXq3usEA
FGGQP3cut0NdDdU/S+v9MFMoaOvOShusARJl96r7YK/T47KE1RZoFLIqPWra
A10kf0VRVv9Czsp9E4G7OmD7b/WyFFYUHjnejvjWVcLL8roblsHFIPmw1iPn
3xVAPSLpzWIsBIqWF0PavCsBjw8rwcgKBaHlQ6mDp6rAJP1KHP16CSgiGR3o
aK4G8eV7yxT9S8G+m9yPx4brAOV+0va88kpgFiswx+/RBNYnLWvsdjcCH2PL
A5omHWCOLV3B4FojEP/udI4tpQNMibOHKn1rBAWkgNLbbJ2g80yONeuhJvDa
WWnv8fxOkFMiQE9AmsH35ExVf9F/wOVjO//E5VZwTySoQLSxBwzqWZ1xie4E
j66+Ffm6MAA0Rh/b1fd2AqKyVDlZZBB88o67JS/WBRQ5rDdOawwC819TL6Yi
u8DKtPEJRb9B8Gf/k1yHj/i8FXaOEeQhEM8XL3Q5rAfcprKc7dw7DJSmFmgy
OgPgHHfzW2WJUWCruu1ex9UBcGnoEY+cxih44yey4uc7ANSYbG9PWI+CKUnA
PlY6AKyzLvZUho+CeOsAsQStQZC+bma5nWsMkOtFTksgQ+DcZy+XyLExMJ8B
MoSPj4BjL8xlHD0mQN3+4yTXiyOA9wDL25LgCfDlq8r9yqcj4Ixi2YH+lAlg
HnPguHvZCPi0XPf3es8E+PFGtLLFeBT4CC4fyFafBC63lvre2I6BE8/Hm2/M
TgLdyVnNMZ8xUPRA/q/4tikgdo2RcCJxDMQE7w/7LDYF6mxGnWiTY+CJ9Jzv
zKkpsM+oZVH/3jhgUqx4x/JpCozvy+Bj95sAQnK9cJsyFRQnpdyxSZ4AyZZ/
v9noUkG4ZFJrVs0E+PP4z8JjKyrQFfn8yZ5/EjhiPvN7HlNBwvZX0mjEJEi2
+ulGKaEC2wkHDc/UKTCn+uZOlSYNqF61j2uunwLWWk8ObzejAf6Bi2z7pqfA
5ArtvagtDRR3WNZ04t/V2fn1Y+4TGhCr1DqrUkwFU2ENR//m0sC/xF0uM400
cON07slOCTrI5UgzT56lAcOqY6ckD9BB6PVjRy9T6EDM1oCufYwOjOQsmerP
0UHsQsldATM6KE57GZLcRweJ0aZRNC86iMuaz71MY4AcvayxwhY68KL4RAry
YeCQUdej/F46uHCf/1n9QQw0sSXSgsfpgHR0n/7xexgwBr0/+lfpwPfX5W7B
VQyczGH5gYkzQLbt6NbY82lg3HRiVeYqA0gS5e/+CZsGUDnFUsaZAd6V3B35
nDgNgtfOBG13Y4BbkkzVlpXTYOxGTcWD5wwgPSIS8odrBux+viefNY4BwsLs
2KJFZ8CssImJZDIDsOgkuz+UnwHFnNri0hkM0J94xFrx9AzIkCt401fIABHX
TfdGB8+A706i70U6GIBD+EP4w/gZYM23o9+plwHcqnq3ncmaARpHn8fEDzOA
mdxNOnfbDGDxaoioxhiAi/oi96HwLJBvHRxe58CAp8tvvTMxs8BRvaBc6RAG
tMDCVb6MWZAT8Iaz4ggGuAgHvSuLZ4F90YlHp9QwEPEjvuBY3yx4YiadK3AS
A7nzL/ftEpsD4wGVNSMWGPAqL9XtkJ8Db3IUuxjnMKATvmH/Tn0OVL9PCJuw
xkDr0TuRLDZz4HEwoSr1CgZmH1nxjH+aA9wr6ev372Lgl2GIbGzKHHjKYW3O
4o4B75112ud/zYGIb7+ynj7EAKEYPKntmgMn55bB6WcYUGCWYWQIzwOXsPxp
jdcYcPJf+OsRPg8kdunlvEvAgJLVQdqhpHkw4MBrgHzFwIrsjW3UnHmQ+6rT
aPgbBgJqepCLbfNgsfn0XrYMDCTxlv3QpCyAa7tu52bnY8Clb6N+dc8CmGa7
f4H1NwaOZBydyjq8AFTUI2/rFmGgzDRVUtpiAbSw/7yWUoKBwdCQUK6QBXAl
kfkHrRoDyVfrMkrjFoALhx1xqBYDrkc46h7/WADeeSqVdfUY2Gx/yIY1LgCa
sUWUTxMGdorY3W/hXwR6nbTMu50YGJn6FBwkvgg47BZ8Bf5hIPV3a7rOwUVw
4MFet+/dGFC7qDeWd3oRaGbBjT99GLCKPXgu6vUiMLnfKvRwBAPznH1236IX
wdfhqAjqKAbe3Q5yzs1YBMey1U5YjGOgWmPSu7FpEag/rTFlmcKAQ9KHoN6h
RWB5/QVdn4oBFj7dD1Nzi4DM+Lrdn4Z/rzc+jU1wCQQnvqEMMTDQrm2WR5RZ
Atd5JvczTWPgbtpWyS7VJcDc20GmzODr9bTpUL2wBAoNn8WIzWFAb5hrSOfm
Esi0+OJAnsf3Z1BAM3+8BKpmD+hszf+3f0GWW9FLgDXvSEDBIgbyvct4HmUs
gW7iAlfAEgYsJ+8K+aNLgLckdtBoGQOv8//Kxw0tgbGIQ2jBCgb2SXgd/T63
BNh7VQbtcN9W+Mtr/WZbBmtzjgFMa3i8z7481ya9DDgPBIbtXsfAp+Kj9kNH
l0FFhSdvwn/v09JjzpjeMth2KUZZbAMDza/DHqyfXwZJ/RdJr3F2WdDy2X5z
GRwXePJ9DmeuizNBgo+XQUehOOG/9+qkspgPe14vg4no8hP/vVdryZ+OV4xe
Bvrxhiemce4PXU87kbEMPPqoZKX/3n/XUvIM0GUwkHqiwgln4Svn/5xrWgZq
P49YfcI5u4az/urQMticl6pHcTZVyu24g2u/p7dIpg9n2serQ15sK+CwDpfT
7H/vw8xk+iuBFfDB4/77DZz33ihZipBeAfqgMuW/92q08TZL0tEVkNWzN2X5
v/dv1V28WXoroJ9ADMXv32A5pk4IPb8CxgSdr/7FOYzTU7LeaQVcjbu3E78v
g0O35Q7881wBg61/8r1xbmjvODoetAIAYq5ijLOThp/W/OcVINvyIJgfZ44k
ZWPmjBUQ2DxWXoXvP553+BwfugIotRkNHjhr3A+2F21aAX+9kSRxnP/1gFuy
QyugdOiKbhEeX3dtxoMjcyuggq6ZbIYzOS3KR4ttFTjFXS7rwfOVSTZ8bSKw
CnaMRIdcwtnIc+WDjfQquHVTg6sDz7evwdl0d71VgAQ6/k3F9SDxky3/+flV
0BAPtm3DuXBH1p93TquAs5y/5AKun4UJ/s6UoFUQ83a/zzCutxDT4qG8z6vA
/kWi6w6cFfKd6WXfV8HzdrdUHVyfDv7VLP2Nq6DMxa72Ga5fG/6bedUDq6A9
s58ag+vd7AOPc/b0KqBvSV7JncWA+leTtpeENVAzKrSrGveL0sGZl24Sa+C7
a4x2OYYBmbwQjcuKa6A184N/Pu4vUmXbV2XTNbA9WnyPL+6/bSYPbMRt18AM
34cLNrg/N9qFiVyua+DOw9PO+3H/ToxZP+p/uwasbwy0p+P+LuIYMgr8uwY4
NT/kaQ5h4Oeb58z3+9fAsYMBWQ0DeH0SlMq9jK2BgJ+xdLN+fL/SjuJH+NfB
8eL6MrUeDDjqMmb6T6+Didomr9A2DFxqeJtUc2kdmLMpY39bMGBx9pB1jss6
MLJtGGRuxvPp4FYW+GYdRHAqjek0YIDitxp+pGEdKCSe9DSswP3CF2Uo0bcO
tBweEA6VYWDr/QkmbsY6aCL1G3L/wcBU4rMbA7wboIIl78RnvL6i5Rzqr4w3
gJELknY4G+83xsnT9y9uAKqwucDvH3h9adNPtL21AX5Jmsmq4PU7fDSIT+X1
BgikXSjjSMGAMzt5cKBuA6Ts2M/CF4MB+9fZ72t7NoDhS0hViMLAOYGzBrm0
DRAXkGSv9RH3q9THrFc8m0D3cYAtEor7UUfcT8VoE0j3HT4f5oeBUt/9+4Nq
N0F3YtETDye8Hm69j5Xu3gS/nxz+8scBj+9DJsGSqU2Q9snl4oY9rneXNqbF
7Vvgs83e4ZN4//Oxetp+WW8LrFX0XyIYYmC1edJw9dwWUJxnOv9PF6+fxpYl
Yde3gPmoiE+oFr5eLbm0ar8tIKI4kNh87L960uJ9uHwL1BtXrXnJ4P0y6cRS
fesW+L1tSLVIEvfn7mRnx5EtoLK1IDkphvfLV8WpDcxMyJXRCeXtFAwwPQsN
Z93NhMSeDM+/usUAAzdOON+6zIRoH46Vt25mgJ1fZ5PUrjMhu+Pv1FvXMYDV
yNdBzttMyKHVV5W6FQzQeIl0Lt6LCWnbJzL6r4ABUItxzY7PTIih5r+nCzEM
EHMiWEizhwmR8qEMo9cZ4N8jXXO+ESakzI+z1dCWAQTz14K6qUzIFvWZc5EV
A7xRcmBxX2NCXJTDoiz0GcBL5jg9RYQZuRzyS0pHjgEuEUf/UM4zI46FjjfZ
R+iA7VPr/Cs7ZiS9wtqd8o8OUiTLpFmdmJGXFTFzTI10sHT4S+DMI2bkZrbB
outvOnh31s68IYoZ6dNLnfjyjg5KI3sH/QeYkZjq51bcynTgtLeevDXBjCzt
6qBXy9ABIb1Qx32GGdHP7P1qK0oHNsWR366ysCC1JVWHBVjoYHHg/B3NvSxI
pO2AaXA9DchKtzOtXWdBMvxvEF/Z0EDD93Klu64syLSA++oXYxq4fzTn6qQH
C2LzcbjgrQYN/NELq+p4yYJUnel26ROnAeub5u+yU1mQmo2KryYDVPAms0Hc
BWNB3rtc0VfDz9/Kx4rNRpfw7ztaWVzAz+f/StKf2zCxIp+2aR/Qw8/RMi1B
4wZEVuRhPGF3ED8VoAsGGTKHWZH7n9x600rxc7lapcagOytiLiqYSZKcAhUW
mTqVXqwImS+r9zzfFIhw/miU7seKmNzP9LuzOgk0om9eeBjOimTcNHlCbJ4E
gcwEd2IuKxKT9OIl39NJIFllla65wIoEzh072Pp3AiwMaGbLbLAilr98k3kK
JkDVyr7fvOxsyBz3vkpS/ARw2b9R1UVhQzyU1i/535sAv97EjdxRZkPGqk1E
+SgTwOzMlGj8PTZEaTXO1t1wHOx1aZEM8GRDSFoL3Q8PjYNFv0I5l+dsiJcu
ea++0DiIyn9zVC2UDan4rFtvMDQGJkQPWzT/ZEOWWO6ldd4fA8+GPANZZtmQ
4JYfBymhoyDjNu+KvSs7Er95/+tW4jCgtSguzXqwIw6Fz/N++AyDfaqWCz7e
7EigXPUP6cvDIIEpciY+hB0pulrLOC80DD4Fy04NZbMjdw0Gaid9h4Bv1slu
+xV25FNTiFen5SC4sPSwyN6HA+HhJV9wCu0FbE/HvO3DOBFdT+JtFrVm4HKP
9YxdFCfSI4wtKA00gc7rErK2CZwI+u3yDWm/JpBmeqHhYjYnYvFJ6t6FpkZg
Kdkgcr6VE0kLPmcmX9MAvpTnZJlQtiHHCOzUfPZqoMXzYlQ9bBtyb3DT2fDZ
L+D9cY++UNh2pKMxpFLEOgfKcyau0yO3I1wSKq0STbmw0006s+zLdqRbWaGo
UzcfKpjKCd3N2o7cNn9rbXDoN/zHcXC0rnk7wnEk5k3bMxQqu6l5+xC5kM8T
sRVE3Qo4dtqsgP6GC+GW8PavqG6EwYXNzmXhXIgVUk98KdkE1fdZSkRGcyF2
1GoxsmcTDGE/56/3nQupenAi4uH+ZggKbc58qedCtE48TL73sgVGyDnOWPFw
IzHIXAtyrB0asj2VK3vJjZzISvXA7LqhbZFaq3YIN8K/Jb4WnN8N3d0Xvco/
cSNKrDJYI18PjJ+41VqRyo1kBKemSfzqgct1Nk+r67mRi06mixh3H0x4r9bW
QORB5LR0Nv4aD8B16cVnXR95kIB5l3rbrCFIGvix/0I8DzIuvkespmMIyny8
1f4vhQcJ/qIyvLQ2BM25R/f3/OZBJLVkD8aeHIbJWEt7Xy8Pkk23qxJvHIZn
8n/Ij+zmRZgHTCh/ekfgd/1bnYxvvMhN9pamo7VjcDpE0qrvBy9y0THKYNfY
GFTq6eioL+BFZMcv9P5lGoe5LlodadW8yGPEIiLsyDiEoULtTpO8yMOpL7FJ
UeOwsbekZUyWD8GG+IdY7CYgSeaBRbsiH9Kxq4uW6DEBLV3lW8pV+ZB3PbWF
Au8mYBfLh+YEPT5EwCpYw6Z4Ag7JODfZO/IhTBofWF8KT8K5O4J/+77yITW2
OiF+pZNQ5Xft6YYMPsTtGllie+ck9GDzbijK40NEZSf3W9Mm4Xo4tT6qkg9J
srcLdKFMQbZCtO7COB/imjIhZWU/BQU5bta0S/MjlSraWtcXpqCViYRBhQI/
8ld5Q26Ngwo/RbRV56jwI8l+YmR7YSrctR+pDtPlR0RPJfV/U6NCGVOBKnMH
fsRaXExV9gkVqn6C5Q2J/EjKogC/8CoVjihkqDt+50fs5fPzVbhoMLg0Oos5
jx/ZMZhkJiVCg1O0J3HKVfyIelx8yr1jNBgF1J98muJH6qJHH/fdp8Fnd21E
soQIiKFA17djYzTYrt7atiVKQAJ+21o9m6Ph/jAKNpIgILwXmh9GMdFhV+Tx
bWOyBIRhOex5VoQOlcpFFoXVCIjy6HXDbkM6HBXqavKyISBCExXu7l/pUH3I
9HWtLQFZc2E7rfGTDkPSqvSErxEQicm0A4OFdKihmQ9/3CIgBA/D6wVNdBjh
9CF9xIuAJARdvVS0QocGRWdeGsQRkJX6O6cvn2TAWP967Q+JBMRF+5YPkxED
LprpMI18IyDHgvslfSwZ8MuY8oMnPwnIxXDZRZlrDLjOT7mWWUpAajdqJjle
MOB3+2ZEcIyA3FfqSLKCDJh44zHt9BQBObpir8ZZwYBRrtIR/gwC8sGBSSGq
jgEDvR5hy4sEZF3khcWjLga89kkyupuTiHSOvzDmn2VAm7g6fQoPEakNHv+0
vMSA5snuC0YEItIysOFes8GASG6NUbEwEQl97zIhux2DO5vvrsXKERFSjxa9
YxcGyV07v3YdICLzK8vTPHsxyDVQYU5SIuL9TPCtvBwGl+kiKc/ViMjI6JP3
8ocx2LK91MrBkIj8fF7qp6KLwUBNcu7+W0TERUZtKNERg956RXZX7xCRrtsn
CmKdMehhcp33830iEgiGGl+6YtDh4u+rfF5ERKdQMlzGA4OaD6+QZ94QkarU
nt0f/DCo+owXyoUSEdl3SanbAzGo4J/nZP+BiGir9/A6v8bX/577T0sMEYmd
cxZlDsPXl5nlmptJRLbd+uF+JxaDWN7FnVg2ESn93DF8/QsGx4o5q2QKiIjM
gegIkyQMttZZi38sISKmCS9851IxmDHB2uDZTERyqtVmg3Px9UlY7tecx+Px
+9Ntw2oM3sMeaR5aJiLDmnZiOrUYfFYcd273OhGJv3eOT7keg5E22HNmNhJy
S4l372wjBhsjAntKyCREVfw4daYDg73Xf8z+ECIhZO8nPhFdGJxS6dwWL0pC
6o4N7D3SjUG2NqkjPntISMFC36hpHwaPEUteax0mIefjBwooIxjUHRj/onSU
hFhmxPK5jGLQMoPvl+RxEtL+t0yoeAyDLsY2YywnSYgxf32I1iQGPXc+X5/V
JSFW8oZyD6YwGED9Rho2ICF3P9kVxVMxGP9ySaPUnITEbT8j2f/fe57VrjNZ
Z0nIC3UWyn/v6YUyOje/XCAhzlcntJcxDHaUh3x4bk9Cjkj/jWXMYJCHRWH6
5F0SciU6v95tAYM7miw5lN1JiPfjA/qaixiUjvXcufcRCVH29XZlX8Lzq1Gt
x+ZDQkgeh6bdljF4mnf60vwLEpL5QOiSxAoGbXoE74+8JCH8a9PxpTi7P7oa
VxaMxyvNtWNmFYPP9V/lZb8nISeLRjsfr2HwnfDP+oSPJOSpDq11C+fP453D
YZ9JyDWaZsujdQym5G6t+MaRkFO2B7rpOOe9kCbcTyQhDY5ec1YbGCyzNJa+
9o2E+Cy/lizEuXmPm/qZdBKif0LDRWgTg/2zn8x1fpCQkozVbiecaSUljkdy
SMiD3fmuuTivvpvwkiogIew184qrOHPa8r8XKCIhi+b5EipbGKQcVEllLyEh
vkOhJ51w3r1pU7JQRkL2SMVHheOsUP+8Y7SKhDSf8Vf4jfPxqBR6Wx0JUdO5
s9aBs97NJtaKRhLy6rIQOx3nM2rLO3JbScjuH7+MVnG23y6umNRJQqYmpVr+
e1937dTRDe8hIQGX0yM2cH7y1dnGb4CEHOU7+HkO50D30LvuI3j+I0gDgzhH
6PwKcJggIWd09G2rcE6kDEafpZEQuGG88yvOP4c5c3Sncf3qSZG8cHbrrK14
NU9C1NcCK/RwPlr/trNxmYRIz7mZcuG8WmIxJbBBQsqUfVP/4PEozBVav8BM
Rj4u5jTfwdkrtZs3lp2MyAVfQf+LLxIbIz66nYycu6Xlko3Hn+X9lUP7+MhI
3/SVtlM4l7+UOXmbREaojkcYTXj+AryoltmCZGR49mmmOc4G9zIcVkTIyOUr
juQaPP8NNkcDn+8hI/XHXcOicL28M1uLrJIhI/bj8Z+XcD1Z6MJ0Xnky0vjn
o5g+zp0HTzV9UCYj73tGTf/i+vy0l3u4R5WMTF6QmWLF+eKOv/O7T5ARccBe
oYDreYjlnHCaDhkRa7Xguj6PwYQlkX0z+mTk094XFm5zeL2g9R1XOU1G7la0
xD6YxSC1zeEyepaMmGjLsthOY/B7zb477NZkJGO4aEYb95MrZPgYXMa/v/U2
Shz323yye1LrdTLy172/JQf356anH33Cg4zoipu5XcH9jboabB14QkYuFnvR
5/B68PwaH/GeNxlR/N3i+nAYg9tMwpU3XuLxyJpVvDKAQaJkkicxkoxsn6dk
fMfrTaug0+uzMWSEc1o6fASvR+HcCjGRX/B4Mquk8bVjUGQh549UGhkpcN9D
1WjG4N6q8u1qRWSkNZl+lKcGr5+FL0WflpARjeUT4gOVGPz2w/hAWTkZ2c0/
ffBrOa7nyDbT0w1kxN2JWYOvBNeHy+gH+358vUvia8fz8HxR2KVfMVOQRo+T
x+bw+rynSSfen52CLD8UKxONxuD6a79dvtspyN+TspMqkRhM59wm9IRIQfay
PnDSfo9BwhrXttu7Kcg34T1c+QEYnMgz9L0pRUEOhKjvu/MCgyVuQUyOchTE
kvNbsqgPBu8yeFdsD1GQcw1zwtqeGGwbJEyZa1KQOR9fwT68H32PNnMw0aEg
gbtnPcVuYNDPOmTIUB//fn/MsNE1vP+0kbu1zSjI4MkTLJ4XcX1UCdap2FEQ
mUIPG35jDNpm7Pwu4k1BZHUKqHRZvF47X9wn9IKC9F5LmhHE+ydJLjqJ/JKC
SC8FDsuLY7A0XjyGJ5iCmPnx5+wSwOtjuOS7zVgKYkI+JUJhwvXyWPbuEEpB
2mdiGinNDFh27Aajr4yCJD1Tfztbi58HFr85dVdREPgmI72gnAFPu+6/0tpI
QYABIsxawICZVxQsKwYoCFuE0IxnNAO6GyirpDAJICLcOb0NVxkQO/k1PoRN
AEmuVtA3usiAjidE+D23CSCug2v7M88woLUi04QhQQB53Wl6aZ8ufl4QrPtI
FxdA8tRb3w9KMSD30JUNRSCAhHOte+4ZoEPf7vYbO04KICFV69FT7XS42arf
znxKAAkISjkaVk+H05UHM5pPCyAWbfZ/Xv+iw/b0NVu3SwJIeovYFimUDmMf
hpblPRFASDSNov0adLjjHsehWG8B5NOJa4Q1Jfx85vzwc8ALAWSQmzs9WYYO
X1y+7H7+tQCyNe6b85lAh046+2XXogSQb2TzpPEBGlQmlr7SKBRAhuRMT6KP
aDCdS2VZGhVAbk3GZlreokFptm9X+csEkDuak0dLL9PgjqU3JwZqBRCxxy5B
B7RpcLPnAubdLYAA7VwJRW4arE6eNS9fFUCCfBIvZAdT4XIly2+WLQGEsWeC
4vqMCqXHSXsQVkHEk7X03qoLFfpIHZ77xS2ITPmwjz00pEL1+HuhmTsFkfmk
SnlRFirMjJxvidQQRNJ3i04mXpuCfb/Y1Lu0BJEqwo+XsmZTkPcfJUHwlCBy
NuDJ0fvqU9BJ+IhbsIkgshHolXmTNAX3vr9P8bfF5ytwYa/4PQkj3ixa3vXB
x48WbayyTsKKdI6iDD9BxGArxoyZNgEX6gSl6IGCSKrNL+aGlgn8fnR04Xqo
IDK80vOzIH4C8gQ8eH8xQRCJLbTRazsxAZ95L7fpVQgixQVH9Vccx6Gj2+pZ
cS4h5IlvYMPekFGYbu0vR+ETQpQ30aC/bqNwVouyvo0khFh8P2ugc24UehIV
4mZ3CCFxn8j1waKj8M13O2q5nBASEJ/zIiNuBOZMVD111hdCunLSL3MmDEOW
ix+SCwKEEK8fX3srvQdhpI7yqgWnMJIyG65af64LhplfqvrMLYyEWPy9X7PR
Cd9cDggf5xdG0kY5RJ2+dEKfhz1KnsLCSJl2WkcYvQM6pfvejJcTRmbem0fm
PmmHagJtPdOG+PiO0q/yb1rgv5H78PU7YSRhYvKK40wNFPHN863csQOR+dP3
TzEyAB7sz7SYwNlovaSqQjUAaqulSG4X2YF0BbfH2LT7w1vTUagBzmvuHNwB
RH+I2vis1+Mc4vilv9f/BXQ4YuzWKroD4b432vzCzQf+HBu6Mii2A0mKs28N
ifSAlZo9Siy7diB9v95d+dX+APZEtTHvwZlD3qhnkPgAsltUxVzF+d8z09eK
AfehFUzvHsdZr7+Vud7tLtz84GHBEN+B8C+spLNHOULy3B1JfokdiOV8Rao5
6TqUPX1z5iDOr/f/C40JuAbN2C69vYPz4v5o2WP37WGC68naeZyF08xEOqKs
YEGt+ieB3TsQu5Xr3K4vz8AGaZUbKjhvPFCZ2OZuDpd6ZDk9cJ6o3zPoFq0H
eVQl2yNwPnyx5WTSAy0oESqaWIDzdSuNfRlxqvAIg+L2D2e2V6du7kmWhf//
/T/y/9//F/8PkzOJNw==
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{(-2) Pi, 2 Pi}, {-0.999999916456827, 
         0.9999998412622314}}, {{-6.283185307179586, 
        6.283185307179586}, {-0.999999916456827, 0.9999998412622314}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{579., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.4056777764286547`*^9, 3.4056777910360394`*^9}, 
   3.4056867426154213`*^9, 3.405702771154598*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the streamfunction", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"N", "[", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "/.", 
      "\[InvisibleSpace]", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .19314 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00459847 0.31746 [
[ 0 0 0 0 ]
[ 1 .19314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .19314 L
0 .19314 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00459847 0.321429 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.294302 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .16187 -18 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .30902 -6 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-6)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-4)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-2)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(2)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(4)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(6)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.08317 .01472 m
.08317 .01847 L
s
.12106 .01472 m
.12106 .01847 L
s
.15895 .01472 m
.15895 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.31053 .01472 m
.31053 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.68947 .01472 m
.68947 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.87894 .01472 m
.87894 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .16187 m
.50625 .16187 L
s
[(0.5)] .4875 .16187 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(1)] .4875 .30902 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(1.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(2)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01475 L
.02605 .01484 L
.02729 .01503 L
.02846 .01527 L
.03053 .01587 L
.03279 .01678 L
.03527 .01807 L
.0379 .01979 L
.04262 .02373 L
.05205 .03491 L
.06244 .05214 L
.0842 .10331 L
.10458 .16662 L
.14335 .31094 L
.18458 .46296 L
.20517 .52463 L
.21519 .54917 L
.22428 .5678 L
.2338 .58332 L
.24277 .59399 L
.2477 .59817 L
.25224 .60093 L
.25461 .60196 L
.25597 .60242 L
.25722 .60276 L
.25853 .60303 L
.25925 .60314 L
.25994 .60322 L
.26115 .6033 L
.26184 .60332 L
.26248 .60331 L
.26365 .60324 L
.26489 .60309 L
.26595 .6029 L
.26711 .60263 L
.2697 .60176 L
.2721 .60066 L
.27647 .5979 L
.28114 .59389 L
.28669 .58772 L
.29194 .58051 L
.30174 .56359 L
.32176 .51621 L
.34021 .45972 L
.37961 .31422 L
.4175 .17253 L
.43858 .10619 L
.45784 .05909 L
.46737 .04157 L
Mistroke
.4724 .03402 L
.47776 .0273 L
.48291 .02217 L
.48757 .01867 L
.48982 .01737 L
.49225 .01625 L
.49337 .01584 L
.49455 .01547 L
.49565 .0152 L
.49666 .015 L
.49789 .01483 L
.49854 .01477 L
.49922 .01473 L
.50037 .01472 L
.50164 .01478 L
.50276 .01491 L
.50398 .01512 L
.50512 .01539 L
.50617 .01569 L
.50854 .01658 L
.51113 .01788 L
.51634 .02153 L
.52094 .02588 L
.52585 .03167 L
.53469 .04501 L
.54496 .06499 L
.55607 .09166 L
.57624 .15148 L
.61721 .30188 L
.65666 .44917 L
.6765 .51136 L
.6946 .55618 L
.70461 .57505 L
.71409 .58868 L
.71929 .5943 L
.7241 .59831 L
.72661 .59995 L
.72938 .60138 L
.73077 .60195 L
.73228 .60245 L
.73369 .60282 L
.735 .60307 L
.73627 .60323 L
.73747 .60331 L
.73855 .60331 L
.73973 .60325 L
.741 .6031 L
.74165 .603 L
.74236 .60285 L
.74362 .60254 L
Mistroke
.74478 .60217 L
.74705 .60127 L
.74949 .6 L
.7539 .59695 L
.75897 .59223 L
.76451 .58563 L
.77459 .56986 L
.79428 .52609 L
.81525 .46353 L
.85686 .31013 L
.89694 .16147 L
.91533 .1046 L
.92577 .07747 L
.93551 .0561 L
.94506 .03919 L
.94997 .03216 L
.9553 .02583 L
.95822 .02295 L
.96091 .02067 L
.96344 .01887 L
.96623 .01725 L
.96872 .01614 L
.97106 .01539 L
.97235 .01509 L
.97353 .0149 L
.97483 .01476 L
.97548 .01473 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00459847 0.64881 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.233891 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .13166 -18 -4.5 ]
[.4875 .13166 0 4.5 ]
[.4875 .24861 -6 -4.5 ]
[.4875 .24861 0 4.5 ]
[.4875 .36555 -18 -4.5 ]
[.4875 .36555 0 4.5 ]
[.4875 .4825 -6 -4.5 ]
[.4875 .4825 0 4.5 ]
[.4875 .59944 -18 -4.5 ]
[.4875 .59944 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-6)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-4)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-2)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(2)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(4)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(6)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.08317 .01472 m
.08317 .01847 L
s
.12106 .01472 m
.12106 .01847 L
s
.15895 .01472 m
.15895 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.31053 .01472 m
.31053 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.68947 .01472 m
.68947 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.87894 .01472 m
.87894 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13166 m
.50625 .13166 L
s
[(0.5)] .4875 .13166 1 0 Mshowa
.5 .24861 m
.50625 .24861 L
s
[(1)] .4875 .24861 1 0 Mshowa
.5 .36555 m
.50625 .36555 L
s
[(1.5)] .4875 .36555 1 0 Mshowa
.5 .4825 m
.50625 .4825 L
s
[(2)] .4875 .4825 1 0 Mshowa
.5 .59944 m
.50625 .59944 L
s
[(2.5)] .4875 .59944 1 0 Mshowa
.125 Mabswid
.5 .0381 m
.50375 .0381 L
s
.5 .06149 m
.50375 .06149 L
s
.5 .08488 m
.50375 .08488 L
s
.5 .10827 m
.50375 .10827 L
s
.5 .15505 m
.50375 .15505 L
s
.5 .17844 m
.50375 .17844 L
s
.5 .20183 m
.50375 .20183 L
s
.5 .22522 m
.50375 .22522 L
s
.5 .27199 m
.50375 .27199 L
s
.5 .29538 m
.50375 .29538 L
s
.5 .31877 m
.50375 .31877 L
s
.5 .34216 m
.50375 .34216 L
s
.5 .38894 m
.50375 .38894 L
s
.5 .41233 m
.50375 .41233 L
s
.5 .43572 m
.50375 .43572 L
s
.5 .45911 m
.50375 .45911 L
s
.5 .50589 m
.50375 .50589 L
s
.5 .52927 m
.50375 .52927 L
s
.5 .55266 m
.50375 .55266 L
s
.5 .57605 m
.50375 .57605 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01477 L
.02605 .01492 L
.02729 .01521 L
.02846 .01559 L
.03053 .01655 L
.03279 .01797 L
.03527 .02 L
.0379 .02266 L
.04262 .02869 L
.05205 .04511 L
.06244 .06864 L
.10458 .19095 L
.14487 .31522 L
.18364 .43479 L
.20335 .49445 L
.21376 .52432 L
.22486 .5533 L
.23566 .57685 L
.24076 .5858 L
.24546 .59255 L
.25018 .59779 L
.25267 .59987 L
.25394 .60075 L
.2553 .60155 L
.25649 .60213 L
.25759 .60256 L
.25868 .6029 L
.25972 .60313 L
.26093 .60328 L
.26204 .60332 L
.26327 .60324 L
.26457 .60303 L
.26571 .60273 L
.26695 .60228 L
.26946 .60101 L
.27178 .59938 L
.27394 .59749 L
.27883 .59194 L
.28404 .58417 L
.29362 .56561 L
.30232 .5449 L
.3423 .42823 L
.38077 .30958 L
.42169 .18338 L
.44205 .12181 L
.46109 .06932 L
.47046 .04776 L
.47936 .03145 L
.48426 .02459 L
Mistroke
.48685 .02165 L
.48961 .01907 L
.49216 .0172 L
.49447 .01596 L
.49559 .01551 L
.4968 .01513 L
.49793 .01489 L
.49898 .01476 L
.50025 .01472 L
.50145 .0148 L
.50252 .01497 L
.50369 .01527 L
.50497 .01572 L
.50632 .01633 L
.50874 .01781 L
.51098 .01957 L
.51307 .02157 L
.51784 .02733 L
.5278 .04422 L
.53852 .06836 L
.57971 .18769 L
.61939 .31007 L
.65755 .42778 L
.67884 .49239 L
.69816 .54614 L
.70783 .56873 L
.71291 .57883 L
.71829 .58787 L
.72299 .59421 L
.72549 .59694 L
.72816 .59934 L
.73062 .60106 L
.73287 .60221 L
.73395 .60262 L
.73512 .60296 L
.73623 .60318 L
.73726 .60329 L
.73843 .60332 L
.73967 .60322 L
.74073 .60304 L
.74188 .60274 L
.74313 .60229 L
.74447 .60167 L
.74687 .6002 L
.7493 .59826 L
.7516 .59601 L
.7559 .59076 L
.76578 .57405 L
.77649 .54998 L
.81738 .43165 L
Mistroke
.85675 .31023 L
.89461 .19345 L
.91566 .12943 L
.93491 .07533 L
.94443 .05253 L
.94945 .04214 L
.95481 .03263 L
.95995 .02522 L
.96461 .02011 L
.96686 .01823 L
.96929 .01664 L
.97041 .01607 L
.97159 .01557 L
.9726 .01524 L
.97371 .01497 L
.97491 .01478 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00459847 0.97619 0.188537 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0757881 0.0147151 0.256165 [
[.04527 .00222 -6 -9 ]
[.04527 .00222 6 0 ]
[.19685 .00222 -6 -9 ]
[.19685 .00222 6 0 ]
[.34842 .00222 -6 -9 ]
[.34842 .00222 6 0 ]
[.65158 .00222 -3 -9 ]
[.65158 .00222 3 0 ]
[.80315 .00222 -3 -9 ]
[.80315 .00222 3 0 ]
[.95473 .00222 -3 -9 ]
[.95473 .00222 3 0 ]
[.4875 .1428 -18 -4.5 ]
[.4875 .1428 0 4.5 ]
[.4875 .27088 -6 -4.5 ]
[.4875 .27088 0 4.5 ]
[.4875 .39896 -18 -4.5 ]
[.4875 .39896 0 4.5 ]
[.4875 .52704 -6 -4.5 ]
[.4875 .52704 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .01472 m
.04527 .02097 L
s
[(-6)] .04527 .00222 0 1 Mshowa
.19685 .01472 m
.19685 .02097 L
s
[(-4)] .19685 .00222 0 1 Mshowa
.34842 .01472 m
.34842 .02097 L
s
[(-2)] .34842 .00222 0 1 Mshowa
.65158 .01472 m
.65158 .02097 L
s
[(2)] .65158 .00222 0 1 Mshowa
.80315 .01472 m
.80315 .02097 L
s
[(4)] .80315 .00222 0 1 Mshowa
.95473 .01472 m
.95473 .02097 L
s
[(6)] .95473 .00222 0 1 Mshowa
.125 Mabswid
.08317 .01472 m
.08317 .01847 L
s
.12106 .01472 m
.12106 .01847 L
s
.15895 .01472 m
.15895 .01847 L
s
.23474 .01472 m
.23474 .01847 L
s
.27264 .01472 m
.27264 .01847 L
s
.31053 .01472 m
.31053 .01847 L
s
.38632 .01472 m
.38632 .01847 L
s
.42421 .01472 m
.42421 .01847 L
s
.46211 .01472 m
.46211 .01847 L
s
.53789 .01472 m
.53789 .01847 L
s
.57579 .01472 m
.57579 .01847 L
s
.61368 .01472 m
.61368 .01847 L
s
.68947 .01472 m
.68947 .01847 L
s
.72736 .01472 m
.72736 .01847 L
s
.76526 .01472 m
.76526 .01847 L
s
.84105 .01472 m
.84105 .01847 L
s
.87894 .01472 m
.87894 .01847 L
s
.91683 .01472 m
.91683 .01847 L
s
.00738 .01472 m
.00738 .01847 L
s
.99262 .01472 m
.99262 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .1428 m
.50625 .1428 L
s
[(0.5)] .4875 .1428 1 0 Mshowa
.5 .27088 m
.50625 .27088 L
s
[(1)] .4875 .27088 1 0 Mshowa
.5 .39896 m
.50625 .39896 L
s
[(1.5)] .4875 .39896 1 0 Mshowa
.5 .52704 m
.50625 .52704 L
s
[(2)] .4875 .52704 1 0 Mshowa
.125 Mabswid
.5 .04033 m
.50375 .04033 L
s
.5 .06595 m
.50375 .06595 L
s
.5 .09156 m
.50375 .09156 L
s
.5 .11718 m
.50375 .11718 L
s
.5 .16841 m
.50375 .16841 L
s
.5 .19403 m
.50375 .19403 L
s
.5 .21965 m
.50375 .21965 L
s
.5 .24526 m
.50375 .24526 L
s
.5 .2965 m
.50375 .2965 L
s
.5 .32211 m
.50375 .32211 L
s
.5 .34773 m
.50375 .34773 L
s
.5 .37335 m
.50375 .37335 L
s
.5 .42458 m
.50375 .42458 L
s
.5 .4502 m
.50375 .4502 L
s
.5 .47581 m
.50375 .47581 L
s
.5 .50143 m
.50375 .50143 L
s
.5 .55266 m
.50375 .55266 L
s
.5 .57828 m
.50375 .57828 L
s
.5 .60389 m
.50375 .60389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01476 L
.02605 .01488 L
.02729 .01512 L
.02846 .01544 L
.03053 .01622 L
.03279 .0174 L
.03527 .01908 L
.0379 .02129 L
.04262 .02633 L
.05205 .04034 L
.06244 .06112 L
.0842 .11807 L
.10458 .18129 L
.14335 .31069 L
.18458 .44782 L
.20517 .51051 L
.21519 .53758 L
.22428 .55917 L
.23316 .57682 L
.24277 .5913 L
.24534 .59427 L
.24806 .59697 L
.25057 .59905 L
.25292 .60063 L
.25512 .60178 L
.25625 .60225 L
.25748 .60266 L
.25817 .60285 L
.25882 .603 L
.26009 .60321 L
.26125 .60331 L
.26248 .60331 L
.26361 .60322 L
.26486 .60303 L
.26616 .60272 L
.26737 .60232 L
.26953 .60138 L
.27185 .60003 L
.27714 .59565 L
.28195 .59015 L
.29135 .57555 L
.30023 .55761 L
.33869 .44954 L
.37961 .31354 L
.41902 .18198 L
.43881 .1204 L
.4569 .07149 L
.46621 .0508 L
.47635 .0329 L
Mistroke
.48191 .02548 L
.48462 .02253 L
.48707 .02026 L
.48944 .01843 L
.492 .01685 L
.49341 .01617 L
.4947 .01565 L
.49594 .01527 L
.49724 .01497 L
.49847 .01479 L
.49916 .01474 L
.4998 .01472 L
.50097 .01475 L
.50222 .01488 L
.50333 .01509 L
.50437 .01535 L
.50552 .01573 L
.50675 .01623 L
.50934 .01762 L
.51206 .01954 L
.51692 .02415 L
.52147 .02977 L
.52569 .03606 L
.53527 .05383 L
.55576 .10478 L
.57436 .16078 L
.6144 .29331 L
.65292 .42239 L
.67244 .48428 L
.69389 .54384 L
.70373 .56607 L
.70915 .57645 L
.71429 .5849 L
.71906 .59142 L
.72425 .59697 L
.72654 .59888 L
.72897 .60055 L
.73105 .60166 L
.73334 .60257 L
.73456 .6029 L
.73569 .60313 L
.73693 .60327 L
.73762 .60331 L
.73825 .60332 L
.73953 .60325 L
.74024 .60317 L
.74091 .60306 L
.74213 .60278 L
.74342 .60237 L
.74569 .60139 L
Mistroke
.74782 .60017 L
.75267 .59629 L
.75791 .59044 L
.76271 .58366 L
.77351 .56389 L
.79251 .51702 L
.81324 .45477 L
.85391 .31995 L
.89306 .18896 L
.91305 .1262 L
.92356 .09609 L
.93466 .06776 L
.94462 .04644 L
.94989 .03705 L
.95554 .02867 L
.96074 .0226 L
.96548 .01853 L
.96776 .01708 L
.96896 .01646 L
.97024 .0159 L
.97135 .0155 L
.97258 .01515 L
.9737 .01492 L
.97475 .01478 L
.9755 .01473 L
.97619 .01472 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{679, 130.875},
 ImageMargins->{{34, 0}, {0, 1}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 678}, {129.875, 0}} -> {-0.0880394, -0.0144882, \
0.00468449, 0.00468449}, {{18.75, 218.875}, {126.75, 3.0625}} -> {-8.55224, \
-0.267221, 0.071981, 0.0185364}, {{238.875, 439.062}, {126.75, 3.0625}} -> \
{-24.2418, -0.334415, 0.0715163, 0.0231736}, {{459.062, 659.188}, {126.75, \
3.0625}} -> {-39.6135, -0.302944, 0.070849, 0.0209612}}],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "GraphicsArray", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plots of the forcing (or dissipation)", "Subsection"],

Cell["\<\
Forcing is calculated to equilibrate the dissipation since there is no \
advection for a flow that depends only on y
Some arbitrary values are assumed for the parameters\
\>", "Text",
 CellChangeTimes->{{3.405677580537345*^9, 3.405677646827773*^9}, {
  3.40567768158708*^9, 3.405677702176744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Forcing", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", ">", "0"}], " ", "&&", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], ">", "0"}]}], ",", 
     RowBox[{"Simplify", "[", " ", 
      RowBox[{"DS", "[", "  ", 
       RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "]"}]}], 
    "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["A", "2"], " ", "C", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", 
         RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "7"]}], "+", 
      RowBox[{"3", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "-", 
            RowBox[{"Sin", "[", 
             RowBox[{"3", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
         RowBox[{"10", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"7", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"4", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
      "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{"6", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405677810825055*^9}]
}, Open  ]],

Cell["\<\
Setting \[Mu] -> 0. shows that Flow1 requires a forcing with discontinuities \
that disappear in Flow2 and Flow3.\
\>", "Text",
 CellChangeTimes->{{3.4056778880865917`*^9, 3.4056779589082003`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", 
        RowBox[{"\[Mu]", "\[Rule]", "0."}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0."}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0."}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405677815714443*^9, 3.40567781989952*^9}, {
  3.405677852460116*^9, 3.405677854705751*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwU23c81d8fB3B7z3uNa5QIyShpCTmnomQnlUo7I1FfpRJJRkIqUjIiK7Ki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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {193.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3c8Vv8Xt/d6hlmKUlnZDzKee2U82aLhq20lKZHZIomiQvZI2VJJCJHn
c1Jkh1AZZRWRvffP7/5zX+d11vu8z/ncez6S9u7WTkwMDAwBHAwM/3+bGPPp
r0qKwn/9m1sPDdd+e2OKY4coPGj7esBhg4bLS449ERITBd3L66cfLtNw8Yf/
mUoJiQKnBHtQwDQN51v+vKRM3JLdJN20/9DwTUf1bIxPFAInY1I+fqPhUy2Z
NuZconDz9yptWw0N79MhMZ5gE4XIAP3jRm9oeGvu7XwXJlEw8/d2Nk6k4VXk
qRM+GyKg7GDyUeYWDS8MPM0ZvCIC2Zp3L46foeEZ/xpLohZEoOSvCHcylYbH
2Go7Pp0RgeU4kZUDYjT87qfnhFcTIgA2V7XaZoxwHyURVD4qAlnHbni71Rrh
thzzop0DIsDXk/e20dUIN/Zy+Dz4UwReB/seyNEwwrX6Wr2mu0Sgl3k5/yWj
Eb69LP8Lz1cRqD2Vz+vy0BDnlRK/KfZFBCL9higalob4RkS4rHSDCOj9J13j
wGeI9513uav/UQQOORxI4r1rgLd+7VQ5jERAS3vYPlfHAK/CDPtOV4jAIufd
mO5pfTxTeJf2tSIRaOnMvWZ6VB8//7l7qiBDBCypVtpyTAdxW1WTVPpTEfhW
FNd4JlcPP/S0zLQxWQT8h3b0lJrp4bK+sdnD0SKw0padsyMSxyf2Wp7cESwC
D/2vr3ewU3GfkKrP4Y4ikEI05rttr4EHGz5Pdd4jAtRjjeU3v+zCIfya1U5J
EajgtTs9Pi2Br7WaMn3fvuVPWBf9orADv3p6wsmYvMW36hm19z+EcHtf1f3y
zCJwVwh3s5RnxFMrWX4NbQjDmkKJw27/OewHc2fkkxVhaPpD/10g2o1ZRfrN
8c0IA2M8Ubqbfw5hzysrpvuEwVb1Y19UKwGuTT66lNcjDNhJ7irHfjKUUM7u
dPguDGm9dtU7B4RBoYrpTvsXYQgbd3WCYnHY3k0zKaULA+tei8JAEymwlRRd
cy8XhvGGdaldUXsg5vzoK+kSYThu28w007wXuOceEJJeCcMRmeylfEUZWOFp
+34jRRiupD8SoNzZD+o2GWGUhC1/Pu4bTYEK4JnopTMRLQyiVi1tG16K8HeP
8LMz4Vv59M503H+mBFJuI4dFQoWB3O4c68ejDGcL3zG3BgkDu+ok/dVVZfhO
PXn+4DVhKOX6+3xGVQXId/eLrnoLg8uzfCbOhypg1bBRX+QhDIfyxf949qvA
A0LLDbdLwnD0W56rurIqfD6eprDngjA8hJxSuxuqwJTq2dfrKAzzTVnrw1Wq
QB3Sfxx3Vhj4TDIuD7OoQcmVP/PstsKQI3TlivN1NZgpKc0BG2Gw+vjf7vXX
aqCwfu8/f0th4GxMVVPrUwNXfTtuFVNhGDT+cU6UhwJZ9+UqR4228vvlaFSo
UqDvy9rljIPC4CDxnUPmOAW2CzVLnKQKg/Nw0G9PHwrYnnzaRtYShreBAo+f
R1EgJv1KcBNFGLjfqN/6mUuBlhE99RBlYRhj/Fex+z0FuBVJI9T9wtA1fmwh
vIECRt5DiYvSwuCl9d5F9hsFgiremhZICcPijisdxF8UoDOGrrtICIMKvenG
f4MUWKHZvpbcLgwN5zTJpCEKqD+SOdclLAxtDTKVR/op4NG+QowmCcPsN6s1
1W4KxFlb2sXwC8OOO1nmgW0UeN+SkRbLvTVPt6+e2KihQL/F0kgcuzDctzjs
BmUUYGsyU0pgFoafTFVL33MoIG+a5pu4KQQ0H90suxgKHK6bpyetCgHXdgsd
21sU8KGZsKUsCoHrzprcIScKpFSnmj+ZFYJTirxTRFMKVOnPxqROCsHasXvy
C/spMPyB1vN0TAj2KojfS+OjbNU15Zo+KASjtPseT+rUwFbHsDDjlxBU/u6/
Qs5Ug5vlicuZ3UKgpKro8uyGGtSWHLyX81UI1Ck27frSajChFv8l94sQ+JK5
XW+vqgKpaEwor0EIyPanlSSaVOH065islx+FQJhDybfxoirM5vypelMkBKop
d9n/JKjAjsSw9YpoIQhys/N//UEJDIR/GVRGCMHbKu/NK3eU4EKs6gN6uBCY
Ma5XPjdQguKoHrEPd4SAkPGr8Vq4IhiHKWjWXBWC4sBn5mz39oPX9TbPFhsh
+GBSzKLtLwNJy3vLWy2FINP/vzXvJWlAvtcZv5oKwZgrpZjiJw1cXlKRHfpC
sPxL+3Kk/z546ubzqktVCJ6YJoZk390D9afERoZIQuBZxSyQ0yIJlk91sBV+
IXin+Lhw/pwktPedjuPn2aqvUqwudU4Ceh0yDLRYhOAYn4uXxA4JmLognxYx
JwhGAYksh1jFwfuFxVLmlCD0r/+VFMW2w8q/K5bl/wSB+WZOC/ONbcBy5e36
0JAgRGS1zhhsioKwD9VOq2PLPiWeul1eGFJKz76xbBUEPdHeBucAIZBYDuJw
ahKEJMaXXdNbdrI3PpdEVAsCyVCF2vSADNQgK9Lvt1v2tMWaMEkifPzo6bry
RhBMgh+mtzwiwCHW2A/8+Vv6hgx7s00BOHzvh7tWtiDEeMTczf3KD46P7Bsj
4gQhS+SysXgdN/z9Erw767EgSAWwLvV3cMFlQs618kdb+SzcGYpGOME3Zkz6
d4ggRNND4w5IcEBYktddLV9B8Jxo7xtvZwH+nrgey6uCIPHrvJKSAAvEiL9T
dXIXBPsOj9Z/Vszw5Nl6f8R5QWBwjSy4PcAIBdkh1N/HBaFY+irDtdANRBnJ
jV2xEQTXWpbmKat1VC7T8I/fShBM36iyru9eQx9f8idrHRKEApdT17f/WUaH
JpRnLA0EQZDMcamtfQk1Kh4xdsIF4dzEKVOHxkXUWZiwGKEpCE7DYyf+65hH
J+bKLbLUtvC/XlE8+2cO9VF6s8qVBEG5RMvi7uYsGi2TPPJbWhBeKD/Ydtl4
Bq3T8wq0RAXhdiQt6MClCdTYpcizShYEwxOCZOW//1DKQvH5CgFBQE1iSy1e
Y0hHAe3Q4djq73n2S9i7EcRjYnBtjVkQRG+r9cp5DKNup7qO95tk8HmpFLam
/gdde/L1ge4iGaSiOC7Gjg4ik3e2I+szZDAYCW8P+TaARDt69ekTZHh64DH7
65Z+VMYzskL9Q4YCc904gcZf6J70pWObW/+xy29kN34x/UTHDWbeoF4ymCnu
Klm06EEL19dc8A4yyBl27GKW+oFq4m9/YmglQ7PN46nbL76h2CI2iQ+NZLAU
5zp9xrATqY0JfNP7RAb2UY5o31dfEQt7nAoTkOFSpMTuU9faUPuubY+qKsjw
OVdnZuFYK7pqt8dQv4gM97MiZKL9m9FBn7xnzK/JsA/bDEu+34iIjxXXPuaR
wbdBsP9AcT0qrDtQZJBOBvkBUj068hkF/abzsaaSIe3Q+KmA2mp0mNHAtTqR
DDStfV+DrT+hKU0LSaMoMiSFjdVdyPqA4MjXG2wPyXDihZ7hOTdAEVdsv9fc
I0NYT153SjgdnX7QqxoaTIbCxDLrtHPvkUKufQQtkAzXjDf+if9XjjY+Do+y
3yBDpNjfTPcrZaj5l5tRrS8ZPpUzazFll6BLwr7rh9zJUOW4ebnfqQjpqK7Z
cl7c4mv+GM18/A3isbxdXOdMhivs66MaDwtQjyubQJg9GbTE38dm38tHL0PC
L5qcJkOQT4R85a6X6Ea6wGcuuy29jO5v0z/PkSk9dlfDUTJEndjhwNKag0bn
n/4wNSfDXGnlZTVSJion7KHwGJNhps8h755zOrq/Py+y0WDrnGu4tdC/P0O2
xor/HuBkeO55InLtSyqSdiqmmeuQ4SK99CzHnhS0FHggg1eTDK/MhAINXyWi
zyn0jSZVMty2eGdx2ykeObfXvrWQI4O0P2fl5H/RSH3KnMC/jwxu7sZZtyKj
ECvPV7cvu8iwEST+PPhbBGrfZ1sbsYMMSgn/IoLbHqBM/d7dVmJkqIUBHkve
MOR1xj5AQIgM+3lavvncCUUG14e7WghkGHu9Z7JR6S4ix7upR/GSQQN+ap8m
3EGDhdNRhznJILvdVtdD8jZKYVsJsmMlgwthQ4w+dwsds2PycmAkQxf/2/ie
8euIP5/LyW2dBIV+7ddkZfxRLSPpmPcyCRSjckJ/pvmgoKPbaLfmSZAj6v7G
x8YLaT/frRk6TYIrHosSbw94ork1OZnIcRLcOJVl/MTqCsq3UhNL/EuCjfyJ
7QPSl9D5TB3u9N8kyCV1T5xgdkUSSwZref0kcLG/NUmWPY+6TM3Hi3pJcGy7
R9ifOEcU/fToz/c/SGDy3+4ggoE9Mps99aW6gwRDT9l+a8qfRWw0Z2huJUFo
mbV5ecxJhJIuv/nWRAKCp3F5vup/yG/CJ72vjgS4m7XRc/ljSPlgQPTfahL0
ZFbrZvjaoNHY0OCZDyRwLyo+Ic97GGX+jfBerSRBem/yt0+N5uiUboIzS/kW
H9yf3NqWjZFQ1LPjvCUkCJvudKuONUItQ7mHhApJkNKRp/IlVh/d13xzYGc+
CcLFqAIMUzg6+OCdrHQeCcx1nH97quui1V8ftilnk0CSK2i/3o4DqFi1nkcr
nQR3xPCE3fco6HJo2/rBVBIU7Q96IO2sgvZ1d02YJm3xVZnff+C4IupTGPx1
JG6L3+w3/8YSZVFS0FjLqcdb/OppDvoG7EU2nbMfnB+RgDP5tf+/uV2IR3at
0D2MBJHx3H5n23ai6pssmX4hJNDOzH1VniiGbrXyxN4O2spXUJhBlRJCmnsE
Q8JukYBLRvPMnv+IaNpP3Df6GgnGTnvFJRrwobzGPS4pPiQQ9GUKXPvGgRwl
FP7L8iTBTc5xHg9jFiTupW6Sf5kEclKFviv+DKjzM1W71JUEpxV5/9xNWaFH
bqPJgzMJTtSmRoScnKcbu1uK19mT4CG9gbefc5rO9PE4X9tpEkj3jZvRN0fp
74XObnbZkSBAy1LygO5vurery9TgMRK84jjNxBHbR1egX+n/Z72Vj/3l/H+v
f9BHCP5t8xYk0FyV/Ttd9pWe5nT744YJCYzkmS4zMTfT7d7dL2ankUAtmaMu
PKWGTuZ9nCWgT4JrbJ9TgrqB3nQ2KU4UI4GKMFujaFcZPaQ4PXSXNgl41Ehc
CSKFdJzjhZ+cBgmuOgpsFDLm0ZdPFF1QU92ap7btu/IvptMLX1fY6SqSQN9n
StysIJHuxvzJ1EiOBBcdL9v6JEfR9xxv1LHcR4IJKYLMhdeh9J957fttd5Mg
24meq60WQE/Y6NlxbicJOlx3ZL8R9KIftv7N77pt6zzUTqzJq1ygc2WPM1wV
JsHnYP9LxOLT9E/L89PXSST4evrpI1Uxa/pN842BYP6teRXMPGkUYUBXT2Nr
f8hNguK6YDqcVKdrffGo02MngZMZ83n39j106noPfZ5p6zz7/2AV7CLRD8od
Kn6+QQSdE9O8pAgGutF/Rc9PrRBhe/LeozzNI5UmoTueEhaIsNxwYDBKsaXS
4u39mOppIrhZPFEJjn9TaT04d99/nAj01VdPXmU9rDxOOBuw/y8RupOG0ku3
nas8iTV49Q9t2bNJpZ6V3VN59pK6a2wfETgGjqvfKWx+75icdsa4hwjJ5E2b
Oz673rvU8Rxd/0aERzIq9Ojrr7XdFn1N3nwlwvmOMX0DjVydK3sGMacvW/pl
00B5FgFdLxsLimgDEYzxu8tzIod1/W6/k22qIYIi04/i48a3dW+8lpK4XUWE
z975fj5p2bqBvRGCFDoRou79Q4rGNbrB3Ktcf98RoSA1w3R6pl/33gFnhidv
ifB9uGJN5PeS7oPzrfNWb4iQW9ru0fyBjxoZqzPG8ooIhLOHeftsJKkxH3P6
ynKJwFR76Nal7SrUhGlip1smEVARLbi1Vo+asvNWg8QzIpTZXV7UibKiPjP/
C+3JRMDc5Aqybp+iZl4/UnIvnggdy5Z6ioYXqLnP0QudaCKIP3I9WjnqRX35
TTZt6hERiMeWBkSaAqkFrHFxmWFEuCrSZ55JC6MWqzI+sA0hQt/U0Y4IQgz1
3Tm32zxBREif5A/mYUil0iO++cBNIpz1y5YT2ciiVlUedPPyJ0LtE09Zh/zX
1JqxV+ekvYlb+x8Ps4dXCbVeVPR4zxUijA/Vh3icQtRmWrBZpNsWfm1ci5pS
TW3zntQzcCGC9NuIFw9dmqidGXYaSw5E0I57z5v0+Su1q7Va/uUZImSkVWqH
WndRf24q7Tp7gggln0+08R7vpw7sTxEmHycC+XiOnkj6H+qfE+y8tdZb+bv2
D48cGqeO3vdkumGxxY/u0g2/+hnqRGnvoqLJVr1iHH6b44vUmd+HxgcNiXA4
h0X2L75BXSAVD8TrESHzg0e11wYTtqK387upLhEs1CoCtAvZsQ33sKZNTSIE
djqv/j7HizGlzlcVqRFBg9tDIWA7EWNrPFt2XokIR+T4H91TE8K4VhpebZMn
grDsQPZewW0Yn7RGxpd9W/Ybgjw87hIY8Vh6wp3dRBg5tCYU8WM3JhTM+0hj
JxGyj7PrKP7ch20r9LszJkYEk0VWI6doeUyib9DvqRARPA9ohu7mVMak+Cwv
2xC34rfND57VVsOkdcod2PmIsHndoGlsUgOTd93zXwUnEf5L/nR4SkMHU0qI
tHBnJULcMK1LNRrH1GpW9XczbvVv5YjaDhd9THPO+cC3NQKkd1wc1cg2wnR2
tSmELxEgNXh+RsLOBHtG4lazmSNAV5Ijz7sbFhgzq8GBbVMEsP0ayUWNO4w5
L9ygDo4RAB5VFt7UOYLVD7/VfzFMgHvKXTqPDxzHFH5MHLo6SADzqN3xL+Ls
sKj6fRbavwjQcuTpBfqp09hcxVkb5m4CRKQ8Y601O4fZvkq0begkgNntbR79
eQ7Y+9S2U9FtBEhcd4r3sHTGdkZyO5xoJgDhLZeElt4FLOi2gcvuegJwj7/g
CAh1w/543rw0Vk0A6vHir2yCVzATxxLPog8E+LRAmkoT8cReHZ30vV5JgOZ/
/6q5bbwwAZr0Tf13BND0NOfgr/PBvDTPBXG/JYDoK0SuD/DHvsskhX4tIIA8
25GJwhs3MO1tXx8kvyRAqTyvZXJ1AJbKw/PYIZcANQ8unrcruI0xbRjEy2US
IOhgRIRJ3h3MefJmyuxTAhyeZNkv3n4Xq+srSatIJsDDvRKFocr3MPm2yew7
8QT4T4xbya8mDIv8KP3SNJoAw0tXEoTjH2JzxefekCK28LoZM/+xicSOZyeV
dIcRwCT0fuiTjSisPP5rRUYIAVq7u7n2NkdjO+7zfLgYRACSyf4jgtWxWNA1
wxrVWwTg9Bdxl/oTj/2+eKth1Z8Ad2oMe5XUkrCXFlMd4R4ECAtZ1/R2eIoJ
4DLdNpcIYEctSYvZk4ZdVbbv23aBAHITAmmuJelY567k34OOBNj19EYQv3Mm
pkVuH31xlgCq+9MZ3dSzsVRW3qmrJwlQtCfFMEAmF2NcNJzXtiWAUJuz7xm9
PKz2R+lmgyUBTvRPNB4dycfkG6ZYYkwJYFrfQ+WgF2AR72W4TtIIcCYxVnZ6
RyE288qeX0qfAOecL9xXSCjCjj1NJv+jEiDrHrgIyb3FyiPbRYu1CGA5/sKQ
50cJJh7Eu/OG+ha+a31mtzPKsCHHABkeBQKsnt91cTb6PXboWJlCuwwBxDbn
XUQr6dgL2rRqyh4CjM8GOt8LBozvgOwBR0kCvCFxWtS9/4BtfeWo8uJb/bjK
4qrK8RHr3JaiPydCgOWQLtPC85+wA7wdh96TCRAedlXuQE81xjBlZGPGsxX/
EHbZmqMOc+wPsCVzEKC9L0R05kM99rmt7FQPMwH+DDZcLI5pxB69lXVxWxUA
hsc0ZU7DFmwm2+GS2qIApBc/ML55vBU7mpDiuTYjALur7up/8WvDtl/nu/lg
VADy793YfXe0HbuQWS/85I8AMB1jjpuV6sRKmkIKXw0IgH3wlY5bl79hhyU2
h5u7BOBjSfr5HcpdWKpxRdCvTgEYaHtoa/OiG/vn6Ss+1SYAqiF9en/Ue7GQ
6klrQoMAuAdEYfoH+7CvEy/GJT8LwMF7Zdd+7+7HJERc7ql83Ip/p6zmEv8A
Vu7aV2lTIQD3DYjaPqxD2CR/q3TcCwE4f6ZPMNpnBNM58PBjdo4AdGhr/bxX
8BcLszc+XZohADe9Yyr4Fkcxqbcfor8nC4DdNw266otxzOPnTYW/8QJwjePI
o/uikxidXatuOXor/rOtA2gyhdnaFW6IPRAA31RrrqWeaSzrzuVEuXsCcOQm
n6H6mxls5qWsmk6wAAgvbaooPpzFHm6mXzh1QwBeJpOf8p+ax6oyo9ufugnA
s6xjutXnljH+Zkv3AhcBGEt7OkzwX8FOLnJzfXAUgJObSDo+cRVbNA7GBk4K
wJm9+y5yLK5j8pNeeVLmAkA4KtxmEcOI+4soG1KMBSBms3zAgcaE1+iN/zI0
FADrJL2mxk0m/GyMk+B5XQEo8u0xmgpkwWMPHAt8vl8AHvu+UkU17PiAPXFb
ucxW/2UJzSXZHLjSg+a39XsEgNtY8H7aA068/qfR2Ji4AHhHng+MceXGN+5o
HFPgEwAdWRa7tCv8uOmr2SkqlwAIVacXz+ICeELn63BLNgE4bVYQWtcogDtb
WwX1r/GDbEIMu+QEAW9JUbZ17uUHx+RVqeHjZJwh0z2ut50fRtyaylw5BHGl
F6/ajzTyg239W7XG94J45DuZw/oV/DCXqZu+V1kYt+qUNJFI5IevfOPB/2hi
eAs/UafrCD/wrhgHvY6WwBmEra4dNuOHxFm73SGckrjSjkdltfr8cFyj/9dm
oCQeKc9FKVXhB41h+98FXrtwK2MmhRgBfpitaJ/OvSSFtwTN7LRo5IPXcxk8
EgnSOEOY0unqj3yQYX60xEhSBleKupyiU8EHH/M9ktfzZPDIp6Micnl8sGfv
dEkpksWt3g8QOO7xQfpb1QjXMXm8Zb6NuUqfDy7/6d6WnKCEM6wLHDygzQeo
jsDT06WEK7FYBhao8IGyVdXU+e3KeCSxYS1Vkg8cd9g+Ij5Rxq0UP85f3+SF
5ON4/43HKnigOqPa7AIvZBl+YxtoVMELdDFP1wleCC+9rDHOqooLmFVM2Pby
ggzHl6QnV1XxLy5Fw5QKXqDcOEOY1lLD234tWlGLtuQDnXG7ndTwzmM65UYv
tuSEcz/CH6rhP5oCd1tm8MKZmsZ+oWI1vMeg+sHxZF44UC3y8s13NbyvgnPh
TDQv3G7TkjdeVcMHVSzOuITzgobvqnX9Ngo+KvFN2f86L1hwFjnpHqPg4/Hb
km9f5QUV81ErzisUfIrvLEvYRV6oSGsf8wyl4HN3My89duCFT2vpjudTKPji
2khn0gleGCPysLXnU/CVq/vxDBte2Mib1cmmU/CNUY/nL0x5ISNHJrWhgYIz
2pcQi/V5YeoY9k+5k4Kz/Fi5/l6bF6RCPMQ/91JwDivs9yfVLbkm65z/AAXn
/nzHokmOF1a0/aU1hig4H7W2tGM3L7DSzuyb3NIT3/JI/tzGC8HqzWcif1Jw
QfnDYX9IvEDU8NvD9Y2Ci2TEzk5w88Ja5CMps0YKvl2s6+QiMy+U4LwuRlv4
dkbtqNlc5YGHgzxn/76k4Ls4HBQ55njAaEhkZE8CBd8bkJMg8I8HDKpDzccD
KLjMwhij6BAP3LH9elTZkYLLX1K6KNnDA5O5EwZDBhRcacirXaadB8LN4geX
JCm46ol3uiqNPNDb8PSu/Rb/6m3r2VqfeGAIKQkItqrhWsYHBfTf84AstrHJ
kqGGUyHE37SYB45Iu7vv81DD9TQaBmxe8kBfa9F2T2013CCf3+xkJg8sp9a5
dzOq4Yf2HHnrmMID4rMugXafVHHTlIQdl2J44Nxy17bhIFXcgtQb6v2ABx4V
FNf766riRxmd7UJu8MDILwbL+GwV3NYv7+MjLx5IkWISED6qgp+cnJCPd+OB
NHexmpBNZdy+13cz5+RW/aO7F6UPKeNX3t3PrNPhgdIjaWrJVoq4l1Izb5sa
D7wYnR7UdFPAfXOIvl3yPDBoqnO7IGA/fis22XhsOw9ovionWzySw8M9Xk3w
rHPDoZ6lqFjTffijkenjgvPcUPKxSuHQvr344zPqH8THueFGmN6y8aoUnmCO
ohV6ucE0/1lWyoNdeLZMq6ZVJTdI6VRk6LwWw132vfkQ+JYbeKOdGrM2hXHZ
PVEmb15xw7+8r++l9AXxfInDJ4mp3HB02V5CxZgfLxVuDWi/xQ02l9/Mkjom
sFrW1hpbnBuOs9e7p8QJwlh/y5FzH7nAkdePtU9KFfJ/FfRGVXDBo6BoyTQm
NbjSG+lcVcQFe7PiDhX8UoO571Z+uzO5tviL/ywcrw5rX1qSfwdzwcDjG8Kp
Cwe2LvwFUkI3uaDfZKnJoV4LAhsiXxl5cwF3+9si1RRtYP1shXKcuODEtM5H
qwO6wEdvGbhgxAUxhz/oR8ni0FJRcDGJygU3hwx+XgrD4fG7yLl6dS44ZfA+
8c0IDkJvrdjk93FBo+b3pV3P9GDnyxaZCXYuyDq7JvVy6SAMPC8o3MGwFc+9
exsy1ofMnEhtyyVOAM+N/ucJ+iCdYWVeMMIJ/+JV6qsVDUApqeWKZx0naFx2
O3FezxDumfkwLQMntDSlprwONoS+jW0xAWWccKl8drrvkyFovvmwh62AExiM
li3HGI0gwuF86YMcTpgstb6ItI3gjyCvMekpJ2weEqRbeBoBtbawKzGOE2o7
Bx6EZxnBhPzGevZdTmAlZVV1MdLA6FdGxP6bnHD4R1VrhywNUqOMJYu9OOHC
+dtvLa1osKA/Wajlxgml6wqjVE8amC/EGHxw4ATHvfZfkiJpkJmr1Uk7wQkS
/dwvTrygwZpd3/lma074+VLz5bUqGhzhDVk+YsIJrjIB49MdNHiJ5MK79ThB
QWmb7/vfNGDxbN1uf4AT/F2L8c5pGpyU8s0fUdri4/EXFZ0VGhR3bsfdpTnB
/c3fff82aMB9v6p1ficnUHp1xoc2aWCv7eJwQ5gTzgoo6O9dp0H5OO88Ez8n
SM069BYs0ID4rCjkPhsnPAkOsQ/5RwNX6/9EBDY4oOxTzsXnP2lQxbL5PG6e
Azwyj94Rb6KBWGmmtvg4B+x4cVRquJQGnhdMmjKGOCB7mKuM+ykN6rZNnZbt
4YDPYyExUUE0kGiOnSr4ygFqpUYrAfY08AvUDtJo4ICx1BTCLyoNWlT6SfQq
DjB0qB0uFaaB9O+QLIPyrXiN9IvkcSMIjJfXaHjDAR9M01036Ubw3bit9vBz
DnioOxEe/NAIQvPF/51O4ADp7lMbERJG8PPsx5u/IzjA5EJGhfJvQ1AnXeB3
C+UAc51/FzKzDeGPb7GKvw8HWNSVzmtLGAJV1u7T5iUOuC+idDTouwHE9Wwe
DXHaindt+EnPQwMw1DP1jz7CAbjRLz/hqa155RpAr1Q44NnF0r62mIOw9j70
sJrsFr5IU6U+jYNwxH3/YLkkBzwpNG7K+q4HzO1+bLUCHFAgn//rLUkP7J/w
mw9MsEPUzqY81t9UkFTS7RJ6wQ7dd9NYJFo1wMz6b5xCBjs4PTy4b35OHfy8
Ym2MktlhRt5p5a6wOjSXjTd6h7NDytfoT0H/qcE1vVTUfpEdAqIY6/w6lKDd
ejPzsTw7lA1ZjTal7YZNrxfn8qTY4QTr2mXasCTIxh/fUbWdHYy2319RVpSA
wO7X8dM87OBnWVA5+kgU9jueDbMaZ4MwxqN14cEcEOL9wZ0vnw0Wcn9vzh3k
xN/EX5Lfm80GLZFCPasi/HjPO9G/uqlsEBv0Z0D3IhFX2fCwv/SIDSw1Z14k
MYngv0J2HW28vBXP4ZqM+CFJnOt5M2HImQ0679y5r3NvF67ecK159TQbOJBa
cgU/7MYf8H+lyVmyAWVU8OT97XtxzYQ7WmGKbJCqk+s07yuLO5QrLqbtYwOj
P1KaNtfl8Ec93UXvdrJBcZZ6+GcfeXxIQm3/X342UF+ozf98VAHn1+/7y8DB
BnNHbh46eEAR13J6kC3CwAa9rHletlxKeNTzoZ2Hplghk2dZJf+HEv6+IbLn
zAgr7DlFdDfVVsZHxnUSfftY4Wmlp35fgjJOVYkl5rSwArxMWlykqeAXjuh9
odeygvWkZkxgogoe4zMe3gmsIGcYf4BnWAUfLTdkZXvDCt5MxGXcRxV/EVVa
fzWXFRauHRM0r1TF3VxkIvufsgJjk2RpzaYqLo8lH7WMZ4XnlVVMZbpq+Lgg
77bKR6wQ6MYsIO+rhuf/u9UnG8IK1zKhX+GlGn7541RWwk1WuNp94lRTjxqu
mGR/kc2bFU7t4DkoyLm1L11pV/JyYwW1HUQJQWUK/oZmtNDvwAqcIV8te45Q
cM8dZRWWJ1jhcEn/yDUvCq4yL3O70poVwqcnyxgjKfhsQ7KRnAkrEBffawXl
UPDidF6eRD1WKJ+ffcBXQcG9/ANa2Q6wgv9Ljgvv6ik4xWo6zkuJFQquEcXi
tvaphb0OJwf2sYI5V97Vsq19qHS9XdJqJysI7GuqVRuk4H7tRsOVQqzQodM4
sHNrn9J8UfZSjo8V3vQYLD3qp+DLt2U9E1lZYfWhfGZ8NwUvt03RYF9ngWbS
ZI9lGwW/psi37jXHAiqqGWNN1RRcmy2wamCMBdRHbB2kSyj4Ws90qNUgC7T9
uCPik0HBK4sczOldLCBADxZpfkjBb4V1EOXbWKAMO5JG86bg1HO074l1LPDm
22HRlf8o+KbGuyfsH1jgzpgm+7o2BQc+OQfvMhbYbk/lctnaVwN/p0gPvmaB
AGTbZr2khjNFBxbRU1mggME2ge2FGv7xwoyffBwL6OybY9sMVMODcUdq0kMW
WG4e5e08ooazTtDqvG+wwB7901K3FlRxDmP+X/J2LEB80K+iL6WK1+28nZl0
mAW8eByDK8dU8LCFmQscxizQU/h9tfmNCs6d2Tk3qMECDfv9nvFrqeB8m0+4
kgVZwOnyf6rndJXxLx38LRy8LPDYYrlrclUJj3x5O9aHhQW49Y8J0t8p4QQ7
JwnrWWbQzYz87KyqhJPfyqtztjJDYvN16oCeAr7tYsU53wfM0JOObd4YlsGT
amuNeIOZwXtogHLzjAwutrdTLuM6M2g9O9y28U0aF+ufmm92ZYYYrRswUL8P
Fzm+N2yvMTMkhF5jCS7fg5P1owo7WJlBTvloCm+rJB7zLDX+4joTPHrrJa5i
J4mTNl7cYJxngljnN4ThIQmc+K7GaP8QE5xOjnxis7ETF1Bc6wquYoK8nMsP
1yK24zzbzjOrBTBBwu1Dd/nOCuEP/LxG6nyYYEfD0fONeYI4d+ftpjOXmeDK
qSVHs2UyzhWVEh9+ignYM7nDHqeRcA72NrlBbSYQ1TfrYtpJwO85/hLwV2WC
cuZLUpmhAjh71b95PjkmyHJ8Xdw3zI+z3WQHLTEmUHw3y/QznxdnndU58niJ
EYwjnzdZPObEg61MDkhPMUJKLrnrUQoHzpJ/fAd9mBHEveU5k1+x4ywXPEf+
djLC7Og7KTTIigfXBDQFNDPCLrmil7kcrDiz1MNCwRpGqLiq+5JRjQVn+pVz
Q+8tI/Doxvk9ecKEB+m8PfftJSNsCLtee9nNiDMmVRldymQEIS9J/487GXGG
o70CidGM4N+q0aJ5dRPbqCdmTXkwgm/tR4mOcyvY4YS9b4VdGcHcRjGPZLaM
ZTppVVPtGcHoSpGQCbaEmTDY/35gzQhjjuJW/dgC9qTJe77IhBH2igYZDJrN
Y1NJ91m7DzLCRNrNuzvt57A4yps9MqqM8KyU8cr9zBnsL1M1xUqOEZwrsjJt
W6cxnZbvhr67t/IXfrDOYp3GBlwZnKtJjKBNHqhfYp/E9j+zzD43xwBgMtaj
kPUXC7zkUHLvHwPU1IvIPXIbwdq0fGteDzGA9uEFT358GPPrSP2z3s4AMjuY
Grdx/cYa0gsXpJoYwLunynN1cxDbcaWGzayaAXx3njuWzTCIfeKa2Jv0lgEa
c8JzSJL9mPB3Ro0PrxhgocSctHUbxVyzBGkjWQxgG3s0prT1JyaA655Xj2OA
KuuVEqEX3ZgD72HfU48YoDtLxXtRuQsr6XIMDQ5hgKXYsLl7dd+xk94Pctp8
GMDpFScpQLoTe33wWenyZQYQMC2xaJhox5gEij9LnGeAvMn8x/Efv2K5ed3D
l48zANoVH/k0rhVb9Z1cjLVkgGf+3ae6olswC0NmjkoaA9S2+dP3an/B5n7J
SnNrMoA0v3CR7vMGjPaKqqmixACEJYVzAkz1WNI160P/STNszcOHUa0rtRgu
eM0lR4QBHn2PV1O7X41FDzz0axZgALvtS/NnVD5hf16n3ZvnYIDXn7ODnoxX
YUKxjw+Hzmyiztfdn2jxgL1XLPfoGNhEhsPbtQI4EGZf3x+1++smuuBr10pn
qMRebSq1oaJNZF64xtNh9A6zTrKd4c3cRK2MM/Fij0uxJbVA4smYTXS6VTL8
4cJbzMD1i/WS1ybqz1PaMGcrwkZZFj2NnDaR92kRy9Ov32CRT3dExxzdRIdX
XQ5LXirA1LWMigYMN5FMbkXMrpv5WE/7pa9K6pvIoUH3gKPhSyzIPXb21t5N
ZFNAVdylnIdJc1WSmoQ20Xt54Qf3qbnYVYznyIXFDXT8a+4H+9JMzEAf3XX4
s4Ei33zkMd5Ix4RonqWnOjaQovgMQ69jGjZssufv8U8b6Co/4YBv21OszOK7
mHXRBmpObhtWJD3B7luHm5mlb6Bbuq27vO8lYXbHqLeMojZQZa7Pc0bFBGzt
VGa/lvsGMtePc8xkjsGazh0nUU5voAZOpV3zco+xVCcuQ0XzDVQVyk3f9I/E
3C9U+sjobKDavD/s/p0PMfzSldzdchvoG7Por/CVMIzgsbtLXGwDSfFUDOef
uIcNeHVyi3Bu+Z8eCE+Yv4sV+d3XJS6tozqhxaM6n+5gwTd03HmG11EVoSqm
9uNt7Gjg5DO2znV0uHuE/1B/ALY3OL2NoXod/TbJkPv26Aa2GHqUZbVoHdVk
qQn23ffHasM51OfT19H+zphP5xt9sMSIivOTUevo120nrTYrL8w1+nLi38B1
5HGyA/tJ8MR04iUbBt3X0Yl9ItQ0risYb3L7Wu/pdSS56+5Jtktu2M/UUIXv
5uuIccd9A+9dF7CCdK2zbTrriAZWX6L2O2O3s8ejGuXWUbvi4fv/Qhww67xn
H2vE1tHkTs1nKfvOYbvzbeaBcx0pPnr02IN4Gpt7w7avYmkN0aUbK5+Z2mHV
b9/Zvh1eQ2wXpy7WTR7D4t65hb3uXEPaVbXHqudssPOVO98/r15DKUEy7ZqH
D2OaH9rGM4rXULCOUzbvsjnGWX13Z2rGGrr7ozU2rNcY66rVPJzweA1VMk+o
OuoZYS8ax4Ie315DyX//y7cS1sdutKQWP7iyhqK/a0nJ2+CYefvhPyFn1pBm
zRp3/VdtbMd3FpHbFmtILEIkoy1dA5vsLjW+rruGzj5tsZJhVMPgl+t1b/k1
9I6p0Z/6UwmLGhR/5b5tS1brMFM/Jo/ZD7f8vMC1hjgODJsEF+/DVMfuCDgu
r6KKEkrEHrQbY5lUP3h6ZBX9Z8t33O6sBNY58/eq7bdV1Pei2/As5zYsZyEl
y7pmFb108yh+RhHC/FYsv5m9XUUDOiavM/YSMZMNJk5a5iqKPzG0lxLEi21j
KtHSi15FLPt6aK0/2LF/rBfctINW0cLBqyqvZJixSs7tqRSPVcRT8enw/sQN
6iPeL18Uz64isaPmO/YaLFHPEIIYZS1X0ZKqzcPabbNUJUGKqhR1FY19LWq1
+zlOZRQdcdyxfxWR/x7HzkoPU9u2J8eJbF9FhIujJ+2a+qkZEha1RO5VpBtn
STm4s5vqJcW4wrOygpL+nHRp8m6nGkoXy7H/XUHLrVPvsAfNVCH586cYv6+g
nICqD6kPaqjDimIRqzUrKEPlSsYbD6CWqTbB/NsVdPCqRNWrF6VUJeGHh4jZ
K0i3TeMUi/Ibau6KWYtC3Apq9l3l18jIpUr85LE1DVlBcR1Wxt+c0qgJHxp/
nfdZQZoi1XmBCglUgawH54OdV1CYiPK3iDuR1Hv3zCafHVtBpcKjLJwSIVQG
Nx7fSqMVRLrIsa+H5SbV17Jx44f6CrLLfhI7HetJnVB5ELKwdwsvz82NZMXz
VGchMz6S8AqqnbH68YZ0kvpzmTtOkX0FyZ89Uv/Y3Yp6rLdB3GxxGRE7yDvy
7hykNkN4lsvwMvoPcwh1nFGlGmWa7r/7bRmN2wkYRjtLUemh3G/TPi+jL50m
v6+nkqjqFxt06KXLKP87y6GEu4zUfIvwT105y+g1dyuPYtw/3b0qpmaL8cvI
zqOygrO1XTdVkLuddG8ZcYtk2iHFcl2h5foTSn7LKEakcrSdmKz7qCds0Mxl
GVmn33C4q+WtywYmFy/YLqOm2Z//Pgwa6t7K4Jq9e2gZ+XCk2RzezaY7H1J/
LV1zGYk9YlLaqZCp4+YaxoSkl1G296+12T+ftIfMTcK6RZbRCIsa74m0tYqT
ylzEJY5l5Jv82FHNtOR9O7k+kby8hF6oZgnYNRMqzZbuSyr/XUIS6dZrQpUW
lZ+6jZ+b/1hCbbcrjPMyr1fqIE5l17ol9FLkRclC47PK4vS6spB3Syj26/YI
5iuoUj7kPp7xfAk11/LZ33f4Xpl5wbgWJS6h6HqNxFb3qcrt5pxWPfeX0Pu7
v+P7u5jpMUp135b8l9BQCH3z66IgnYd8/4yg6xL6ksaY8Dh1Lz148dCwst0S
Wlssrto2SaGvdXG4W5gsoQivodu6Ggb0q/TaBVetJbTS/Z7m2nmYPpp271ao
7BI61u95MsjyNN3+7iG2TLEt/1araMKoC73LheMRcC2hmiK2b7GDV+nWZrWC
vSuLCK7m5z6ZukWvV7z3ZHl0Ecnt0bhEuBNKP0g6tEeoexH1vCYfUQqIopcv
sL9SaVhEXhhP/cGHiXSVrs9qlhWLqNuRvz/1WDo9rzL0/cUXi2hhKDxc8+9z
+q40msG95EWEO+3oHOMqpCcFszdmhi+iUa1rEjENZXSCy2ebD9cXkfHlKNMj
7UC/Zxra3XtxEZns7z+iE1dDZ1CkOaycWESyjb0LFRtNdD8i+5iQ2SJKECts
zCr7Sp+ar/FU1VlE0o/zrrMW/qC7/AhZsZRfRC27HK4kJfTR+94bBbltX0Qf
zVI2WAx+022fsXHd51lECqRDvpzcY/SWOzVRWWsLqP8Ot1MscZp+6HyIaNW/
BcRgzvzW/MI8HUyM0n72LKBsAdHu9PwVuqYCm8xq4wIq/NUSei2EAb0m1BQI
Vy4gKt+zzSN2LMj6NMGk78UCOtviv5fNjhMt5J0czE1aQKN/3FwuOPCjxMWc
Gx73F1AZpwudw5qEdAxmBbX8FtDH5wyuwznC6Fck9TXT+QXkmSJ8Mq9lOwrq
vX+o4egCYknArpf7SKI9sh390QYLKPQvxbSOsAfV+khcP6m6gOoUen0vWcig
ix8vkvfsWkCN+91s+QwUEJ9A6atxgQUUxn4824FNBb05yUQr2ZxHMeTm+lZ7
Cjry3Lzv1sQ8EhHh+nyZdgAtzif403rnkW3FkzyBGl2UdHCIKNA4jzIFi+hq
/npIN0Lx5ffyLfudHPxCHgaor/uaYdrzebRa1eab2ElDd6Rrfl5ImEdeI5v7
20tM0V5vgp9K6Dyq4eE24xGwQnUfThJWvefR5cB3FLYoa+TGl5v30XEeZS2L
9v5yPor4T8zqP7CZR5YDPv4DSbaoMIfae+TgPPp42O2vlMZJdHTuvo+48jxS
Zci0Ntt9Fi3hHfx/ds6jvRpYbLirPUp+KPE8n28e+TztmSxddETUrosHfdfn
UOXTk5oVredR/97SbuzfHNK1udnCwXARBV9l8ubonkP/sf80zgq7jPaBOV9r
3RwaEZ+QFNb1QPU8iTmJZXNof5iU3vTFq+jyf0O4fc4cYmX4I97R6Y0I2Ypd
snFz6KmgxRf+O36oeOba1dngOYR2sFeb+lxHtlgNz/urc0j7QoZubMkttBpO
yA62n0OYUJOr4p7bKPX7Scz88ByS4psW0t9+B+ntyf0uiG/5T909Im9wFw15
zHr8VJhD222+7mh8FopC6VTuHPE5RFW3UsDVw5Asd1imO88cYn4m7v2b4yFq
Ot6hq7k6i9KaWK1f8UWiK5kS3xhGZ1EIS/4JvfdRiDR98Urd91lEHFOr/hgR
jUp0Szkff55F31RzNCfCY9F/YUwZdiWz6Alb3cVnRfFordNcZ3fWLNJ+edWj
nzMJHbwydLk4aBbtGLdgXrZ4in6/V+S46TGLhgNxreO70tA9zutphmdnkaLP
/tj/KtKR3LEaLT7LWbR3k8/3qlcmak4ntHfqziId809uLy2zkcfkyUtP5WcR
v6yojZRlLiLr5LK5bJtFYe8Z1kneeciug3pgeWkGaa86PqLrvkbrkmFtH4Zn
kPlO368lMwXo2eWOi2GdM0hkrFQAnS5E+hUSrDbVM4hpkvve8aEi9IfdLXVb
8Qy6b+0uNBH8Ft0/UqoxlD6D+K7ZUTb1SpF8GlPry6gZlFG2gQuJv0NXtRKZ
qe4z6BRhKuKLaiWKidnWc+z0DHonn03jckGoeOJJsbv5DGp7jwS7fwFaSE93
SpObQbEWz4s0rnxEQutS1HKxGcQl8fRHTOcnpHE8R+gr5wwSoFYVHreuQX7c
Lz+zjEyjY0o3nws8qkOJTgrPxL9No+uP/cK3WTWgclTgp14zjTweaHx4K9eE
Vq++lXHJnEZPBpMTeJJa0PZmDabb0dMI/OT8k9+0Ih3p8q7EoGn0bxHCjb63
oVs99PCGs9OI26Lpi8fRDpSqruc4ZDmNDKlfNHRedSIU+VFnnTqNrmlFqJYK
fUcMhrXjCuLT6OnetdBbkt1I8qlJDY1nGtVW/j6s9qkHHVxuTD27OoWWzqz7
Xrr+E9151Wr5+McU6i++NKsi2I8y2Y9Iv6idQsx81O2dhAH06Vwnw6fSKdSB
Z//RExtEbELdb+Zjp9DfH7lGvFa/0d4rp8L47k6hwR8lHbq3/iBa/S/7fV5T
yHNbetf3d8Po3q0h0n/WU4g0cSqW4cQoyv3u/M9DbwqNf7vafOHDGKpT+fsp
TGkKhROkTyyojyOu4XHv93xTCNdwKX8qPYWOBfWl5K1OooeMOXBlC3e8+m/z
nh+TSOahY2dZ5zQSezrxGoubRKuNzZwJObPopM3sWQ+vScRQ6vA588kcesK+
RMiwnkR/ol8Uk57MI4krjF5s/JNI27OPzPpuEe3RI2s2hU4gl8YfYq8vriHn
eZG/G04T6PK369sNt+41uc/Fk5QMJpBjxHkFMtsmkiXuW4tmmEBXeSppksMM
4FYj96r65zg69Auz50xnhFfXlE4vvh9HbctLrRv2TKA0eADs/McRmyFx9uYi
M3jEUz0eHB9HRXeVvHQaWKDQVH8XnTKO9D5bN3tksQKl2CxYcuYfYok9Xphx
iR207p45NOL6DymXbubnWXJD3dLNrNOm/9Bu+JmUQOMBW7cUpg65f4jk/Jud
bsgL3jY/3n/4N4aSzDnEho/wQ4GkjXLy5TH0WfnoV4Y+AmCxHo8IlmOIEP7N
J9CbCM0ckWOhimMoLuiEmhEfCf5NNmZ5TY2iAkN8X74xGfbRjcQsPEfRIveB
RoERIShRdvL9ZD2K8oY6zvyJFwaDrDvtWqqjyHk17QezqQjYP4BH++b+oiPX
P0dwVIhCqp0WM6PPXyT7Ibc368N2IC/u/1fkP4KuNnx5XlIgCRmuZsaydiOI
fSPJRFByF6j8dM1+pjWC9pZx2Xx8vAusqnPOPlwdRhF2Zw1++++G8GjJDueb
wwj4ZuqZj+0BJiVBuujtP+iPZX34iwMyMOmyFhFwbwidSQhhHoxVgvZ8ZQEL
5yH049jBIaPvSlA+5xy53WAIGXJR+udFlSE4sDXy3eYgSjz3qvVPkjKIJWRH
zfoMokNi6j+6I1Vgs7ebUHVkEPXe21dm36ACQ7sJjyNVBpHSzUneCBZVeP36
+uP9EwPo2H6D2ABPVTD4bBV93mkANQmWldG01ECGN4Skrj+ArGJPLN85rwZ8
NhXRLJIDW/8/4QuvH6vBXMIU6etGP5qS2ZNYWKEGP37uiUnr6UenLqdw+Qyo
AV3qBPlKeT8KeKBJGWCjQKZrZAw1oR8l0g4/+iVNgfsF1WRen350g4c58tgh
ClxeWInptulHIk13QdGJAjY6SoJ5yv2op6DgnU0ABTSDnGL9+PtReU2u0os4
CuyoTRKkjfchl+qy9R0vKMDM1xIr2NCHwmsspRLeU2DEhlVoKLcPWdZJdW/W
U6A5USuuMKQPxT6/EYN1UqDol7vQbcc+NCUSyab3kwIJe7LiLA/2oUAOfrWJ
AQrcvNgltEOiDw210b2UhyhQbb9T4cfqL1Rpq3Rrvp8CkRP3FXxKfyFJqXC3
PT0UsLs2p0C6+gv5hrk2vGyjwB62M4oFCr9QYW5dqm81Baai6hTNR3+i5pWV
i57FFCgXV1MazfqJXqrlHgx7SoG7z1OVQs/9RLKjndUvQyhgReFUlhL/icKu
T6jVXqCA2Ieryh++96KVzAqvhi2+fpv9VD4d04tkVy6JZO+mQMH3Qyqrlr1o
Iijc9dCKGlxzLFJJ4O5FNUmd3hmNamA4Ja5K+dyDEqR28T1PUoMu9llVd2oP
GtIqORYgowaZ0afUeFa6kfbhPaMao6rgvrNW7fnbbiS90tTvmq0KLBpPKIPy
3aj7SiWjGEEVmqvY1QNHutDb7N3P7yIVSLTwVBfP7EIZSclVJhdUQMGZpnF8
Wxdi9o8ZbMhXhqXpNxpznT/QGXexzQATZfh4c7tm1OMfKHH5etXNfiWwjZ3W
bOD8gVw1QjVsGJXgzqdkLWzpGxoslHgqS5CHkeYD0U5l39D3OxPf+QTkwOLH
t7Fwv2/IYZff/AibLIhNkJ58X+pEShzNYRU9+6BA+MGmx3IHKt/58eGC7G4Q
2iVrm/CuA0E0h2jCmCRcl68toPt3oLrz6n9+ZkqAkR6LPfdKO/oaOJVdyrwd
el1vfMpc+YpcSv6c4P4qAAe9xcQbyr8iZa8hp/ZGbsgNKPOevvYVLfnVHF/v
YgWvmLm91NU2dDa6KFP53Cziorvd/7baiu5pvxJWstrELu8qTyGvfEHnKlmC
dJwl8QMaC+bnrn1Bvg+DhjSlduMsZiqbr1aaUfRD14M3h6TwZO+8c7TVJlTc
NVyc7yqN19Ym7b221oA+PMg+sfeuIr7L/XrBr43PyLpaR86xQx0fv1N6Tj7g
M6oZkddpLtLAyxJmif6bNahWPqK0NlITt6y66E1kqEFzXoNJHwy18BuCJ7UM
GT+ht+dlJTnjdfHOCp1PecyA7Ha+OTf8XQ/f7m//c4YHoUXR/KvDSgfxB9dM
1SKJdNSwTfzoYshB/OJN8b568ffo/D95IYb9+njXLTZ1l90VKOWv7LPOG/q4
SeBkOKtMObJ8RrX1q9fHZe980MDVypDG/xgu73isuyiA23s9w0hWkp2shxLP
PWRG8kqlUkaoFBVSUlYlDRJpWFmJUkZWxvP7ERkhm0JZ2Xtvrz/P55x7xr3n
fO738H9d6DqnD1H3P4R0H8jHeOdOYP7v9IEjKKL/NsrDMqYig7NG9GE02OlZ
7uEcrOWE0Lq/iwGcfmz+z9LiC+YhsXqc6b0B1DzRPDh9PBtzDm8W+NNjAGmh
7EPy9plYf4fS+nkzQ1CV+OcdVvcZG6sii67cNQTi7vw9PzrSMdGTb5Pz0g1h
ds+jRuaBD5hmhfaD8A5DaJQ9cxemUrGgL39M79EbQabCXjmf1RTs37dmSX8Z
IwhT2mrJZX63zXfuLf6HjeCaSqP/NF8SJub4qu6uixFYqCcpKogkYESzcfFr
D43A1m0084d5HHZvi+X+fwlGIOYZyqbrFIWtOh49I1JgBH+8Ve3yfF5i7o65
WT9+GEGsX1u+Qng41vJHFZ3pMoICjgUxvf9CMPaQHZcqR4xAU0CnXtH3ARaj
p3iIe94ILh/iWFM64bM9z/fC5NeMoCFH/Qub3QVs722tctEtI2jxTKeqZh1F
I41j9IPbcuxNgxGLGA8Uazojem9jO9/M0xU6CQFoY8w9dmHJCBqTiQLHPB+h
0XmdPOqUEaSZOanlJIWhEEtnc7t+Ixg1LO2khrxAHnrZazYtRiCvK3q/2us1
qrvawLC/bDufg96KVnYx6H2L9YmFdCNoi3JxmZKKRywVryPfvDCCxVevaTk7
EtHfWHlOeW8jEIj8TrzNk4yOp5z6mH56u77weWfEmIK2KiyJsgeMwPqZZBHT
8nu0/F0yMIlsBLeeWvDWjKehg5OBPdIThlAQlJ5v1fYJdQt93n0x0hA67v3m
FP6RgQ4stk7tdzKEO8CUOfU3E7nufOGhqWoIsTqqTLkt2YjbMmpx5JsBKGmb
fBb8+QWFth9/khtsADQtO+vb1TmITsF/rfuwAfzRDE1HtDw0OBIafLtSH9w0
3p1ILMhHrktHbnEE6sOmejEd85cC1PlqrkdJSx/EVEetat4XovpTdPTuSYfA
VtFww+o5DVVtmrYnndED7dcpoYvxGHr67EmvyIYucAUy8plZ46iwpNXjdIwu
jEycT5i4UIq2/J4m+rcAJFZIlSs//IZaXhW47rehAvlGCnt+RSVaqM07I3JA
Exg+nmh6eKQKRcpGyJWaasB0D0u0dWsV6jknasJ/lgJ1ZhcUVweqkYuA53jU
HTUIkpI9qsNUi6iURk6PS/tgfcSqxn5XAzq+4swYdEkC5pg+KR12akCGTbB1
TUYURsWZI1TTGtDw7GJjVuAO6Diee4ZRpRHF3DL2umBBhNxS/olkaEI8myon
bl+cQeldrv+F3G9Cj61f63D8rUfJSxW5N6qaUJu+6CAjUz8WvtfL19CiGTkd
/1qR2UKPu71p4x22bUEnbnA+ABt+3ClHybMhqQXFlmkV3rISwm1+BnUUDLWg
O9FL/E46O3FTZs2ER1dbETxhNV+6KoHLXn+lquDXho7s+XLWP2MPLv506iXp
WxtyFPPVXh6RxgXeG62tsbSjkf8knyXvlMWZupe+1Ya2I1J7+nctR3m819j6
uFtcB9o9Gn/ZMlgJp/67Y1/X3YHMn392ueqyD48KSHBVFP2FGrh9mbUllXHL
wtEHo9G/kPnEuVnxaWX88wnecJPOX8hL6ti3TQsVnGNOLS5V+Ddipd2paPyk
gpcp3M1zfvMbGZ6z9LA5o7rNKwllFR2/0V/HIkPhdNXt//l7vZRQJxLR9Xre
sayKt9GN/b53shNVrje6xeiq4aqxvEN9LzvRr9xh/HKQGh56QH1Ot60TLTJf
UjhSqYaPtlpvxfN3IcZDVB5jJnU8kSdR0PZFF/ra0mv80V0d3/zwfTetuQsN
Uhm69iSr46eNxvaJkroRufGj5Z9GdTyvn1f7jmU3MrVfdfq7po4T/dWNO593
I/PDHJfUJbd5TOSUlVZjNyp8vaE3ok/Bawru2r3h+4McXs9d5HCk4NLHE68s
H/2DOnYstCdv89m9me+3Tj77g2qwdp7vryh4T8jY/bz6P6goSpjtTjoF15bn
e87P8xdpHaWptZZs89Z39VjPI3+R6bLw9Z4fFHze4VRa89O/iDSey/Zpm88s
tu7mqtb+Rcl3dqQc3uaztiONPVXMPUikLPO/6m0+Y4rpd761pweR3dJcDmzz
merowriMQQ/aGdUd/3Fbb7efzaPdsQfx36icVN4+HxokvBJ0vwdtJvlH/N72
X9yi6KeR3INWdv7kKqyl4KOSiHnwWw9qltcl9GIUXOj6f08i+3vQXavTj+0z
Kbghdp5gwNiLEqKaQo/EUXBPbq9X85K9SPjLiE3+IwqeeCZYNFmvFw0n/LTK
cqfgDWlRScccehFxh9TckVMUfHMpXY4xsBfNTYf8eKtDwRUNsYzshF70e/ny
va/i2/z4opHiUNqLBo7G137aUseD+/qLCL29iPn8Tbtn3dvvpbyoW0rXh3bH
fly99lUdJ9UJm0tAH6ob2iXhd1kd19u5t+WnbR86X1XO2Kirjl+7hE77+fUh
LUenSFcBdbyW2dH5D60P4WHfPjcUquH3qZ98Y3T60fwZyw6dWVU8+ynGZHa2
H4ma7vg2UKyK9/xufLx2px/96rb66RykimvfXHx5urgf/RhZO6oroIrPZ6AM
oYMDKEePK1ZaQQWvVThIvHZ2AIlJPAu3H1HGk95r3Kj0G0BOiRoMvSnb8/N2
70Gv8gHkV29SsSqujGeF7qxsPvIPTd7KU9LboYS7uS79CbUbRM93krlZS+Rw
w5FZ3cHAQZRmd0bliqocLuo0mazzbhAd/XFJwy5VFq+1+ecyPjKIfPoNOo+/
lMHlzZoXTTyGkKPHe8ORO3vwIfkMHuagYeRZrcOj8mAXTkv5cN0mdRhF855p
nOXahb+UTGn5UjOM4mZ+XrZ5uc1/wrFRDrwjqCgtdjbWRhxPZn8ijb8eQTcF
+G4eGNqJ33kQ9EiwaASZx1SEiZB24sfoA8fdukeQHkQbVuoJ4wwrt7JFJUdR
CL7v3otPQrjdsDPV5+MoSghPUfmcxY/vd3RIaKobRdFxp2turpNx3p6zTPLT
o2jFwlZRwZSM09qtajrUx5CTz5KY6TwRF63UO6FBG0Mnh4U7RW7w4fN61K8h
PWMo+s5CSVMJL15LOyDyj2EcWRz7J7H1mge/k6fcF2E0jry+RbE3O3Hhv9+J
uc00jKMioZNWTifZ8DyWdMvU2XGUn1j6ce0SKx5x4YCmLXkC/Yp+e8PoHgtu
JmdFV3dyAjX/ZthMqGbCZR/3DtzznkAdoxOy/ouMOPOYW7VW9AQqSHYqzpZj
xGnpj8JT/0ygdI3PA+mJ9HgUt+BNW7pJJBq0wYaG6fCbbslnBCQnkVKlx89C
NTpcWRmTuu80ibQO3zbayt/AEr7M59mOTyJWwzE+6F7GfMmB0QI8U+jSuvef
SnwJO32D179u3xRytt515OTnRYyoKW9y0GMKHTcYmU9ImccmX+XvnX0xhVKH
ChKGMuewH8v6xLS8KSTilbBqUj6L3S+07RRYnULrN0QJPswzWGbI4t9B7mlE
0vmb0qo6jYlRdSzLxKYRJl/tWt0wia3F1Wh4wzSyZTsrfattDMux+7c1eG8a
LecahJ+NGMQkCYruZS+mUVeaFiI5/cPCSt0HYt9NI4vVD8K0QwOYqyRdtVXl
NFLleVllKd2HdTUZHlTumEb31lZ1r8n1YofvhXziHJlGuiJ5x0Y1ezDpAeHw
Mo4ZRJj7wds12oW9eGHPFLdzBtlmbSxeN+rEGAxSvbwVZ1CBf7z39/xf2N93
lDPK5tv/7HUS36+GNsz8xJ06TtsZ9PI2+GveasWKWb6hoaszyEm043Skcgv2
+oKFVNzzGdSfuzupsLERYxF69dI7cQYpJxaF6H5twDyrutmOf5lBh16FV4ec
+4n9J3d5grN1Bp153ZEyGfwDw39l2Q79m0GuAgfFGCuqMaXHy41lizPoSaX/
UtiOKoxj7EGet9As+kR8ShhnrcBuRdfKHpebRX/POnnlvf2GDZqSopW1ZlFE
Dn5p3rQMs1o/xc1lOot2tjNi+ZylWFl6vN/QmVmU08FXqFaMYcpnh2bKrsyi
9qX9ljfvl2Bx3EqOcXdnUdVzl57HbkWYj1uR8fG3s2g5jF3+U0I+pocWHHky
ZtFccL+fP1MexsG3L6CSNov6G+pqPPxysMaei7H+9bNow1/tuj3hC/Y6K/Hr
gT+z6OcDKwGlr1mYXWBX6+zELOKSK79SdSMTkzkmMPtxYxZdGtDktXz6Gcub
fyQvJjqHfr9XVnmr/QHzrfhm2K44h0wdiBVXjFMxg5cbDmHac2jO+vAFE88U
jOuCpp+J2RzievFB+x4tGWvRvB7NYDOHxBYrf3rvScJi2D7mF12eQ2Wdd97H
vk/Azv8aaPb0mUMhP590XT0Uj83etuYaippD2aKLysP3o7FC03DZ+A9z6NlB
9epJgzdYgEit/qnCOZR21CAgct8rzHiC2Z5YM4eMUjWTbqJIjI+G7v74NYfU
lLaemXlEYB2h3m/uj8yhtQDL4cGq59hb2y+5Oivb+S1cz1OjhmFK9DKTGULz
KLWY3LOP7gm22GjHcUl2HtmMDZC4woOxksQoacn980jB3yst2SoIu+/Rotdp
NI/8xmzEv+nfx8z0eWxfnJxHobH6dDa2gRiZ39jnyIV55P3s+n8hCf5Y57+A
Vyw359FSVxK3FsEXS8wr+oIFzaPBjwyrk7t9MJeHCz9vvZxH7sLSc2e8bmGq
1vvGVVLm0dGiofOjjF7YiuwltrHceZTwxCbbqMoDw1cSpZIr5tGkWPolB+w6
FlzTBWdb59Gz7y7/6muuYhbRAmcF/s2jYepIvq/rFUzwioX3z/l55NQp7SBo
dwn7o/04MphpAaV50lcYxzhjKdzlWbrkBcT4oOq2vIgj5vZno2519wJSCHYd
1vhtj1EyNEe/qC2gr1NLPU8TbbF1v+ssrocWkGF2UBj/yhms3OKjpPSxBfRa
g/8vOcMae7LrH/WvwwI6f1/y5f7i45jlrNiZ1+4LiJl7V/l3oWOY8Dfrm/8F
LqDDP77ejSyxwHojwiM4whfQE9nuGmbjI1iqY23Gt4QFFENRmfv9xAS7RmGp
vZO1gE7eQf+dOmiIabLAMKV0Ae0mW5wgmR3CNtu8maYaFpD0qTSj6zmAfX//
RSK1ZwEJxz3mM27XxkJuTWjbTy+gHb0s7crN+zErE5lTwnSLKHKuS6ztCAUT
Eba/0cy7iPhoC95fD6hiA6NRz5+KL6KD7ZUqovz7sI9FLZ8M9i2iN0xI2cxF
HnN/ylOzSV1EImJ5UdnnpDGts8aD+eaLiOFcqsTkX0mMQSmQ4fq5RXS/vW64
olAcq94sEpN3W0QL6iKnVMOEsbCfC1r9dxeRzW7fVc09Aph1/L6TMSGLyNPt
nE+uPRGbZ/1jnxa3iAiTVSzKfdxY2NWnV/IyFtGLT2/pT8mwYYrtWje/4Yvo
JtGyZPwCI1ZNHQloaFxERg3pXb7rmzTnlFdPu/sWUW3q8quO8GUaA4/hq9G5
RXQuaqIo69QcLe7GfMIS0xK6rgYGLGiSptWdmM4ksIT2zatXansM0dr0/8sn
yCyhX4mSz5pZ+mju6VulYvuX0H2Hyvosr04aD/lzrYLJErpTWsmemt9C++hj
077/9LY9y9C602Q9zbifo8/g8hLqGSFMTrR8pw0c/jpueWcJpR080Xs0Baf5
Z19Ysg1ZQoRDV+x0lvJpIsICDK5xSyiU6cbpLbosWkFAOdftjCVkRkqTSSh9
T7MacRd8iC+hqUqZAxkW8bRpi12SLxqX0LqUikzUZiQtpOCnYkLfElqWsKSP
4wyhyUv4an6eW0J2K17y92mBtO8PFfW2F2ikYuo/IxN5k+Yw9dusin8ZldXV
UHJartA2Tzw62Sq9jHaxDmMhvPa0KJqmQ5/mMmK//NRN9cYxmob04JUp42U0
pSn0i6RvQGsKeXFz/dQyem6XZq0gpkFzW9ALZL+8jGh2zrvas/fQOM7OPBW4
s4zutSYL9Pwi0VLK377aHbKM3PI1lXU/09H0FM0TleOW0eKbKP3r+0dK/kas
p+tkLKO4UymFkqkNJXfWPuQfxpdRRRx9QqlzdonQ+VNlJxuX0eVslvXqkmcl
OTWsdY59yyhPKcXq9LpDiYVqXvv1uWX0WJLrjAC9XMn4G8c+X6YVtHT3AO+e
6pbiYHrSxBP+FTQkdX4h2YxSLHWpdOm19Arq4zQkPrrmdxBvuMqQormC4rT+
edbqx2jb7Bfj/mK8gp5SDeaGFlh0lt/WCuKnVtDDJ1stvyMP67xg9ZGsc1lB
y5ZLD21Id3RUrsrt/e2zgjj2xxdL9yXq1Le1aw49XUFfJmSrX8+U6bhQg/Tm
Y1dQFt3j1x8n/uiwpKgfoc9YQXQFs9eOflzQSeTuP8mDr6CjoUfe9a5zUKk3
njvsbFxB0baTfjLRYtTfXchVtm8FxS7HrsSSlale+pM3KXMrSHMnuzfzV0Ql
pccE6jGtol1P4l4KfDhCzSSZhhzlX0UZCqvGRf6nqWY+K69spFfRI1OHMfjm
TB3ue594SXMVdSWGfbjb7069f/jEJy/jVaRfUY8fvuRLlchmKrh3ahWR1tT2
NLY8pBbv+FIW5rKKnLQMHBUPhlOtA+zrYn1W0fkXf+6SzaKpC8O8HR+eriLZ
BMUqU45kargFrS8/dhUVX3surjOcTlUquDJR/nkV0aIOzfjdy6HWiO9cbsRW
EceB11cfZxRTnR9WM/xtWEV3GCNDBqu+UW14L+dX96yiEv16qf8u1VD/e8V1
JWd6Ff2ekPsq6dFINRT/LPGWbg193ZE71tXWRtV+f7T1Ed8ackDxPFPx3VTV
fTOPPCXW0PxnuYY1nn6qTH441VZ5DX2p5/FsOTZMFUHqcyawhla0ejJ0miep
xMrW9+oWa8jV8l1Tr+Mcle3oTRtxuzV0WyK4M4G6TN1oEyJwXFtDg57N+fTi
m9TZc4UV835raLQk9/bSGwY0PHjm9t9na2hy9IxSXwcL6nbbUKp5u4Z+dS2b
rY9woqbFuP6cjDVEds9z8lriQ1W+8PottoZYeLaorUFkVMLSZ/b45xrKmUqI
8CgQQtmh9+hv/F1DbGIWlZAsilIF9uTZTq0hja/BuX7Zu1Bs3HeXw1trqHYr
qFGPaw8Kl74oTuFdR12tBZl007Io+DN7i7j4Otr55beRxLW96K7Gx2COfeto
QyTpqJ+FCnKnmeksUNdR+t6BO0/M1NFFw8mZv+brKGI66fHLAk10rv5ZSs25
ddRfU1apnXgQHTuhcibXbR2x7NwtpsEFyPhPE2+87zoKfzcaRIvUQ1Rnz/LH
oeuoZxUPeOdlgNQn+b1vxK2jgWyqQGqBMZLzyt9r93kdFX72OGHnbIbENq37
DtPW0ceJrvE0AwtEDlp9SalfR1KMj53poywRB0+MqcSfdRS/d6N2TeM42orU
oeOc3LaXFQ4f222N5kX/5ixsrKPSzyE/Cy6eQaPv/C/1cG+g7Dt7N0a4bVHP
XkmxH6Ib6M9hX+8TofaoNfdbU+7eDaRcbbLz2s/zqEbH6WG8zgayHC4zCT3q
jPAKFu0nRzaQN7ewny35Eso7kjp94+wGahOXt1vZfQV9bDV5Z+e6gQSP7Vnq
vn8VxZ8dO2V6dwMlDxIe0b29jl7+e8qjEbKBuJx9+pw/eqCnrkrfJGK38xH7
zvJy7AYKWPh5k/PTBmKu5Tzy7fwt5HX3uuJi8Qba8YTH+qKQD7rCTOrtqd1A
t1Szdxjy+CKHkJzIH10bSPfX1KzaO390kv/E4bzxDdQgJ3aYdCkQmcUubcav
byBrRvaOyOP3kd6eN1+ecG2i+Tddpwtdg9D+T1oXvUQ2kX3meaWPOcFoL6VL
xF5xE0X4iyxhe58gIQPxIA2zTVTz/JiRhUMY4qnDtXbZbKI91XczWRaeI8bj
DlOcVzbRSrx+y/XUCLTcxZi86LOJFvzlXxX5RqJJx3fWvU82UcFSQK7c7Veo
f9yQuzZ6EwXmWLwXi32DOjyHS/M+biK7P7sfCI9Go2/3FRSe/thEvh/P3LAL
ikdaW5Hx0p2bqCK1bf3ZeALK9qYTKB3dRI+eC82aX0lC8vMuT86sbiIu4dO3
BFjfoUS3VrpF9i20JujafpWWgoRHkFfYji2knbbaOx+RisLPfxiTl9tCd336
T1s8+oACrf3abI230C868qenvz+j1aYR09WTW2jzZGccd2wmcj9iVfriwhYq
tg/WcOvJQqOVNI19N7dQEoVU6LL/C3LQk0uvDtpCXMWltrwpOeh3ccQux5db
qLE7SMpdPg9Zam6+3Hy3hY4UflzK/p6P9BSbA9QqtpD5Rwo1wLQIFaboLNW1
bKFj/oylARolSGVX6pWLA1voZ9LXEkMqhvie0D7W09OB5Bntx8UtpcisymMw
mp0OjqYdC2tn/YaCmeV2XSLQwTjvZpKoWTmi8494ybiLDlIPkqqVOSuRdolx
Y4MsHbwMHxwJfViFbq1ucMYp00GneZypllANmva8GLAf6ODhYOfKL+86pJgt
WsxsTAdXRh3+CzH7iS5ONS02HaWDB8+JTEHRDajnks4VV1s6yOV6XPPiYxMS
eT+bonWBDlwZ9qyermxG1gPve1mv0sEoi7Xt/HQLajhHPJnoSweT7Xnin6+2
I66YyudXg+hAlIfbrKuiAxn/ulOrHUoHsiY9+isKvxF+bEi3PZYO5Mp9FLXk
u9F6WMyd5Hd0YPEmGQK//UH76//Lv/6JDm6FPPror9mDMo2LFblK6IBhY53z
wVYveqvzXFC3iw6uBlXWm3EMot+3DS15BujAflbtgKvsEBIoWHvaOUYHxtwX
rZUsh1GoqjOD1xodzE/cuDFaPYpqru7UOcRID/oZm18ihMYRy6eGm3yc9PAj
M5lLy3MC+cocnPggTA9v/UL/zchNo0LHaZlbkvQQ99lv/Mj4NFpMeOdgIE8P
6JWMYHfuDHIT4ev4e4Ae+IiOH81s59A5wr8y8il60Cs2ZA3kW0JMUS3zT+zp
gUpPIf2QWUYfJMulGV3owe9wOZuxyTaXqCU9nrlNDwZqEww/Pq6huOLw4ov3
6CHAuJ5kNLGO9A0CJ/8+oYfON/VrfQc2UdgJe8v6GHqI3CE4lXmbDjT+Wtw3
eEcPc+TdYWdU6aH7AuQVf6KH8ZxBU7ZpepD3Fhf+SKOHQ8R8xra7jPAturv3
YQ89GEvS6UoPsoCLVB1pa5geKv7Uk6saWIHvU7GB1ww9TJsFOu8vYwMbWnSa
IwMDVGSfvdH1lQMWe05d15VigIDEpiz7TR6IuWSSVKDIAEx+h4za+PhAb3Z/
6z4KA7ws+tKrmMIHzxiFDogZMgBBmCGepYsAstJtdGsXGGDDeEVp2pMM9Z8r
VN2vMcCfE6fC30vxww3NXMeRWwxQmfqOfW8HP5QZv6hqf8QAv1NK7d4eFoQz
ly3Dcj4yAFd1aniTjTCEZtaLu00xgLvS9CzvawlQP0D7798SA+xICJRk4N4F
v0s/3bOhY4R/snqXw+7tApnmp0OHCYxQc7bJ58QNScAXDmfIqDHC9csf0pVd
pGBOq5La68UIz9S/nn73RBa+H8s0qPRlhGN7eJUDOeTg9ZU3Zp+CGKGw4Czr
n0dyQI27fNr7JSN0lO39+e2RPDym5/Mi5DHC2Qo98ZUniiBZZf1Jd4ERhjf2
7snUU4aFHt0cmQ1GKJIulCn3V4aqFfkibmYmiFHQlTpGUwY3hY2qX2Qm0Pub
1/dOUwUKQxMGrqszQaPXh9FLu1Qh5P3jsZPaTPD85gfzpFOqYId7zOroM8GR
PIkbHWGqwDJrQMdhtS37TP+dWVOF/46P7kz0YALm39/UVsrUQMqtWTLYhwns
fpVZys+owWJQsZzbPSaouqpLrRFVh5iCUE2tCCaIlnC05HZXh6uNN6kS0Uzw
5oBCxpM36qA3amfAksQE8iFgsg9Th+GdaseasplgcoccSwwTBYrURU4XFDLB
jIckC0hRIPQIs31cGRNcatJixXQpYO88eeF+DRNQvGwDWc5SQN2v3c2liQkq
6F9vMHpRgPU1fsPiNxOY1SoQ3j2lwO/MtDsafUxAFu+90h5PgU/V4fdERpng
isrx7uBsCvj3+TxmmGWC/JTL/70vpcCxNcfnwytMYK3b8leingLSZPPX9fTM
sPPKu9r+dgqsKGq+zWFnhg8KHM/+/KFArYFEShSBGSKX6du3+ijw9hz7J/8d
zPBjVjlCY4AC7jdnvzjvYgb2n7TF69t6g7DOQjM5Zkj7qeeX0E0BobTyUlUV
ZrjDUbSa00qBsdJPVUIHmIGmFBISU0MB2u+XPzeBGWqmQguMiynwfM6vbcCY
GVrlybYfPlDAketSd40FM6g10tVlR1JAc4/lQKY1M7wO7yo+dpcCHNSDYy/t
tuNpDp71s6dA1wmp2TsXmWFXmNRpWT0KZFzlXnG4xgx5de5duuIUGG9WXpq9
xQweY+Sb1gvqIL/faiEwgBkmknofSFaqw4WYm3PEx8wwH7iv7/kLdUimi55J
DGeGy1+DD7w5qw59jrQp1WhmMGKxFVCUVAfx6t6JsiRmoGdNGKb2qUHUc9nR
vhxmUBDe2VlopQbtC6bD7iXMcEy1J4HAqgbk01cHGb4zQzWLdtG3HFV4JpnX
J9nODPwDF19KMKhCbdCvnuy/zOC8q8S1NEEFOMbW/+gNM4P9+GZDmrYK3P9y
qNNhhRkCNQU4DzsqQ5nghV+z9CxwzON+JEPfPtjyedweyMEC17IlhzdmlOC2
fmNz4k4WaNSp4c9ZUISrredq+3RY4D/F9Cu2IbKQfiCwxt2QBW7JWvaft5GB
0dh3VQxHWaA6Lez7ZUlpcHQeL5e0YwHGPRzh8xG74fSSd4lDIAvQj3x4KrxL
BF6diS2afcwCPHTh0d4aO6AFw78GRrBAw2GGiwraAnA0mDUvMZkFfvomDgkI
84H+jsjPfd9ZoMD6Rf4F+xG072DmWwdOVmhpfMDkPiCEM/kNBji8YIWBK93J
6ccpuJsH43H7GFYIsHwvG6KhgXdckJC1S2aFrqnfJCMBTTzd4nT92RxWkNwR
u/tN437cSrJe+FQLK8hnecrOqWrjNIGxiZNdrGB8vIixm1kHl+VkKz0xwAqJ
UqwqBm06+Pqc7gWreVag3qhnGHRDeFJF7pejZDZgZtnN6KKji3MVNgWZi7BB
ddLtr0+jdHGvz1OnjkixwZXHu92rF3Txw6/k6EzV2eB1A/u1Qyl6eM4Tw2YT
7W37mpn202t6uJj/+RRjfTb4MtAaDuaH8NmLsWaGVmxQkXvozb6JQ7jN2UJx
Axs26JjvNhI4oI9//6999pAjG7QqiwoHBerjUVqEN7qebCAyE6lYym2AM+1T
ugJ32EB84mqB61ED3G23KUL32eD++/dszqEGuB7Xg3/aL7bzWb0Wx8BkiKfT
JRYcjGED/yDHjKdahrjAAu2JVjIbuKu8263kZoj7j3SeO5DOBpcYNF064wzx
0e5llf052/+aq9zLR7WGuFUTP7NmMRvUElgclJYMcdp31Q5KORtsXeJSw8WM
cNmiox/Va7dloQMiGoeM8PCMK75qLWzAFyXY+9DRCF9PevSfahcb4HJnlz8F
GuHOr1OkVAbYYGe7aWhCrBHe8PTb0r5xNjhR2hVkk2uEawX01CjNs4FYXKbf
r2ojPPnGRuzedTaYLqpoJHUa4TwuwtcVmdjB48dsOOuIEX7rnKa+Ahc7VDXv
eZU1Z4T3WVoJypPZobnO+TrvmhFuZnR9VFaEHd75xHqKbxnheQdDS2Sk2IFV
XjinZ1uWUP4YJq3IDuW7exmPbRjhj6Wqzu9RZweL/IJlryUjfF7on4aUNjsw
VK8MHZk0ws9xM3Ds1meHIubdQ796jfAqevHuXWbscLNP6YdokxGuungwU8KK
HZoy0mVEMSM8ZtT6nrgNO7yViD3SlWqEs/y9cULMkR1aioiH7Z4Z4deaw+VE
r7DDix8vBz67G+G/KzPWd3qyQ7z7sdh6SyNcv7j2p/AdduhMY/z4fZ8R/jlz
JHHHfXao3EpbjmM3wgPe7DYRfMEOdOFsXqQcQ1yR9d36RDQ7SBUOfsl/YIh3
eEpnliexwyH9U5z+Voa4koWcoPsXdljao82ZOmKA/yr5UGNcxA6rHtJpYpkG
+H0FRV/xb+xQH5GlP+RhgP9m2fevtokd5k+o3Eic08cfeGa+TvrNDncNWE5l
Zujjyn0qZrf72OH9kHCD4SV9/GGJ+heZWXbgPfjljknrIVzdUysgkMABQ6cS
+h3C9fC/vUXqp3ZwwBP/0Hk3bT388VGd4X27OCAiIiktaEAX75GHo93KHBCy
K+Ptrn26eEivgeh+Cw7QW3LIlrJD+KD5f18nQjlA88yvH5v9+/HnxU1Xyl9y
gAJvi24o535cW95KIjqOA2S7819+UNHEw5lPPjT+zAFJT4OX9t6m4KjY5nhS
HQdce2My2kanir+WuzhjzcUJN59FO9vzSuOHXo0k7yNzQlui2c/vx6XwSabL
1iwinCAq8W99b5wkbtDjin1R4AQSHVfTgSti+OxLjxAeU064zxW32E8i4KZM
fnLljzhheNy6cVyMDuxKtFr0wzlBueOj9d0nLODltehbEcUJAu+p0cNdXJA4
7Nry/SMnNMfufm8bSYblWhu/6jpO+PtHjzonIAE8QULyh9s4YVXrWxrRaxfs
Ri0tNX84wZ83cPNfrSSYZ5nK105xAv+tx8bC9nsgOVKrtZ7ABbY+EQ5uEvJQ
aL7od1SYC9zYcsbrDyjAT9Zs+QZJLhCllzfkPqwIq95y/o1qXOBbZVY2aq4E
fGr/5C21uaAS27vpcWgf7BmPb23S54IGPs/Ik4LKYHFOSKHlOBeI7T/yIHJe
GZwFW1qtznEBRjVtUrdRAZ+GZ/6tzlzAwhM8J4+pQIoea1vbTS6I2B3nKn1T
FYrXyvxP+nPBbd9Tk2q1qtCY46vQEcwFqf/ePkgVUYN16UX/X2+4gCFgcbUv
Qw2IPVkKpxO3/S+5nPs6qwYyb1zbfn/ggpqrC82CKuqgbSkXcOYLF5Dv3dli
u6wOlpz/FLqKuODMSz2X1/HqcLE8vs2mnAvyLuTebmpUh7t3bQK6a7ngsqbo
lfJNdQjXEFI818oFH4L2Gd6RoUDqVHPbn24uMDr7qIXNbJtPUp8F2A5ywdU1
cpz3FQo025sq9kxywbWf57r+BFNgWJi13W6JCz7d7HY3SaDAZnNZQO8WF3wP
Vh6syaUAOcRX0YGNG/xLTh278Z0C8oZa7X183KCye975TDMFYGsh4PwObkjD
rliFdVHgeEGW4sAubkgVgjqZbZ5yue7a7ijPDRoTaJmyzVv+8nKB/1S5wfrU
wMWf2/qX/QOKzge5we3eRwH2bV5Lj4lvHzzEDckdj62Wt3mr7LhN4AUzbigv
86zK3uatdh6hvcNW3BCSsuBgvs1b45XN7RfPcoNi9+iJ3m3eYgh4FjjixA2/
qScIgS+3+U3LdK+L23a8fAsVIz8K7J1j6Rj14oYqqpi/kRMF9NLLAi/7ccN5
T6eRN8YUsHby3Tv+kBsKl596HJejgJuYVseVMG7YGQz7n7NS4F77QuDEa254
nit+1rFfHT6buHZMpnHDf3vG3fZu89Z0uKT1nyxu0CIPz+hcUQfVrvb2uq/c
gALTXtzXU4c8N7329Gpu2Hw90L85ogZYhGCbywg3tAQxdKZLqwFDd+3x0zPc
cKpp35DHrCroSwe2mqxwQ/aOL06MJapQVTDeIsvOA1W6MF5qrgoN3aXNg7I8
MH7sWFKMswoQZW4ea1PmgfyKScZgeRWwuqbYXLGfB5h2DDmUTSjDL4ZXTcnG
POB7zDHcwV0Z+mSuNDpc5AHV5Fy7sTElmLsu8PPPex6YmXzzmfhPHjSKfpjX
Z/AAwXOPpJyjPNxiCqgvyecB62xrPLhfDtZfjtXFVPLAna6DnV79ssBUjNee
HuIBlUkvjX2j0iDAcrmmTZoXtqL4WJp37QbroxKHvyvxwpjhYkHzJ0mIet1a
navBC5ES/ak7D0qCmAJUvzDkhVDF3flpp7b3OQv+KktnXvBo4E2+elQc9kdh
FfXveGEfc1Ij284dMKCUoX3xMy+Q108Ofz8mBM+/xX2hz+cFA5cS1othgjA6
fjdBvYoX1PbKKJ3nF4AYpH03apQXYvZc+H7ZnATGLQrzanO8gFdYxHunEGHh
4s7LdWu84P/vVpQrAxFkTO4q+rPwwc+Wt8mLFXzg724j/EWQD+QZRjl/LHBB
m3ZL69ZOPrgGVoMs/ZygyGr23EyCD/7RFifi2zngV/RBtkFZPgg6sMcxro0N
lJ2/fFPdywdRJeRbbT2sEKSs4Oenwgez9RdkBGZZQLVCeFFIiw+yFFnbD2/v
IcHPwrOcqHxQXjexzHWUCf6e4nDN1uMD8y97hK/7MMLTyZV+U1M+YHXf8zFr
iB7+Cf5q9LXhA4/nZmiEfxNp91mE/LDjg9y95CnrinUUnl5lLOTEBwklC38P
+q8hqm4BluXKB4meZ5OcBFfQC05ln83rfCAjSUtQnltCY63vNUy9+GCTXffC
zV+L6LXLq08DvnzwsEA40bd8Hk2q815SuccHOzFNnbKqOaS/FSTl+5AP5L4l
EoPbZtFMhFe0YBgfVBU3H0jknkGHS44/OpzAB4538muyvo+h+Id1+q/e8UHa
Q/m4sVOjaPE/A7qBND7YP3kOzq4Po6RB9Zt3s/lgay8jn4DrIFrNTFetyeOD
N8/2d9/U+ocsfKQmBYr44Kyebp8h/wBa5yU7ZX7jg4pJDlWPmV5k+fuJxEYl
H4hEqAgtz/Sg1GTGLpNaPpCkTQt4rP9Fxw/MWfa38MGRgfLhD9e6UDrjZR7l
X3zgld/YUlvzGzHU91Xf6eaDS/0fmPUO/EKfHZpAYHD7vvxUTRUt2tC7S3fG
zUf5IEzWd/roRguKuSb9+uHk9p7w5FTUoaJm9Nj39tTy4rb9zYVGtguNKOCB
VLTKGh9cObFXLfpYA7r1tN7QZYsPVjiZQzdj6pFTlGRcJythe/686Vt+1SCb
hFoTMhcBBBxlcxLFqpFlqteCGR8BSlUPhr3yqUSQV2NGEyLAU/G6/DrvcqRZ
4rm8KEKAZd4Dkbw7viGlcrHkfbsIILRhm3irthSJNLmvxcsR4NQWOUGxg4ZI
v0Te/9pLgF9iB/MIn4oRR893S6IqAYZYJm5oJxUi+qFrm4c1tuUacgXv1wK0
PCH84Z4WAQr/611YH89DU/Plx4upBOBrFnx2TycXDa650S/oEWBgIp9PJe0L
amb/Zu1sSoDQ4yIaPrWZqIbPlentUQI0tffRTTBkIFxQMLP9GAHEKQbzH16n
o3yx0jN81gS4lK149efJD+jznsusJjYE+F7T4kKkpqJ3ivxfAuwIMC39V1zf
JAXFqGHnCh0JEJ/J6GF2Mxk91iXlKbgSIEW5xn5OLQEFGJfYO14nQOWp8IJ3
d9+iW0cvcMfeIMCwSzwDqSYGXT1B+NrqvV2P0o2rv0yikPPZIkceXwJ0nadj
qF15hc46OvEZBRKApSS7ZKAtElld5i32CyLAyVhO90N/IpCu93nSTCgB9i9o
1bDah6H9/tyYXAQB8rR0fWmfQ5DSw3wXh1cE+NpG+VvU+RjtCbUXiI4mQGYM
e0CsfjASieQsa35LgHcs5s81/j1ApJhcV65kAjSb6J+I/HoPcSTZ7jBIJUAn
j9gYHS0A0X9gr7ibToCFlA9sk91+aDnzy7W8TAKIOXh5Hwu/g6byz4pM5RDA
+vK79tVwbzRIY62S+UoA800mLu7fXqi7IsvDroQARwu1eHgdPFFL7RnxN6UE
aEDXfnbvcUc/mpl/NFYQgCJz/eAHiWuo7HeGF0cNAVRsthJGo6+ggt5Tkofq
CeC/titZ6NgllDHMWO/TRIC0KtEdHLbOKGXqk3dO27a/C1a3PAvOo5jFk3sm
fhOAydKVM8zaHkVs0Dfu+UsA2nC3iqT7OfSYKf3Ouf5t/XRVkF7qaRTAeUL2
1RAB9ATUDmYbn0S3iHQtP8cIYPEwbdjDxApd3fHBj216O7/CrOijCf8hZwkr
Bd15ArjXWd8NfWaOPKZu66osE4AtT+Ui9dNh5E9LOLlrnQBvq0XPemkZodCQ
KlcCHRH4/gROeyjqo2ibqXv0TERw8bQ8Z+Gti1IVBKJmWImQFfSANLiPivJW
tTN7OYnQcKKOl51OC32rPv+9kZcIUS/DLpQf00ANrx93lZKIoGM/+kJKVA11
X8iazRIkwtoXd+HrR5XRqEYHW+JOIoDY6fi9NAW0xLwlFi5OhDdK9pek78kg
ptY9lMDdRNAUG/Up/b0bEZLNTN1liHB9J25S9UUCiXl42DsoEGHA6NEbl42d
SFEv6qblPiKQ3hU2SZ0RRAcIpSF6akT4usvMNPsCCRn2DCWpahKhXXHLMo2L
D1ll8BRKHiSC8Nnwcf4rHMjel9JARNv+pfZ+3pnMjNyO2AwyHCLCPtG1yI4E
euQjcm991pAIIe12YW3h69TgsTRi/2EiWDXRpB4zLVEjCxtkm82JkEH6zJzl
OktNfLRE/WZJBNe8p4Ua/01QM6zFjn85QYQpt7icKdkharGMweWk00Qoe2yC
kuT6qDWLlwMizm3Luy732Ol3Udsrwl/dcyDCuQMHL5c3tFIHXnz95OFMhGE2
4X0mmQ3U2fM93867EIHR2k1mr2k1dUuV9fcxNyK439CIT1wpo3IxKE0fcieC
wWGjzwlyxdQdjVYs6l5EkPhwiHnzfQ5VOt5HROo2EdYjEvcmj32iql9NVCX7
EuEDSn2+avuOqkutNmYKJMIpQozJC4E4qjn39Ln5B0SIK6Cez2l9QbXpErgx
8IgI5GNWciTrp9RLH3WetIRs68VuJ0YNBVK9bjsmlD8nQnP91nRP+i3qPZMn
+TmRRGhLCd49c/UqNUwouy75DRFWHJ043989T40d6uh/EUsEbrLYybVrJ6kf
8rZW7icQ4cF4dp7mQVNq/gNpvhvviPDw7lpZkTOVWm51RNopjQgs92hDLBRl
atNuT+3jn4hgWiLIUW4rQf07G2VpkEUEa4/H4VbsvNTx0tKLlFwiHH510knq
4JrOatiw756vRNhd+XS4tfCfDqsdbyR/CREuGLqu5VbU65D3aXxkLiXC6bz7
Tt7vs3V2bdqULpRv3/ev2s1uq3Adpbp77f+qiCDX5WWXkOmiczDmw0RrLRHO
js0Zxbvt1zG+3Mj4vYEI2BExnr6aOe3jWss78lqIcOu91qhO3H1tB3Zx5ZQO
IhCqnlpxmR06eK3DwPBlFxEu3vfz4uxSL777/opNUA8RUvTJMr4FtcWPvSLc
vQaIYKa/FbXfUbzktUFhsPMwESQHzvS51JwoeUfujTsxToTHUumJ4mGBJdn9
rLmG09vz1+rM7CT3rsSz48f3J/Pb/bHgtvJ8oLxEs+5ZR8Py9jz+o7XWdPaU
rJYeG+Xf2LY3ueno6bJUUpwnuH6angTDP+vULBa5aL4fO7njmUmQp/voaa2V
BA3i34r/YyeB/O7UfEF+FRpD5HkVeR4S/JL5+WmqCmgVj2QOXSWSwGP1mj/7
4aO0YN8xqxwBEtCGKj5CzxnaYY8M5xVhEqxFja2p9F2gcV30uEUVJ0HyfFpc
/ncPWr2N5uN7u0lwjI/99IdKP1rYf2vRVTIkeOTpu+NNVzDtmCH2iVuRBDon
Dua82AinCRy8h1kqk2Bwr7uymlMMrWOfUeMrdRKcZKdd42lKpkVJcfZ37SeB
xI2UgcytT7SzO37O79IhwQmj05MK+rk0CZ4Ilgu6JLCMlg8syi2h9TGcFEo3
IMHkvwB2Ke9yWvKSsPyMCQlUIjX+3ez+QXMe/3NQY5uTzQqe33hCa6LJ9iYe
8bEkAY/A6FrSbAdtrNXZFj9BArsZg7KKqz20zzXy15nPkCAl6rTYH89/tGvY
ZOBhWxKUsR24s/htjKaak/3i2XkS9Mc4TDg2ztDmU71SWi6QQINYeeJS1iIt
L1arYMcVEjylcd52ylqneYdvVp+7RoJzJLlgEhMDpv2wrDPJcztfjO3Nhdss
2KZP0MTwLRKII4vi/r+cGH7t8NbeuyQ4ddL79awSAbvnxEPwCCDBF4/LkxiB
HzM83SRZ8IAEPW/F3Dm/7MDYjr5U33hEgtyRH3R0KuJYzaHThnqhJNjMOuRb
2yaJPd0vZv0wnAQht5jj/d5LY+Z7+y7Vvtz2//3F2oK4AkaQTPEhRJNg6JKa
PZOiMtYi4BJy4i0J9ty3fS9JUcNeciq9jU7ajq/dOkkq1MCs6WYze96TIO1i
0DfFH1qY8EJu2Z50ErDfnC29dRthXSPeLS6ZJOB3c/GcdNXD3v7RGczIIUHx
AF9DbKAB5tBMvzxfsN1fop91jrCaYFJVFexaJdt6BaM/UuxHsMHiRzv9Skng
aip04dAPCywt68je8goS+A/RToTbHsOupBAQew0JlMVEWDkPn8CUolstzOtJ
cL0tZWAp4hQ2/eyNQ0TTdr0HToi6GZ3Fsu+f9exoIwGXx64dn/LtME/vXUGi
nSQg7DP1/c55HtN0+/fK4S8JmvTjwx1TnLBVh7S09/0k8Hpg+fBi6EWs+KRr
0fgQCVqiI19p/biM+Zqp1KmMk6DiXqpro+NVDHQX/nhNk+C5l9PfrqzrGIPG
1+mieRKMCj3neTbsgVXI32WgXyHBk1J1vwtnvLBgcV2y4QYJnh3k83nH640d
JjNLP6Eng01ZT1g/xx1sd6NB4kNmMozQvautE/LD1kOCxO6zk8GgmuPsXc0A
rOVwZZQ/Nxm0hvVC3dnvYZ9Y2QTvEshgb/2AfS/zAyyo3DjCm58MsZQ2Zdre
h9i5gEe8XjvIcD0xrv980COMb42D7eouMkSnZLDUtYZiw/mm9y/vIUPSeNTG
+kgYVur5lO6iHBlSl65tBQeHY1EqdXcc95Lh2/2wiHfGLzD3Se4VOxUyLM3u
1Xqk+BIz/Wh+4yyFDAOiovVBGq8xqYvPZk4dIMPeu8KXeS5FYa29fKOWumQY
SmL6S7J8i32O+8/5qAEZOHgU5VlYE7CgM+F9piZkOG3mO1Xmm4jZCjWfMz5C
hvLFBM0qQjK2v5XUqf8fGZSnZi0ySt9hfOFWJ3WPk+Hl5mXL3WHvsRHzyGad
U2ToZ6WE9PqmYVFVArUa9mQ4h9XkPyv/hHk8OGms5kQGGlL5lM6biZnpvS7f
d4kMDuFfC/n+y8KktjpA0XU7P+5rPvfeZ2MbRTtKZK+T4dBUVZUYOQdru3X6
wJ4bZNjNcpzA+joX+0yJzt3lTQaFwfVHl9XzMbsMkc/CAWSoOZXXGVNUiB24
clZe8AEZbhqHJm2lFmNEubgU0iMyMO+p+smRQ8O+JYq/5XpOhj/K/x47vCjF
YmztdrJHkuGZ/f3ILzVlmKdIwivmN2Sgmp+Y/kEsx6RfSoZtxpPhdlmPcHDn
d2zT8jzXWjIZgsPsyG1nq7B23uTgpVQypBhNV6GFaiz40Z6A6UwyVHw/fnHL
uQ6zN3TeGM8hwxmX/CiVQz8xLcb33iMFZBg1cuATiWnAxu7Iuvfh2/1WeY5i
V9CElR+4NPmnnAxmZz1fyHY2YzGLaS6dVWQIn5Ulu3C1YubXFM63NGz3Y/09
4ccx7Zj03it/G1rIwLQrgvpovQPbGkk/U9dBhoVmriw9199Y5nklq+89ZKCI
SLkY3evGHklcbSgbIAOd7umYH3J/MYfuDDNsmAyv7cUmS673YKSTKgYF02RQ
DdtF8Dbpw7wOq2t8oOMHtvysSsfbg9jUofeJ4Uz84CSmPhUfO4Rd1BHm9WHj
h3O8LEUfaoexM8p0w6Z8/PAjdOtq4NExrEXOw0qdzA9zGz7GdMnjmPnuQVxE
iB/qaetBH5knMRCofTMhzg9Zf44/W7k1jRXyIpa23fxwo9O0OZE6g6mxZ7vT
ZPiBc4k89JpzFpNef2X6bB8/uCy8/SJVPIdx9p3fUEb88HFs59+WO0vY/c62
SzsO8cPr0kP31gOWsc0WkzZ6I34wSPW/NfhsBZuu3JfRZM4P7JTu6aLva5hL
aeLOIkt+aAnxNGKaXsf6C/mDk07wA17M4F0luYm1fVqz8zzHDz9fnjtXYkmH
H33vVmfjsF2/+UP33lU6vCq+94CBMz8UzQ57i6bS40URlUQBN354oPPURZ3I
iMd7R5Tn3+WHC2mMl+RlWPAdHiwq8QH84L8ueddmlQUPv+IdG/yAH/bVKvwz
aWbFH9jaep0K4Yc6S9/EuJfsuIuBguxaDD/IN5jb0Dtx4/3UuBf98fzAM+fv
1X+BB7fZT6CvTeYHBkpy48Y1XvyowtKvmHR+kHXJb2H6wYerE749oRbzQ2ph
jJa+AAn/xKGxLI3zQ08sqUAsi4RLM6U58pZv+/e9EEw5SsZ3LIXq9PzgB376
2fcikfz4ZtfpqYDO7fdKHW6qMhLCq1NnLStW+SHYfOzANwMxfLmSoYhhix/S
tNefjEuJ49JDxN3AKAAh6+WlFYwSeOAetblCTgFgix4X8RyTwLUTPSIyRQTA
J8ypdr1OEs+Mnm+OpgpAVXF5fWSLNP6nkEn7l54AyDrGcFuflsG5f5OTBYwE
oO72meW5HhncRYji+fyoAGBNnPcdpmVxqcgb5Id2AvB6bLD4Cb8C/jp00co9
UACYY7Fnifb78O+fWEoyggRASOBHNtPIPnyhVmDPxGMBaLtOTcU0lXFLTs2F
CxEC0LLQUPyqWBnnCr4ZeTZZAPY/UjuSW6KCa71/uBGVKgDSuy6Wl62p4Je+
v3LqSBcAyxsfD5bvV8W/MxVQjuVuxyt5F2qRoYr7Byy3Gn8XAIv+d+XaT9Xw
z/Fs1KAaAfh4liMsClPDuzGhlG/1AvDtsrUNzKjhWpv7vajtAgB3ZFbZj6rj
F0VN/vh0CoCY9/sbdD7q+CvtU4Zf/26f1+r/byBZHZ+/7S2gPiwADrT0QKFZ
dVwy6pHv9XEBaGKbGtbip+D/fX0z+HlaAPCv2T2TFAru35FmPj4vAKSS9pui
VhT889LXPLmV7futGKjJuErBuwRqxC5sCEBE41GuZ8EUnFPjd1AyvSC8X5x8
khxHwbWOj072MgtCV8Az2q8sCn7Rc/WEOIcg3PTOMhAqo+CfzjyUI/MIwulE
7X/+9RR8Vo+8zkYUhFq0WLuvg4JryCfUb/ALwvmq6rOkvxTch6CUMLtDEMyy
yarC/RQcXy70GBIVBPPI+7vVBig4U4+RYdcuQUgWZ/rvSB8FN6lsEWrcIwgZ
srlS1t0UPPSz/ViFnCDMiSyeOtRKwZsjJ0sK9wrCnelrjFvVFFzork9Yhoog
9OeoPPcpouBnHdnOJ1MEwaq/rC0tjYInmkZS3hwQhCM2Rwg+Lyj4kKokW6iO
IMgTCyd6fCi4onDG70BdQfhu2BxaZ0vBr9Frf7ppIAid+89HqAEFzx2u8rti
sh2fYC7CIkrBV38et7Q/IggcXclN+xfVcWp+n9T/Fdx7OJR5FAfwbqJSNtP0
/l4RI4na0Myw0sVhmBdFhsp6FmVzCRkpimq6qq1cdqI1yKWbaNA9JcmbLrSz
qt2SaNqNxGwXkWSLxp7+/Px3nu/3PM/576yUUDDgdPZdrUrI7imMG/BaQUFp
wb+O8gIh27B36J5zIAV3MvvpohghOzH2QL4wmII3L5Oz2+2FrN/yqXHWoRSs
4vYESoYErNrcbgonigKVW29dhkzA8sbXdOrGUmBx4pCtj6OAjej1rBpaT0Fx
AWwzes9n39euCelMoqB3BEd6y5fPCkt67J5to8Al6ElHNu5vUoZs9MOdFMTP
fqgJOz6PHRWsKK3aT4GtIlrU9dKOZdwstp5Jo2Bjh9+U3O12bNqc894n5JjP
eXkccO1Y7pffP6TlUBArH63z7zob1kqhXbi6lALesh92ZByazcZuTzVYUU6B
IenL0+yzZi+Ek3bPc9hnC+9GfIIVu0DI/0VwlYIXY+2HAxwtWZ8/w/8c20BB
ZYWle1M4j826+uHEoArnFUQf+jLdjH1atGNTzwMKUtv71pgfN2FDpbnTWpsp
yJa+Wyt0IWzChMbwii4KJKV/t0y4M4494i784q9LQH+BfbPPV1047BfSUDCB
wI+Pugvf0gaQsWp/dpcBgVr5Afq6BQd2J6v5WwmB7wrv+JpIjSC6IiXmuDWB
nz6YDpxRWoATt0nds4TAAove3ssf54HQfFjp5Etg8iKR+JOGDza21skpywmU
vTLjF6gFYO4p45JgAkF7Lg143bSH8bKZPs5SAjYpMx57b5kPrR2JtelyApfD
5gTpLQZ43FuU3nyYQEdlaPrzUwD3tfd+4uUSsF49q+XGRBeoI9P/u3SMwIcX
S3xcm1zg+kyPu9piAq7RG65ctHeFSv6Gwx5KAn/8I1E9yHIF5dK7duoLBFzo
azFlHiI4GdijnXmFgAnUaxcViaAwwqgxrppAuoUgkNcngsyd0qjRtwmM5PHv
7Mt0g7T0nB+8GwhwxiwpePHcDfbl1eko/iBgvlLb7GTpDlsuTT0+u4mAA70j
q6TCHRJuwvqEFgKxWn+Z4q07SO9HL77xnMA9XZtSVysxrH12WF+vncDUu401
uavF8LPmRqukk0DhpFNOGb+JIahfU3rkNYGqPGqjYb0YVo7ibH7VTUCsCM2h
+8Xga7DI3baPQNojtxqFKQNexpGc5AEC5aEBrbvEDLhZH2qrGySwq2jsX41R
DCx2qD6rP4KGo7fcEzYcYMBR9Eq2cgwNF+Z17YosZoDva7D0qB4NC0YUnS2u
YeD74PlGr/Vp0LhWlFr+xYBl9BqNYDINRU02k1+1M2C2Ob1SxqVhIIOzX/2e
AaOUKyn1NA2Bb66WjvvMgO0/5/w1aP7I5V2AdnNSmo8zoiF7k4zZjI7tyWe9
0Dt+ka5rQ7NBu4ca0T6r4z3KvjDQdGWrqht9TDAr6xn6tWFinsE0Guof+A2P
H2SAcy/SUYI2mzJiYSQ6wt474TH6ZWaEmDvE4B0Vi/rRM7jb8xej5W+cDaca
09Bt8okTia46xj8XgJ5tqo24jNafRN62oscum1vAfGWAFzW5ehCtQ+lpo9AO
t8cfNDahQZA0b2cqetWWr7NC0HX6azUq9IXO9jVt6BqFrYerloF6FzV/1HQa
tB2eF4PR6vymkTPQYYKTzkloHf+GojB0f4rhdSXa6MxN6V70zN0zyuvQNuOq
F51CpyZIa1rQP9ZWPOtCV9aWi3SGMT+jEqWeKQ3zZQVXafTuxKPJ1ui1n+t8
5qLL5mRRMehpB0v+lqDZfWmdqWiONOzpz9/+mbTtvVyOLj8r6duA1iqS/LvR
22RVaXI0py/e3MCMhjci/oRCtJVPTK8tep26WalELzwdxvqiN+89HVOJlowJ
+TUe3XzwlPdNdMSqgJBMdI37fV8Vess137kX0UeMzRIfo3/leg09QgfuOXJN
jT65XqT6iDYddOZ1oKtUC/O4PBo2Gk48/Rp939IhygHtHD7KrwfdvsvWMQBd
nW9q3I8eUFvpJqHj48J0P6P1Hc2f5KD9jz3kDKHNsqYVV6GLR4e5aNH23VMS
WtEjE6fLh9FenpNEg+jAtuHhb/4fFteAPQ==
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {580.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3c81d8fx+097+XiXqOEbBIl+TqfJBEiGtKSRKg0JU0RCkVJMgvZlbIy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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {967.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{674., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.405677858203236*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
Setting \[Mu] -> 0.5 shows that the discontinuities disappear in Flow1, while \
the forcings in Flow2 and Flow3 are hardly modified\
\>", "Text",
 CellChangeTimes->{{3.4056778880865917`*^9, 3.405678010764269*^9}, {
  3.4056783216133003`*^9, 3.405678349750502*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", 
        RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"C", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsRow", "[", 
   RowBox[{"{", 
    RowBox[{"p1", ",", "p2", ",", "p3"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405677815714443*^9, 3.40567781989952*^9}, {
  3.405678299741843*^9, 3.405678312368596*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUV3k4lV8XNc/TNUf9KhqQJKQynVdRkiJRkgazImUWZUpUKmMiQsgUEUIZ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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {193.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUl3c8V98fx+09Px987IxIts/HKMm91keoSCqprySjKEpEpSKyUgmVIiWj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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {580.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUmnk8VO8XxzGDGeuMZWZsWbOPLUXIfZR2Zf2WJJVCKy1SSZIkUZaS7JQt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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {967.5, -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{679., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.405677822668429*^9, 3.405678026726883*^9, {3.405678305770659*^9, 
   3.405678317322577*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzFfQmQVkW25t9V/18rqxvIpogiLtitPrvVtu1u7W53AcEFQQW3BnFlLwqo
YhFQEQVZlU0QRVyAYpEdpWQV2QS0ZqbfexHzXsyLmOW96HgxEzEzET33y/zy
3Mxb596qst+LqYiC+u9/783Mc75z8myZed/Q0cOeeWHo6OFPDb34jpFDXx42
/KlRF//hpZHRpeKf5HJFH+VyuXcuzuHvv0R/8p+/5BoaGsw/H+MfXP7/d6G/
+bsYHTN/4df74t/wphH4rwjf/qNy5z/gX3NphHd74qYN9lrlqVPf3/XZpwfN
p2uV+35mrz373ntfFs6e/cF82qjcx6YeNf+17rNw4cL666+/Hr/95s+fj6s9
t2/f/s9t2rS54MCBA1dt3rx566233jp67Nix7z700ENDZs6cmcund/Ox91fu
W//Si5+VnDnzg9rNn9pr6OIHY8ds6LPu4/25D8y1Cq0vWvta8xzVIDuqV4cN
GzZ9+PDh7uvKEydOjB0zZkzhzJkzQ2fMmNF/3rx5uF4RXf9zZWVll6+++ip6
Yeqopr3+2nb09PqdO761ozK3cSx/s2P70X4fr91fM/uN7bk1dizJHqS1qjXK
sdxkv3pu8aLd702cUHf5l18ez51vr4EqSwcMGIDfXLH5N3/jxx9/LK8A6tB8
ub3/P3fs2PH2lStXmk9F0v+rzed8xalTZ5dMrK57e8qUzfi71j405Y3Xt11W
X39i0KpV9VmsBMt7fF1/Yurrr23LTbHX7l23bv/wJUv2mk8dUztdHHTa9Lgk
rcd5NN3bfjv83SV7ux04cNJ8utmS60bzX2HWzBlf9I2YgYF8OGbU+vO+/fZ0
rpsQpGDuKgEgXNu9N23a9L9KS0s77N+/X2PHVfaRn/zwQ8O6Ua+s777/65NX
791zbM60qVtwrcY+UhsxH6A3IMig1uQ3Z+/If/+9vY/UQp/fmD5tq/nUXfpa
1PK+kj4XHjny3cLJkzctm1BVl/ulpc8v7Nuu3Lv32IjFi/e4R9qeOHHm1ddm
bUuSqND+m2++WfHAAw9Meumll9befffdv1++fLkq+aTP0OXLvvzlls1H3PWf
b9v2zZDly7+cbEGGMU+a8+YOfFpaPaEug0QAHv4CSXMWjHmw8cWFC3YPe3fJ
nk6HD3+XpFLzu0sSOXGGaIckMuxAd2Ps5YpfjtoGVc2nLglaFefPnj079bnn
nrOUUBq90l4DQF6b8epW3mH+XTN29IYi19pEO9rOhw+denrZ0i/xCdS41Fwu
h1L8U9euXSE7QAWujho3btycIUOGvN+3b1+jYLQxW8LmQXf8FRFyb8fDh09Z
6OYHRwLc/6OPvgbH7vn0kwNJ2jY9PEvT/MQ5b26HYh/9zrxdrU+ePEvJ/Ll9
4qIDB07NnVK7xR98++PHz8x2yO9irwWqkwR+Z/DgwdKauWYmVQu94v4fffj1
Ddu3H/Xf/JtNdYdlviRZoajv/WTdAXyC/F1mybr5N7/5zb2LFy/Gpyu2bt36
t126dIkk+4dzjhw58t/btm0Lfa3ODiSrUXzRX88vXrTn15s2HSZZ8fHcY8dO
gxJj583d1V0ZXlHa8IpjbSfvx3B+se2Lb0Ky/vHdd/dedPDAKXuvvTZvSu1m
wVQne+2ROXPmnO3Ro4dp2zIx/w8dOnT4b+3atcPv/muvvVbDDqE7MxIKuUZi
QP3NmDXzC5/GoK/jBWSLrSvKv8IptVnPPPPM/EGDBr39+OOP/13nzp3rbrvt
tl+tWbPmxerq6nV33nknifRD9+7df7tq1aqYcGZKuMa2a/Qp1c6dn392kEww
4s1uQ59crBCjuPnE6B021nvPnmMAX8gRIYnHkT98/vnB2zZuPGw+dbbXIg59
3/rYsWPmU2ultSvstVbRVDbhrTk7fIHAWErPnPnefKq23zy5fNlXblYE4Mq/
++6snU5yZTevXbv2iVmzZuGTj3fQftHAgQNJ46+vu+66wW+88YYPzqBLltoF
NO261H3//pNDViz/KlcTEge/y6qr6roro61QXm2tkUKRmxyjTxj5mHlzd7o5
/gb72AXffPMdFLJPkOLoMTdxOL2gEXP4ksV77vzss4P+szdt3Xrk/nVWLzhi
Vr391k5HYBC268GDJ3OXmO9KZz777LNQCj4hX3v66adByJxHyUGzZ89uipJQ
9U8tW2ZUPRgGxjlKyngI3mvSqdbl0KFTzyx970t33TwaUg2twE4zn6jFnWqJ
Jd3oVco8hAcy7tMKn6VfpFWtx3HYXtft2HHU0apTfX39K1VVVT6tXqJg5zzJ
/vXq1aubohXei/e760a4rX1RMKaY1w/TR/OcZ+oWfrl1yxGIok/VBJl8jeHI
BB0r9uaVSgd7CcZ/gDFlhx6TWIg4wXbD2GV89lebNx+5feOGQ7keVjKG1dbW
nrz88ssdsa7csmULZiTID2YkqCeAT5uQSKffr19/8OatW79x1w1dLJ1KYMTA
iHLfwRaEPPVOx1YkCjuu37FdXucT7W9iVCQHjklJIJlBtGt37jz6QGR++M8+
umrVPliqPtF8rF4ROUMPfrjmaxKtGI7diV69ehmiWQTlI39vzNxoSlnev3//
vgsWLND0OQn28Acf1Pf66qvj7jqMdEcwTGZ3f/rpAfddv7Uf7f/Zrp3fZhAM
9k/ld999n0EwDACDNJ/K7LXpvjBekU4w2MHGrfEIBpsYXpFPMF99dIxYDBS7
MIFGBQcFd90QnFQAgzBq952bZtOpUOJrBfyOeucdYxXeFBACnTK6NUEIEZkr
RCtdoZCpTBHaKjscw0RegyaHRrfDL47thgJ8EjH2nd7goJMEcTNd74RaKfEp
jd8XFi7cfcO2bUfDoQadLFOAnsHzoIVmDlqGk8HzJJN85CffVXb69Pfj5r69
M4PnNYnX3fHZpwd+t2H9oaYJcXGkXt08qBLicnsNWJH7GN4Anzo6Po2313wz
ws0pQe+0yZRESY7CI0r4Dr43IKJme6TABCrnoTVrviZ1rlcoUaFQrFc6dQZE
xug1u3cf86kD/Qql5VMHfsmLzoIqUiCWTp1GPB4538r1JOU1LSRQEo3nHz16
+oVFC3eHBHrkg9X1V+3dE1iSQauGQEZl9IrbL3ZCTrLgs7RHssA8Qjgrte8t
IAviIZgCJ6XjpqYRWYo9r9aJm/8EUC1ieWNAFVBAfD5SBSY6AmHmUwfzb5MR
X3xuVlCBkAvUsQbXcfaa73z/tbQFnH+6e9e3pG1kTm1M0jawbLuaf/PJodNQ
SI42PchV7AdmnBccqMlfNOJJkjZ3rP/8kBhnNjSaGa9uUUSip73mu2e5SnsN
MeTyCFI+T6Cab3Exu7+SJ7+tqzuMoEsG3gNKdbNESQ49bbjpkdli6AIoPp8p
AfubZkqHaPZAvMZ8asPXNjfIzpiyC1e471y8IoNPCECaDIjHp8DSIp8QY7ja
WQmpfPLMmkaaFG+E62SjNEb5uWisI1l19NmkbfApPdGgxOyLWk4Asg7gAwj9
fgRdJ+uus19d8vXXJ6BXzadWCqc7JJni4hvuDhfgKBaC9RRUbBcXgKzAdPDE
ihVf+azAzAxn22cFRE0op4kMLabAR+WzsCmlDetPm/jGc0sW7/WpIjEIkR2f
9JnDzHsuPTQnDAL/1TXpBAfwoGh9ggfy04jgEgfxeoI4SIYUBBysjEkl10l6
50D45AOZxETPIH2748fPvJwweM45duyMGEHV6boEoSGT+VNJ35IBE/WYQeCw
+Y1oCotM6Duxui7vUrqtYsiFM7vPhJcUSUSAJYMJAVc10RqrgIWERIYQmcKm
mBCIL58NNBGZ4KYSnz6BpmjEhJYM+KqYghJB5X3SkcZMyPkmDemDqRyxw5gJ
ifC+tSRKWhLCuSzGv7CktcIisqNWYQdyOJIOyWAHrJBM5WvjCMapQLzCvw/z
iYRMU6bylgz7KmWIvO+lhQv3IE+kMUUBbRAJucBe03IfanioyJsRAu1PFkAL
X+wCgRkSgTijkDaDBTCIRbVo6pgsCNQc70M/TNwdn7oqAy3OGKjvaARmGV8+
eNX7+0SkSXSXssXs5+J6tJUCJ4BEbzK9QagHBg/vA00k0ptB50BdZ9A50FAZ
dHYZTP8+RPIw9XhQbzqZcZXSBt+H+PONX9ABSJAWtqCTXJJ2+YTxEit20NTI
GHSdZIR+w/WmyAiDRtya2JbsnQ4+TU8EwptXrmlBYBIqmGqKYxCIjkkQCs6N
c2baKK/IIFTQJe3ZMcoQSSgkpAQLGXgbH/ntyclFI1lwrYUkq1WwBZ0gM2yC
ZMqwn33v3b1waWOS+Qow8OLbKJ3TCKUNVgsY9m7msxMU1JJQgd66UlCbodUC
UW6aPJjbEeRORZStyzCGJGYp86mtvYaoWDs3a/07EUrTYBqhgmsaongNRoeQ
raC0axPcEk9GtMndzmG7YodskhXBwmtnv0VW/NfO2MsgVIA8q4YrUTfxL61b
t/6n8847D7//Wl5e3qIYFon7XmRhNweFmrg2TqHqxHUVTD5xg2cTxN0X+aIu
QdROuf2ydDwCi4jw+oyBmEPczafR9hryzRJh1LSPJXOh++7du1Gc4a4bEhch
UpMrNDs0RVJPVxR9tZ+DyZhMapuJ45779p2Q5FpBkYEEqWFA7GE8uZ3SvCG1
0YzaFNI2Fh65fq+9NuDDD+vfnjp1i88whJrEPtUGRvNJCb0U/NDLH5YtWzZi
8uTJJGJJ7SuvjPvTlVfcUnnypFE6QfTFhABIbWildSNf+dykEDXvj/ch8A7N
5nf+zenTtsK9MJ8eSBeKFNVM/sD6kSx8QXkiwR9YMM6yIX8CaydDFIKBaby9
x157fcarX8ACuhRGIt8Hg1FgpHHKFhNV3Ll06dIFjz76aMnp00bkvr3llgFb
/vCHfs6bDIIxiW7ytchgwcUyVOipNMVn4Y8gYuQPEenDiFd7Vo4ft8HxJJjo
SOFXFszf3ebEiTNNSQ98EgTr/WezZgFfoElhmOS9nUS1kDuBkrvbEglFqhgO
4Ihh8JUwECWloM11tvSofPKLL76I2lB8OnjrrQ8iXOOakTqdDO44Q+j98eM2
ZnHHpSW8IeZRCwCJQxkThtHP3orMkBhqBYW5GQzCfQil+M8GlEwwSCHy5dHs
ItDWGMS6ChS9iGPQ3l6D8pJsKxmELOZDaz4wfhjqQPhKzO23btp0OJVBdoJp
Bck59/Bhcx+mlf9bXIxy0RMfDXzkeYR13Oiywjr29VIzBU8dRLosnV3oHapv
fHa52j1nldDGHzl//u4btm876ol9MaqRJHhPNgShQt53dSQIA1evrjefSpWe
s8gIIb6a2bO3Gxnt7tp9Z5fIrCaLbGNIBInbN2yw8YZzLftZTZ1DFaCb5MnC
Yj+NGM9ulEqYvBLW4hMIv6GsyGN6YdiSJXu7HjpkgLC0uqrOlGzwHXDeRRQ0
3UnOQ/RW9utnpALF7chCRkCq77d82ScwLSLTYHvn+vqDWbEje60AF/Xtqba+
GPhGCMNhW/PDoeNkLrN4L+Q9wuB9plKeRZ8gyaj57+xeUDNpM6L9JH1QbFWI
qSXhn4vs43j1JyNf/jxC2DZU8RokmIGQ/3CzI7J9vWrcmA2O/8GsyJdDk0jo
ly+H2oiQv+OtqVO2oG8JCCDg7yoAzrHXAjVrb2/dyGRu+JGLgXrEPZWAPYEE
HQid6APJdzTBNXDPAenxlZ5SZFuY/MVepCtQfvLkSUS4ql9++eWP7rnnHky4
GCNS4oiAbbrrrgc33nHH/YiAqX0mipAccVItJh37AoND0qp8R2BrEkWowJCo
VAPrv4iid2prNreJTLRrd+08Onbu3F1EUVCBRkZLkVvM6FIkZGA+/bSubvN/
7NXrhiZZwWinK9/G7AkLlM0G0wabRYZLggLE1/IJVXWIZ0TAPjxq/rxdCXyh
ZMJF14ivwM6319qm5XZ/9PKsHsoozlGu3WXH5ysgENvwjbyFtSs+EwkJd00i
z+StLzeClUI6ngJTqKEhwBPak6wz28TMKvWZbPP5qG/AmXuH6QPx5MvOnOnT
tpCxmKQ7uEm6EL/a1ADGjC1zq1FA9k8fGzwxSXaN6lwghFE5SQZezEgycIU4
r0wJ9CyBKZ8rBqYJcOFrJ+xkLhxccU0Yfs1K12etJEhdcGYG3UPRlhkI8+eZ
IldgRG4HXi65jfi9LN6wFdNmoZlPExRBgbbxuhB6fIFxQDWDmZ19htaE9vTb
w7wh4Rmia37NZCwWaQgQyoIsoB8qw32HGkrEQC16wsQ32RzUntjVH6193uB3
VTS/HL7pxrscfwAjNxJhROy42s4XBkVTA2bOACwZgAvSiAQcJvxbvFVqRnwS
gFO0SRCksteyc+4tW7Z3SUy6apeCtJ0qDupTibJkYaZBJ1Gmxf8geaKD2BYc
XcluafVo6ZZWozpGZFcwZxN4EHJJ3mhGq+1CIZgiGlimTuCB2LJeJvrFlDpw
9ap9FynsLlGasPmw8sdXrtx3PVYjNNiiqqffmrMcy6h8hqgjZSIdeDfLaHgd
NhqSJRcpTRbi0Us5e7eYYEVekTFEEOV95zQJPDFCPeBlVxw0fyUkkYDcm9SH
EnVBvuxOBZ1ald0lClHYblBodkmMSsn7tRCByfImZ3ERgWjKrKlIQyDN62Kl
SBipmzKXWqLHDbbLbMr7ggVxXZU2ShSo2vvKlkyeuMmpXLDro3vv7XPgtt8O
duzSuFXQZQ+zBzz0ixQCcuT+EiOHyKTswRSCCBORLrUFnTyfYaTzlPFYo76p
8osm148SEZitLnWoIxLhdYmXRiSiDgr+vc8OrDSRuqxLFGKQpm6Rq39fEEzk
+5ZWT4hrSjOQmCyDxHQI/UwkBrUYGUhEIhtBFL8LQZznSkXgPCGU6uauCpdK
FHLYxbalGLZ/r2OV6aPGKi3exH4E6x67puOxwq3q8+7D9CRuFN8XKKb2ITAR
VHLhCAIzSFcSmGklKARDyrLiHnHfRWsTjnBnxX0lHGGTyFJj9h3VmqhTbwqO
cEMwr/n3vRmZ8UnaavErBY4qPgLCEG9o07jZTeASBqosGoxx+aXM71cqz3p1
SGKvaXggvgJzhovAYbtJBMVbJS24i61hUjJY8OHVc4lg881BEWap0nveBy6L
j1EUI3dcGEsTRML7iSx1H5GKX9qoGsfSvlmLjy9R3nqewvY77DWEFKRsqyge
vDyfMV+jiEpcRd63sGbS5iSLtbyRBsuAxdqzhBvalG0WMmCpqZ/A8MqAJZgo
hX4ZsNRAgXFIXUdRzLr/WVHRJot1vIbJWmZikgalYlLlwmaCgoJSZchdFMnW
8tbtQowqyAlKQHqkoy5AmIZvoi7IPWup++7pqGvlTwy8L1jY7Im1rA/UUOf2
rfDD3LwPtpIs5WUbaLOVi6hq+eLuCg3YRhBU4bq1yGP4Xu7l2AJzsUs66jQ2
BxOrR4NkNKEx5Irg/3oKUtbo8s3BgicNaNyqoIO/4l6rFEgAzcclwRIU02hA
I5ExwwoIuAwBboe4YXcoxCNRYMhJPEIDmma9MIIwwC9191Lg5zulHi8ZKIql
WXJ4fKK3SfZwPs/ogZbECVak8X2YvURZEV5wdkYuoFVOZqBNcfG7KHDV4EXm
wgZJBoqC5QYZGg32gRTE8tryqvEbRTzZBmxgMbu1WZf3abuZaBrNFl0UEDWG
OzxlxIgRbw4dOhR2nuTY0C3kxLEesi2JAImJXpfcSeecGHti3dHhSqsx8vZA
eXP61C1mtyvzGmNCMs+KcP2SSdV1xpAozX5hUSwnYk1a/BdgBY+urZkdbP7D
eme8evW4sRuw8wxXT+hksYnrMihE7fv71n28H86RZUQ+SSFtdiGW502piQ2D
VtmD9MoIxWXhq+H+SAokQ6vDpETlvQ+RZdXeCsC22V2oTB9JoFNKdUJQJSF7
KNnf4pjs9bf99qGA7HaZZGHJkCHPf9T/gceC7zgi1AdMwOp0fLLlP6XaXk+y
IpRrpsf5oYrK7FFXxI+0dTFjb28aWCHxNd+uDpJtvAasyBNNcLw8bkSqnksV
chd0clMyZ/nTJ5dVAMnjRo8enUSyLX5mEWcJYs+Hr7nmGiSdcGXXTTfddP+i
RYtK2Cryk6NHrTehDuxOhVRuG36HWARnR9m/RLN92CGtTg45LxbiA6TwaZHi
RGCxvYJxtoyE8qyZM7+IrJ+TiydP3GScmJLsVrxAiBg4Fqx5BFWgqd0gLMsK
wM6nI1/+rENkcb/56rQtZnouzyYbtcjC0aOWaF/D9IOhwCnI3/VFNVApeG9P
mxq7vK2yx0kVotm+QZgxQ4VgPw+JyuSV97XN7kKGCnnVt9XKFCpQfyAELIJY
FNK8ltgKaW6+/k+XXHJFz337jvtfc6CroklApl2rRUqClqNfWNNwQNixYDFj
ZfaYK1IF0SSqJXiVYSxoNj+QLaRvgvNUJUGYUFMlJQrZKWyIp81+lRvOcYav
nVK74vhVV/VOYpl6hC2kLYV9YeLEicsiZ95ha/X9998PreS1UMjBnnUL/o4f
P52bOmVLxntL8d5Z998/eH6f+x9K7ormMgN47tjPb7ijyfpQjhKaR5YLNdjM
FyaedulaaC66yWs3RhrJEJndlteniZDVkyZLtuDRRwcdvuWWvv4waKlAV7gY
J8D79tTazU4FCWX5SkfZi7IZ8kXfPsM9huR9hiyvGrexferjZU3tSOetAhEz
UYsWFFKbkJS0ox/Jj6BH0sFCeYHE2TK0GRw4kQc+i3dJxqKdwrLWityw2/Nr
Jm+SqJm3jlqjCLXZ9MaesbDPuSFNs6/UydORG2+80/l7wj5SAPVWkttplfou
s7tgWq/xlKMuVSH+lIXR+ebzjz3ArCOxatKxvb/mOEMtBn4an4XPJ8tHWin8
4xQUZKs0B744m38UBpiFErUhyxc/+eQrqJhKil9oXiFZgJ23EFVve/ToUaTv
74g66kpiMMUlMmw5RMCcoU9T5OYXX3j7iRkzZuJT0tQKorgUt6DmmmN849Xp
W/2tnGAFIRylaTjCH/sUy0p7dg8lMfKa9Oa0OGzBbbMIeZBhkFV4p8yebAuz
ptSLlmZT1FoB5V/+/neDtK/xLeIkpjSwY9idgKrsPkK8siBEU2JtlKHzGqqL
xG4gioMsY4a2Cmp3+CzCUJLQa6+02ypdW6E0RnZDK2SMm6oK4dvE1hdC8mkz
Z25qTHLz9T916nRJkuQcJQJrWD9gPp2b0QNSILBSS2P9IfmO1goFaH6tHjs6
NvK0mE5GGbs2RYGLsiopo92gDfY52DCkOGPc5CimTXkPnZn3Bg16+m8vuujS
JGlDJYOizlV9+vQZP2rUKLwVSRRYa07JIAhXHyapTNmza4xKBksVGu3dSSUT
1OlREv11A/iFyIBYWkjX9NSEfigjCLUmd5GGWyezBKkYNKKlRujDoeOrxoxe
5zpOrYLUgZQf83EwRWyx0mwSUqvsvvPOIdrX+BaF7qYO9cK4Jz4JCTl4Acg5
pSqUtsqAWyukzMejqE7sUaMpFCiF5C6lIo6eQgnarUxXKDCnJO1eog+ZumTE
4kW77/qcsbrikNA777n7ycaENl+fvO6625OE9uKpYoacqzfuzR0SLyOY3I5y
MSQT46a1A5Ym4/6NA+p+GCjI4JG7mOVkn8vWSmvlypvZGgK9sookrw/UW3Ai
uWrqjbeeeXrEyesbkzHQG8UPzp07FwXr/tBzkZvcSFvCAnOyWinKYnujzWup
LILlM7bz5doaluKzZ40NiznPDJbEhDRJrqGNAm3OdwiRZiaSiptuW5bw2A1K
8hjThwMfGbHn5pt/5emRlZFnlMypoemk4RWQlAmJdY89Vi3XKEVBnMBr2icn
mwnqJ7RaFYYF0kZJYqFCWtYqaaUFcVWvVm3mmRMSPmuT3XBGGAhqWeS4RB8+
lYiEIzzKOyqbieCK+Np/uKLXDb4UASDw0k0s/Vy9GQ42yGXxcbe/oof71MHy
EWBk3pRa2yJFqrlVAGWR6eXOIHBdgAHyTg0TCBXZXShXmFoaS5QUO+R1QtAP
wCwur+DjA+fMebvB0badr0NKYJX8fadOnVodP27ejsUl5x88eNA5dDC3E2tC
cljb6qqFOaYccuzME/tbPJ8XM1LgaF9Tpq2NcnMytAChhijiW9MYqclQJjAx
ZSNjT6tLYpXKJKvZVxa8s9vUQVsHo3j6Sy9V/X23bj2McqyI+xOuKjfL/Uuz
yWkXapUCXjOnT/tcu8WJLeqqZH0aOxLsmu1ttCKmUYZeSRsw6fb++LEbhEaa
ya3tWJ6hYeDWrxg/fqOvYdK6kKphTGK/TBk78QSnUib4fEj6aTNnbIRl6uja
M/76X9q3vyBJdnb71s2bDsPDNp/OVVr2NnmUqjmKV7BtaWX2kPkIVh1cx8pt
p2eaWwQX7J/HZ7GCU5yu8uwuUM8EcRl2C5EnWdFaUKjg7QaAk12MeVQWE/if
27fvkCQwbRamtH+3YsUKrOiaFjmdWIhnEoVOsWCxs0uiuWvwwBxhnLLx9hHy
t0Y/XxmYpVmZtn4O33Q7ePDk7IjtBP5shwD8aps6UWiQNRShYU8xz0ulE/1F
tVnPCxKThNurVZw6dfq/RK64r3CgD8R1Y1uIiYmXX5pBWeodtyGyeo9XPPfx
6JHrvQhLuPG8m7yjuUj29NYcoVYZY28V40zqR7V6ieYqHbaPOhXRma2bbl+z
afylka5PwfipFRBhwTJHowVKYtrvv+WWe9586qk/Cl2ZGl/5xz/OakTzkpi3
UtR3jtKmtrVsmUKHiowxlwpmdzziFmprrkuGykG9ryz55LPAn+CyLKP9jBhL
UANdUMbfJsYmxNq0x7GufubpmY3oSmVD+JoIiVPWLpriasS8oQT7bXVUusv7
ULKeLCuGLSCrgE3zJkxC5fGq35pWqVah6KyMHgTvYw+WV8XHbbhdEeAtmJPt
PGIjhAnb1gS1WBmKdLrs1UlQ+mfDuGKrm7duOSJ91Oar5gos+wIDT7b87RIL
VpWrE2Ffgv1jvfs+Gj1qvQnRsi8oEJM1pNy6G+OU7eEqYg5KKPYChc5lCj84
r8DgiJz1YOf6oCQvjipQbKDmErOynCVi4uIdFPH2jrwQf489gBmNakmzrqhS
ebZtCH8l85JD+MQtS3Lw9wnAZ2WhundfUKjp7QUg5UrajFkZD0f2BSqJ3ycz
YFksHAIsG5FTD1QIhIjvwx4qklWiIASb8fBZAGdBzeRNJmZBUKEmU4I93pYF
sjMgK/igBRdOnrTJ9FvTohmCoGnAIm4QO2LJ4j2uLx38RdLsS1Azzb7AkUdZ
hClwZl8QaUCdmy8IAZTIDxTDYDsFI+jnKwJNWgV7xp4bwxDANxWPnFGDisqM
mSTYebMiFgmo0UmA8vnxNYE2+xIcGXCe0ODUmrFjNph3ahv7UiQoaSZh58pv
3QIgQMZdcyLhQ44i4cqM/C6BfNLNkviakC1DJIKSXD6LyTDpF8hafk8ksGhS
EuC8Dz6TbGLC9wEK9zmjhiIR7IBkx2sOSX2vekIdxgdIdlKQzVcGqpbdQYYK
Kt0gQgs+Z0hFgDqSf2jUDbzPZL7YF2gjsRlLYukR8jN+X3z27A/QNGgfiCHI
4CqLIqBggNJifrSKhWp+7eTNpkz3PGUoWlSIphtmKzxr4tbkfLBELkMwguXu
7EvEzUOINBqTnMIHU14UgebKsS+IY2A/M0PC1gqpE4KB4jhX8+hKjMd7sWR3
DaBzzic5E+hn3odsn6xOL1Xua5UuGLX+yjRyGtk1MQ6804VkjiISg+NgeF+w
rKUk1mGCnJ/FukkqTWxf8pg/oCefWLniq/bHj5/tmC4YgeplTBive2PG9K2I
YmJq0vyPDNkIEj0WyHnMBGgeC5YAOPYoCDNrLpW1dvJwW2HJYAJ84KMP97NH
8OgktULxgLgkvCrZ/2AojKhzFVHQxMOGHPPQ6VAwbl8FGvfBMREZEhK8kt1B
YRFoaySMyJdTnT0JCfjVLh4KIGAWBzCwEdi+lBBj6RxFhwwJv5e/zDVLanUx
afo65/gaRIIVKcF9+EUgJhIjDR+OTCCJu56xnlW51qg5zKyQsozmTB2U0hxm
HbPVWHpzTVOGbUheNCauue+1GTO+iGa8066S2n8WiiWjAqmZFDHXRJUmmoEd
iAhKE/g0eYNEzzObPj/7vgpnkmrPpmOuYExZQ7VXvzA71kGtNUEOkZHE0F39
a8ayfVyCyC2fMH4jLE24dtjwLX3vCXXPHf8aXmMM22IdrpinYXRqcE1voiL5
GkSKobRR24OjmqvfmrMzjX+suAxWnuZyQQwsSxbt4wWwArZN5EVsxtemWki7
P0OlGIMgq60mYAVPySwJTKdUWZJSCHKg30ZVp1DIW1+b6F7AW4SiOmIdbEY5
j0Z5hFdR42rspKaFTFRJhrqRSSX7fUYYYNYhgGLQndrzRkjtt3bt/pui2bll
SFXFGpdgGSGriV+jbporZLzPHQ3fxIh/1IzG9WepMxqy7dgsJr13uZQpphkU
a9QcMhnYZSfDwIJaNyniBDFkZ6h/gxkNtolJDCTauG3jhsN9UACd0LdwWsxu
Wj+CAco1CVElmoG+BqIzZjTxUJshbHKtCdWTeS2d4cJcWGcoO547pXYzqjea
kKralEkNhiPqQzOIbILN0Y+x6Zs7emUmQ8LEHOiYMpO54Ppfox94zaySjH6M
V5Q+B+UxctmIICeyXtN4Civ3HwftPxg7ZgMkQ9JfadhomfC2CEPiSDb3fcSz
2U05+jF9z9BvP9u589sEHRpx1KTA0uevgMuwxmA7owr/R3LZsCZDyYgvmy2q
MgzYPbD4zbaGzRwGfpFpg+n1109m5hqmU6NhWshJCetmD1cNvznGIwrucm9x
2K9xxBzu4KTqTeYdNvJagP013kUiHdU5LKQYZE8ZLUBTqfSJQSpEfSUd40W6
BfCs/XHPwukCGTrHr0QNjHHaS5WmvQC4FMdr1LtMuWaDPYVrd+36FrEDKZDH
j+b0k8yQNdmTkeRAeA7GtkfSsJylSAefi+F5wwWGTVSQFERTsn1w+uo5kQOU
wiKbezkM+i7ZpJD3MCwIDYpw39VQ7qlAN+VB7B0iYvjoEUN6AsxAHExW4nyl
5xlWk7LdcQHYQORKtv7Aj0clUeDlCvMyRA8W1XvVEzaZdTmkBMJcZkNq/DBs
wuxaDtm7+lAccojOOA+KG1NFb2VOMggTsiPBCqxUoTKZV4rXKr8Qtjx+c1Ei
HzyeYQ/zicBCjZds0lGIxVBIpGVtr1HIyPdh3kQdpPHC2ZdaJSuqZUoRdJC4
HgGqbMnVSFbwPe4jUWEySe5EqyDQQoa8BkPIVOTBfNf2AtROVCIy8My7E6s3
md0uyRpMn1LaXR630d9VGJC8yC3KOoMLFJLHJa/a4mv2ACb+iglVG3vv3i1J
06Cn7EEQgGcPoKhke57zY3DIprEJrIP3LqHpsA5xThyMY478SGTYF0+auEkS
kJxKIKLJDHawZ2fGVDJFkRi4frJlGfui7dyjVS0gYySlKs3FP98HN/XDMaPW
mxXh2lyhLe3j/IFYtWSwCD6AR1JBKfh3URoeaQdxyKw40q6xC5fs339y5XgW
kHdLx39N43C7yUkLycmGoFaZ14IcbXks5iKzHZQ2MhxbqLSRbm9L9iVyak8v
m1BVZ3LaFcr72C5IJxVevAbLRFZwaX1p01gSEogMjCtnA/pII1owSUqmjvfB
chYy8n3BBnyaJLDrmKhky+aKWLIkR5uPFYUINpGG3MKFziDjfZPcMkTvfW5z
al8SAvLwfWC7KJ+SuH9J1axNxsj8rahiZS1hCBNE9udKkQQoMERSuTIZzZ/r
VhRqdcOUBKBHCptcxUakLKQiopvSVU0SiBYoGjEavczcTxIKM9hhm/chy2+O
p8EnLQWXIQnIkUnaPq6zPAvLzcwsmv3Da8G6RfYFlROyBxb7EihCSoLzYdHE
BO7f41AKjn0dnteZQ/GEK/ogWjB5JhfIwBISknnnu8s2yhmSgEiGnCjE+4Ii
HPYFLowUaXhbmIoC9ZaGylzB9+EeiY5fE0uH9IWwQQ5bttYiwqEEZbrNkATY
ZrIolu/D3Ck2W2wY2K7K2dqUgSu//PKY1PpqRe+UASQYuiU6CTtdyq+1nbK1
Q8c6xKL+/vixG83uyNoANa3M/oFJUEfG7r5QaTdDBjB5S20yMYsaDtnmwZPH
JGhwMFBkdAQLSiCPQr8LlT4nZMDbaUjwifX4rnknA6hrcLs1kq8mt5dYaArx
laG3iu8LyVjkOTzB/snsQTCnsAfBuq5usYQkCQpLSJaDV8YENU5QE8hHwkc8
YldGZ07fCZmhbahbxApA8+li+4bkbuE5zyAOwEWwYplD0gvSwI8yCtnBnPch
Li2TggZ+ust5/9xzAgSx7odXZ5hgFco1gh8miVRSXhiDtThAhsE+OYSctBQv
8Il5U2q2XOxO29HiI4R8YDzxPtTSyEk9zYA8TFZXyMWVODnMYE7V4hd/R4Cz
fDQVSiKkHAXskTs/56qmVukKQ9P2wX3EKJSH+NJs45rIMRKak6dmAy9XSsn7
oOmF3pUxHqUdDfN831v+DljEchAMycA87pG6tmZgvkZpH7Zi8hgrDfNBnwrx
uJPvq1EwHxxmwNKoOdG4kxsaaJjXZjk895bbo4jvg+sgM1+Gwoe8JEujILeJ
DQpCZ7YyvS+ohpPZVSsOTKAf5qxzUh36Ib7esVG5D1Z/nYu8MstRcy4Mcgvu
a2gQxEzaxI2J0mou6NkyOi5i32Bi6ds6Hjlyii1jXpDSsugXVokJBihvtOd3
GBtV4r8U3wnRHHm5q4v0jibBfqY+xKcqbtCiyZM2SdnRj4Q4XBrZUKCg3EeI
BxtJs/1fbtly5Nn3aHhdnA5xON6yCUKnWGQy1zdrar0Qi6WIG98XVAhnQByZ
C/Gi+Sym1cRGP+H2bRkQx3QigcBOyn0JiPts5JKjHI6bQjkHWFkVKXuYeXab
3MI9n356wHXj5QUL9piMICGGGIeU1LYM3AXURH0wdvR6yA+GaiwLu6u1OfsI
74W5ifiSMR0zYA3NIhqMMIBWS57ihUBFMk0RbJfC+4LyxWbAWts2WFnNZ2z9
pOnq9v7z2x8V3XORE3y+L3BrCWvYCTLDkPWgp/Tf08gCba/MObk/xxv+MkK+
L6gOzYB1sPN1p3hswgO2EWyzo5VckwZ5P33U+cfAOm8K5MeO3mAgHXWF21uP
iagbKa4646yzfhJe4oAgjGuscOIXUQiJVth287Awl0b+8XsTJ9TBurDQzcP1
RYUrYAujiO8Hh8UhI2qRwpENnrkptbZ9ZlDbSdQgCyb7dPA+KBXZ2IzSmzyX
JlUZE2WYU2UbKN4XnOvC9qG0ZV7V9hnk+5B2lY2jiVpERaWOn5zVNsANlpMQ
KfjcIdyfxMSXFkyevMl/X7AbcSMbW9viWtvrBuEXsZ01Fcz70JKcQ+aNSOLd
xCoj+2ZzW6cGuG86cJMMmQdi5kVxxD3gs8HhOQQX4Cm7FGaAS6uB7u9vusT7
kJ4Vp5PgavZMTzCgrkmiUrwv2E1RS5D5JbyJ9wUHOxNcECjJYpMVmJUFwNqB
Q2RtsMAkHwNYauu990mhdnMXEHaOAZzcwR2KSARc21uA98GBFluS7wumtATM
sCzCxaPvVNhdrnSdEMAsJbMNYRYcAXB1zFI5EI4wQ5BJinS0k0bK4mdly8hi
hRT2ffmkDvPiY0IlNt0uUiHv1E7e7L8ymHAyVr7BfJaJmO8LzqImwhAAFBez
i6I82C4CipKNqFSkklwN3DRy1a17bwphAVn5LNCQNHwCNLEvMJjCUxSsfyC0
6aJogwTCsDDSaeMWIiy4T3v2KkUoyRZ0R0xjrZSAbcCTlJC3dh8VWfK0sFTb
LuPEkcBz1ezeopicorT4PoxP4tuXKRAlK4JZkv0b788zZC3gKWuteB/uEbh4
hy7JteYuANVyrZrSZ1/uc2W73n19167df5s7F907WkoWXiVg5pObUIG7IGln
Q27fYJuqPBFcI7iwEkt8Nu30QW1gBFc7/xBW3qec6dVicGmggS6Q8EmGDguM
cL4P45NlmBnggip+YdGi3anj1lapeqBOnCmWTx6H6htgGqBguib1kVZ/hrJT
OX+b982bUrtZlpzwfcEeDQlA+c3fbv5VT1l/dt68tX9u1ap1i05Zd1tw+EfE
2BNiw8gvIRgcCX2JAiONZNwpJzkzwrCAQWAdnQImU9koziGvKEa52JtsNsjv
e4hKNKsiTzvNDsOStfMa8piiC1RJkcJ5bZ9Z3hfMvBfacSdZteHhh0eptaIZ
aAwWLxfFLJVIFfsUJME1W5XvC/bhJRq5DNGE010XLBpTz2TvtXv3oU8GDPhj
i89k90qixM8lKjFMKWsiKgPvxcKj0emuxcyVcOeopJ6DdQ0rm2CESSIhrgQY
4XHKhncEI8wuiW1ooPC2c5H4jXZf95hREvokGJWzicM8tQaQVjo1irgppLXC
SpLM+d8lJeVgTnPdBdubkgDeDbbmHpaP2+Y7cV4sDBAkwZmxC470TIAOTrnD
owVd2YvKebHuQHaQgBGcxmey61iD5SUZdWIN0UMJxF6lcIFYg9vV3Qt9u2UP
lTrxwVhYA8QanED/aR9rwc4sxFpwckD68v6SYLOIBrvzMOJClyqPaNfIVESx
ZbOEhvgoeTIVk70vKZhYIUw2Xl74c9u25wn53eC0ACPPFF5ZNX6jTDrRL3bs
uCEyONlacg6BSYPWtSRp6xBCiK+4pffUW2mnrzsI4f+0I9hz8T40bhPmaL5M
nLIeZmgzEASbU7KS0S9UEYIY3Ec2iSDvsPZ8EFdoEIczOECdSEsKoHktQYpQ
jRhF0S8sfHxuIVpg8Ps1+4PfX7kv6qFTAQ+uWVMvE1WDWaNotnijHkoS+//k
8yUgtkG5rcc3YVqJj3SLOy9ec/SL9aUIAPAMErQitWTRr8ntMyyjrHcXyMAp
cdC2kGmTdm66Dxnt8PQM2yvowd3KNe0cUuIGtPPJDVMTWpe4WVrtbVrlemi5
Vwi2TUqoneDs82aAJ9i5LPqFLYeuZYAnMLgtGwt+JkMMbPIwqBaPfo0ZZs2V
RqfVr3r2mZm5lHVgztCmfkIMwe+esYa4i+KgVe/vc6NCONyEd5sBm8b2emXa
4eb4G0YnouNywrm2VkSroyBWZk+fHmf9NayQgdM8w1VOKyVQXozsGRcFA9VN
OIdACY5dTADFmU1+OygDc34/dn58A/m6ypiLUubkAKnZN+koyaO+2gWVIcnc
98LZ5YjRYtK22CgJzo2nxolXNDaCh3PsLZvzbm9bBxMio42n5WAKmqKni5Vh
JJDhc4/ISDtdHN9CDJ1VaY4Zz1gBGGxddY+9BnmSuGg6MvLLJ4wXNQGOMOmJ
WKSLJyKxZohOUATBqgQoguJEggI0dRoFp/6ZdIdtJ790QqylIH8aHpgNC2qG
rAjnMceipgH4hTlBPMA0AF8+HDN6A0xuO0EV/OPaJT+TAgaYPphHCQbUGLwU
CUZkkO3DhN0upnLlyZNnsMevs98D3BIE3DhFlm/j0+/tm5MHenMBqR+0wQnR
RQBHrhgHRMvLza1FnhkSBKoJBOFeE0CAqenyBx4Q4A66lWwYmXHTCYSgNjoB
hKAekECA0efqQMR2JBCcUkUXnl66dC+BEOhaAgEzzghXH0rJgxWALQvbIt5N
5mDaxzWz3y6nGf+c9B969uxtsJosZpVj7SSK+vr2hS5vx5dfu2vn0Y9HvbLe
aE4tIJbgvF+gea+9tqJqXHzoaIZ4I/4tKVRytZufAyBXaxSuwonAfaDFkonV
da3DnmLRBXPgrdMO4MS3yZiTnLTNLTf8bkNGzfxCFroyVjN/MeFdw2r+8XPf
2nXjF18czRD7u6NpJhJGa8w+bJsDxiXb4YBHzwLdkoDAw8p7E4zBJO9qMO9V
+JjBmGBG1p69QmEMZzf4y5hwjLiSK7NYwG+SIlwNqp1lmCtC1CVXosVdpsju
D8EGPugCy6bnTJ+6FTPG9JgfJkEJtWa8+J6KHiMznFb0mQEHUbyNBDMCCpEZ
0GqyDCzBDLts64ckQSXMkcGMgPAtZMbLC+bv2vTC858a5UaSPLzmg/odw4d9
YqLZbgmtf4KapXJpWizCYC52XkhUsHfz8yM+fRiF/q1jPVX3wvOfGc8mg/jB
aZskflDykCB+gHoSPzj7MkF8hYC4/bLgqEwz3XgF89LIfQrHe9lrmKUlHMkB
RrbJmYRIFld6fhpJXhIcJtVgj1aEE8ZpxrntMbVD3IOOl6e3KBYSfi+LSS+A
I+llO5+YlGZHRwlhNAQTiHDvEft4cF5s01QPEgcZ+2IEC29I/yA0TvpjnpWo
5YP2Df45O+LYekSFY1uTQlRcfyIWZkn09VAkzFIgH2AxWz9g54HEhrfuCCZz
WIZzee+LwZXYqV0lVrDxJ59FKYzUefSKiSphNx56lHagiHPtSDfn2aXRrTam
G5IfEqDLoFugwbJFO9i+M0E3jNst8bQHMqpLQTW6BYUOpBs4LqY46RZUDPBw
rrQDEtIcH1TpNkG4YOlkD2UoJFyNDrggS0TCuaimRjisNnF1oyRckEAyhPN1
YtAXjdTURjBKpTDXkivrMIOSpJvg5FChFpp7IlY8EtnroWDnEQV6VGTBBp6P
KMKWIJW/FTwHHuS+MzCmES1QDSQaUvQiw4/rjNai4o/Za3A+JVOTgZ2ksipS
cDJQaaZVSBC/RpWDCmImGfvjgGgS2+tjrwUZFhIk2FD1caVL5KVGDWQ4ZJYh
NQKzI0UFkRpQN5IgGag8nqDGxAlxOJLUCJyYDGoEqypJDeRd5JQ9UiMoFLLU
KEXMRyLzfLdETikl8HFlaXi6lKThIihuHqgIFCnhzpGF2net9VVQyP06cjkn
HvClZbLg+BGQkLArx++2ffXHj3lf6mQ5/gtcuvuJGG1iyTDTFOztz0GBZjIV
EFnIXEjVzEBlNInBY4ZwEmzL9Vr3WbhwYf3111+P337z58/H1Z7bt2/HbOEc
0B333vNMUPSQsa1Y0DzJlfeV2eUKj0guzPySkOO7L3VVlEOU5+j6IwwgC2tt
m/nkuCxcypK+dHKrMKIqKOltBmF918k6I61fHTZs2PThw4e7R5BiGRvNI8jJ
w4z5H+ec07Hs9Omzvv+o5uS1g6aJ3GA27KnIDgkL00DWOvLdUOVm54khynMk
bLCYpq8+Lq0GYfCKFbvETvDIil3t2jmDNUNtObI2qs8qQsvcMg++3/4bb7zN
zUnO94vzg946bhldP2W0qZQzB3W5zbYs2aQALQOPsGp/6VKefaXfhKDms46c
Pn2hK2sz5sSgmDhSy9sS4sBT+6Bfvwede+pctYztEOFqyqlj/WI5kCkuHWCh
/UnlJCvDvPs0akG6ZXlQklrlWqq4qqpquuym48ErEBHCK1hSSApytUUOBdEu
gnpXkoLOL3PDdX5ZBgWDU0VIQZTMSLw+Q0RRVyzuJN8tVdsZIop0nZwK0oh6
Wtb0uWnTZsmCCY96gSCSesExtQnqmSXAdKsbUc85Z05pOu8sg3rBUqN+iuhm
UA8UkEUtfDeKk8ySMFJPDq/0qBfgsRH1tORhpGFWixHuUS+YHUg9SLSUvSeo
h1VFbjZnzUKgWblBoXPWqqMZpnN9/UHnrBmaGTPF2zhD2n9AkQctpm9NkLj2
lJQz9wzlO954vRHmahtRLdcqOS2keZmuLSqJgAEkW5DiSpDNn/BYsfvInDlz
zvbo0cO0ztNa4bCtv+eeh7b+7nf3wmFL33W5uCyyv6rdhiz97bXZ06dtyTvu
tIBwhjBD04U1GG0fpftWFMo0f1OYmdOPwCXxgiXPJJ47VxTC5d5ytwjY962P
HQuOu8MrxCLNoByCaqPfYSCClHth0aI90YRsLQ0GeIM9Eoc0Dblg0tOyO32V
vvOE0uR7YUlDXAcrr6kMqQN7xVXIDFAEKKM0FJOMVOeSEsGRUKSEq0/LooSP
IeSVxX/QKPGoHXVt4h3OpxocEzRt1OihWxjEUTdeAFbkWVPBt3wiUD704a70
S1OSE5gFcfTDgcIGSFbYB71+NDF4eYHd6CR536yZM7amjVjpP5wHWX+YUr/i
Dul7SCEDh/xrX9+TvUGPG7jTLUcdzA/MpQb7Q1krsETivHyHW2xL9i6eWF3X
gsFi3ZtYGimDRXgC5WIcLMxCMWw42GD/FA42iUMfy3il4IGDhYuFWII/WERR
jcnBd7hqysEJCHmDddvgIp3sFtw9pCAzpdrApXgfUujjZX86u617OFh/T2JZ
lzk0Fn7xSDlY5EylPoCDxTUTA2eXXJEMBwvNJaX5icEiFuZUDnuO7dOKgi1j
irzZIqif5xNBWIvBB7Gb8MkmLMrhQf+pa9euSwcMGFDJIplGSyGYjoYdZla+
RT8gqylSIF2COnjSBTgT+59+D4TRAEPknHEzoEEkNUERfywcH0J+4okp6XJZ
fvFIrF+kClZbZmHf29adSo5PaUX4+E70WvSDSNUQLOR+0r43mFxYRxss07K0
KCB6shxbrPlCRXJgI0EZH8nhjp7CvOFm54dj5SICpJBDVig/Er9eVluRHIHR
Yee6Mjhp8wcNGoRc+d917ty57rbbbvvVmjVrXgxSNGV+pThidmbLmujn/k/W
7ccGEk8qLWgFxlY6bGzUIwppEmyfmaAJvGEHNTvGwvREeWUuITIiUKQhICOQ
0CBCmty8du3aJ2bNmoVPPlzCHGrBL32WcEvemxo1agQ2AKkxlUdLuGDbY7HE
STA7QQ1vPxoXZYWGlmSpUyA2VSuzEi3NxZMm1skK1+5OA3lVNXa+KZ357LPP
Qh58IiSSnmV+Na8cAB79uHKFJ5VxkxbLvSK2JC3cjxact6vnZb827FfiouF2
gGWwHYMd04g1dA5BEdoaV+/Z863kLDUPiXToVF9f/0pVVZVPB/EwWc/gl6fK
dhw5nvPwlEIELuEAHyQnaDmfNyZ39ANEYaJ+XHk8QQSUAYcVIOc1FR9WF7w1
2BI/SX5FP61Onvwe+39zZsPeR6LoLoq1k+xUZBVtRXA8e0O6W+l74Ql6wZWR
PJihVxF0nPWRK7TxaWNiqs+kGqIft8W4hyxJdJCobnuG9yNouFSNzb2cmxUb
TluvVRZR55ORL39ucgzRz/RIN92yZfNhYt7kcwStpGiwZx+nROUA7kZlkLGp
/0WSmmKeeegD8mQpiqVrm+QQU5ehRZ/dgUerxo3dyKzIY++v2Cdrt0lQt0wc
uHbyZZxoE7PhfvP+siOYjR+OGbXBOm1UiNgIasvzIz45/+jR79wAUMAo+6c9
6VTZeDPlGkhx8Ldv2HBo4AerLT25Egydl6m8v3SHgYhgFVQDg7vsCWaSbc8N
W+ePcZC8gIG0tGUwmjc6OWaHlIU8GQsBbjX15RxN50OHTo538jZKGi7Kblhb
yjVC73yj9QFYkKFGFNjzwCSyPc+bPL33w84HluvIROf1hjWSpfS8OKhe17Kj
k2Lui7PwVMxXM2vi/6fttXcnTqjr4LKjye6GrWmHE/jdTAQKebtfXu0lMf9R
edkPyluKlLcYRplH2TwnPC3g5pf2okz6vyrtfq88Xqw//kow3iDQ86/pIwru
G2df8Rf81195xvvC/m3++fjf8ULuJ/8PTazt1Q==\
\>"]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the pertubation problem", "Section"],

Cell[CellGroupData[{

Cell["2D Navier-Stokes with scaling", "Subsection"],

Cell[TextData[{
 StyleBox["We have taken u = ", "Text"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", "\[Psi]"}], " ", "and", " ", 
     "v"}], " ", "=", " ", 
    RowBox[{"-", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", "\[Psi]"}]}]}], 
   TraditionalForm]]],
 " (definition used in fluid mechanics, opposite to the convention in GFD)"
}], "Text",
 CellChangeTimes->{{3.4056784807764606`*^9, 3.405678508854782*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Epsilon]", "2"], 
     RowBox[{
      SubscriptBox["\[PartialD]", "T"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], "-", " ", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "+", "\n", 
    "      ", 
    RowBox[{"\[Epsilon]", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "-", " ", 
    RowBox[{"DS", "[", 
     RowBox[{"\[Psi]", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "+", " ", 
    RowBox[{"DS", "[", 
     RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}]}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expansion", "Subsection"],

Cell["\<\
The streamfunction is expanded up to the fourth order in \[Epsilon]\
\>", "Text",
 CellChangeTimes->{{3.405678519006564*^9, 3.4056785401302223`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Psi]", "[", 
   RowBox[{"T_", ",", "X_", ",", "y_"}], "]"}], " ", ":=", "  ", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "+", " ", 
   RowBox[{"\[Psi]0", "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"\[Psi]1", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], " ", 
    RowBox[{"\[Psi]2", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "3"], " ", 
    RowBox[{"\[Psi]3", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "4"], " ", 
    RowBox[{"\[Psi]4", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS2", " ", "=", " ", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{"NS", ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], 
     ",", "\[Epsilon]"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 0", "Section"],

Cell["\<\
Extract order 0 terms from the general expansion and perform algebraic \
simplication.
Fairly lengthy expression anyway.\
\>", "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.4056799005414543`*^9, 3.405679948493458*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a0", " ", "=", " ", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"A", ">", "0"}], " ", "&&", "  ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", ">", " ", "0"}]}], 
    ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"NS2", ",", "\[Epsilon]", ",", "0"}], "]"}], " ", "]"}]}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "C", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox["A", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}], "+", 
    RowBox[{"12", " ", 
     SuperscriptBox["A", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    FractionBox[
     RowBox[{"8", " ", 
      SuperscriptBox["A", "2"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]], "-", 
    FractionBox[
     RowBox[{"8", " ", 
      SuperscriptBox["A", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]], "+", 
    FractionBox[
     RowBox[{"4", " ", 
      SuperscriptBox["A", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
      RowBox[{"3", "/", "2"}]]], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["A", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", " ", 
       SuperscriptBox["A", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "\[Mu]", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
            RowBox[{"5", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"2", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
     "/", 
     RowBox[{"(", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "A"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"A", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "3"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
         RowBox[{"A", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"A", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "3"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["A", "2"], " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "A", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], 
        ")"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A", " ", "\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
          RowBox[{"A", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"A", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "3"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], ")"}], 
     "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["A", "2"], " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{"2", " ", "A", " ", "\[Mu]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], ")"}], 
      
      RowBox[{"3", "/", "2"}]]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "A"}], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["A", "2"], " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "A", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}], "2"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "1"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"A", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "3"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"A", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "3"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
            RowBox[{"3", " ", "A", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "-", 
            RowBox[{"A", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", 
               TagBox[
                RowBox[{"(", "3", ")"}],
                Derivative],
               MultilineFunction->None], "[", "y", "]"}]}], "-", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "4"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}]}], ")"}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"\[Sqrt]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["A", "2"], " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "A", " ", "\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}], "2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Psi]0", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"0", ",", "0", ",", "2"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], 
        ")"}]}], ")"}]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"\[Sqrt]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["A", "2"], " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{"2", " ", "A", " ", "\[Mu]", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Psi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Psi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X", ",", "y"}], "]"}], "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Psi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}], "2"]}], 
       ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
       RowBox[{"3", " ", "A", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "-", 
       RowBox[{"A", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["\[Psi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "0", ",", "4"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.405680437302593*^9, 3.405686782110867*^9, 
  3.405702863564118*^9, 3.405705927313441*^9, 3.440940666341217*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell["\<\
The 0 th order solution satisfies a0 = 0 as soon as it does not depend on the \
fast variable y \
\>", "Text",
 CellChangeTimes->{{3.4056787688339157`*^9, 3.4056788439856663`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule0", "=", " ", 
  RowBox[{"\[Psi]0", " ", "\[Rule]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[CurlyPhi]0", "[", 
      RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Psi]0", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[CurlyPhi]0", "[", 
     RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.405680437709983*^9, 3.40568678273033*^9, 
  3.405702864034481*^9, 3.40570592823939*^9, 3.4409406667746763`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification", "Subsection",
 CellChangeTimes->{{3.4056812924802628`*^9, 3.405681294988698*^9}}],

Cell["\<\
Check that \[CurlyPhi]0[X, T] satisfies the 0 th order solution\
\>", "Text",
 CellChangeTimes->{{3.405678887077858*^9, 3.405678911528989*^9}, {
  3.405678944352785*^9, 3.40567896841066*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", ">", "0"}], "  ", "&&", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], ">", "0"}]}], "}"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"a0", "  ", "/.", " ", 
     RowBox[{"{", "Rule0", "}"}]}], "]"}]}], " ", "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4056804405524597`*^9, 3.405686785513888*^9, 
  3.405702870471019*^9, 3.405705933507183*^9, 3.4409406695945463`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Useful rules for simplifications", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rulea", "=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "2"], " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox["A", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], "n_"], 
   "\[Rule]", 
   RowBox[{
    SuperscriptBox["A", 
     RowBox[{"2", " ", "n"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     "n"]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["A", "2"], " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["A", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], "n_"], 
  "\[Rule]", 
  RowBox[{
   SuperscriptBox["A", 
    RowBox[{"2", " ", "n"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
    "n"]}]}]], "Output",
 CellChangeTimes->{3.4056804409028177`*^9, 3.405686741897224*^9, 
  3.405702769751576*^9, 3.405702870934696*^9, 3.405705842326382*^9, 
  3.405705934446885*^9, 3.4409406274535418`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Improve", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Together", "[", "#1", "]"}], ",", 
     RowBox[{"A", ">", "0"}], ",", 
     RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Together", "[", "#1", "]"}], ",", 
    RowBox[{"A", ">", "0"}], ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], "&"}]], "Output",
 CellChangeTimes->{3.40568044119874*^9, 3.405686742026483*^9, 
  3.405702770031386*^9, 3.405705842353067*^9, 3.405705935121743*^9, 
  3.440940627541308*^9}]
}, Open  ]],

Cell["Periodicity in space", "Text",
 CellChangeTimes->{{3.405679044282816*^9, 3.4056790705350523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solva", "[", "expr_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"expr", " ", "/.", " ", 
       RowBox[{"y", " ", "\[Rule]", " ", 
        RowBox[{"2", " ", "\[Pi]"}]}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{"expr", " ", "/.", " ", 
       RowBox[{"y", " ", "\[Rule]", "0"}]}], ")"}]}], ")"}], " ", "/.", " ", 
   RowBox[{
    RowBox[{"g___", "[", 
     RowBox[{"2", " ", "\[Pi]"}], "]"}], "\[Rule]", 
    RowBox[{"g", "[", "0", "]"}]}]}]}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 1", "Section"],

Cell[TextData[{
 "Extract order 1 terms from the general expansion, use formal solution to \
order 0 equation and perform algebraic simplication.\nNeed to be put under \
the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]1", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", " ", "=", " ", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"A", ">", "0"}], "  ", "&&", "  ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", ">", " ", "0"}]}], 
    ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"Coefficient", "[", 
        RowBox[{"NS2", ",", "\[Epsilon]", ",", "1"}], "]"}], "]"}], " ", "/.",
       " ", "Rule0"}], " ", "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"A", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "C", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "8"], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
       RowBox[{"C", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "7"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "3"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"C", " ", "\[Mu]", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"6", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                RowBox[{"Cos", "[", 
                 RowBox[{"3", " ", 
                  RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
              
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"5", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}]}], ")"}], 
              " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
             RowBox[{"10", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "3"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", "C", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", 
                TagBox[
                 RowBox[{"(", "3", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "y", "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
             RowBox[{"\[Mu]", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "3"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "3"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{
        FractionBox["1", "4"], " ", "C", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "13"}], "+", 
                RowBox[{"Cos", "[", 
                 RowBox[{"4", " ", 
                  RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
              
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", 
                TagBox[
                 RowBox[{"(", "3", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "y", "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Mu]", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "9"}], "+", 
                   RowBox[{"11", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}]}], ")"}], 
                 " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                RowBox[{"8", " ", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
              
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "3"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ", 
           RowBox[{
            SuperscriptBox["\[CurlyPhi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X"}], "]"}]}], "+", 
          RowBox[{"C", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Mu]", " ", 
                 RowBox[{"(", 
                  RowBox[{"3", "-", 
                   RowBox[{"7", " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}]}], ")"}]}],
                 "+", 
                RowBox[{"6", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
              
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "4"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[CurlyPhi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X"}], "]"}]}], "+", 
          RowBox[{"C", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Mu]", " ", 
                 RowBox[{"(", 
                  RowBox[{"3", "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"4", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], 
                "-", 
                RowBox[{"15", " ", 
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
              
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
             RowBox[{"5", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "4"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "C", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]1", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SqrtBox[
               RowBox[{
                RowBox[{"\[Mu]", " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"Cos", "[", 
                   RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
                 SuperscriptBox[
                  RowBox[{
                   SuperscriptBox["\[Theta]", "\[Prime]",
                    MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ",
               
              RowBox[{
               SuperscriptBox["\[CurlyPhi]0", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X"}], "]"}]}], "+", 
             RowBox[{"3", " ", "C", " ", "\[Mu]", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}], "+", 
          RowBox[{"C", " ", "\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", 
                TagBox[
                 RowBox[{"(", "3", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "y", "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
             RowBox[{
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "4"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "-", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[CurlyPhi]0", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X"}], "]"}]}], "+", 
          RowBox[{"C", " ", "\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox[
                RowBox[{"Cos", "[", 
                 RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", 
                TagBox[
                 RowBox[{"(", "3", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "y", "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "1"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Mu]", " ", 
                 SuperscriptBox[
                  RowBox[{"Sin", "[", 
                   RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{"Cos", "[", 
                    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"3", " ", 
                    RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], 
                 " ", 
                 RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
              
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Psi]1", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"0", ",", "0", ",", "4"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], ")"}], "/", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
    RowBox[{"5", "/", "2"}]]}]}]], "Output",
 CellChangeTimes->{3.405680469323229*^9, 3.40568681210163*^9, 
  3.405702935985776*^9, 3.405706173972464*^9, 3.440940696888153*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Extraction of the linear operator and verification", "Subsection"],

Cell["First derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680267654934*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"A", " ", "C", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "7"]}], "-", 
      RowBox[{"12", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "13"}], "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"4", " ", "\[Mu]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Mu]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"3", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"4", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"5", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405680475064075*^9, 3.405686818017201*^9, 
  3.405702947644118*^9, 3.405706187599757*^9, 3.440940702480812*^9}]
}, Closed]],

Cell["Second derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680284810182*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"A", " ", "C", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "8"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
            RowBox[{"Cos", "[", 
             RowBox[{"3", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"4", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], "-", 
         RowBox[{"15", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", 
            RowBox[{"7", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}]}], ")"}]}], "-",
          
         RowBox[{"6", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"10", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"5", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405680481735201*^9, 3.405686824150296*^9, 
  3.405702959741571*^9, 3.405706201606166*^9, 3.440940708570601*^9}]
}, Closed]],

Cell["Third derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680267654934*^9}, {
  3.405680300316112*^9, 3.4056803028255*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F3", "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", "]"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"A", " ", "C", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"12", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "-", 
      RowBox[{"17", " ", "\[Mu]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
      RowBox[{"7", " ", "\[Mu]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"3", " ", 
         RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
      RowBox[{"16", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"]}], "+", 
      RowBox[{"24", " ", "\[Mu]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405680482456992*^9, 3.405686824898526*^9, 
  3.405702961055523*^9, 3.405706202731677*^9, 3.440940709497376*^9}]
}, Closed]],

Cell["Fourth derivative of \[Psi]1 in y", "Text",
 CellChangeTimes->{{3.4056802226061697`*^9, 3.405680267654934*^9}, {
  3.405680306086762*^9, 3.405680308433175*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F4", "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"A", " ", "C", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
  SqrtBox[
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]]], "Output",
 CellChangeTimes->{3.40568048286045*^9, 3.405686825095542*^9, 
  3.4057029616301*^9, 3.405706203451018*^9, 3.4409407100880527`*^9}]
}, Closed]],

Cell["\<\
Complete form of \[ScriptCapitalL] and verification against the terms \
extracted from a1\
\>", "Text",
 CellChangeTimes->{{3.405680327200042*^9, 3.405680367142193*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalL]", "[", "f_", "]"}], ":=", 
  RowBox[{
   RowBox[{"A", " ", "C", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"y", ",", "y"}]], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        SqrtBox[
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], "f"}]}], "  ", ")"}]}]}], " ", "+", 
   RowBox[{"A", " ", "C", "  ", "\[Mu]", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"y", ",", "y"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", 
           RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}]], 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "f"}]}], ")"}]}]}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"f", "[", "y", "]"}], "]"}], " ", "-", "  ", 
    RowBox[{"a1F1", "  ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "1", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"a1F2", "  ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "2", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{"a1F3", "   ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{"a1F4", " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}]}], ",", " ", 
   RowBox[{"Trig", "->", "True"}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405680483359929*^9, 3.405686825436984*^9, 
  3.405702962363421*^9, 3.405706205041713*^9, 3.440940710838992*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extraction of second member: a1a", "Subsection",
 CellChangeTimes->{{3.405745203832325*^9, 3.405745206527741*^9}}],

Cell["\<\
The second member contains only the first derivative in X of the Oth order \
solution\
\>", "Commentary",
 CellChangeTimes->{{3.405680924835505*^9, 3.405680976013473*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1a", "=", 
  RowBox[{"-", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
  RowBox[{"A", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4056811907123632`*^9, 3.405686825639031*^9, 
  3.40570296285511*^9, 3.405706205562864*^9, 3.440940711187598*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reconstruction of the first order equation ", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "We", " ", "check", " ", "here", " ", "that", " ", "the", " ", "first", " ",
    "order", " ", "equation", " ", "is", " ", 
   RowBox[{"\[ScriptCapitalL]", "[", 
    RowBox[{"\[Psi]1", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}], "=", " ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
     RowBox[{"A", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}]}]], "Commentary",
 CellChangeTimes->{{3.405680993611363*^9, 3.405680997989916*^9}, {
  3.405681035330802*^9, 3.405681097427763*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a1N", "=", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]1", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "-", " ", 
    RowBox[{"a1a", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a1N", " ", "-", " ", "a1"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405681196602668*^9, 3.405686826350112*^9, 
  3.405702963578828*^9, 3.405706207010185*^9, 3.4409407122448*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solvability condition", "Subsection"],

Cell["\<\
The solvability condition is that the integral in y from 0 to 2\[Pi] of the \
second member vanishes. It is obviously satisfied with the second member of \
the first order equation which is proportional to the second derivative of \
Sin[\[Theta][y]] , as checked here\
\>", "Commentary",
 CellChangeTimes->{{3.40568122874508*^9, 3.405681235935019*^9}, {
  3.40568130878643*^9, 3.405681371971428*^9}, {3.405706217329728*^9, 
  3.405706234207999*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a1a", "+", 
   RowBox[{"A", " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405681201315318*^9, 3.40568682657369*^9, 
  3.405702964009238*^9, 3.405706207093014*^9, 3.4409407125585546`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell["\<\
This solution is meant to replace \[Psi]1 in further formal steps of the \
perturbative expansion\
\>", "Commentary",
 CellChangeTimes->{{3.405682181618347*^9, 3.405682241109109*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule1", " ", "=", 
  RowBox[{"\[Psi]1", " ", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"f1", "[", "#3", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"#1", ",", "#2"}], "]"}]}], " ", "&"}], ")"}]}]}]], "Input",
 CellChangeTimes->{3.44094062693674*^9}],

Cell[BoxData[
 RowBox[{"\[Psi]1", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "#3", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"#1", ",", "#2"}], "]"}]}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.405685988576124*^9, 3.405686826795513*^9, 
  3.405702964250146*^9, 3.405706207409132*^9, 3.4409407128629093`*^9}]
}, Open  ]],

Cell["Notice that f1 has SinI symmetry", "Commentary",
 CellChangeTimes->{{3.4056822559201202`*^9, 3.405682257900504*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical solution", "Subsection",
 CellChangeTimes->{{3.40568214744515*^9, 3.405682158019816*^9}}],

Cell["\<\
Numerical solution to f1, from the first order equation integrated twice in \
y, and with g1 = f1'\
\>", "Commentary",
 CellChangeTimes->{{3.4056816122258253`*^9, 3.405681633332135*^9}, {
  3.4056816843433733`*^9, 3.405681749314281*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Eqg1", "=", 
   RowBox[{"{", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], 
         RowBox[{"g1", "[", "y", "]"}]}]}], "  ", ")"}], " ", "+", "  ", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], 
          RowBox[{"2", " "}]], 
         RowBox[{"g1", "[", "y", "]"}]}], ")"}]}]}], "\[Equal]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "C"]}], 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}]}], "}"}], 
   " "}]}]], "Input",
 CellChangeTimes->{{3.4056815996983547`*^9, 3.4056816018673487`*^9}, {
  3.4056817667860727`*^9, 3.405681767066577*^9}, {3.405706246948409*^9, 
  3.40570624749131*^9}, {3.405706314575869*^9, 3.405706337819771*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "2"], " ", "\[Mu]", " ", 
     RowBox[{"g1", "[", "y", "]"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["g1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}]}], 
   "\[Equal]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}], "C"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.405681454709593*^9, 3.4056817684708776`*^9, 
  3.405686827019577*^9, 3.405702964678041*^9, 3.4057062488632*^9, 
  3.405706344083208*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["With Flow1", "Subsubsection",
 CellChangeTimes->{{3.405706360288899*^9, 3.405706365291543*^9}}],

Cell["No solution when \[Mu] == 0", "Commentary",
 CellChangeTimes->{{3.405682270906063*^9, 3.4056823076350822`*^9}, {
  3.4056823538003397`*^9, 3.405682354189416*^9}, {3.40568242018408*^9, 
  3.4056824220428467`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Eqg1", " ", "/.", " ", 
       RowBox[{"{", 
        RowBox[{"Flow1", ",", 
         RowBox[{"C", "\[Rule]", "1"}], ",", 
         RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "}"}]}], ",", 
      RowBox[{
       RowBox[{"g1", "[", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
    "]"}], ",", "g1", ",", "y"}], "]"}]], "Input",
 CellChangeTimes->{{3.405681773347843*^9, 3.405681773941864*^9}, {
   3.40568181377392*^9, 3.405681839055987*^9}, {3.405681869514463*^9, 
   3.405681873703433*^9}, {3.405681909005368*^9, 3.4056819326317368`*^9}, {
   3.40568196556674*^9, 3.4056819888316507`*^9}, 3.4056820216931334`*^9, {
   3.4056822989698257`*^9, 3.405682302285568*^9}, {3.405682359535001*^9, 
   3.405682361288138*^9}, {3.405706507788413*^9, 3.405706509774545*^9}}],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.405681991415235*^9, 3.405682022340774*^9, 
  3.405682364383728*^9, 3.4056868272169847`*^9, 3.405702965323932*^9, 
  3.405706277994282*^9, 3.405706511101094*^9}]
}, Open  ]],

Cell["Exact solution when \[Mu] == 1", "Commentary",
 CellChangeTimes->{{3.405682270906063*^9, 3.4056823076350822`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1A", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "1"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.405681773347843*^9, 3.405681773941864*^9}, {
   3.40568181377392*^9, 3.405681839055987*^9}, {3.405681869514463*^9, 
   3.405681873703433*^9}, {3.405681909005368*^9, 3.4056819326317368`*^9}, {
   3.40568196556674*^9, 3.4056819888316507`*^9}, 3.4056820216931334`*^9, {
   3.4056822989698257`*^9, 3.405682302285568*^9}, {3.405682540698832*^9, 
   3.405682549646378*^9}, {3.40568682429978*^9, 3.405686825979868*^9}, {
   3.405706514455022*^9, 3.405706516182363*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "y", "}"}], ",", 
      RowBox[{"Cos", "[", "y", "]"}]}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.405681991415235*^9, 3.405682022340774*^9, 
  3.405682551470401*^9, 3.4056868274570513`*^9, 3.405702965903803*^9, 
  3.405706297896535*^9, 3.405706521592774*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"Numerical", " ", "solutions", " ", "for", " ", "several", " ", 
  "values", " ", "of", " ", "\[Mu]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"When", " ", "\[Mu]"}], "\[Rule]", "0"}], ",", " ", 
  RowBox[{
   RowBox[{
   "the", " ", "second", " ", "derivative", " ", "of", " ", "f1", " ", 
    "tends", " ", "to", " ", "be", " ", "singular", " ", "in"}], " ", "+", 
   RowBox[{"-", 
    FractionBox["\[Pi]", "2"]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"When", " ", "\[Mu]"}], "\[Rule]", "\[Infinity]"}], ",", " ", 
  RowBox[{
  "the", " ", "second", " ", "derivative", " ", "of", " ", "f1", " ", "tends",
    " ", "to", " ", "be", " ", "singular", " ", "in", " ", "0"}], ",", 
  "\[Pi]"}]}], "Commentary",
 CellChangeTimes->{{3.40568232181746*^9, 3.405682323174533*^9}, {
  3.40568256853981*^9, 3.405682595845359*^9}, {3.4056855367856607`*^9, 
  3.405685583688298*^9}, {3.40568563791998*^9, 3.405685651364607*^9}, {
  3.405686856415606*^9, 3.4056868962700033`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"g1B", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "100."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1C", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.1"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1D", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.01"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1E", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "10."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1F", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.001"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405681773347843*^9, 3.405681773941864*^9}, {
   3.40568181377392*^9, 3.405681839055987*^9}, {3.405681869514463*^9, 
   3.405681873703433*^9}, {3.405681909005368*^9, 3.4056819326317368`*^9}, {
   3.40568196556674*^9, 3.405682016653285*^9}, 3.4056820887613773`*^9, {
   3.405682479836936*^9, 3.405682517784671*^9}, {3.405682554131682*^9, 
   3.405682555422155*^9}, {3.405682609625046*^9, 3.4056826300251503`*^9}, {
   3.405682892687722*^9, 3.405682920347066*^9}, {3.405684928580121*^9, 
   3.4056849689274282`*^9}, 3.405685191977766*^9, {3.405685493979383*^9, 
   3.405685496169139*^9}, {3.4056869948874702`*^9, 3.405686997075314*^9}, {
   3.405706560061238*^9, 3.405706581695346*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706583062284*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706583080649*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706583323489*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706583339161*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.40570658335434*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pC", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1C"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pA", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1A"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pB", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1B"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"pD", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1D"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pE", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1E"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pF", "=", 
    RowBox[{"Plot", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1F"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], ",", 
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], ";"}], 
  "\n", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pF", ",", "pD", ",", "pC"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"pA", ",", "pE", ",", "pB"}], "}"}]}], "}"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.405682679304923*^9, 3.405682756118494*^9}, 
   3.405682812014813*^9, {3.4056828831425953`*^9, 3.405682890096424*^9}, {
   3.405684977337996*^9, 3.4056851606579313`*^9}, {3.405685201488823*^9, 
   3.405685201925613*^9}, {3.405685319254837*^9, 3.405685323971859*^9}, 
   3.405685397510726*^9, {3.405685435043001*^9, 3.405685474542745*^9}, {
   3.405687010468215*^9, 3.405687016124189*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8lM8fAPDdfRzrZiukQihSFEWKzBS6CImShBRKRYmSlONbjhwhV4jk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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {193.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c81d8fB3DbvTYZkSKSQooiGs6pVCohWYlIRkX2pqzsUchIUjKShGRF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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {580.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c81d8fB3DbvfZWUmSkkJL0lXCOUEQiskqkUJKVnRINo8hoIJGyEhmR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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {967.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Xk0Vd8XAHBles88axKKlEppkKTOqYiiUKJUpsyJEhr4JkrIECpRoiiJ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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {193.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc4lu8XAHBK3iEpoZBNCiWRULlvo1JWiuyRrLIaVlIykojiqyHSUFLJ
lhGOkbKTREiZ7/s8RoQyUv2e31/P9fnjOfc5577OuW4pZ9/Drss4ODiUODk4
/v8Ncf2s8ltqAcq0Kvj46ly1HfYUXRMSWYBnnch097wewoKJbBX+BfBU2R0s
NH8ELa8zvOexbAHQ9UJO/vnjKEYW6J2D8yAS9zRs//xZlDz05FtuOuWfx+sN
FiLQq2Nn49zk5qFnI3O9+5//0KT9KvLDpjmI2R8x8pf3MWo8n/dBYcVPsCp1
paupFaEL8VPnW1fMAI9qfOdF8So0dGgNb/DqHzBtxc/duFCHnE5r3zcdmADa
2LKUX7wt6LlC4lM8SsLdSOLsKaN2VLu1il89bQQUvu4ynuPrQjgxz3CX2wB4
6n6TvXfzC+qrLOLLmuiB0Bot8TS9AdT1vdx41KUdiFuDy7wqhtFwY+s0z952
SAk18tvfOIymM/pvb5FrB2eupY3iXcNopSPX4KmRD9A41R9UPjWMdN8bBsy5
fgA3r5qRVzIjKDunJ43LvQ3W6HdZno0eQcyBqW972pthi9rOqdOGLCSXLKAQ
ltgMPqbcFvstWQibafi9OdwMQTb2iauPs1BAdSjd8GMTjBe9uX4hmIUGHq5S
sepoBEGZEYmyTBYqcVYKP9NZD+H6Rc/DlrGR67C77NOeNyCbb0Q6PWOjgHZ3
T8XUN/AycuDQYj4bRVe55+fYv4Hks8XpoeVs9DzVHZf014LKS38O4/ds9N3c
3a6BVQNxFS6GYzNsFFTnljQ2XQUG2Rd3LmkQ6GqBW69vYRXcT18w2KFDoLsP
3aRn/asgWddF8egBAgX/bnZa+AFw5tt2ZxNrAi33ar4j+rcCzvak9a0JIpCQ
cRPdSagMXE8FSubmEkhjc9Mtj+RS+Bl+8uGBYgLZrmiSPb2hFIRtlHe/qyDQ
g4pGHC5dAqblmoPejQTavLUx6PHWV/Br25YfzoMEMmI2cr/MK4L8vk9m6wgC
+bAakorUiqCHCFLMniBQflpD7lutQlBdrX4tfJ5Au/kaCGJfPoTZ6n+qWkki
h7H6gB8NeXCP58z7iDUkCntXz7VolAehE8ZN8kIkehtaL8lzJBfkrPRU+SVI
9KH4hr18Vg4IRlVYWMmQSOjUjXMa+dkQe0aadVGeRPf7r+fZVGaB8wfvCi9l
Eg3fud7i+eYFfCcKy1RVSbTJ7DoZ0vgcrBmZiT3qJMqvjpe635kJP5wN0bs9
JJo7F78n98tTyGGqt6zUIdHu7fHW1YMZIHwlMFdFn8rnUVzC0PfHML+tW0D4
IIkqJ/TeFn1Lh5G806SgMYmKNRYXr7Q9Av5etY9jpiTKjchVtql+CMcON+Xf
PUyizFY3F6X8B1BU0echbUEirKq1/c/e+zBRI9AZbkkilYaMlIfy92CCJtz7
2ppE/D9DfUZH78C1D4CK7Um0PHa8K775FvD/Mgk550iiWUlrHdXsJFj/ovnf
2mMkGnlV97zreiJY1+8ri3ImUafRdoGQ0zcgXq4p5cNxEsXX7fmNM67Bqbvu
SbMuJPL9IdR69UQ0lP7dnDTpSqJDYlMP2pUiQfKcfGyNG4lcEhPZ6v2hwInn
vL3dSSQ/qh9X7xYIG33ktKYof4r47lrY4w1tH/d9P+hB1e+W4Zzz3hp0daai
L1AO8pPkFVDCqCrqFT2a8m3voeKBPy4o1m+r10nKdEek7jh/BrF6xvNkKe+l
xd1oOX0eCcZEfX5Fxa+29P5572cY+u+dZr8k5X7FJGmL7VFonqex3ZnK7++/
MtOVvjHo7Yt9FSFU/hs6BkJqX8Sjv16Q5UPVJ2bOZbHHLwGlCepna1D1K1Xe
HruT+B/K8Bxu7aH6tXuTYvhs7k0kuCNX1MKJRIaJlesPvb+NRncWP3zqQCKb
JbOcFxPJqPyQt0+7HYlOuo3spa1MRateBt/6ZEOic21BX5wV0tA9gxa1PCsS
GbW/54pTfYiyxpvx9BESmV8RbivTfYTeGcGwpRmJbHcfTyHM0pFVSpjnLRMq
XsYvFf1TT5CLGnd8mgGJztjiP6dDM1Co18/jHnup+Ktj6u/HP0XHXhxI5tEl
UXSwmOPvrGcoXduv9qsWiTJM9K/lky/RyVqh0HIFEr1cHm/ZP5+NZAs+lFls
pPL/4rmGxpWLxFdIpTdIkcg5oeiL2to8xHss4qDueuq83wZnb6gUIO/Fmy9C
lpPo16cJK/nSAqSluX35jz/UPslN1K7EhQjILy91qPkNc/3CGDctQh0tnvNB
4wS68d73wX6fYiQjt9N030cCfc16+alpvBjZqQl1C7UQSClmjHnIswSpq1nS
G98S6J2+u7+VRylSqufc0l1KoL+lDgdPOL9GwwKGCw/SCOT12Hg25iggBV+b
MOZxApWFxW7m+wRok49ovaQtgSJzXHIaNlehItvXgWJHCNR+7dGwcWYVqt5Z
KtCkSyDv/eKmR59Uo66ViXZ/JQn0uFxQ1v1+LRLTuZ/x7zMbGb4o1H72tRaV
9klEpFD7djr5iPWY2Buk3XN2QeotG+HAhHjf1Deo/URH0yS1r3tVeBcCk+tQ
9NVdz27FshH/U67W6P/eoe/NUcYmmmwUmjAT+PxKE7obL8VjGM1CQb0uRrub
m5DreCNv/XkWOiPXKdm6uhmJFB9dre7LQm6lJQ0/kikHfLJjWbCQycAFUc2s
FtRV/G/ugTQLiavQ4V3beyS2+8/yutIR5OCxKmJ6ZTt6+sNksK9/GP2hyTTy
He1E8fX3VT5IDqHT0XXlClVfUbGepUl63DdUIxJiHmc0hJz4vaMuL3WjkI2v
2RzxbDQRWP5N4kMHumxQM/c1agw93fYfUVTQhqolJh+XdEyiXQ8W9BLzGlCz
oZKuDm0aPaSH1+Zw16Kv/HtP9f6bQZ1WqbmfoAxdLZzympH+hSyuD5on3c9G
dsc4Mquk5lFu8Ik/fvuTUIjD1qXLQotoXJq2Z5vNf7BDfVK8YccSml3fcsUi
iNrbwgKXqrf9RbFbb5bLWJSBwdhIl6giBz5VL9oqfKQWFKcPLbVrcOKE8LLK
7csa4dHfCXBRW4bX1slc3hLVBq5BHSd37F2Oa6rzL2hMdkD53Hhhvx4Xdlaw
cPtS0w1a95N4oveswM4a78XDdb8BV+HlAz5G3DjngV2b459B8MGLRscOceMX
7G0alswh6Gr2OWRuzo3rh1QumK4bgucjlpZadtxYKtJYRFdlCA6tU3Dl9qIs
Pcup5DoEqcGtl9JiubGKR5HabPMQqOqsK2lt5MYxy7lrdVKGIbUl9nV1Kzdu
0J0KWJk5DNw2HFDYzo29HD9zfCwchs9nyLq7Pdy49vrd1sOtw3Dx8euPbqPc
2No1r3sd5wg00pwm/zJo2FpyXUaM6wg4t2ZuVD5Awz/2Bb6K28SCsEtlcoHG
NByZEJ13YgcLHmxvlgUzGk7vignU0GVB361JaVMbGk4Ouyr10pYFVo7qEr6e
NPyAtUAbjWOB8VTtupw4Gt6Q4nbOY5IFXo8+Cc0l0PB0WZLmwd8siDFnC6Jb
NDzlynFJmMaG+hKmwPs0Go7Km8ah4mzQDTNbPZlDwwGeM0v2RmzQ4P9GV26n
YaeiOyqij9lw9M0ULbCThr3KL/BnZbPBP2AZDXpomHDO+Clbyob8HrkVpkM0
XMc77NDSwoYt6V6cvrM0vDg9JzX5kw3SaosL2UJ0XJ6267iCDgE6LJ6FXyJ0
zGL6n+M/SIDTHbF5bQk6Tpmf3tp3mIB7S/hXqzwd73hlt1XYhYD1dVemv2tQ
/4/suiB9mQDeo4JjW23pOOZYeuCOagJ029LNtzrScaih6/uX7wgIOLi9cstx
Oj6w55EZvZWAfm3TBCVPOt4nHzDj3ENAofzVnQrn6ThbNfJ35g8CyIfrHm4O
peNvV5aaleYIEN+QwdwcQcee9poyCUsERK+u7ZOPpWNXE8f4RW4S7BaWIuRS
qHiv3sweFCEh4WzshOx9Oi6Q0rjRIk7C2wlhS9l0Ohbu0dVRliFh26C6gswL
Op7aKaFzXZEEV7u6/6Rz6NiHemjHKVPv6s4jf6QK6Jjri232CVUSuJpOtUm+
puNLG2l6FVokaO79pykJdFwoYi2qpk2CD8SlS9TSsYxzb0e0DgmfC54HiDfR
8Qi9PqRpPwm8WzX7xd7TsfFcn2rpQRJ0M98dEPtIx2KW5+0jjUnISh3esKGX
jqWupifnHyZhQOhslOg3OvYa7fYTtCBBKIFzSmSIjg/2fj9iYUmCIc8NaxE2
Hc+xj4iesSbh0mXxWuExOnb01CrytCWh6F+WkvAkHTOga62uPQmj53bdWj9D
5eM3vfmnAwkSsw3/1s3RMSFuNhrpRIK5j9WJdb/pmNO0bP+PYyRcJVjtQv/o
WO72rJrWcRIqnf13Cy1n4L1X3z52dCFh5svyDEEaA5sX/7p6zJWETZaJfII8
DKxXYNiF3Eiw/yB5ToCPgVfwXQtdpJxomDO4di0D397/1D/BnYR3dXuM1q5j
4GSTjnwuDxKWUHMRvygDl8BJDXPKKmU2EvwSDLyw35B+ibKbGhm9RoaBnZKO
ylLvG0jJDpxeLc/As2be8V6U2zZx261WZODSLacMtlBekZ5Ux6fMwEUdyLyR
Ok9LTEaZT5WBJ2bKC/Qo+97Ou7NqJwO7atR7JFP5PV6Dl63axcCyprr+TVQ9
3bGtnryIge/Fafd2U/Wu4rb/tFKPgXcamKe/ofqhd2lMe+V+Bp7mnOyLdSYh
aPFcJo8hA/NUT6UoU/176Ufn5zFlYIjd9T3HkYTB77fOM48wsKFH3shKqv+G
QwUmDFsG7vPNoNnbkCB51y9z1oGBbblPzNhYkfDr0I5l/c4MfPyZoezOoyQ8
qnxV9OokA5tUqd6MMaPO8w/ke+TDwAyp8kVOUxKMlTROxJ1h4PW6SXOWRiTM
J5ducAlmYKNedaUH+0hoPRQcYHqRgSO+hqcl6pGQTtvVphXOwMolUmIumAQT
//KINTEMvGyFbeFjTaofh2C0MpmBBTI0w+4rkBBMu6T//B4D1zcs3Y3bSIJp
JU67+ZCB05M96mylSVhUrDHzesbAZV7k1B1hklqVdSXCpQzMtdlGJoWaz42V
l/lXVDDwhV9KevGc1H377fOaqmLg3y3cFc7UPGcOvpN4V8/AwtwfvXKp+f9b
0Rjl95mBwy1FTYep/dDhF9vv+IWBM+baE9gdBDxTNNIy7Gfg7fSAqhZqn5gn
t0xIEQzcbbYzT6+GgOd+bebv5xj41cWQ671PCbBU7JRWWMfEb8t2FIx7E6A0
eCtEUJSJtxhEXddwI2BZsmUnhwQTu//qGD/pQEA2d/fVro1M/HVF6YZIEwK4
BnunItWZWPvR+o3XtxCQe2eg8psFEyfeDFDXYbNhlz8SkLRh4ginS3yGfWx4
a3bvhJMDE+ucFC/e9ZENvUxrgQE3Ji6wON/UXskG7gttJwYDmfi4sX/wQBIb
7I6BwEgyEz97Mp3VvJsNdIV7J0f7mPjoaPAT9YssOPbaSuinKw8+rGJRYNA9
DBlDnLwjx1fiS0z7K2mpA6BxbnZ0bSAvTj3/9c149heYUg/4pH15Fe5/ciTx
qWwX7F7c7Kgfxodl7LDKg/J28Ly51kP/wGrsF1ceYLa3BcK3KU59rF+NTfcN
v7iT9BayHGMuDuxdgx8mmhuMZFdByN74S/Eta7DlwAexoOQiENqq2L7JiB8v
qDf6XQnMgKMtXredP/Fjn1WpaQ5V5tAfTP49Q/n1M11vB29zOLnJzS2Csvfc
Vm0HEXMIjXDc8ZjyngsFLHu/I5CpefjjCOU/OzzM7Dcdht9PdvKd6OTHLvLA
LJU0hQcXl13x7eLHkbqcxiVV+qCgFPo9lHLavXLLEhF9KOr+bXGDMv6c61Li
pweNaj9l8ygr1S1ElmzShZlRds00ZTl3ZtlpKQT7LFv++n/mxz/Tw4rOVqtB
G9dBtyjK+jPPOfz8VcEm/23LLcpld2eM/TZvB1/eqtRiynIXU7+Q0spwpzZf
a4HykU6VyPEaWZA+rfyI0c2PrQ2s1SYUpOGleBZDhLJofHdzr5wE1Jx78lmL
cvY9h7SvdQJgJC+NDSlfH94oWKXIB50daU9tKYt4pU7VNHGBU7gonxflz5vI
lNiu2cox5TsBIZQ1BZeYVgmBlf8DjXVoNQ==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {580.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk0Fc4XAHC79+xZW4hEhVKEEO60KCVRSVLZKkWEIi1KlLInSpS0yVch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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {967.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->{628., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.405706589232052*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["With Flow2", "Subsubsection",
 CellChangeTimes->{{3.405706360288899*^9, 3.405706365291543*^9}, {
  3.405706436700979*^9, 3.40570644212033*^9}}],

Cell["No solution when \[Mu] == 0", "Text",
 CellChangeTimes->{{3.405682270906063*^9, 3.4056823076350822`*^9}, {
  3.4056823538003397`*^9, 3.405682354189416*^9}, {3.40568242018408*^9, 
  3.4056824220428467`*^9}}],

Cell[BoxData[{
 RowBox[{"Numerical", " ", "solutions", " ", "for", " ", "several", " ", 
  "values", " ", "of", " ", "\[Mu]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"When", " ", "\[Mu]"}], "\[Rule]", "0"}], ",", 
  RowBox[{
  "no", " ", "singularity", " ", "occurs"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"When", " ", "\[Mu]"}], "\[Rule]", "\[Infinity]"}], ",", " ", 
  RowBox[{
  "the", " ", "second", " ", "derivative", " ", "of", " ", "f1", " ", "tends",
    " ", "to", " ", "be", " ", "singular", " ", "in", " ", "0"}], ",", 
  "\[Pi]"}]}], "Text",
 CellChangeTimes->{{3.40568232181746*^9, 3.405682323174533*^9}, {
  3.40568256853981*^9, 3.405682595845359*^9}, {3.4056855367856607`*^9, 
  3.405685583688298*^9}, {3.40568563791998*^9, 3.405685651364607*^9}, {
  3.405686856415606*^9, 3.4056868962700033`*^9}, {3.405707000732164*^9, 
  3.405707007707452*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"g1A", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "1."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1B", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "100."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1C", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.1"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1D", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.01"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1E", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "10."}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"g1F", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"Flatten", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Eqg1", " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"C", "\[Rule]", "1"}], ",", 
          RowBox[{"\[Mu]", "\[Rule]", "0.001"}]}], "}"}]}], ",", 
       RowBox[{
        RowBox[{"g1", "[", 
         RowBox[{"-", 
          FractionBox["\[Pi]", "2"]}], "]"}], "\[Equal]", "0"}]}], "}"}], 
     "]"}], ",", "g1", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox["\[Pi]", "2"]}], ",", 
      FractionBox[
       RowBox[{"3", "\[Pi]"}], "2"]}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405681773347843*^9, 3.405681773941864*^9}, {
   3.40568181377392*^9, 3.405681839055987*^9}, {3.405681869514463*^9, 
   3.405681873703433*^9}, {3.405681909005368*^9, 3.4056819326317368`*^9}, {
   3.40568196556674*^9, 3.405682016653285*^9}, 3.4056820887613773`*^9, {
   3.405682479836936*^9, 3.405682517784671*^9}, {3.405682554131682*^9, 
   3.405682555422155*^9}, {3.405682609625046*^9, 3.4056826300251503`*^9}, {
   3.405682892687722*^9, 3.405682920347066*^9}, {3.405684928580121*^9, 
   3.4056849689274282`*^9}, 3.405685191977766*^9, {3.405685493979383*^9, 
   3.405685496169139*^9}, {3.4056869948874702`*^9, 3.405686997075314*^9}, {
   3.40570645367916*^9, 3.405706471466228*^9}, {3.40570690058339*^9, 
   3.405706940246229*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706957443754*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706957697585*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706957982632*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706958277486*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706958576184*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"g1", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.5707963267948966`"}], ",", "4.71238898038469`"}], 
         "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.4056820585376587`*^9, 3.405682093568039*^9, 
  3.405682523785432*^9, 3.405682793999538*^9, 3.405685040001812*^9, 
  3.405685192925127*^9, 3.405685497115932*^9, 3.405686830112656*^9, 
  3.405687000025931*^9, 3.40570296642378*^9, 3.405706959047872*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"pC", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1C"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pA", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1A"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pB", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1B"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"pD", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1D"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pE", "=", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1E"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", 
        FractionBox["\[Pi]", "2"]}], ",", 
       FractionBox[
        RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"pF", "=", 
    RowBox[{"Plot", "[", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"g1", "[", "y", "]"}], " ", "/.", " ", "g1F"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", 
         FractionBox["\[Pi]", "2"]}], ",", 
        FractionBox[
         RowBox[{"3", "\[Pi]"}], "2"]}], "}"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
      RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], ";"}], 
  "\n", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pF", ",", "pD", ",", "pC"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"pA", ",", "pE", ",", "pB"}], "}"}]}], "}"}], "]"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.405682679304923*^9, 3.405682756118494*^9}, 
   3.405682812014813*^9, {3.4056828831425953`*^9, 3.405682890096424*^9}, {
   3.405684977337996*^9, 3.4056851606579313`*^9}, {3.405685201488823*^9, 
   3.405685201925613*^9}, {3.405685319254837*^9, 3.405685323971859*^9}, 
   3.405685397510726*^9, {3.405685435043001*^9, 3.405685474542745*^9}, {
   3.405687010468215*^9, 3.405687016124189*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8VW8cB3Cba14yCkWR7Z5bIqOcb4UKJSVpkoqSUlZI1q/shEpISmQL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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {193.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2Xc8VX8YB3Dbvfa87rllpKEkWlbJeSpECKVIg2Q0rBQlW8NMpITslURS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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {580.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4FW8bB3DOOXOcY6dIUrRKu0QS5q5oQ9aQFiprlKwVIrKLUAmhUH4S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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {967.5, -118.66252583997979`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8ld8fAHAV7r1GRhmVkGy+SiEk5zSUjIyMNil7ZWdENKQkK1nZSaWQ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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {193.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3k8lc8Xx2W991qTtbIkJRQtEoqZFi0oS0qRyFYiohApol0U9RWlZE0i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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {580.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k0Vd8XAHAZ3zPPlVIoMqVS5nJOJJVM8UVSJGQWGYoKIU2UBiGpkGSI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          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       DisplayFunction:>Identity,
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {967.5, -355.98757751993935`},
       ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->{640., Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.405706964608183*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 2", "Section"],

Cell[TextData[{
 "Extract order 2 terms from the general expansion, use formal solution to \
order 0 and 1 equations and perform algebraic simplication.\nNeed to be put \
under the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]2", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}, {
  3.405685906475298*^9, 3.405685933174532*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2", " ", "=", " ", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", ">", "0"}], " ", "&&", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", ">", "0"}]}], ",", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Coefficient", "[", 
         RowBox[{"NS2", ",", "\[Epsilon]", ",", "2"}], "]"}], "   ", "//.", 
        " ", 
        RowBox[{"{", 
         RowBox[{"Rule0", ",", "Rule1"}], "}"}]}], " ", ",", 
       RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}], " ", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.405707115570497*^9}],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection",
 CellChangeTimes->{{3.405689902151525*^9, 3.405689906517454*^9}}],

Cell["\<\
Here we extract the terms of the second member, factor per factor, and we \
test the solvability condition\
\>", "Text",
 CellChangeTimes->{{3.40568617718019*^9, 3.4056862579374123`*^9}, {
  3.40568991337463*^9, 3.4056899311116037`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"]}], ":", " ", 
  "a2a"}]], "Subsubsection",
 CellChangeTimes->{{3.405686378322873*^9, 3.405686385538538*^9}, {
  3.405690025024864*^9, 3.405690026158256*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2a", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"a2", " ", ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], ",", "2"}], "]"}], " ", "]"}]}], " ",
     ",", 
    RowBox[{"{", 
     RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"16", " ", 
       SuperscriptBox["\[Mu]", "3"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"48", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"48", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "6"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], " ", 
       RowBox[{
        SuperscriptBox["f1", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"16", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
       RowBox[{"7", "/", "2"}]]}], ")"}]}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"C", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"48", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", 
           RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "6"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "-", 
       RowBox[{"48", " ", 
        SuperscriptBox["\[Mu]", "3"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
       RowBox[{"96", " ", 
        SuperscriptBox["\[Mu]", "3"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "7"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "7"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
          RowBox[{"Sin", "[", 
           RowBox[{"3", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"96", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"48", " ", 
        SuperscriptBox["\[Mu]", "3"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["\[Mu]", "3"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"24", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["\[Mu]", "3"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
        RowBox[{"(", 
         RowBox[{"\[Mu]", "+", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ",
         
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "\[Mu]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ",
         
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["\[Mu]", "4"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "7"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", "4", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                RowBox[{"Sin", "[", 
                 RowBox[{"3", " ", 
                  RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], 
             "-", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", 
                  RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
              
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"11", " ", "\[Mu]", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
             RowBox[{"\[Mu]", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"3", " ", 
                RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
          RowBox[{"4", " ", "\[Mu]", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["f1", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "7"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"]}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
          RowBox[{"2", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
          RowBox[{"2", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[Mu]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", 
          RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "16"}], " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"3", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
          RowBox[{"2", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "40"}], " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
             RowBox[{"21", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"3", " ", 
                RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
             RowBox[{"Sin", "[", 
              RowBox[{"5", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"18", " ", "\[Mu]", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{"6", " ", "\[Mu]", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"3", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{"12", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"5", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                RowBox[{"Sin", "[", 
                 RowBox[{"3", " ", 
                  RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], 
             "+", 
             RowBox[{"6", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
          RowBox[{"8", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"13", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
             RowBox[{"Sin", "[", 
              RowBox[{"3", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{"14", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"21", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"3", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"7", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"5", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"112", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"]}], "-", 
          RowBox[{"6", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"7", " ", "\[Mu]", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"2", " ", 
                RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
             RowBox[{"6", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"37", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                RowBox[{"Sin", "[", 
                 RowBox[{"3", " ", 
                  RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], 
             "-", 
             RowBox[{"6", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "4"}], " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                RowBox[{"Cos", "[", 
                 RowBox[{"3", " ", 
                  RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
              
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"25", " ", 
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
                RowBox[{"Sin", "[", 
                 RowBox[{"3", " ", 
                  RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], 
             "-", 
             RowBox[{"24", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f1", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{"32", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["f1", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", 
                TagBox[
                 RowBox[{"(", "3", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "y", "]"}]}], "-", 
             RowBox[{"8", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["f1", 
                TagBox[
                 RowBox[{"(", "4", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
         ")"}]}], "-", 
       RowBox[{"24", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[Mu]"}], "+", 
             RowBox[{"2", " ", "\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["f1", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
             RowBox[{"5", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["f1", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"\[Mu]", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "+", 
                RowBox[{"2", " ", 
                 RowBox[{"Cos", "[", 
                  RowBox[{"2", " ", 
                   RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["f1", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              RowBox[{
               SuperscriptBox["f1", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], " ", 
              RowBox[{
               SuperscriptBox["f1", 
                TagBox[
                 RowBox[{"(", "3", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["f1", 
                 TagBox[
                  RowBox[{"(", "3", ")"}],
                  Derivative],
                 MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
             RowBox[{
              RowBox[{
               SuperscriptBox["f1", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", 
                 RowBox[{
                  SuperscriptBox["f1", "\[Prime]",
                   MultilineFunction->None], "[", "y", "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["\[Theta]", 
                   TagBox[
                    RowBox[{"(", "3", ")"}],
                    Derivative],
                   MultilineFunction->None], "[", "y", "]"}]}], "+", 
                RowBox[{
                 RowBox[{"Sin", "[", 
                  RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
                 RowBox[{
                  SuperscriptBox["f1", 
                   TagBox[
                    RowBox[{"(", "4", ")"}],
                    Derivative],
                   MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"16", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
      RowBox[{"7", "/", "2"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.405687299958961*^9, 3.405703482763621*^9, 
  3.40570774659085*^9, 3.40575336214437*^9, 3.440940912911866*^9}]
}, Closed]],

Cell["\<\
Check that this simplification can be somewhat improved for the term which is \
not in factor of C\
\>", "Text",
 CellChangeTimes->{{3.4056862817471857`*^9, 3.405686293409556*^9}, {
  3.405687379626865*^9, 3.405687409487836*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a2a", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["f1", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.405686477381343*^9, 3.405687312568282*^9, 
  3.405703482887491*^9, 3.405707747595942*^9, 3.4057533625583067`*^9, 
  3.4409409132093363`*^9}]
}, Open  ]],

Cell["\<\
This term integrates twice in y and satisfies the solvability condition\
\>", "Text",
 CellChangeTimes->{{3.405690121361199*^9, 3.4056901296072617`*^9}, {
  3.405707882353025*^9, 3.405707885483936*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2aI", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a2a", ",", "y"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.405707182438018*^9, 3.405707185668837*^9}, {
  3.405707762365654*^9, 3.405707771439313*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2aI2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a2aI", ",", "y"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", " ", "C", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]", "+", 
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["f1", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["f1", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
         "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"\[Mu]", "+", 
            RowBox[{"3", " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["f1", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
           ")"}]}]}], ")"}]}], ")"}], "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405687843186754*^9, 3.40570370366247*^9, 
  3.405707986290822*^9, 3.4057534646847973`*^9, 3.440941018129593*^9}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a2b"}]], "Subsubsection",
 CellChangeTimes->{{3.405690035550551*^9, 3.405690037683858*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2b", "=", 
  RowBox[{"-", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Simplify", "[", 
       RowBox[{"Coefficient", "[", 
        RowBox[{"a2", "  ", ",", 
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], ",", "1"}], "]"}], "]"}], " ", "/.",
       " ", "Rulea"}], ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], " ", "}"}]}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "A"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"32", " ", 
         RowBox[{"f1", "[", "y", "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          RowBox[{"7", "/", "2"}]]}], "+", 
        RowBox[{"32", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          RowBox[{"7", "/", "2"}]], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "-", 
        RowBox[{"32", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         RowBox[{"f1", "[", "y", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          RowBox[{"7", "/", "2"}]], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"32", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
         RowBox[{"7", "/", "2"}]]}], ")"}]}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"C", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "32"}], " ", 
          SuperscriptBox["\[Mu]", "4"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "8"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"76", " ", 
          SuperscriptBox["\[Mu]", "3"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"]}], "+", 
         RowBox[{"20", " ", 
          SuperscriptBox["\[Mu]", "3"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"]}], "+", 
         RowBox[{"15", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "6"]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"4", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "6"]}], "-", 
         RowBox[{"224", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "8"]}], "-", 
         RowBox[{"64", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "8"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "10"]}], "+", 
         RowBox[{"32", " ", 
          SuperscriptBox["\[Mu]", "4"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "7"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"304", " ", 
          SuperscriptBox["\[Mu]", "3"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"44", " ", 
          SuperscriptBox["\[Mu]", "3"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"4", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"560", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"400", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"672", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "6"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"192", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "7"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "8"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"96", " ", 
          SuperscriptBox["\[Mu]", "3"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"96", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"96", " ", 
          SuperscriptBox["\[Mu]", "3"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"256", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"224", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"64", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "8"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "7"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
     "/", 
     RowBox[{"(", 
      RowBox[{"32", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"D", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"32", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           RowBox[{"7", "/", "2"}]]}], "+", 
         RowBox[{"96", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{"32", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{
           SuperscriptBox["f1", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"32", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
               RowBox[{"Sin", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
     "/", 
     RowBox[{"(", 
      RowBox[{"32", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        RowBox[{"7", "/", "2"}]]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405687481063635*^9, 3.405703789087614*^9, 
  3.405708459749359*^9, 3.405753503847404*^9, 3.4409410576444807`*^9}]
}, Closed]],

Cell["\<\
Split it in several part for integration. First isolate the part that does \
not depend on C and D and integrate it once.\
\>", "Text",
 CellChangeTimes->{{3.405745492990153*^9, 3.405745570156051*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2b0", "=", " ", 
   RowBox[{"a2b", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"D", "\[Rule]", "0"}], " ", ",", 
      RowBox[{"C", "\[Rule]", "0"}]}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.405745451200237*^9, 3.405745483222468*^9}, 
   3.405745655293355*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2b1I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a2b0", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{3.405745579931936*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"A", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4056881282704763`*^9, 3.405703789576619*^9, 
  3.405708461015973*^9, 3.4057535044806767`*^9, 3.4409410582391987`*^9}]
}, Open  ]],

Cell["Then isolate the factor of A C and integrate it twice", "Text",
 CellChangeTimes->{{3.405745589367653*^9, 3.405745618950581*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2b1", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a2b", ",", 
     RowBox[{"A", " ", "C"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.405745623012708*^9, 3.405745659658623*^9}, {
  3.405753432891119*^9, 3.405753433760559*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2b2I2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"a2b1", ",", "y"}], "]"}], ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.405708443762661*^9, {3.405745672954757*^9, 3.405745674746818*^9}, {
   3.4057534375848083`*^9, 3.40575343789323*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"\[Mu]", " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
  SqrtBox[
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]]], "Output",
 CellChangeTimes->{3.405688158081522*^9, 3.405703811778435*^9, 
  3.405708490878653*^9, 3.40575351635338*^9, 3.44094108758409*^9}]
}, Open  ]],

Cell["Isolate the factor of A D and integrate it once", "Text",
 CellChangeTimes->{{3.405745754960486*^9, 3.405745759642454*^9}, {
  3.405745791092037*^9, 3.405745808312101*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2b2", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a2b", "  ", ",", 
     RowBox[{"A", " ", "D"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.405745812649135*^9, 3.405745828351323*^9}, {
   3.405753440570002*^9, 3.4057534411203814`*^9}, 3.405753527993288*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2b0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a2b2", ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.405745835025645*^9, 3.405745836743738*^9}, {
  3.405753444866274*^9, 3.405753445314739*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4056881642759657`*^9, 3.405703812606026*^9, 
  3.405708511034817*^9, 3.405753517211644*^9, 3.44094108815919*^9}]
}, Open  ]],

Cell["\<\
Complete the solvability proof for a2b by check that nothing has been \
forgotten in a2b\
\>", "Text",
 CellChangeTimes->{{3.405745389447373*^9, 3.405745403146656*^9}, {
  3.405745764672007*^9, 3.405745784943751*^9}, {3.405745896667426*^9, 
  3.405745935471117*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a2b", " ", "-", " ", "a2b0", " ", "-", " ", 
   RowBox[{"A", " ", "C", " ", "a2b1"}], " ", "-", 
   RowBox[{"A", " ", "D", " ", "a2b2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.40574540948459*^9, 3.405745437037369*^9}, {
   3.405745841759482*^9, 3.405745865636389*^9}, 3.405745940805416*^9, {
   3.4057534480064774`*^9, 3.405753452172996*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057535175270147`*^9, 3.4409409134540567`*^9, 
  3.440941092250198*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reconstruction of the second order equation", "Subsection"],

Cell["\<\
Check that nothing has been forgotten in the extraction of the components of \
a2\
\>", "Text",
 CellChangeTimes->{{3.405687499347293*^9, 3.405687519117462*^9}, {
  3.405687570045809*^9, 3.4056875715644836`*^9}, {3.405745942937049*^9, 
  3.405745950226455*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2N", " ", "=", " ", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]2", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], "  ", "-", " ", 
    RowBox[{"a2b", "  ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "-", " ", 
    RowBox[{"a2a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a2N", " ", "-", " ", "a2"}], " ", "]"}]}], "Input",
 CellChangeTimes->{3.405687585410922*^9, 3.405689971668638*^9, 
  3.440941108713813*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405708612492112*^9, 3.405753537981843*^9, 
  3.4409411102939777`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule2", " ", "=", "  ", 
  RowBox[{"\[Psi]2", "  ", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f2a", "[", "#3", "]"}], "  ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"#1", ",", "#2"}], "]"}], "2"]}], "+", " ", 
      RowBox[{
       RowBox[{"f2b", "[", "#3", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}]}]}], "&"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.440941121352686*^9, 3.4409411242392893`*^9}}],

Cell[BoxData[
 RowBox[{"\[Psi]2", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f2a", "[", "#3", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"f2b", "[", "#3", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"#1", ",", "#2"}], "]"}]}]}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.4056881724009247`*^9, 3.405703814113815*^9, 
  3.405708621168304*^9, 3.4057535424394903`*^9, 3.440941128489338*^9}]
}, Open  ]],

Cell["\<\
f2a has CosI symmetry
f2b has CosP symmetry
f2c has SinI symmetry\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 3", "Section"],

Cell[TextData[{
 "Extract order 3 terms from the general expansion, use formal solution to \
order 0, 1 and 2 equations and perform algebraic simplication.\nNeed to be \
put under the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]3", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member\nNo attemps to simplify here"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}, {
  3.405685906475298*^9, 3.405685933174532*^9}, {3.405688214542055*^9, 
  3.405688233724618*^9}, {3.405688414807213*^9, 3.405688425967601*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3", " ", "=", "  ", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"NS2", ",", "\[Epsilon]", ",", "3"}], "]"}], "   ", "//.", " ", 
    RowBox[{"{", 
     RowBox[{"Rule0", ",", "Rule1", ",", "Rule2"}], "}"}]}]}], " ", 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection"],

Cell["\<\
First reorganize a3 in order to make further extraction easier\
\>", "Text",
 CellChangeTimes->{{3.405688359831512*^9, 3.4056883786622953`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a31", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a3", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.44094115301597*^9, 3.440941153826576*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "3"]}], ":", " ", 
  "a3a"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"a31", " ", "/.", " ", "Rulea"}], " ", ",", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], "3"]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"C", ",", "A"}], "}"}]}], "]"}]}], "  ", ";"}]], "Input"],

Cell["Term excluding factor C, which can be integrated in y", "Text",
 CellChangeTimes->{{3.405690303565764*^9, 3.405690323803512*^9}, {
  3.405690427766193*^9, 3.405690440196372*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3a", " ", "/.", " ", 
  RowBox[{"C", "\[Rule]", "0"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f2a", 
   TagBox[
    RowBox[{"(", "3", ")"}],
    Derivative],
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{3.4056884479239197`*^9, 3.405703816650679*^9, 
  3.405708654607628*^9, 3.4057535963939047`*^9, 3.440941673978059*^9}]
}, Open  ]],

Cell["\<\
Split term in factor of C  in two parts according to 1/A factor, and check \
that the combination, adding previous contribution, reconstructs a3a\
\>", "Text",
 CellChangeTimes->{{3.405688495447377*^9, 3.405688524661201*^9}, {
  3.405690464708074*^9, 3.405690509076673*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3a1", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a3a", ",", "C"}], "]"}], ",", 
     RowBox[{"1", "/", "A"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3a2", "=", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a3a", ",", "C"}], "]"}], "-", 
    RowBox[{"a3a1", "/", "A"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"a3a", "-", 
  RowBox[{"C", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"a3a1", "/", "A"}], " ", "+", " ", "a3a2"}], ")"}]}], " ", "-", 
  " ", 
  RowBox[{"(", 
   RowBox[{"a3a", " ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}], ")"}]}]}], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4056885308606787`*^9, 3.40570381692071*^9, 
  3.405708667588608*^9, 3.4057535986938543`*^9, 3.4409416764221992`*^9}]
}, Open  ]],

Cell["\<\
Rearrange a3a1 and a3a2 to perform more efficiently the integration, and \
verification\
\>", "Text",
 CellChangeTimes->{{3.4056888358413982`*^9, 3.405688860112525*^9}, {
  3.405688948382*^9, 3.405688963506495*^9}, {3.405689623082596*^9, 
  3.4056896289455833`*^9}, {3.405689678955811*^9, 3.4056896822218227`*^9}, {
  3.405753971491406*^9, 3.405753976101232*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"vars1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], ",", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], ",", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], ",", 
     RowBox[{
      SuperscriptBox["f1", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}], ",", 
     RowBox[{
      SuperscriptBox["f1", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}], ",", 
     RowBox[{
      SuperscriptBox["f1", 
       TagBox[
        RowBox[{"(", "5", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a3a1CA", "=", 
   RowBox[{"CoefficientArrays", "[", 
    RowBox[{"a3a1", ",", "vars1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3a1CL", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a3a1CA", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "}"}], ",", 
     RowBox[{"Map", "[", 
      RowBox[{"SparseArray", ",", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Improve", "[", 
          RowBox[{"Normal", "[", "a3a1CA", " ", "]"}], "]"}], ",", "1"}], 
        "]"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3a1RC", "=", 
   RowBox[{"Total", "[", 
    RowBox[{"MapIndexed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Nest", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#1", ".", "vars1"}], " ", "&"}], ",", "#1", ",", 
         RowBox[{
          RowBox[{"First", "[", "#2", "]"}], "-", "1"}]}], "]"}], "&"}], ",", 
      "a3a1CL"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3a2CA", "=", 
   RowBox[{"CoefficientArrays", "[", 
    RowBox[{"a3a2", ",", "vars1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3a2CL", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a3a2CA", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "}"}], ",", 
     RowBox[{"Map", "[", 
      RowBox[{"SparseArray", ",", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Improve", "[", 
          RowBox[{"Normal", "[", "a3a2CA", " ", "]"}], "]"}], ",", "1"}], 
        "]"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3a2RC", "=", 
   RowBox[{"Total", "[", 
    RowBox[{"MapIndexed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Nest", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#1", ".", "vars1"}], " ", "&"}], ",", "#1", ",", 
         RowBox[{
          RowBox[{"First", "[", "#2", "]"}], "-", "1"}]}], "]"}], "&"}], ",", 
      "a3a2CL"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a3a1", "-", "a3a1RC"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a3a2", "-", "a3a2RC"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.4056886682320557`*^9, {3.405689641223836*^9, 3.40568967589008*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405688709915635*^9, 3.405689833511498*^9, 
  3.405703903407806*^9, 3.405708758697594*^9, 3.405753641768442*^9, 
  3.440941722760968*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405688709915635*^9, 3.405689833511498*^9, 
  3.405703903407806*^9, 3.405708758697594*^9, 3.405753641768442*^9, 
  3.440941723146035*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3a1I", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a3a1RC", ",", "y"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.4057537709319763`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a3a1I2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a3a1I", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a3a1I2", "]"}]}], "Input",
 CellChangeTimes->{{3.405771264529305*^9, 3.40577128733813*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[Mu]", "2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", 
         RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]", "+", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}]}], 
     ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"5", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405689982778051*^9, 3.405704228207664*^9, 
  3.405709525014339*^9, 3.405753782411105*^9, 3.405771365025547*^9, 
  3.440941883684947*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405689982778051*^9, 3.405704228207664*^9, 
  3.405709525014339*^9, 3.405753782411105*^9, 3.405771365025547*^9, 
  3.440941883832446*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3a2I", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a3a2RC", ",", "y"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.405753767330104*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a3a2I2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a3a2I", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a3a2I2", "]"}]}], "Input",
 CellChangeTimes->{{3.405771292728134*^9, 3.405771310200075*^9}, {
  3.44094168999466*^9, 3.440941691827896*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ",
         
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
  "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
   RowBox[{"3", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.405690116474918*^9, 3.405709764807762*^9, 
  3.4057538972743893`*^9, 3.405771395365473*^9, 3.4409420095502243`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405690116474918*^9, 3.405709764807762*^9, 
  3.4057538972743893`*^9, 3.405771395365473*^9, 3.440942009555828*^9}]
}, Open  ]],

Cell["\<\
Solvability is satisfied since all components of a3a integrate twice in y. \
Notice that it would be sufficient to check that the solvability condition is \
satisfied on the first integral but more compact expressions are obtained \
when a second primitive can be obtained. \
\>", "Text",
 CellChangeTimes->{{3.405690369471695*^9, 3.405690390351179*^9}, {
  3.405746127058013*^9, 3.405746150970755*^9}, {3.405771248852193*^9, 
  3.405771249117156*^9}, {3.405771324636036*^9, 3.405771476043433*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", "factor", " ", "of", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{"Group", " ", "of", " ", "all", " ", "terms", " ", "containing", " ",
   
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}], " ", "in", " ", "factor"}]], "Text",
 CellChangeTimes->{{3.405690572298355*^9, 3.405690599510146*^9}, {
  3.4057574744603233`*^9, 3.405757483084566*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a33", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a31", "]"}], ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", "a3b"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3b", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{"A", ">", "0"}], ",", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"a33", " ", "/.", " ", "Rulea"}], ",", 
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"D", ",", "C", ",", "A"}], " ", "}"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.405690674595083*^9}],

Cell["Term not in factor of C within a3b", "Text",
 CellChangeTimes->{{3.405690618705862*^9, 3.405690622111414*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3b0", "=", 
  RowBox[{"a3b", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"A", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"f2a", "[", "y", "]"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{"f2a", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f2b", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{"D", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"A", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2a", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "3"]}], "-", 
        RowBox[{"6", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2a", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2a", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2a", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.40569067849599*^9, 3.405709767863743*^9, 
  3.405753898377462*^9, 3.440942010898777*^9}]
}, Open  ]],

Cell["\<\
Curiously a3b0 does not want to integrate at once, must be split in parts\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"i1", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"a3b0", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A", "\[Rule]", "0"}], ",", 
       RowBox[{"D", "\[Rule]", "0"}]}], "}"}]}], ",", "y"}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.405753705813236*^9, 3.405753721907073*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.4056908206387672`*^9, 3.405709768698935*^9, 
  3.405753968471878*^9, 3.440942011431843*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"i2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a3b0", ",", "D"}], "]"}], ",", "y"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "A", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], "2"], "-", 
  RowBox[{"2", " ", "A", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"2", " ", "A", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405690823376124*^9, 3.40570977035732*^9, 
  3.405753970541827*^9, 3.440942012333714*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solva", "[", "i2", "]"}]], "Input",
 CellChangeTimes->{{3.405771511211359*^9, 3.405771514781848*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405771515675128*^9, 3.440942012813765*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"i3", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a3b0", ",", "A"}], "]"}], " ", "/.", " ", 
     RowBox[{"D", "\[Rule]", "0"}]}], ",", "y"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4056908251305523`*^9, 3.405709771483996*^9, 
  3.40575397083665*^9, 3.440942013441976*^9}]
}, Open  ]],

Cell["\<\
Check nothing has been forgotten, completing the proof that a3b0 satisfies \
the solvability condition\
\>", "Text",
 CellChangeTimes->{{3.4056907219500847`*^9, 3.405690806443172*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a3b0", " ", "-", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"i1", "+", 
      RowBox[{"D", " ", "i2"}], " ", "+", " ", 
      RowBox[{"A", " ", "i3"}]}], ",", "y"}], "]"}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405690833290091*^9, 3.405709772203891*^9, 
  3.40575397090725*^9, 3.440942013882443*^9}]
}, Open  ]],

Cell["\<\
Term in factor of C within a3b, checking that it combines with a3b0 to \
reconstruct a3b\
\>", "Text",
 CellChangeTimes->{{3.4056908582981787`*^9, 3.405690913088511*^9}, {
  3.405709381407221*^9, 3.405709386605586*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3b2", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a3b", ",", "C"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"a3b", " ", "-", 
  RowBox[{"C", " ", "a3b2"}], " ", "-", " ", "a3b0"}]}], "Input",
 CellChangeTimes->{{3.405709392793869*^9, 3.405709394330489*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405690920055438*^9, 3.405709772691623*^9, 
  3.405753971191379*^9, 3.440942014227624*^9}]
}, Open  ]],

Cell["Rearrange a3b2 to make integration easier", "Text",
 CellChangeTimes->{{3.405690926440522*^9, 3.4056909561129503`*^9}, {
  3.405753953905211*^9, 3.405753958211792*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3b2CA", "=", 
   RowBox[{"CoefficientArrays", "[", 
    RowBox[{"a3b2", ",", "vars1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3b2CL", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a3b2CA", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "}"}], ",", 
     RowBox[{"Map", "[", 
      RowBox[{"SparseArray", ",", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"Improve", "[", 
          RowBox[{"Normal", "[", "a3b2CA", " ", "]"}], "]"}], ",", "1"}], 
        "]"}]}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3b2RC", "=", 
   RowBox[{"Total", "[", 
    RowBox[{"MapIndexed", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Nest", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"#1", ".", "vars1"}], " ", "&"}], ",", "#1", ",", 
         RowBox[{
          RowBox[{"First", "[", "#2", "]"}], "-", "1"}]}], "]"}], "&"}], ",", 
      "a3b2CL"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a3b2", "-", "a3b2RC"}], "]"}]}], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4056909950720654`*^9, 3.405709823675107*^9, 
  3.4057540668633337`*^9, 3.440942041498638*^9}]
}, Open  ]],

Cell["\<\
Integrate twice a3b2, completing the proof of solvability for a3b\
\>", "Text",
 CellChangeTimes->{{3.405690998215687*^9, 3.405691050436213*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3b2I", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a3b2RC", ",", "y"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.405691071157219*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3b2I2", "=", 
  RowBox[{"Improve", "[", 
   RowBox[{"Integrate", "[", 
    RowBox[{"a3b2I", ",", "y"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{"f1", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], "+", 
    
    RowBox[{"\[Mu]", " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ",
         
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], ")"}]}]}],
    ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
   RowBox[{"3", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.405691286647016*^9, 3.405710198141897*^9, 
  3.405754247822092*^9, 3.4409422367540417`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a3d"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3d", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{"A", ">", "0"}], ",", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"a31", " ", "/.", " ", "Rulea"}], ",", 
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "3"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"D", ",", "A", ",", "C"}], " ", "}"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["Extract the contribution that does not contain C", "Text",
 CellChangeTimes->{{3.405709452831823*^9, 3.405709487758203*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3d0", "=", 
  RowBox[{"a3d", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"A", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
     RowBox[{
      RowBox[{"f2b", "[", "y", "]"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{"f2b", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"A", " ", "D", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", 
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "3"]}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "-", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f2b", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.405710513092377*^9, 3.405754662837373*^9, 
  3.440942237386046*^9}]
}, Open  ]],

Cell["\<\
Split a3d0 to prove it can be integrated; the leading Sin[\[Theta][y]] \
contribution integrates to zero and is removed from the second line\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"a3d0", ",", "D"}], "]"}], ",", "y"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "A"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
  RowBox[{"A", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"A", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405710514222651*^9, 3.405754672327066*^9, 
  3.440942237765532*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"a3d0", "+", 
      RowBox[{"A", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}]}], " ", "/.", " ", 
     RowBox[{"D", "\[Rule]", "0"}]}], "]"}], ",", "y"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "A"}], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"A", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405710918478561*^9, 3.4057546797996683`*^9, 
  3.440942238192054*^9}]
}, Open  ]],

Cell["Coefficient in front of C in a3d", "Text",
 CellChangeTimes->{{3.405710925928004*^9, 3.405710928733447*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3d2", " ", "=", 
  RowBox[{"Improve", "[", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a3d", ",", 
     RowBox[{"A", " ", "C"}]}], "]"}], " ", "]"}]}]], "Input",
 CellChangeTimes->{
  3.405711887382365*^9, {3.4057547683618507`*^9, 3.4057547689028893`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], "2"], 
     " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "4"], " ", "\[Mu]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "8"]}], "-", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", "\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
          RowBox[{"6", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "-", 
          RowBox[{
           FractionBox["5", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"3", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"5", "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"4", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], "-", 
          RowBox[{"30", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "-", 
       RowBox[{"5", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
  "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
   RowBox[{"5", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.405711906784886*^9, 3.405754707995695*^9, 
  3.4057547703886414`*^9, 3.440942245468*^9}]
}, Open  ]],

Cell["\<\
Mathematica does not integrate this expression but after a few manipulations \
we get an expression for a3d2 as the sum of two derivatives plus a residual \
term.
In the residual term, f1'[y] has CosI symmetry. Its product with \
Sin[2\[Theta][y]] \[Theta]'[y] has SinP symmetry with zero mean.
Hence the solvability condition is satisfied for all the terms contributing \
to a3d\
\>", "Text",
 CellChangeTimes->{{3.405712617213736*^9, 3.405712705533528*^9}, {
  3.405712750084974*^9, 3.405712913677759*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3d2P", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"2", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          "2"]}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
         RowBox[{"5", "/", "2"}]]], 
       RowBox[{
        RowBox[{"f1", "'"}], "[", "y", "]"}]}], ",", "y"}], "]"}], "-", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
        SqrtBox[
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "2"}], "}"}]}], "]"}], 
     RowBox[{"f1", "[", "y", "]"}]}], "-", " ", 
    FractionBox[
     RowBox[{"\[Mu]", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", 
        RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], 
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}]]}]}], 
  ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a3d2P", "-", "a3d2"}], "]"}]}], "Input",
 CellChangeTimes->{3.405712724887277*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405712947643134*^9, 3.4057547264923677`*^9, 
  3.405754779043853*^9, 3.4409422458219757`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a3g"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3g", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"a31", ",", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["f1", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.4057135888749*^9, 3.405754999269525*^9, 
  3.440942246185749*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Verification", "Subsubsection"],

Cell["\<\
Assemble all the contribution found at order 3 plus the linear term in \
\[Psi]3, and check the sum against a3\
\>", "Text",
 CellChangeTimes->{{3.405713595570601*^9, 3.40571365848319*^9}, {
  3.40571370802528*^9, 3.405713764152111*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3N", "=", 
   RowBox[{
    RowBox[{"a3g", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{"a3d", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{"a3b", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{"a3a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "3"]}], "+", "  ", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]3", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"Together", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{
     RowBox[{"a3N", "-", "a3"}], " ", "/.", " ", "Rulea"}], "]"}], "]"}], " ",
   "]"}]}], "Input",
 CellChangeTimes->{
  3.40571373382877*^9, {3.440941785523119*^9, 3.440941828104637*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.40571369948894*^9, 3.405713782318974*^9, {3.405754986385345*^9, 
   3.4057550042718554`*^9}, 3.440942247060009*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection",
 CellChangeTimes->{{3.40569149000653*^9, 3.405691494113007*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rule3", "=", 
   RowBox[{"\[Psi]3", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f3g", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "  ", "+", " ", 
       RowBox[{
        RowBox[{"f3d", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f3b", "[", "#3", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[CurlyPhi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X"}], "]"}]}], " ", ")"}]}], "+", " ", 
       RowBox[{
        RowBox[{"f3a", "[", "#3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], "3"]}]}], "&"}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4409418599926367`*^9, 3.44094187789933*^9}, 
   3.4409419902317133`*^9}],

Cell["\<\
f3a has SinI symmetry
f3b has SinP symmetry
f3c has CosI symmetry
f3d has SinI symmetry
f3e has CosP symmetry
f3f has SinI symmetry
f3g has SinI symmetry
f3h has SinI symmetry\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 4", "Section"],

Cell[TextData[{
 "Extract order 4 terms from the general expansion, use formal solution to \
order 0, 1, 2 and 3 equations and perform algebraic simplication.\nNeed to be \
put under the form \[ScriptCapitalL][",
 Cell[BoxData[
  RowBox[{"\[Psi]4", "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]]],
 "] = second member\nNo attemps to simplify here"
}], "Text",
 CellChangeTimes->{{3.405679657829858*^9, 3.4056796909836483`*^9}, {
  3.405679880386196*^9, 3.405679880744329*^9}, {3.4056800107889*^9, 
  3.405680078314219*^9}, {3.405680117909005*^9, 3.405680189847745*^9}, {
  3.405685906475298*^9, 3.405685933174532*^9}, {3.405688214542055*^9, 
  3.405688233724618*^9}, {3.405688414807213*^9, 3.405688425967601*^9}, {
  3.405713897641922*^9, 3.405713898274895*^9}, {3.40575505879291*^9, 
  3.4057550692681227`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4", " ", "=", " ", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"A", ">", "0"}], " ", "&&", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", ">", "0"}]}], ",", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"NS2", ",", "\[Epsilon]", ",", "4"}], "]"}], "   ", "//.", " ",
       
      RowBox[{"{", 
       RowBox[{"Rule0", ",", "Rule1", ",", "Rule2", ",", "Rule3"}], "}"}]}]}],
     "  ", "]"}]}], ";"}]], "Input"],

Cell["Rearrange a4 to prepair extraction", "Text",
 CellChangeTimes->{{3.4057550866309853`*^9, 3.4057550996880407`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a41", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a4", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "4"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.440942020391774*^9, 3.440942021197506*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "4"]}], ":", " ", 
  "a4a"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"a41", ",", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], "4"]}], "]"}], " ", "/.", " ", 
      "Rulea"}], ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input"],

Cell["\<\
Contribution that does not contain C.
Can be integrated and satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.4057551808796577`*^9, 3.405755253445551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4a0", "=", 
  RowBox[{"a4a", "  ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f3a", 
   TagBox[
    RowBox[{"(", "3", ")"}],
    Derivative],
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{3.405755374229994*^9}]
}, Open  ]],

Cell["Expand the rest of a4a in powers of A", "Text",
 CellChangeTimes->{{3.40575533835573*^9, 3.405755363289391*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4aL", "=", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox["A", "2"], 
      RowBox[{"Coefficient", "[", 
       RowBox[{"a4a", ",", "C"}], "]"}]}], ",", "A"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "a4aL", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", "3", "}"}]], "Output",
 CellChangeTimes->{3.405755379055417*^9}]
}, Open  ]],

Cell["Integrate separately each contribution and check solvability", "Text",
 CellChangeTimes->{{3.4057554086968327`*^9, 3.405755430519291*^9}, 
   3.4057555228684273`*^9, {3.405760252086955*^9, 3.405760259206244*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4a1", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"a4aL", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4a1I", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a4a1", ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"a4a1I2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4a1I", ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405755545525198*^9, 3.4057555760568113`*^9}, {
  3.4057557082657213`*^9, 3.405755742490711*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], "2"], 
        " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "5"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Mu]"}], "+", 
          RowBox[{"3", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
       "+", 
       RowBox[{"4", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "5"], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"\[Mu]", "+", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}]}], "-", 
       
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[Mu]"}], "+", 
          RowBox[{"2", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "4"]}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Mu]", "-", 
             RowBox[{"9", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["f1", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
            ")"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["\[Mu]", "2"]}], "-", 
          RowBox[{"6", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "4"]}], "+", 
          RowBox[{"4", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["f1", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Mu]", "+", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["f1", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
            ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"8", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
      RowBox[{"7", "/", "2"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.40575623623402*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4a2", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"a4aL", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4a2I", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a4a2", ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"a4a2I2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4a2I", ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405755839609082*^9, 3.405755842151552*^9}, {
  3.4057559316492*^9, 3.405755960986644*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[Mu]", "2"], " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
       
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", 
         RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]", "+", 
         RowBox[{"3", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}]}], 
     ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"5", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405756958196329*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4a3", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"a4aL", "[", 
     RowBox[{"[", "3", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4a3I", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a4a3", ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"a4a3I2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4a3I", ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405755984071114*^9, 3.4057560186636047`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"4", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3a", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3a", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"3", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
    RowBox[{"3", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
    RowBox[{"6", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"6", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"12", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"8", " ", "\[Mu]", " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f3a", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f3a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
  "/", 
  RowBox[{"(", 
   RowBox[{"8", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.4057581287070007`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Solva", "[", "a4a1I2", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4a2I2", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4a3I2", "]"}]}], "Input",
 CellChangeTimes->{{3.4057602648981447`*^9, 3.4057603258822727`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405760463426634*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057604634693193`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405760463514607*^9}]
}, Open  ]],

Cell["\<\
Complete instablity proof by checking that nothing has been forgotten\
\>", "Text",
 CellChangeTimes->{{3.405756111253098*^9, 3.405756132730411*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4a", " ", "-", " ", "a4a0", " ", "-", " ", 
   RowBox[{
    FractionBox["C", 
     SuperscriptBox["A", "2"]], "a4a1"}], " ", "-", " ", 
   RowBox[{
    FractionBox["C", "A"], " ", "a4a2"}], " ", "-", " ", 
   RowBox[{"C", " ", "a4a3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.405756228732748*^9, 3.405756250472097*^9}, {
  3.4057563828863363`*^9, 3.405756451333582*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405758133459836*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], "2"]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{"Group", " ", "of", " ", "all", " ", "terms", " ", "containing", "  ",
   "a", " ", "factor", " ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], "2"]}]], "Text",
 CellChangeTimes->{{3.4057575270756073`*^9, 3.405757546269353*^9}, {
  3.4057576059926167`*^9, 3.405757612014574*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a42", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a41", ",", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}], "]"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4c"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4c", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"a42", ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", "/.", "Rulea"}], ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "A", ",", "C"}], " ", "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.4057590454196167`*^9}],

Cell["\<\
Contribution that does not contain C.
Can be integrated and satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.4057551808796577`*^9, 3.405755253445551*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c0", "=", 
   RowBox[{"a4c", "  ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}]}], ";"}], "\n", 
 RowBox[{"a4c0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4c0", ",", "y"}], "]"}]}], "\n", 
 RowBox[{"Solva", "[", "a4c0I", "]"}]}], "Input",
 CellChangeTimes->{{3.4057627942562113`*^9, 3.405762820166201*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], "-", 
     RowBox[{"3", " ", "D", " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f3b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", "D", " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405762828468363*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057628284738417`*^9}]
}, Open  ]],

Cell["Expand the rest of a4c in powers of A", "Text",
 CellChangeTimes->{{3.40575533835573*^9, 3.405755363289391*^9}, {
  3.405762994029332*^9, 3.4057629944598637`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4cL", "=", 
   RowBox[{"CoefficientList", "[", 
    RowBox[{
     RowBox[{"A", " ", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"a4c", ",", "C"}], "]"}]}], ",", "A"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "a4cL", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", "2", "}"}]], "Output",
 CellChangeTimes->{3.405762943674549*^9}]
}, Open  ]],

Cell["Integrate separately each contribution and check solvability", "Text",
 CellChangeTimes->{{3.4057554086968327`*^9, 3.405755430519291*^9}, 
   3.4057555228684273`*^9, {3.405760225057373*^9, 3.405760236790447*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c1", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"a4cL", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4c1I", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a4c1", ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"a4c1I2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4c1I", ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.405762871324792*^9, 3.4057629051957693`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"8", " ", 
        RowBox[{"f1", "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ",
         
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["f1", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
           " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"6", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", 
             RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Mu]", "+", 
             RowBox[{"3", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["f1", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
            ")"}]}]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{
              SuperscriptBox["f2b", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"8", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
      RowBox[{"5", "/", "2"}]]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.405764121559807*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c2", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"a4cL", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4c2I", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a4c2", ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"a4c2I2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4c2I", ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.4057630839873543`*^9, 3.405763125671565*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
    RowBox[{"8", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{"f2a", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], "+", 
    
    RowBox[{"3", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"3", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"3", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"4", " ", "\[Mu]", " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}], ")"}]}], 
    "+", 
    RowBox[{"3", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"3", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f2a", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"3", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"3", " ", "\[Mu]", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"4", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405766498796932*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Solva", "[", "a4c1I2", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4c2I2", "]"}]}], "Input",
 CellChangeTimes->{{3.405763135685845*^9, 3.4057631677205677`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405766499136558*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405766499201949*^9}]
}, Open  ]],

Cell["\<\
Complete solvability proof by checking that nothing has been forgotten\
\>", "Text",
 CellChangeTimes->{{3.405756111253098*^9, 3.405756132730411*^9}, {
  3.405767620302533*^9, 3.40576762451611*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4c", " ", "-", " ", "a4c0", "  ", "-", " ", 
   RowBox[{
    FractionBox["C", "A"], " ", "a4c1"}], " ", "-", " ", 
   RowBox[{"C", " ", "a4c2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.405756228732748*^9, 3.405756250472097*^9}, {
  3.4057563828863363`*^9, 3.405756451333582*^9}, {3.405758938621805*^9, 
  3.405758969050767*^9}, {3.405763055422038*^9, 3.405763067648732*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405758133459836*^9, 3.405761817581015*^9, 
  3.4057665050932913`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Hence", ",", " ", 
  RowBox[{"there", " ", "is", " ", "no", " ", "term", " ", "like", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", "in", " ", "the", " ", "amplitude", 
   " ", 
   RowBox[{"equation", ".", " ", "Finding"}], " ", "this", " ", "term", " ", 
   "in", " ", "previous", " ", "versions", " ", "of", " ", "this", " ", 
   "calculation", " ", "was", " ", "a", " ", "spurious", " ", "consequence", 
   " ", "of", " ", "the", " ", "singularities", " ", "induced", " ", "by", 
   " ", "vanishing", " ", "viscosity", " ", "at", " ", "the", " ", "center", 
   " ", "of", " ", "the", " ", 
   RowBox[{"jet", "."}]}]}]], "Text",
 CellChangeTimes->{{3.405763029376891*^9, 3.405763047146044*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{"Group", " ", "of", " ", "all", " ", "terms", " ", "containing", "  ",
   "a", " ", "factor", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Text",
 CellChangeTimes->{{3.4057575270756073`*^9, 3.405757546269353*^9}, {
  3.405757599066083*^9, 3.405757622894477*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a43", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a41", ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", "a4g"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4g", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"a43", ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", "/.", " ", "Rulea"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.4057688735777407`*^9}],

Cell["\<\
Contribution that does not contain C.
Can be integrated and satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.4057551808796577`*^9, 3.405755253445551*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4g0", "=", 
   RowBox[{"a4g", " ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}]}], ";"}]], "Input",
 CellChangeTimes->{3.405767457084242*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4gOI", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4g0", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4gOI", "]"}]}], "Input",
 CellChangeTimes->{{3.4057674653494883`*^9, 3.405767485721105*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f3d", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.405768885960895*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405768885984818*^9}]
}, Open  ]],

Cell["\<\
Expand the rest of a4g in powers of A\
\>", "Text",
 CellChangeTimes->{{3.40575533835573*^9, 3.405755363289391*^9}, {
  3.405762994029332*^9, 3.4057629944598637`*^9}, {3.405768933023402*^9, 
  3.405768940484323*^9}, {3.4057707003752127`*^9, 3.4057707137701807`*^9}, {
  3.405770941336204*^9, 3.40577094511432*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4gL", "=", 
   RowBox[{"CoefficientList", "[", " ", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a4g", ",", "C"}], "]"}], ",", "A"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "a4gL", "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", "2", "}"}]], "Output",
 CellChangeTimes->{3.4057689450646143`*^9}]
}, Open  ]],

Cell["\<\
The two contributions caanot be integrated but, after some manipulations, it \
is possible for both of them to extract an integrable part on which the \
solvability condition can be tested an a non integrable part for which the \
solvability condition is obtained due to the symmetries\
\>", "Text",
 CellChangeTimes->{{3.4057691019715643`*^9, 3.4057691027106447`*^9}, {
  3.405769245709103*^9, 3.405769281169829*^9}, {3.405769829880949*^9, 
  3.405769943488309*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4g1", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"a4gL", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.4057698240388317`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4g1Pa", "=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"\[Mu]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
       
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f1", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}], ")"}], "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"]}], "+", 
         RowBox[{"6", " ", "\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
     "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        RowBox[{"5", "/", "2"}]]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4g1Pb", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}], ")"}], "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
      RowBox[{"3", "/", "2"}]]}], " ", 
    SuperscriptBox[
     RowBox[{
      RowBox[{"f1", "'"}], "[", "y", "]"}], "2"]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4g1Pc", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       RowBox[{"f2b", "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
      "+", 
      RowBox[{"2", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
      "-", 
      RowBox[{
       RowBox[{"f1", "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          " ", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f3d", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f3d", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["f3d", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          " ", 
          RowBox[{
           SuperscriptBox["f3d", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
    "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4g1Pb", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4g1Pc", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4g1P", "=", 
   RowBox[{"a4g1Pa", " ", "+", " ", 
    RowBox[{"D", "[", 
     RowBox[{"a4g1Pb", ",", "y"}], "]"}], "+", " ", 
    RowBox[{"D", "[", 
     RowBox[{"a4g1Pc", ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4g1", "-", "a4g1P"}], "]"}]}], "Input",
 CellChangeTimes->{{3.4057693100629683`*^9, 3.405769575467018*^9}, 
   3.405770014013647*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057700938079567`*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405770093907655*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405770094477783*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "All", " ", "the", " ", "non", " ", "integrated", " ", "terms", " ", "in", 
   " ", "a4g1Pa", "  ", "have", " ", "CosI", " ", "symmetry", " ", "and", " ",
    "hence", " ", "sum", " ", "to", " ", 
   RowBox[{"zero", ".", "\[IndentingNewLine]", "In"}], " ", "particular", " ",
    "6", " ", "\[Mu]", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{"Sin", "[", 
     RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", "is", " ", "CosI", " ", 
   "SinI", " ", "SinP"}], ",", " ", 
  RowBox[{"that", " ", "is", " ", "CosP"}], ",", " ", 
  RowBox[{"in", " ", "factor", " ", "of", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], "2"], " ", "which", " ", 
   "is", " ", 
   RowBox[{"CosI", "."}]}]}]], "Text",
 CellChangeTimes->{{3.405769981363545*^9, 3.4057700059682217`*^9}, {
  3.405770043009708*^9, 3.405770053187258*^9}, {3.405774628443433*^9, 
  3.405774643689392*^9}, {3.405774740191969*^9, 3.405774740901881*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4g2", "=", 
  RowBox[{"Improve", "[", 
   RowBox[{"a4gL", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        "2"], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[Mu]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", 
         RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
       
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"f2a", "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "8"]}], "-", 
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", "\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
            RowBox[{"6", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "-", 
            RowBox[{
             FractionBox["5", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"3", " ", 
                 RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"4", " ", 
                 RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], "-",
             
            RowBox[{"30", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"5", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}]}],
    ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
   RowBox[{"5", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.405770135485688*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4g2P", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
         
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]]}], 
       RowBox[{"f2a", "[", "y", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"6", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]], " ", 
     RowBox[{
      RowBox[{"f2a", "''"}], "[", "y", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]"}], "-", 
             RowBox[{"4", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                 MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}],
           "+", 
          RowBox[{"4", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
      "/", 
      RowBox[{"(", 
       SqrtBox[
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], ")"}]}], 
     " ", 
     RowBox[{
      RowBox[{"f2a", "'"}], "[", "y", "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4g2", "-", "a4g2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.40577028245893*^9, 3.405770287327407*^9}, {
  3.405770483455885*^9, 3.405770495291567*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057704974092007`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"f2a", "''"}], "[", "y", "]"}], " ", "has", " ", "symmetry", " ", 
   "CosI"}], ",", " ", 
  RowBox[{
  "its", " ", "product", " ", "with", " ", "a", " ", "CosP", " ", "term", " ",
    "is", " ", "CosI", " ", "and", " ", "integrates", " ", "to", " ", 
   RowBox[{"zero", ".", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f2a", "'"}], "[", "y", "]"}]}], " ", "has", " ", "SinI", " ", 
   "symmetry"}], ",", " ", 
  RowBox[{"and", " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", "has", " ", "SinP", " ", 
   "symmetry"}], ",", " ", 
  RowBox[{
  "hence", " ", "there", " ", "are", " ", "two", " ", "products", " ", "CosI",
    " ", "SinI", " ", "SinI", " ", "and", " ", "CosI", " ", "CosI", " ", 
   "SinP", " ", "SinI", " ", "which", " ", "have", " ", "CosI", " ", 
   "symmetry", " ", "and", " ", "integrate", " ", "to", " ", 
   RowBox[{"zero", "."}]}]}]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4g", " ", "-", " ", "a4g0", " ", "-", " ", 
   RowBox[{"C", " ", "a4g1"}], " ", "-", " ", 
   RowBox[{"A", " ", "C", " ", "a4g2"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.4057705188754*^9, 3.405770577872403*^9}, {
  3.405770822226029*^9, 3.405770861128509*^9}, {3.40577092681625*^9, 
  3.405770927892981*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.405770573784492*^9, 3.405770602304522*^9}, {
   3.405770849493455*^9, 3.40577086373145*^9}, 3.4057709530166407`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4h"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4h", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"a43", ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", "/.", " ", "Rulea"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.40577097598291*^9}],

Cell["\<\
Contribution that does not contain C.
  Can be integrated and satisfies the solvability condition.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4h0", "=", 
  RowBox[{"a4h", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.405772134095028*^9, 3.405772134487248*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["f3g", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.405771315175596*^9, 3.405772135947776*^9}]
}, Open  ]],

Cell["Get contribution in C, integrate it and check solvability", "Text",
 CellChangeTimes->{{3.405771165093082*^9, 3.405771184911344*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4h1", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a4h", ",", "C"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4h1I", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a4h1", ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"a4h1I2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4h1I", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4h1I2", "]"}]}], "Input",
 CellChangeTimes->{3.4057709903100767`*^9, 3.4057710867285633`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f3g", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f3g", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f3g", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ",
         
        RowBox[{
         SuperscriptBox["f3g", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
  "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
   RowBox[{"3", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.405771314890854*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405771314899076*^9}]
}, Open  ]],

Cell["\<\
Complete the proof of solvability by showing nothing has been forgotten\
\>", "Text",
 CellChangeTimes->{{3.4057720487117558`*^9, 3.4057720761673517`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4h", "-", "a4h0", " ", "-", 
   RowBox[{"C", " ", "a4h1"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.405772082667087*^9, 3.405772101676757*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057721045515738`*^9, 3.405772149732856*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  "a4l"}], "\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{
  "contributes", " ", "to", " ", "the", " ", "amplitude", " ", "equation"}], 
  ")"}]}], "Subsubsection",
 CellChangeTimes->{{3.40577326685183*^9, 3.405773276842127*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4l", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"a41", ",", "  ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "4"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", "/.", " ", "Rulea"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], " ", "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.405778535921381*^9}],

Cell["\<\
Contribution independent of C.
  The two terms of a4l0 are of symmetry CosP, they have no primitive and \
provide a contribution to the amplitude equation.\
\>", "Text",
 CellChangeTimes->{{3.405773297999565*^9, 3.405773446969352*^9}, {
  3.405774550179636*^9, 3.405774566382914*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4l0", "=", 
  RowBox[{"a4l", " ", "/.", " ", 
   RowBox[{"C", "\[Rule]", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.405773449821535*^9, 3.4057734506448717`*^9}}],

Cell[BoxData[
 RowBox[{"A", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"f1", "[", "y", "]"}]}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
    RowBox[{"D", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.4057791487556553`*^9}]
}, Open  ]],

Cell["\<\
Now get the coefficient of C. It has no primitive but can be described as a \
sum of derivatives and residual terms.\
\>", "Text",
 CellChangeTimes->{{3.4057785839594183`*^9, 3.405778601640111*^9}, {
  3.4057786442864113`*^9, 3.40577874277704*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4l1", "=", 
  RowBox[{"Improve", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a4l", ",", "C"}], "]"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"A", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
       RowBox[{"f2b", "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "8"]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[Mu]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", 
         RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f2b", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
       
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{"f2b", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"f2b", "[", "y", "]"}], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", "\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
            RowBox[{"6", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
             SuperscriptBox["f2b", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"f2b", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "-", 
            RowBox[{
             FractionBox["5", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"3", " ", 
                 RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"2", " ", 
             RowBox[{
              SuperscriptBox["f2b", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"f2b", "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"4", " ", 
                 RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], "-",
             
            RowBox[{"30", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{"f2b", "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{"5", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
       RowBox[{"f2b", "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
       RowBox[{"f2b", "[", "y", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
   RowBox[{"5", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.4057791595962973`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4l1Pa", " ", "=", " ", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4l1Pb", " ", "=", " ", 
   RowBox[{
    FractionBox[
     RowBox[{"2", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], 
     SqrtBox[
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]], 
    RowBox[{"f2b", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4l1Pc", " ", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", 
         RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"7", "+", 
            RowBox[{"3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", 
            RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
     "/", 
     RowBox[{"(", 
      RowBox[{"4", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        RowBox[{"3", "/", "2"}]]}], ")"}]}], " ", 
    RowBox[{"f2b", "[", "y", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4l1Pd", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "4"]}], "+", 
        RowBox[{"3", " ", "\[Mu]", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", 
                 RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}]}], 
             ")"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
       ")"}]}], ")"}], "/", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4l1P", "=", 
   RowBox[{
    RowBox[{"A", " ", "a4l1Pa"}], "+", 
    RowBox[{"A", " ", 
     RowBox[{"D", "[", 
      RowBox[{"a4l1Pb", ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], " ", "-", " ", 
    RowBox[{"A", " ", 
     RowBox[{"D", "[", 
      RowBox[{"a4l1Pc", ",", "y"}], "]"}]}], " ", "-", 
    RowBox[{"A", " ", 
     RowBox[{"f2b", "[", "y", "]"}], 
     RowBox[{"D", "[", 
      RowBox[{"a4l1Pd", ",", "y"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4l1", "-", "a4l1P"}], "]"}]}], "Input",
 CellChangeTimes->{{3.405778804231544*^9, 3.405778954165442*^9}, {
   3.405779001962867*^9, 3.405779023790101*^9}, 3.405779106948366*^9, {
   3.405779311513914*^9, 3.405779330755417*^9}, {3.4057795204768047`*^9, 
   3.4057795345895157`*^9}, {3.405779690178726*^9, 3.405779700074843*^9}, {
   3.405780014437278*^9, 3.405780016437257*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.405779125968079*^9, 3.405779172163254*^9, {3.405779337151836*^9, 
   3.405779364789768*^9}, 3.405779399805955*^9, 3.4057794547113457`*^9, 
   3.405779503702523*^9, 3.4057795368013783`*^9, 3.4057797019355297`*^9, 
   3.405780017913056*^9}]
}, Open  ]],

Cell["\<\
The first and the fourth term contribute as they are product of trig \
functions with same symmetry.\
\>", "Text"],

Cell["Check that nothing has been forgotten", "Text",
 CellChangeTimes->{{3.405780081706346*^9, 3.40578009218684*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4l", " ", "-", " ", "a4l0", " ", "-", " ", 
   RowBox[{"C", " ", "a4l1"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{{3.405780096973837*^9, 3.405780145849922*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.405780130925108*^9, 3.405780147243774*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  "a4n"}], "\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{
  "contributes", " ", "to", " ", "the", " ", "amplitude", " ", "equation"}], 
  ")"}]}], "Subsubsection",
 CellChangeTimes->{{3.40577306274051*^9, 3.405773131776634*^9}, {
  3.4057801891531677`*^9, 3.40578019344256*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4n", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a41", ",", "  ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"{", 
     RowBox[{"A", ",", "D"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "1"}], "-", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.40578474080618*^9}]
}, Open  ]],

Cell["\<\
The first term makes a contribution to the amplitude equation and the \
secondone satisfies the solvability condition.\
\>", "Text",
 CellChangeTimes->{{3.405773034258717*^9, 3.405773056972809*^9}, {
  3.405773140256077*^9, 3.405773177236987*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], ":", " ", 
  "a4o"}]], "Subsubsection",
 CellChangeTimes->{{3.4057811527477016`*^9, 3.405781154299303*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4o", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"a41", ",", "  ", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["\[CurlyPhi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], " ", "]"}], " ", "/.",
       "Rulea"}], ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], " ", "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.405774813424066*^9, 3.405774821561133*^9}}],

Cell["\<\
The contribution independent of C has a primitive and satisfies the \
solvability condition\
\>", "Text",
 CellChangeTimes->{{3.405775267257039*^9, 3.405775312793243*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o0", "=", 
   RowBox[{"a4o", " ", "/.", " ", 
    RowBox[{"C", "\[Rule]", "0"}]}]}], ";"}], "\n", 
 RowBox[{"a4o0I", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4o0", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4oI0", "]"}]}], "Input",
 CellChangeTimes->{{3.405775332191866*^9, 3.4057753823561068`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{
     SuperscriptBox["f1", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], "-", 
     RowBox[{"D", " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"D", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.405775386767068*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.40577538677227*^9}]
}, Open  ]],

Cell["Expand the rest of a4o in power of A", "Text",
 CellChangeTimes->{{3.405775392778092*^9, 3.405775408735867*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4oL", "=", 
   RowBox[{"CoefficientList", "[", " ", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"a4o", ",", "C"}], "]"}], ",", "A"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Dimensions", "[", "a4oL", "]"}]}], "Input",
 CellChangeTimes->{{3.405775414916768*^9, 3.4057754152964687`*^9}}],

Cell[BoxData[
 RowBox[{"{", "2", "}"}]], "Output",
 CellChangeTimes->{3.405775419368881*^9}]
}, Open  ]],

Cell["\<\
The term in C cannot be integrated but it can be sorted in 3 parts\
\>", "Text",
 CellChangeTimes->{{3.405776170244063*^9, 3.40577618342692*^9}, {
  3.4057764251543837`*^9, 3.405776436923333*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4o1", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"a4oL", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.405776152637424*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o1c", "=", 
   RowBox[{"a4o1", " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"f1", "[", "y", "]"}], "->", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f1", "'"}], "[", "y", "]"}], "->", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f1", "''"}], "[", "y", "]"}], "->", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f2b", "'"}], "[", "y", "]"}], "->", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f2b", "''"}], "[", "y", "]"}], "->", "0"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f2b", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}], "->", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f2b", 
         TagBox[
          RowBox[{"(", "4", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}], "->", "0"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4o1a", "=", 
   RowBox[{
    RowBox[{"a4o1", " ", "-", " ", "a4o1c"}], " ", "/.", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"f1", "[", "y", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f1", "'"}], "[", "y", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f1", "''"}], "[", "y", "]"}], "\[Rule]", "0"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4o1b", "=", 
   RowBox[{
    RowBox[{"a4o1", " ", "-", " ", "a4o1c"}], "   ", "/.", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f2b", "'"}], "[", "y", "]"}], "->", "0"}], ",", 
      RowBox[{
       RowBox[{
        RowBox[{"f2b", "''"}], "[", "y", "]"}], "->", "0"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f2b", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}], "->", "0"}], ",", " ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f2b", 
         TagBox[
          RowBox[{"(", "4", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}], "->", "0"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4o1", "-", "a4o1a", "-", "a4o1b", "-", "a4o1c"}], "]"}]}], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057764696421537`*^9}]
}, Open  ]],

Cell["\<\
The first part has a primitive and satisfies the solvability condition\
\>", "Text",
 CellChangeTimes->{{3.405776455993355*^9, 3.405776489157802*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o1aI", "=", 
   RowBox[{"Improve", "[", 
    RowBox[{"Integrate", "[", 
     RowBox[{"a4o1a", ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"a4o1aI2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{"a4o1aI", ",", "y"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4o1aI2", "]"}]}], "Input",
 CellChangeTimes->{{3.405776500524891*^9, 3.405776558140074*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{
        SuperscriptBox["f2b", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{
        SuperscriptBox["f2b", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405776661427073*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.40577666151683*^9}]
}, Open  ]],

Cell["Now, only two components have no primitive", "Text",
 CellChangeTimes->{{3.405777485743918*^9, 3.4057774874820337`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a4o1bP", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         RowBox[{"\[Mu]", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], 
         RowBox[{"2", " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}]], 
        SuperscriptBox[
         RowBox[{"f1", "[", "y", "]"}], "2"]}], "+", 
       RowBox[{
        FractionBox[
         RowBox[{"4", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "  ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], 
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]], 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "86"}], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
             RowBox[{"5", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"3", " ", 
                RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"5", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "5"]}], "-", 
          RowBox[{"16", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", "\[Mu]", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
             RowBox[{"\[Mu]", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"3", " ", 
                RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
             RowBox[{"6", " ", 
              SuperscriptBox[
               RowBox[{"Cos", "[", 
                RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Mu]", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"2", " ", 
                RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "+", 
             RowBox[{"4", " ", 
              RowBox[{"(", 
               RowBox[{"4", "+", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", 
                  RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
              
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
          RowBox[{"32", " ", "\[Mu]", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{"32", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], ")"}], 
      "/", 
      RowBox[{"(", 
       RowBox[{"16", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{
       RowBox[{"f1", "'"}], "[", "y", "]"}], "2"]}], "-", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"]}], "+", 
          RowBox[{"5", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"2", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "4"]}]}], ")"}]}], 
       ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"4", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
         RowBox[{"5", "/", "2"}]]}], ")"}]}], 
     SuperscriptBox[
      RowBox[{
       RowBox[{"f1", "''"}], "[", "y", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", 
               RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[Mu]", " ", 
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
             RowBox[{"2", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
         ")"}]}], ")"}], "/", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], 
     RowBox[{
      RowBox[{"f1", "'"}], "[", "y", "]"}], 
     RowBox[{
      RowBox[{"f1", "''"}], "[", "y", "]"}]}]}]}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4o1b", "-", "a4o1bP"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405778458937687*^9}]
}, Open  ]],

Cell["\<\
It is easy to check that all the terms which are not under the derivative in \
a4o1bP are with CosI symmetry and integrate to zero\
\>", "Text",
 CellChangeTimes->{{3.405777459366008*^9, 3.4057774700174217`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["a4o1c"], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     FractionBox["1", "16"], " ", "\[Mu]", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", 
       RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "114"}], " ", "\[Mu]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
       RowBox[{"3", " ", "\[Mu]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"3", " ", 
          RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], "-", 
       RowBox[{"3", " ", "\[Mu]", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"5", " ", 
          RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "5"]}], "-", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "7"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "7"]}], "+", 
    RowBox[{
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"]}], "+", 
       RowBox[{"21", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox["\[Mu]", "2"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{"9", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"9", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"15", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], "+", 
    
    RowBox[{"3", " ", 
     SuperscriptBox["\[Mu]", "3"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     SuperscriptBox[
      RowBox[{"Cos", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", 
       RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Theta]", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"7", "/", "2"}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.405778464311108*^9}]
}, Open  ]],

Cell["\<\
The numerator is a sum of terms with CosI symmetry, which is preserved by the \
division by the denominator in CosP, integrating a4o1c to zero. Let us check \
it numerically for some examples.\
\>", "Text",
 CellChangeTimes->{{3.405777517685257*^9, 3.405777657205868*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"a4o1c", "  ", "/.", 
     RowBox[{"{", " ", 
      RowBox[{"Flow1", ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"a4o1c", "  ", "/.", 
     RowBox[{"{", " ", 
      RowBox[{"Flow2", ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"a4o1c", "  ", "/.", 
     RowBox[{"{", " ", 
      RowBox[{"Flow3", ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0.5"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData["0``12.206708418836731"], "Output",
 CellChangeTimes->{3.405778469935143*^9}],

Cell[BoxData["0``14.081160434154496"], "Output",
 CellChangeTimes->{3.405778470090929*^9}],

Cell[BoxData["0``14.518780529848959"], "Output",
 CellChangeTimes->{3.405778470240137*^9}]
}, Open  ]],

Cell["\<\
Let us consider the coefficient of A C
It does not have a primitive but can be put under the sum of a derivative \
plus a residual\
\>", "Text",
 CellChangeTimes->{{3.4057759133907623`*^9, 3.405775984441053*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4o2", "=", 
  RowBox[{"Improve", "[", 
   RowBox[{"a4oL", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.405775573096249*^9, 3.405775577298867*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        "2"], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "4"], " ", "\[Mu]", " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", 
         RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["f2a", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
       
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"5", "+", 
            RowBox[{"Cos", "[", 
             RowBox[{"2", " ", 
              RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
            RowBox[{"2", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"f2a", "[", "y", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "8"]}], "-", 
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "6"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", "\[Mu]", " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
            RowBox[{"6", " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}], "-", 
            RowBox[{
             FractionBox["5", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"3", " ", 
                 RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"4", " ", 
                 RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}]}], ")"}]}], "-",
             
            RowBox[{"30", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"5", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "6"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "5"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}]}],
    ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
   RowBox[{"5", "/", "2"}]]}]], "Output",
 CellChangeTimes->{3.405775668902338*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o2P", "=", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
         
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]]}], 
       RowBox[{"f2a", "[", "y", "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"6", " ", "\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ",
         
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2a", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "\[Mu]", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", 
          RowBox[{"4", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}], 
     "/", 
     RowBox[{"(", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}]}]], ")"}]}]}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4o2", "-", "a4o2P"}], "]"}]}], "Input",
 CellChangeTimes->{{3.40577562322794*^9, 3.405775657223856*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405775690592754*^9}]
}, Open  ]],

Cell["\<\
Again there is CosI symmetry for all terms in the numerator, integrating to \
zero and satisfying the solvability condition.
Complete the proof by checking that nothing has been forgotten\
\>", "Text",
 CellChangeTimes->{{3.405776003944607*^9, 3.405776061621484*^9}, {
  3.405776379775682*^9, 3.4057763809659147`*^9}, {3.405777252614065*^9, 
  3.405777253680674*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a4o", " ", "-", " ", "a4o0", " ", "-", " ", 
   RowBox[{"C", " ", "a4o1"}], " ", "-", " ", 
   RowBox[{"A", " ", "C", " ", "a4o2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.405776064778646*^9, 3.405776123256608*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4057761305680323`*^9, 3.4057763944012136`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Verification", "Subsubsection",
 CellChangeTimes->{3.405783109694642*^9, 3.424787620444553*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Expand", "[", "a4", "]"}], "-", "a41"}], "]"}]], "Input",
 CellChangeTimes->{{3.4057824851749697`*^9, 3.405782490104938*^9}, {
  3.405782524941266*^9, 3.405782532191402*^9}, {3.405782631775648*^9, 
  3.405782636736158*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.40578534016892*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4NN", "=", " ", 
   RowBox[{
    RowBox[{"a4o", " ", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], "+", 
    RowBox[{"a4n", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", "   ", 
    RowBox[{"a4l", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a4g", "  ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "+", 
       RowBox[{"a4h", " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], " ", "+", 
    "\[IndentingNewLine]", 
    RowBox[{"a4c", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
    RowBox[{"a4a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "4"]}], "+", "  ", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]4", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"Expand", "[", 
    RowBox[{"a4NN", "-", "a41"}], "]"}], " ", "/.", " ", "Rulea"}], 
  "]"}]}], "Input",
 CellChangeTimes->{
  3.4057566039740477`*^9, {3.405785280810128*^9, 3.405785289698398*^9}, {
   3.440942086964085*^9, 3.440942135476386*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.405780644817511*^9, 3.405785296758334*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dump / Recover", "Subsection",
 CellChangeTimes->{{3.4057803757773247`*^9, 3.405780388865893*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DumpSave", "[", 
  RowBox[{"\"\<CH-eff1-nu-8b.m6.mx\>\"", ",", "\"\<Global`\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.405707255571572*^9, 3.405707269590346*^9}, {
   3.405707365657104*^9, 3.405707399428372*^9}, {3.405708293588033*^9, 
   3.405708330550449*^9}, {3.40575679967369*^9, 3.405756808002439*^9}, 
   3.44094360498112*^9}],

Cell[BoxData[
 RowBox[{"{", "\<\"Global`\"\>", "}"}]], "Output",
 CellChangeTimes->{{3.40570830006631*^9, 3.405708331989448*^9}, 
   3.405713795903619*^9, 3.405753555714876*^9, 3.405754634680348*^9, 
   3.4057550220528812`*^9, 3.405756959529352*^9, 3.405758134973331*^9, 
   3.405761818912491*^9, 3.405766506606394*^9, 3.405768825483378*^9, 
   3.405772491723752*^9, 3.405774122117296*^9, 3.405774384697494*^9, 
   3.405776566513393*^9, 3.405780205698803*^9, 3.405784783431664*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "CH-eff1-nu-8b.m6.mx"}]], "Input",
 CellChangeTimes->{{3.4057529715345097`*^9, 3.405752973934311*^9}, {
   3.405756812713182*^9, 3.405756814598175*^9}, 3.440943607173853*^9}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowSize->{838, 804},
WindowMargins->{{Automatic, 67}, {Automatic, 37}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>"CH-eff.nb.ps",
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {72, 72}}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> 
     FrontEnd`FileName[{"Report"}, "StandardReport.nb", CharacterEncoding -> 
       "iso8859-1"]]], 
   Cell[
    StyleData["Output"], FontSize -> 12], 
   Cell[
    StyleData["Input"], FontFamily -> "Utopia", FontSize -> 12, FontWeight -> 
    "Bold", FontSlant -> "Plain", 
    FontVariations -> {"StrikeThrough" -> False, "Underline" -> False}], 
   Cell[
    StyleData["Subsubsection"], FontSize -> 14]}, Visible -> False, 
  FrontEndVersion -> "6.0 for Linux x86 (32-bit) (June 19, 2007)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 104, 3, 192, "Title"],
Cell[697, 28, 290, 12, 244, "Author"],
Cell[CellGroupData[{
Cell[1012, 44, 668, 20, 107, "Subtitle"],
Cell[1683, 66, 24, 0, 31, "Text"],
Cell[CellGroupData[{
Cell[1732, 70, 33, 0, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[1790, 74, 83, 2, 37, "Input",
 InitializationCell->True],
Cell[1876, 78, 427, 8, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2352, 92, 32, 0, 27, "Subsubsection"],
Cell[2387, 94, 118, 3, 37, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2542, 102, 34, 0, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[2601, 106, 437, 14, 42, "Input",
 InitializationCell->True],
Cell[3041, 122, 511, 15, 43, "Output"]
}, Open  ]],
Cell[3567, 140, 157, 3, 31, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3761, 148, 101, 2, 27, "Subsubsection"],
Cell[3865, 152, 169, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[4059, 160, 1193, 39, 67, "Input",
 InitializationCell->True],
Cell[5255, 201, 1137, 36, 50, "Output"]
}, Open  ]],
Cell[6407, 240, 563, 16, 73, "Text"],
Cell[CellGroupData[{
Cell[6995, 260, 3458, 103, 103, "Input",
 InitializationCell->True],
Cell[10456, 365, 3341, 101, 87, "Output"],
Cell[13800, 468, 196, 5, 48, "Reference"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14045, 479, 61, 0, 75, "Section"],
Cell[CellGroupData[{
Cell[14131, 483, 49, 0, 27, "Subsection"],
Cell[14183, 485, 202, 6, 39, "Input",
 InitializationCell->True],
Cell[14388, 493, 270, 8, 39, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[14695, 506, 40, 0, 27, "Subsection"],
Cell[14738, 508, 177, 4, 31, "Text"],
Cell[14918, 514, 834, 27, 117, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15789, 546, 39, 0, 27, "Subsection"],
Cell[CellGroupData[{
Cell[15853, 550, 1761, 53, 89, "Input"],
Cell[17617, 605, 81520, 1358, 149, 69052, 1152, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[99186, 1969, 49, 0, 27, "Subsection"],
Cell[CellGroupData[{
Cell[99260, 1973, 1815, 58, 82, "Input"],
Cell[101078, 2033, 19953, 1146, 148, 15269, 1067, "GraphicsData", \
"PostScript", "Graphics"],
Cell[121034, 3181, 139, 4, 45, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[121222, 3191, 59, 0, 27, "Subsection"],
Cell[121284, 3193, 307, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[121616, 3203, 468, 14, 37, "Input"],
Cell[122087, 3219, 6303, 172, 156, "Output"]
}, Open  ]],
Cell[128405, 3394, 207, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[128637, 3402, 2212, 60, 140, "Input"],
Cell[130852, 3464, 125579, 2074, 170, 105121, 1737, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[256446, 5541, 274, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[256745, 5550, 2215, 60, 140, "Input"],
Cell[258963, 5612, 117648, 1946, 171, 95594, 1582, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[376672, 7565, 56, 0, 75, "Section"],
Cell[CellGroupData[{
Cell[376753, 7569, 51, 0, 27, "Subsection"],
Cell[376807, 7571, 502, 15, 51, "Text"],
Cell[377312, 7588, 1336, 37, 60, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[378685, 7630, 31, 0, 27, "Subsection"],
Cell[378719, 7632, 159, 3, 31, "Text"],
Cell[378881, 7637, 865, 23, 60, "Input",
 InitializationCell->True],
Cell[379749, 7662, 361, 11, 37, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[380159, 7679, 26, 0, 75, "Section"],
Cell[380188, 7681, 263, 6, 51, "Text"],
Cell[CellGroupData[{
Cell[380476, 7691, 466, 14, 37, "Input"],
Cell[380945, 7707, 30473, 827, 842, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[411455, 8539, 39, 0, 27, "Subsection"],
Cell[411497, 8541, 190, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[411712, 8549, 218, 6, 37, "Input"],
Cell[411933, 8557, 306, 7, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[412288, 8570, 102, 1, 27, "Subsection"],
Cell[412393, 8573, 201, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[412619, 8581, 418, 12, 37, "Input"],
Cell[413040, 8595, 165, 2, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[413266, 8604, 51, 0, 75, "Section"],
Cell[CellGroupData[{
Cell[413342, 8608, 1266, 40, 43, "Input",
 InitializationCell->True],
Cell[414611, 8650, 1365, 41, 43, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[416013, 8696, 274, 8, 37, "Input",
 InitializationCell->True],
Cell[416290, 8706, 371, 9, 37, "Output"]
}, Open  ]],
Cell[416676, 8718, 104, 1, 31, "Text"],
Cell[416783, 8721, 579, 17, 39, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[417399, 8743, 26, 0, 75, "Section"],
Cell[417428, 8745, 531, 11, 71, "Text"],
Cell[CellGroupData[{
Cell[417984, 8760, 552, 16, 37, "Input"],
Cell[418539, 8778, 28519, 734, 826, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[447095, 9517, 72, 0, 27, "Subsection"],
Cell[447170, 9519, 116, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[447311, 9524, 476, 14, 43, "Input"],
Cell[447790, 9540, 5290, 143, 154, "Output"]
}, Closed]],
Cell[453095, 9686, 117, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[453237, 9691, 476, 14, 43, "Input"],
Cell[453716, 9707, 6754, 184, 186, "Output"]
}, Closed]],
Cell[460485, 9894, 163, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[460673, 9900, 449, 14, 43, "Input"],
Cell[461125, 9916, 3006, 80, 110, "Output"]
}, Closed]],
Cell[464146, 9999, 166, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[464337, 10005, 439, 14, 43, "Input"],
Cell[464779, 10021, 1102, 32, 68, "Output"]
}, Closed]],
Cell[465896, 10056, 179, 4, 28, "Text"],
Cell[466078, 10062, 2541, 72, 161, "Input"],
Cell[CellGroupData[{
Cell[468644, 10138, 1022, 34, 63, "Input"],
Cell[469669, 10174, 161, 2, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[469879, 10182, 120, 1, 27, "Subsection"],
Cell[470002, 10185, 181, 4, 25, "Commentary"],
Cell[CellGroupData[{
Cell[470208, 10193, 404, 13, 43, "Input"],
Cell[470615, 10208, 620, 16, 40, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[471284, 10230, 65, 0, 27, "Subsection"],
Cell[471352, 10232, 1185, 33, 43, "Commentary"],
Cell[472540, 10267, 474, 15, 40, "Input"],
Cell[CellGroupData[{
Cell[473039, 10286, 97, 2, 37, "Input"],
Cell[473139, 10290, 159, 2, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[473347, 10298, 43, 0, 27, "Subsection"],
Cell[473393, 10300, 459, 8, 61, "Commentary"],
Cell[CellGroupData[{
Cell[473877, 10312, 295, 9, 37, "Input"],
Cell[474175, 10323, 162, 2, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[474386, 10331, 39, 0, 27, "Subsection"],
Cell[474428, 10333, 193, 4, 25, "Commentary"],
Cell[CellGroupData[{
Cell[474646, 10341, 482, 15, 43, "Input"],
Cell[475131, 10358, 523, 15, 43, "Output"]
}, Open  ]],
Cell[475669, 10376, 122, 1, 25, "Commentary"]
}, Open  ]],
Cell[CellGroupData[{
Cell[475828, 10382, 105, 1, 27, "Subsection"],
Cell[475936, 10385, 247, 5, 25, "Commentary"],
Cell[CellGroupData[{
Cell[476208, 10394, 2160, 60, 110, "Input"],
Cell[478371, 10456, 1828, 54, 99, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[480236, 10515, 101, 1, 27, "Subsubsection"],
Cell[480340, 10518, 218, 3, 25, "Commentary"],
Cell[CellGroupData[{
Cell[480583, 10525, 932, 21, 60, "Input"],
Cell[481518, 10548, 227, 4, 37, "Output"]
}, Open  ]],
Cell[481760, 10555, 120, 1, 25, "Commentary"],
Cell[CellGroupData[{
Cell[481905, 10560, 1020, 23, 60, "Input"],
Cell[482928, 10585, 410, 10, 37, "Output"]
}, Open  ]],
Cell[483353, 10598, 1031, 22, 72, "Commentary"],
Cell[CellGroupData[{
Cell[484409, 10624, 4247, 124, 369, "Input"],
Cell[488659, 10750, 667, 17, 37, "Output"],
Cell[489329, 10769, 667, 17, 37, "Output"],
Cell[489999, 10788, 667, 17, 37, "Output"],
Cell[490669, 10807, 667, 17, 37, "Output"],
Cell[491339, 10826, 666, 17, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[492042, 10848, 3682, 106, 341, "Input"],
Cell[495727, 10956, 99789, 1663, 279, 80132, 1339, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[595565, 12625, 149, 2, 27, "Subsubsection"],
Cell[595717, 12629, 212, 3, 31, "Text"],
Cell[595932, 12634, 902, 19, 62, "Text"],
Cell[CellGroupData[{
Cell[596859, 12657, 5002, 148, 414, "Input"],
Cell[601864, 12807, 667, 17, 37, "Output"],
Cell[602534, 12826, 667, 17, 37, "Output"],
Cell[603204, 12845, 667, 17, 37, "Output"],
Cell[603874, 12864, 667, 17, 37, "Output"],
Cell[604544, 12883, 667, 17, 37, "Output"],
Cell[605214, 12902, 667, 17, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[605918, 12924, 3682, 106, 341, "Input"],
Cell[609603, 13032, 97635, 1629, 284, 77087, 1290, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[707311, 14669, 26, 0, 75, "Section"],
Cell[707340, 14671, 587, 12, 71, "Text"],
Cell[707930, 14685, 719, 21, 62, "Input"],
Cell[CellGroupData[{
Cell[708674, 14710, 131, 1, 27, "Subsection"],
Cell[708808, 14713, 247, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[709080, 14722, 486, 14, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[709591, 14740, 577, 18, 44, "Input"],
Cell[710171, 14760, 39550, 1034, 862, "Output"]
}, Closed]],
Cell[749736, 15797, 239, 5, 28, "Text"],
Cell[CellGroupData[{
Cell[750000, 15806, 127, 3, 37, "Input"],
Cell[750130, 15811, 346, 10, 41, "Output"]
}, Open  ]],
Cell[750491, 15824, 212, 4, 31, "Text"],
Cell[750706, 15830, 286, 7, 37, "Input"],
Cell[CellGroupData[{
Cell[751017, 15841, 116, 3, 37, "Input"],
Cell[751136, 15846, 3009, 81, 80, "Output"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[754194, 15933, 401, 11, 26, "Subsubsection"],
Cell[CellGroupData[{
Cell[754620, 15948, 629, 19, 44, "Input"],
Cell[755252, 15969, 20522, 521, 417, "Output"]
}, Closed]],
Cell[775789, 16493, 211, 4, 28, "Text"],
Cell[776003, 16499, 326, 9, 37, "Input"],
Cell[CellGroupData[{
Cell[776354, 16512, 158, 4, 37, "Input"],
Cell[776515, 16518, 623, 16, 39, "Output"]
}, Open  ]],
Cell[777153, 16537, 135, 1, 31, "Text"],
Cell[777291, 16540, 282, 7, 37, "Input"],
Cell[CellGroupData[{
Cell[777598, 16551, 323, 8, 37, "Input"],
Cell[777924, 16561, 1018, 30, 66, "Output"]
}, Open  ]],
Cell[778957, 16594, 178, 2, 31, "Text"],
Cell[779138, 16598, 313, 7, 37, "Input"],
Cell[CellGroupData[{
Cell[779476, 16609, 231, 5, 37, "Input"],
Cell[779710, 16616, 1117, 31, 40, "Output"]
}, Open  ]],
Cell[780842, 16650, 276, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[781143, 16660, 397, 7, 37, "Input"],
Cell[781543, 16669, 121, 2, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[781725, 16678, 65, 0, 27, "Subsection"],
Cell[781793, 16680, 271, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[782089, 16690, 964, 29, 60, "Input"],
Cell[783056, 16721, 119, 2, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[783224, 16729, 39, 0, 27, "Subsection"],
Cell[CellGroupData[{
Cell[783288, 16733, 896, 27, 48, "Input"],
Cell[784187, 16762, 892, 27, 45, "Output"]
}, Open  ]],
Cell[785094, 16792, 89, 4, 71, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[785232, 16802, 26, 0, 75, "Section"],
Cell[785261, 16804, 714, 13, 91, "Text"],
Cell[785978, 16819, 285, 8, 37, "Input"],
Cell[CellGroupData[{
Cell[786288, 16831, 65, 0, 27, "Subsection"],
Cell[786356, 16833, 154, 3, 31, "Text"],
Cell[786513, 16838, 1269, 40, 44, "Input"],
Cell[CellGroupData[{
Cell[787807, 16882, 346, 12, 28, "Subsubsection"],
Cell[788156, 16896, 588, 18, 44, "Input"],
Cell[788747, 16916, 184, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[788956, 16922, 91, 2, 37, "Input"],
Cell[789050, 16926, 299, 8, 40, "Output"]
}, Open  ]],
Cell[789364, 16937, 284, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[789673, 16946, 698, 22, 72, "Input"],
Cell[790374, 16970, 166, 2, 37, "Output"]
}, Open  ]],
Cell[790555, 16975, 373, 7, 31, "Text"],
Cell[CellGroupData[{
Cell[790953, 16986, 3192, 97, 179, "Input"],
Cell[794148, 17085, 186, 3, 37, "Output"],
Cell[794337, 17090, 186, 3, 37, "Output"]
}, Open  ]],
Cell[794538, 17096, 219, 6, 37, "Input"],
Cell[CellGroupData[{
Cell[794782, 17106, 249, 5, 55, "Input"],
Cell[795034, 17113, 2961, 85, 88, "Output"],
Cell[797998, 17200, 186, 3, 37, "Output"]
}, Open  ]],
Cell[798199, 17206, 217, 6, 37, "Input"],
Cell[CellGroupData[{
Cell[798441, 17216, 298, 6, 55, "Input"],
Cell[798742, 17224, 2985, 84, 70, "Output"],
Cell[801730, 17310, 163, 2, 70, "Output"]
}, Open  ]],
Cell[801908, 17315, 508, 8, 71, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[802453, 17328, 299, 9, 26, "Subsubsection"],
Cell[802755, 17339, 454, 12, 30, "Text"],
Cell[803212, 17353, 395, 13, 43, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[803644, 17371, 527, 18, 26, "Subsubsection"],
Cell[804174, 17391, 717, 22, 43, "Input"],
Cell[804894, 17415, 116, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[805035, 17420, 118, 3, 37, "Input"],
Cell[805156, 17425, 4219, 124, 103, "Output"]
}, Open  ]],
Cell[809390, 17552, 97, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[809512, 17558, 338, 10, 37, "Input"],
Cell[809853, 17570, 565, 16, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[810455, 17591, 179, 5, 37, "Input"],
Cell[810637, 17598, 1581, 46, 59, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[812255, 17649, 125, 2, 37, "Input"],
Cell[812383, 17653, 92, 1, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[812512, 17659, 249, 7, 37, "Input"],
Cell[812764, 17668, 617, 17, 37, "Output"]
}, Open  ]],
Cell[813396, 17688, 194, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[813615, 17696, 249, 7, 37, "Input"],
Cell[813867, 17705, 138, 2, 37, "Output"]
}, Open  ]],
Cell[814020, 17710, 229, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[814274, 17719, 310, 7, 55, "Input"],
Cell[814587, 17728, 139, 2, 37, "Output"]
}, Open  ]],
Cell[814741, 17733, 174, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[814940, 17739, 1124, 33, 89, "Input"],
Cell[816067, 17774, 143, 2, 37, "Output"]
}, Open  ]],
Cell[816225, 17779, 155, 3, 31, "Text"],
Cell[816383, 17784, 217, 6, 37, "Input"],
Cell[CellGroupData[{
Cell[816625, 17794, 154, 4, 37, "Input"],
Cell[816782, 17800, 3912, 113, 110, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[820743, 17919, 314, 10, 26, "Subsubsection"],
Cell[821060, 17931, 675, 21, 43, "Input"],
Cell[821738, 17954, 130, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[821893, 17959, 118, 3, 37, "Input"],
Cell[822014, 17964, 2779, 80, 87, "Output"]
}, Open  ]],
Cell[824808, 18047, 164, 3, 51, "Text"],
Cell[CellGroupData[{
Cell[824997, 18054, 152, 4, 37, "Input"],
Cell[825152, 18060, 1124, 32, 40, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[826313, 18097, 321, 9, 37, "Input"],
Cell[826637, 18108, 596, 17, 37, "Output"]
}, Open  ]],
Cell[827248, 18128, 114, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[827387, 18133, 288, 7, 37, "Input"],
Cell[827678, 18142, 9302, 253, 295, "Output"]
}, Open  ]],
Cell[836995, 18398, 518, 10, 91, "Text"],
Cell[CellGroupData[{
Cell[837538, 18412, 3812, 108, 162, "Input"],
Cell[841353, 18522, 143, 2, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[841545, 18530, 309, 10, 26, "Subsubsection"],
Cell[CellGroupData[{
Cell[841879, 18544, 331, 11, 43, "Input"],
Cell[842213, 18557, 230, 6, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[842492, 18569, 37, 0, 27, "Subsubsection"],
Cell[842532, 18571, 247, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[842804, 18580, 1835, 59, 80, "Input"],
Cell[844642, 18641, 168, 3, 37, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[844871, 18651, 104, 1, 27, "Subsection"],
Cell[844978, 18654, 1939, 60, 110, "Input"],
Cell[846920, 18716, 199, 9, 171, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[847168, 18731, 26, 0, 75, "Section"],
Cell[847197, 18733, 816, 15, 91, "Text"],
Cell[848016, 18750, 586, 17, 42, "Input"],
Cell[848605, 18769, 120, 1, 31, "Text"],
Cell[848728, 18772, 1775, 56, 66, "Input"],
Cell[CellGroupData[{
Cell[850528, 18832, 346, 12, 28, "Subsubsection"],
Cell[850877, 18846, 598, 19, 44, "Input"],
Cell[851478, 18867, 188, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[851691, 18875, 119, 3, 37, "Input"],
Cell[851813, 18880, 204, 7, 40, "Output"]
}, Open  ]],
Cell[852032, 18890, 118, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[852175, 18895, 331, 10, 60, "Input"],
Cell[852509, 18907, 92, 2, 37, "Output"]
}, Open  ]],
Cell[852616, 18912, 218, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[852859, 18918, 581, 16, 72, "Input"],
Cell[853443, 18936, 6856, 185, 214, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[860336, 19126, 558, 16, 72, "Input"],
Cell[860897, 19144, 2933, 86, 110, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[863867, 19235, 513, 15, 72, "Input"],
Cell[864383, 19252, 6802, 187, 212, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[871222, 19444, 263, 4, 72, "Input"],
Cell[871488, 19450, 70, 1, 37, "Output"],
Cell[871561, 19453, 72, 1, 37, "Output"],
Cell[871636, 19456, 70, 1, 37, "Output"]
}, Open  ]],
Cell[871721, 19460, 159, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[871905, 19467, 425, 10, 63, "Input"],
Cell[872333, 19479, 70, 1, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[872452, 19486, 305, 10, 28, "Subsubsection"],
Cell[872760, 19498, 488, 13, 31, "Text"],
Cell[873251, 19513, 394, 13, 44, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[873682, 19531, 566, 19, 28, "Subsubsection"],
Cell[874251, 19552, 600, 19, 43, "Input"],
Cell[874854, 19573, 188, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[875067, 19581, 355, 9, 72, "Input"],
Cell[875425, 19592, 1525, 49, 59, "Output"],
Cell[876953, 19643, 72, 1, 37, "Output"]
}, Open  ]],
Cell[877040, 19647, 169, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[877234, 19653, 308, 9, 55, "Input"],
Cell[877545, 19664, 92, 2, 37, "Output"]
}, Open  ]],
Cell[877652, 19669, 218, 2, 31, "Text"],
Cell[CellGroupData[{
Cell[877895, 19675, 513, 15, 72, "Input"],
Cell[878411, 19692, 4708, 128, 148, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[883156, 19825, 513, 15, 72, "Input"],
Cell[883672, 19842, 11199, 306, 379, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[894908, 20153, 197, 3, 55, "Input"],
Cell[895108, 20158, 70, 1, 37, "Output"],
Cell[895181, 20161, 70, 1, 37, "Output"]
}, Open  ]],
Cell[895266, 20165, 208, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[895499, 20173, 429, 8, 62, "Input"],
Cell[895931, 20183, 119, 2, 37, "Output"]
}, Open  ]],
Cell[896065, 20188, 1148, 28, 83, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[897250, 20221, 273, 9, 26, "Subsubsection"],
Cell[897526, 20232, 454, 12, 30, "Text"],
Cell[897983, 20246, 359, 12, 43, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[898379, 20263, 528, 18, 26, "Subsubsection"],
Cell[898910, 20283, 603, 19, 43, "Input"],
Cell[899516, 20304, 188, 4, 51, "Text"],
Cell[899707, 20310, 180, 5, 37, "Input"],
Cell[CellGroupData[{
Cell[899912, 20319, 249, 5, 55, "Input"],
Cell[900164, 20326, 1080, 34, 59, "Output"],
Cell[901247, 20362, 70, 1, 37, "Output"]
}, Open  ]],
Cell[901332, 20366, 324, 6, 31, "Text"],
Cell[CellGroupData[{
Cell[901681, 20376, 285, 8, 55, "Input"],
Cell[901969, 20386, 94, 2, 37, "Output"]
}, Open  ]],
Cell[902078, 20391, 477, 8, 91, "Text"],
Cell[902558, 20401, 208, 6, 37, "Input"],
Cell[CellGroupData[{
Cell[902791, 20411, 13464, 371, 617, "Input"],
Cell[916258, 20784, 72, 1, 37, "Output"],
Cell[916333, 20787, 70, 1, 37, "Output"],
Cell[916406, 20790, 70, 1, 37, "Output"]
}, Open  ]],
Cell[916491, 20794, 1294, 29, 81, "Text"],
Cell[CellGroupData[{
Cell[917810, 20827, 143, 4, 37, "Input"],
Cell[917956, 20833, 9773, 256, 417, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[927766, 21094, 4359, 124, 269, "Input"],
Cell[932128, 21220, 72, 1, 37, "Output"]
}, Open  ]],
Cell[932215, 21224, 1004, 23, 96, "Text"],
Cell[CellGroupData[{
Cell[933244, 21251, 369, 7, 37, "Input"],
Cell[933616, 21260, 167, 2, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[933832, 21268, 533, 18, 26, "Subsubsection"],
Cell[934368, 21288, 600, 19, 43, "Input"],
Cell[934971, 21309, 122, 3, 51, "Text"],
Cell[CellGroupData[{
Cell[935118, 21316, 184, 4, 37, "Input"],
Cell[935305, 21322, 398, 13, 40, "Output"]
}, Open  ]],
Cell[935718, 21338, 139, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[935882, 21343, 586, 16, 89, "Input"],
Cell[936471, 21361, 2890, 83, 110, "Output"],
Cell[939364, 21446, 70, 1, 37, "Output"]
}, Open  ]],
Cell[939449, 21450, 165, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[939639, 21457, 197, 4, 37, "Input"],
Cell[939839, 21463, 94, 1, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[939982, 21470, 522, 16, 46, "Subsubsection"],
Cell[940507, 21488, 615, 20, 44, "Input"],
Cell[941125, 21510, 294, 6, 71, "Text"],
Cell[CellGroupData[{
Cell[941444, 21520, 186, 4, 37, "Input"],
Cell[941633, 21526, 613, 18, 43, "Output"]
}, Open  ]],
Cell[942261, 21547, 258, 5, 31, "Text"],
Cell[CellGroupData[{
Cell[942544, 21556, 152, 4, 37, "Input"],
Cell[942699, 21562, 10704, 289, 333, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[953440, 21856, 7351, 206, 331, "Input"],
Cell[960794, 22064, 291, 5, 37, "Output"]
}, Open  ]],
Cell[961100, 22072, 124, 3, 31, "Text"],
Cell[961227, 22077, 118, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[961370, 22082, 217, 4, 37, "Input"],
Cell[961590, 22088, 94, 1, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[961733, 22095, 572, 17, 46, "Subsubsection"],
Cell[CellGroupData[{
Cell[962330, 22116, 471, 15, 44, "Input"],
Cell[962804, 22133, 208, 6, 39, "Output"]
}, Open  ]],
Cell[963027, 22142, 257, 5, 31, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[963321, 22152, 442, 14, 28, "Subsubsection"],
Cell[963766, 22168, 711, 22, 65, "Input"],
Cell[964480, 22192, 181, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[964686, 22200, 371, 9, 72, "Input"],
Cell[965060, 22211, 1082, 35, 56, "Output"],
Cell[966145, 22248, 69, 1, 37, "Output"]
}, Open  ]],
Cell[966229, 22252, 118, 1, 31, "Text"],
Cell[CellGroupData[{
Cell[966372, 22257, 353, 9, 55, "Input"],
Cell[966728, 22268, 92, 2, 37, "Output"]
}, Open  ]],
Cell[966835, 22273, 206, 4, 31, "Text"],
Cell[967044, 22279, 206, 6, 37, "Input"],
Cell[CellGroupData[{
Cell[967275, 22289, 2411, 78, 134, "Input"],
Cell[969689, 22369, 72, 1, 37, "Output"]
}, Open  ]],
Cell[969776, 22373, 160, 3, 31, "Text"],
Cell[CellGroupData[{
Cell[969961, 22380, 432, 11, 72, "Input"],
Cell[970396, 22393, 2650, 77, 106, "Output"],
Cell[973049, 22472, 69, 1, 37, "Output"]
}, Open  ]],
Cell[973133, 22476, 126, 1, 31, "Text"],
Cell[973262, 22479, 11018, 294, 493, "Input"],
Cell[CellGroupData[{
Cell[984305, 22777, 93, 2, 37, "Input"],
Cell[984401, 22781, 70, 1, 37, "Output"]
}, Open  ]],
Cell[984486, 22785, 222, 4, 51, "Text"],
Cell[CellGroupData[{
Cell[984733, 22793, 31, 0, 37, "Input"],
Cell[984767, 22795, 5407, 151, 256, "Output"]
}, Open  ]],
Cell[990189, 22949, 282, 5, 71, "Text"],
Cell[CellGroupData[{
Cell[990496, 22958, 1077, 31, 89, "Input"],
Cell[991576, 22991, 90, 1, 40, "Output"],
Cell[991669, 22994, 90, 1, 40, "Output"],
Cell[991762, 22997, 90, 1, 40, "Output"]
}, Open  ]],
Cell[991867, 23001, 222, 5, 71, "Text"],
Cell[CellGroupData[{
Cell[992114, 23010, 209, 5, 37, "Input"],
Cell[992326, 23017, 9773, 256, 417, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1002136, 23278, 3986, 110, 221, "Input"],
Cell[1006125, 23390, 70, 1, 37, "Output"]
}, Open  ]],
Cell[1006210, 23394, 377, 7, 71, "Text"],
Cell[CellGroupData[{
Cell[1006612, 23405, 269, 5, 37, "Input"],
Cell[1006884, 23412, 96, 1, 37, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1007029, 23419, 101, 1, 27, "Subsubsection"],
Cell[CellGroupData[{
Cell[1007155, 23424, 287, 6, 37, "Input"],
Cell[1007445, 23432, 69, 1, 37, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1007551, 23438, 3108, 101, 103, "Input"],
Cell[1010662, 23541, 92, 1, 37, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1010803, 23548, 104, 1, 27, "Subsection"],
Cell[CellGroupData[{
Cell[1010932, 23553, 363, 7, 37, "Input"],
Cell[1011298, 23562, 481, 7, 37, "Output"]
}, Open  ]],
Cell[1011794, 23572, 203, 3, 37, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
