(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    202618,       6097]
NotebookOptionsPosition[    187929,       5589]
NotebookOutlinePosition[    188995,       5629]
CellTagsIndexPosition[    188952,       5626]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Large-scale linear instability of the generalized Kolmogorov flow with \
modified viscosity\
\>", "Title",
 CellChangeTimes->{{3.426480915962811*^9, 3.426480918437771*^9}}],

Cell["\<\
Bernard Legras
Laboratoire de Meteorologie Dynamique
Ecole Normale Superieure
24 rue Lhomond 
F-75231 PARIS Cedex 05
E-mail: legras@lmd.ens.fr
Barbara Villone
Istituto di Fisica dello Spazio Interplanetario
Corso Fiume, 4
I-10137 TORINO
E-mail: villone@to.infn.it \
\>", "Author"],

Cell[CellGroupData[{

Cell[TextData[{
 "Smagorinsky-Clark mixed model + friction\nU = A Sin[y] and \[Mu]=1\n\
Streamfunction defined as u=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", "\[Psi]"}], ",", " ", 
    RowBox[{"v", "=", 
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", "\[Psi]"}]}]}]}], 
   TraditionalForm]]]
}], "Subtitle",
 CellChangeTimes->{{3.390939342856571*^9, 3.390939347904498*^9}, {
  3.391089110575264*^9, 3.391089121639187*^9}, {3.424682889273964*^9, 
  3.424682901393609*^9}, {3.426402283484472*^9, 3.426402289233907*^9}}],

Cell[CellGroupData[{

Cell["Settings", "Section 1"],

Cell[CellGroupData[{

Cell["Last use", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateList", "[", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390644102774652*^9, 3.390644103635452*^9}, {
  3.426402363369817*^9, 3.42640236483034*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2009", ",", "1", ",", "21", ",", "1", ",", "6", ",", 
   "30.447847`8.236131569602168"}], "}"}]], "Output",
 CellChangeTimes->{
  3.390644298998453*^9, 3.390644391632821*^9, 3.390966222557515*^9, {
   3.410695669891136*^9, 3.410695677087721*^9}, {3.4107648327175198`*^9, 
   3.41076483957729*^9}, {3.410770133976763*^9, 3.410770141089466*^9}, {
   3.426402374254862*^9, 3.426402391485641*^9}, 3.426410474357777*^9, {
   3.426410807785914*^9, 3.426410824117934*^9}, {3.440942497421548*^9, 
   3.440942509656896*^9}, {3.441485178994772*^9, 3.441485190483169*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["General", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laplacian", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]", " ", "=", 
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "X"}]], " ", "#"}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], "#"}]}], ")"}]}], "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Epsilon]", "2"], " ", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"X", ",", "X"}]], "#1"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], "#1"}]}], ")"}]}], "&"}]], "Output",
 CellChangeTimes->{3.390644299342935*^9, 3.390966229052727*^9, 
  3.4106956700037003`*^9, 3.410764832857874*^9, 3.4107701340704107`*^9, 
  3.426402374818392*^9, 3.426410808076452*^9, 3.440942497613501*^9, 
  3.44148517913389*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Definition of the turbulent viscosity, Smagorinsky-Clark mixed model\
\>", "Subsubsection"],

Cell["Standard version", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  OverscriptBox["S", "_"], "=", " ", 
  RowBox[{
   SqrtBox[
    RowBox[{" ", 
     RowBox[{
      RowBox[{"4", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y"}]], "#"}]}], " ", ")"}], "2"]}], " ", "+", 
      " ", 
      SuperscriptBox[
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X"}]], "#"}]}], "-", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y"}]], "#"}]}], ")"}], "2"], "+", "   ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Epsilon]", " ", 
         RowBox[{
          SubscriptBox["\[PartialD]", "X"], "#"}]}], " ", ")"}], "2"], " ", 
      "+", "  ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], "#"}], " ", ")"}], "2"]}]}]], " ", 
   "&"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390966238347652*^9, 3.390966273951252*^9}}],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"\[Epsilon]", " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], "#1"}]}], ")"}], "2"]}], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Epsilon]", "2"], " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "X"}]], "#1"}]}], "-", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], "#1"}]}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", "X"], "#1"}]}], ")"}], "2"], "+", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], "#1"}], ")"}], "2"]}]], 
  "&"}]], "Output",
 CellChangeTimes->{
  3.390644299753632*^9, {3.390966260635838*^9, 3.390966274951733*^9}, 
   3.410695670097393*^9, 3.410764832988657*^9, 3.410770134232663*^9, 
   3.426402374966825*^9, 3.426410808772353*^9, 3.440942497826996*^9, 
   3.441485179233349*^9}]
}, Open  ]],

Cell[TextData[{
 "Dissipation: C in front of the Smagorinsky component, D in front of the \
Clark component\nIn standard notations C=",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[CapitalGamma]", "2"], TraditionalForm]]],
 "/12 and D = C",
 Cell[BoxData[
  FormBox[
   SubscriptBox["", "S"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[CapitalGamma]", "2"], TraditionalForm]]],
 "\nNote that K=-DS in the paper"
}], "Text",
 CellChangeTimes->{{3.428924939118229*^9, 3.428924956684663*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DS", " ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"C", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#", "]"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"y", ",", "y"}]], " ", "#"}]}], " ", "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}], ")"}]}], 
       "-", " ", 
       RowBox[{
        SuperscriptBox["\[Epsilon]", "2"], 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "X"}]], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            OverscriptBox["S", "_"], "[", "#", "]"}], 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"-", " ", 
              RowBox[{
               SubscriptBox["\[PartialD]", 
                RowBox[{"y", ",", "y"}]], " ", "#"}]}], " ", "+", " ", 
             RowBox[{
              SuperscriptBox["\[Epsilon]", "2"], 
              RowBox[{
               SubscriptBox["\[PartialD]", 
                RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}], ")"}]}]}], 
       " ", "-", " ", 
       RowBox[{"4", "  ", 
        SuperscriptBox["\[Epsilon]", "2"], 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            OverscriptBox["S", "_"], "[", "#", "]"}], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "y"}]], " ", "#"}]}], ")"}]}]}]}], ")"}]}], 
    " ", "+", " ", "\[IndentingNewLine]", 
    RowBox[{"D", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"\[Epsilon]", 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"X", ",", "y"}]], " ", "#"}], " ", 
        RowBox[{"(", "  ", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Epsilon]", "4"], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X", ",", "X", ",", "X"}]], "#"}]}], " ", "-", 
          " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], "#"}]}], ")"}]}], 
       " ", "+", " ", 
       RowBox[{
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"\[Epsilon]", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "y", ",", "y", ",", "y"}]], "#"}]}], " ", "+", 
          
          RowBox[{
           SuperscriptBox["\[Epsilon]", "3"], " ", 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X", ",", "X", ",", "y"}]], "#"}]}]}], ")"}], 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"y", ",", "y"}]], " ", "#"}], " ", "-", " ", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], 
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"X", ",", "X"}]], " ", "#"}]}]}], ")"}]}]}], " ", 
      ")"}]}]}], " ", "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"C", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"y", ",", "y"}]], "#1"}]}], "+", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            RowBox[{
             SubscriptBox["\[PartialD]", 
              RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "X"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"y", ",", "y"}]], "#1"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Epsilon]", "2"], " ", 
             RowBox[{
              SubscriptBox["\[PartialD]", 
               RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}], ")"}]}]}], "-", 
      
      RowBox[{"4", " ", 
       SuperscriptBox["\[Epsilon]", "2"], " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "y"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           OverscriptBox["S", "_"], "[", "#1", "]"}], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y"}]], "#1"}]}], ")"}]}]}]}], ")"}]}], "+", 
   RowBox[{"D", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "y"}]], "#1"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Epsilon]", "4"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X", ",", "X", ",", "X"}]], "#1"}]}], "-", 
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y", ",", "y", ",", "y"}]], "#1"}]}], ")"}]}], 
      "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Epsilon]", " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "y", ",", "y", ",", "y"}]], "#1"}]}], "+", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "3"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X", ",", "X", ",", "y"}]], "#1"}]}]}], ")"}], 
       " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SubscriptBox["\[PartialD]", 
           RowBox[{"y", ",", "y"}]], "#1"}], "-", 
         RowBox[{
          SuperscriptBox["\[Epsilon]", "2"], " ", 
          RowBox[{
           SubscriptBox["\[PartialD]", 
            RowBox[{"X", ",", "X"}]], "#1"}]}]}], ")"}]}]}], ")"}]}]}], 
  "&"}]], "Output",
 CellChangeTimes->{3.3906443006459618`*^9, 3.390966283587443*^9, 
  3.410695670192752*^9, 3.410764833177628*^9, 3.4107701343298473`*^9, 
  3.426402376160214*^9, 3.426410809922981*^9, 3.440942498128133*^9, 
  3.441485179333278*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the modified Kolmogorov Flow", "Section"],

Cell[CellGroupData[{

Cell["Velocity and streamfunction", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"U", "[", "y_", "]"}], " ", ":=", 
  RowBox[{"A", " ", 
   RowBox[{"Sin", "[", "y", "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390939372214815*^9, 3.390939382859744*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "y_", "]"}], ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0", ",", "y"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{3.390966213613222*^9, 3.390966311397663*^9, 
  3.39096645682996*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the flow", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"A", "\[Rule]", "1"}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.39064411722918*^9, 3.390644120624886*^9}, {
  3.390966179612975*^9, 3.390966201315737*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Forcing (or dissipation)", "Subsection",
 CellChangeTimes->{{3.410770178070067*^9, 3.4107701801771812`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Forcing", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Assuming", "[", 
     RowBox[{
      RowBox[{"A", ">", "0"}], " ", ",", 
      RowBox[{"Simplify", "[", " ", 
       RowBox[{"DS", "[", "  ", 
        RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "]"}]}], "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.390966299078265*^9, {3.390966374776461*^9, 3.390966383298892*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["A", "2"], " ", "C", " ", 
  RowBox[{"Cos", "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{
  3.390644429582283*^9, {3.390966300469773*^9, 3.390966320068642*^9}, 
   3.390966384224826*^9, 3.390966469268107*^9, 3.41077017309822*^9, 
   3.426410824927487*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the pertubation problem", "Section"],

Cell[CellGroupData[{

Cell["2D Navier-Stokes with scaling", "Subsection"],

Cell[TextData[{
 StyleBox["We have taken u = ", "Text"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", "\[Psi]"}], " ", "and", " ", 
     "v"}], " ", "=", " ", 
    RowBox[{"-", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", "\[Psi]"}]}]}], 
   TraditionalForm]]],
 " (mechanical definition)"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Epsilon]", "2"], 
     RowBox[{
      SubscriptBox["\[PartialD]", "T"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], "-", " ", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "+", "\n", 
    "      ", 
    RowBox[{"\[Epsilon]", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "-", " ", 
    RowBox[{"DS", "[", 
     RowBox[{"\[Psi]", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "+", " ", 
    RowBox[{"DS", "[", 
     RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}]}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expansion", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Psi]", "[", 
   RowBox[{"T_", ",", "X_", ",", "y_"}], "]"}], " ", ":=", "  ", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "+", " ", 
   RowBox[{"\[Psi]0", "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"\[Psi]1", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], " ", 
    RowBox[{"\[Psi]2", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "3"], " ", 
    RowBox[{"\[Psi]3", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "4"], " ", 
    RowBox[{"\[Psi]4", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS2", " ", "=", " ", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{"NS", ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], 
     ",", "\[Epsilon]"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 0", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a0", " ", "=", " ", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"NS2", ",", "\[Epsilon]", ",", "0"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.390966524802245*^9, {3.426402400385173*^9, 3.426402402933677*^9}, {
   3.42641086123245*^9, 3.426410888791479*^9}, 3.426410934409544*^9}],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule0", "=", " ", 
  RowBox[{"\[Psi]0", " ", "\[Rule]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[CurlyPhi]0", "[", 
      RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ")"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"\[Psi]0", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"\[CurlyPhi]0", "[", 
     RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.390644808749378*^9, 3.390966546249953*^9, 
  3.4106956949230022`*^9, 3.410764849284869*^9, 3.410770196824448*^9, 
  3.426402415636349*^9, 3.426410878336975*^9, 3.42641093945647*^9, 
  3.440942612936866*^9, 3.441485193829735*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solvability condition", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"A", ">", "0"}], "  ", "}"}], ",", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"a0", "  ", "/.", " ", 
     RowBox[{"{", "Rule0", "}"}]}], "]"}]}], " ", "]"}]], "Input",
 CellChangeTimes->{3.390966553850892*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390644819502278*^9, 3.390966555599534*^9, 
  3.4106956977876577`*^9, 3.410764851410316*^9, 3.4107701990807743`*^9, 
  3.426402418532875*^9, 3.426410881341795*^9, 3.426410942965988*^9, 
  3.440942615039976*^9, 3.441485200392074*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solvability condition", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solva", "[", "expr_", "]"}], " ", ":=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"expr", " ", "/.", " ", 
        RowBox[{"y", " ", "\[Rule]", " ", 
         RowBox[{"2", " ", "\[Pi]"}]}]}], ")"}], "-", 
      RowBox[{"(", 
       RowBox[{"expr", " ", "/.", " ", 
        RowBox[{"y", " ", "\[Rule]", "0"}]}], ")"}]}], ")"}], " ", "/.", " ", 
    
    RowBox[{
     RowBox[{"g___", "[", 
      RowBox[{"2", " ", "\[Pi]"}], "]"}], "\[Rule]", 
     RowBox[{"g", "[", "0", "]"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.391000452193688*^9, 3.391000459871495*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Useful rules for simplifications", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rulea", "=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["A", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", "y", "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox["A", "2"], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", "y", "]"}], "2"]}]}], " ", ")"}], "n_"], 
   "\[Rule]", 
   SuperscriptBox["A", 
    RowBox[{"2", " ", "n", " "}]]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390997187091499*^9, 3.390997228439785*^9}, {
  3.390999347740495*^9, 3.390999366871413*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["A", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "y", "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["A", "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "y", "]"}], "2"]}]}], ")"}], "n_"], "\[Rule]", 
  SuperscriptBox["A", 
   RowBox[{"2", " ", "n"}]]}]], "Output",
 CellChangeTimes->{
  3.390644390627693*^9, 3.39099723163207*^9, 3.390999385174366*^9, 
   3.4106956768951597`*^9, 3.4107648394652357`*^9, 3.4107701408431396`*^9, 
   3.42640239092657*^9, 3.426410823566575*^9, 3.440942509430598*^9, {
   3.44148519031323*^9, 3.441485204362782*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Improve", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"Together", "[", "#1", "]"}], ",", 
     RowBox[{"A", ">", "0"}], ",", 
     RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Together", "[", "#1", "]"}], ",", 
    RowBox[{"A", ">", "0"}], ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], "&"}]], "Output",
 CellChangeTimes->{
  3.39064439112236*^9, 3.390966578735698*^9, 3.4106956769858837`*^9, 
   3.410764839478401*^9, 3.410770140951776*^9, 3.426402391067347*^9, 
   3.426410823707108*^9, 3.440942509536072*^9, {3.441485190331273*^9, 
   3.441485206383933*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Treat", "[", "expr_", "]"}], ":=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"expr", "/.", 
       RowBox[{"\[Mu]", "\[Rule]", "1"}]}], ",", 
      RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " ", "/.", " ", 
    RowBox[{"\[Theta]", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"#", " ", "&"}], ")"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390987308394297*^9, 3.390987352088105*^9}, {
  3.391062874073991*^9, 3.391062913605971*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 1", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", " ", "=", " ", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"A", ">", "0"}], "  ", ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"Expand", "[", 
       RowBox[{"Coefficient", "[", 
        RowBox[{"NS2", ",", "\[Epsilon]", ",", "1"}], "]"}], "]"}], " ", "/.",
       " ", "Rule0"}], " ", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.390966587887556*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], " ", "A", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"Sin", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "+", 
    RowBox[{"C", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "y"}], "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[Psi]1", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "0", ",", "4"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.390645061914023*^9, 3.390966591771355*^9, 
  3.410695714698844*^9, 3.4107648574736147`*^9, 3.41077021484639*^9, 
  3.426402440082368*^9, 3.426410957775817*^9, 3.440942626358666*^9, 
  3.441485215821641*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extraction of the linear operator and verification", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", "A", " ", "C", " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "y"}], "]"}]}]], "Output",
 CellChangeTimes->{3.390645078512116*^9, 3.390966987607293*^9, 
  3.4106959335324802`*^9, 3.4107648600637693`*^9, 3.4107702229392147`*^9, 
  3.426402444621018*^9, 3.426410969895265*^9, 3.440942630029463*^9, 
  3.441485218280916*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390645098657657*^9, 3.390966990914146*^9, 
  3.410695935148497*^9, 3.410764862058133*^9, 3.410770224232823*^9, 
  3.426402448275309*^9, 3.426410972090662*^9, 3.440942631379696*^9, 
  3.441485219731318*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F3", "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], " ", "]"}], " ", 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "3"}], " ", "A", " ", "C", " ", 
  RowBox[{"Cos", "[", "y", "]"}], " ", 
  RowBox[{"Sin", "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.390645100240435*^9, 3.390966978275214*^9, 
  3.410695936409995*^9, 3.4107648646459923`*^9, 3.410770224991054*^9, 
  3.426402451585247*^9, 3.426410974140536*^9, 3.440942632625881*^9, 
  3.441485222962374*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1F4", "=", 
  RowBox[{"Factor", "[", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[Psi]1", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "]"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "A", " ", "C", " ", 
  RowBox[{"(", 
   RowBox[{"3", "+", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "y"}], "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.390645101259821*^9, 3.39096693372031*^9, 
  3.410695937735771*^9, 3.4107648664919662`*^9, 3.410770226360991*^9, 
  3.426402454425151*^9, 3.426410976812773*^9, 3.440942634346863*^9, 
  3.441485225263979*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalL]", "[", "f_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], "A", " ", "C", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], " ", 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "y"}], "]"}]}], ")"}], 
        RowBox[{
         SubscriptBox["\[PartialD]", 
          RowBox[{"y", ",", "y"}]], "f"}]}], "  ", ")"}]}], " ", "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "y"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["\[PartialD]", "y"], "f"}]}], ")"}]}]}], 
    ")"}]}]}]], "Input",
 CellChangeTimes->{{3.390966744278953*^9, 3.390966766229633*^9}, 
   3.390966896672676*^9, {3.390966945079826*^9, 3.390966949035727*^9}, {
   3.390967121282786*^9, 3.390967159701912*^9}, 3.390967228992849*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"f", "[", "y", "]"}], "]"}], " ", "-", "  ", 
    RowBox[{"a1F1", "  ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "1", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"a1F2", "  ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "2", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{"a1F3", "   ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{"a1F4", " ", 
     RowBox[{
      SuperscriptBox["f", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}]}], ",", " ", 
   RowBox[{"Trig", "->", "True"}]}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390645103430953*^9, 3.390967173192747*^9, 
  3.390967233419091*^9, 3.410695940174086*^9, 3.410764875102374*^9, 
  3.410770233034121*^9, 3.426402462796425*^9, 3.426410984404523*^9, 
  3.441485228395095*^9}]
}, Open  ]],

Cell["As a reference : complete operator for the full problem", "Text",
 CellChangeTimes->{{3.390967271442037*^9, 3.390967295818772*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalL]", "[", "f_", "]"}], ":=", 
  RowBox[{
   RowBox[{"A", " ", "C", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"y", ",", "y"}]], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       FractionBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
        SqrtBox[
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"y", ",", "y"}]], "f"}]}], "  ", ")"}]}]}], " ", "+", 
   RowBox[{"A", " ", "C", "  ", "\[Mu]", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"y", ",", "y"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", 
           RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"Cos", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}]], 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "f"}]}], ")"}]}]}]}]}]], "Text"],

Cell["Operator to solve problem after two integrations", "Text",
 CellChangeTimes->{{3.410699676810645*^9, 3.410699719098432*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[ScriptCapitalL]2", "[", "f_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], "A", " ", "C", "  ", 
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "y"}], "]"}]}], ")"}], 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], "f"}]}], "  ", "+", " ", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "y"}], "]"}], " ", 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], "f"}]}]}], 
    ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[ScriptCapitalL]22", "[", "h_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], "A", " ", "C", "  ", 
   RowBox[{"(", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "y"}], "]"}]}], ")"}], 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], "h"}]}], "  ", "+", " ", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "y"}], "]"}], " ", "h"}]}], ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.390966744278953*^9, 3.390966766229633*^9}, 
   3.390966896672676*^9, {3.390966945079826*^9, 3.390966949035727*^9}, {
   3.390967121282786*^9, 3.390967159701912*^9}, 3.390967228992849*^9, {
   3.410699616519631*^9, 3.410699658975482*^9}, {3.410764879450055*^9, 
   3.4107649107352*^9}, {3.424803652636642*^9, 3.424803661626382*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extraction of second member", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1a", "=", 
  RowBox[{"-", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"A", " ", 
  RowBox[{"Sin", "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.390645104359546*^9, 3.390966892616673*^9, 
  3.410695739760963*^9, 3.410764915540312*^9, 3.4107702432265997`*^9, 
  3.426402471091138*^9, 3.426410994418473*^9, 3.440942642801206*^9, 
  3.441485233650126*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reconstruction of the first order equation ", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a1N", "=", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]1", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "-", " ", 
    RowBox[{"a1a", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.390967247414754*^9, 3.390967250548628*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a1N", " ", "-", " ", "a1"}], "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390645105742691*^9, 3.390966906477495*^9, 
  3.390966959103455*^9, 3.390967255377091*^9, 3.410764919142273*^9, 
  3.410770251398219*^9, 3.426402478886118*^9, 3.441485236785146*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solvability condition", "Subsection"],

Cell["The solvability condition is obviously satisfied ", "Text",
 CellChangeTimes->{{3.390967345922397*^9, 3.390967347103238*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule1", " ", "=", 
  RowBox[{"\[Psi]1", " ", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"f1", "[", "#3", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"#1", ",", "#2"}], "]"}]}], " ", "&"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.41076492553459*^9, 3.410764926749961*^9}, 
   3.440942650968644*^9}],

Cell[BoxData[
 RowBox[{"\[Psi]1", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"f1", "[", "#3", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"#1", ",", "#2"}], "]"}]}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.390645356063478*^9, 3.390967358821859*^9, 
  3.4106957446766*^9, 3.41076492809886*^9, 3.4107702557764177`*^9, 
  3.42640248228535*^9, 3.426411005223502*^9, 3.440942652783698*^9, 
  3.441485240289711*^9}]
}, Open  ]],

Cell["f1 has SinI symmetry", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution of the problem", "Subsection",
 CellChangeTimes->{{3.410698163237179*^9, 3.410698180512445*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"solf1", "=", " ", 
   RowBox[{"f1", " ", "\[Rule]", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       FractionBox["1", "C"], 
       RowBox[{"Sin", "[", "#", "]"}]}], "&"}], ")"}]}]}]}]], "Input",
 CellChangeTimes->{{3.4106982300668373`*^9, 3.410698243412751*^9}, {
  3.410698296829687*^9, 3.410698331665875*^9}, {3.410698425749959*^9, 
  3.4106984281036997`*^9}}],

Cell[BoxData[
 RowBox[{"f1", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     RowBox[{"Sin", "[", "#1", "]"}], "C"], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.4106983367937117`*^9, 3.410698429520835*^9, 
  3.410764930088696*^9, 3.410770258575027*^9, 3.426402486257643*^9, 
  3.426411008184335*^9, 3.440942655011741*^9, 3.441485242487394*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"f1", "[", "y", "]"}], "]"}], "-", "a1a"}], " ", "/.", " ", 
   "solf1"}], "]"}]], "Input",
 CellChangeTimes->{{3.4106982000393333`*^9, 3.410698224202031*^9}, {
  3.4106983437711267`*^9, 3.410698345158553*^9}, {3.410698441754877*^9, 
  3.410698453091793*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.410698348839287*^9, {3.410698436568519*^9, 3.41069845385083*^9}, 
   3.410764933419425*^9, 3.4107702609768744`*^9, 3.426402492137348*^9, 
   3.426411011260729*^9, 3.44094265704787*^9, 3.441485243591717*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 2", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", " ", "=", " ", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"A", ">", "0"}], " ", ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{"NS2", ",", "\[Epsilon]", ",", "2"}], "]"}], "   ", "//.", 
       " ", 
       RowBox[{"{", 
        RowBox[{"Rule0", ",", "Rule1"}], "}"}]}], " ", ",", 
      RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}]}], " ", "]"}]}]], "Input",
 CellChangeTimes->{
  3.390645139368509*^9, {3.390967388897168*^9, 3.390967416234942*^9}, {
   3.390968025572403*^9, 3.390968044741805*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "C", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Cos", "[", "y", "]"}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"3", " ", "y"}], "]"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{"C", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            RowBox[{"Cos", "[", "y", "]"}]}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f1", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "C", " ", 
            RowBox[{"Cos", "[", "y", "]"}]}], "-", 
           RowBox[{"4", " ", 
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{"C", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               RowBox[{"Cos", "[", "y", "]"}]}], "+", 
              RowBox[{"Cos", "[", 
               RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["f1", 
               TagBox[
                RowBox[{"(", "3", ")"}],
                Derivative],
               MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
        "+", 
        RowBox[{"2", " ", "C", " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               RowBox[{"Cos", "[", "y", "]"}]}], "+", 
              RowBox[{"Cos", "[", 
               RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "4", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", "C", " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"12", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
            RowBox[{
             SuperscriptBox["f1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "9"}], " ", 
               RowBox[{"Cos", "[", "y", "]"}]}], "+", 
              RowBox[{"5", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"3", " ", "y"}], "]"}]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "3", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}]}], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
            RowBox[{
             SuperscriptBox["f1", 
              TagBox[
               RowBox[{"(", "4", ")"}],
               Derivative],
              MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
       ")"}]}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
    RowBox[{"4", " ", "A", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "C", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "y"}], "]"}]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"f1", "[", "y", "]"}], " ", 
           RowBox[{"Sin", "[", "y", "]"}]}], "-", 
          RowBox[{"2", " ", "D", " ", 
           RowBox[{"Cos", "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "-", 
          RowBox[{"2", " ", 
           RowBox[{"Sin", "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "-", 
          RowBox[{"2", " ", "D", " ", 
           RowBox[{"Cos", "[", "y", "]"}], " ", 
           RowBox[{
            SuperscriptBox["f1", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "+", 
       RowBox[{"C", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]2", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "1"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", " ", "y"}], "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]2", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "3"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "y"}], "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Psi]2", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "0", ",", "4"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}], ")"}]}]}], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.390967417355269*^9, {3.390968035167341*^9, 3.390968046025116*^9}, 
   3.41069605354443*^9, 3.41076494183449*^9, 3.410770268671612*^9, 
   3.426402505484304*^9, 3.42641103038211*^9, 3.440942665718611*^9, 
   3.441485254221203*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection",
 CellChangeTimes->{{3.390967728921045*^9, 3.390967732833753*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"]}], ":", "a2a"}]], "Subsubsection",
 CellChangeTimes->{{3.390967493107402*^9, 3.390967497028902*^9}, 
   3.390990600929834*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2a", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"a2", " ", ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], ",", "2"}], "]"}], " ", "]"}]}], " ",
     ",", 
    RowBox[{"{", 
     RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "8"], " ", "C", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"Cos", "[", "y", "]"}]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Cos", "[", "y", "]"}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"3", " ", "y"}], "]"}]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f1", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "9"}], " ", 
         RowBox[{"Cos", "[", "y", "]"}]}], "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f1", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "9"}], " ", 
         RowBox[{"Cos", "[", "y", "]"}]}], "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["f1", 
         TagBox[
          RowBox[{"(", "3", ")"}],
          Derivative],
         MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            RowBox[{"Cos", "[", "y", "]"}]}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", "4", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"12", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            RowBox[{"Cos", "[", "y", "]"}]}], "+", 
           RowBox[{"5", " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"3", " ", "y"}], "]"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", "4", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{3.39064654359012*^9, 3.390967504117148*^9, 
  3.410696281839519*^9, 3.410764997436119*^9, 3.4107702984827414`*^9, 
  3.426402538038032*^9, 3.426411125078573*^9, 3.440942680267173*^9, 
  3.441485263388205*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2aF", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"a2a", "/.", " ", "solf1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.410698515032694*^9, 3.410698547592513*^9}, {
  3.410698683948745*^9, 3.4106986846086407`*^9}, {3.4107002734303226`*^9, 
  3.410700282214159*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", "+", 
     SuperscriptBox["C", "2"]}], ")"}], " ", 
   RowBox[{"Cos", "[", "y", "]"}]}], 
  RowBox[{"2", " ", "C"}]]], "Output",
 CellChangeTimes->{{3.4106985224296007`*^9, 3.410698549026968*^9}, 
   3.410698686323007*^9, 3.410700311126924*^9, 3.410765006097581*^9, 
   3.410770957672964*^9, 3.426402540719757*^9, 3.42641112844087*^9, 
   3.440942681594322*^9, 3.441485266164924*^9}]
}, Open  ]],

Cell["\<\
Solution of the perturbation problem
(- sign because the problem is already integrated twice)\
\>", "Text",
 CellChangeTimes->{{3.4106990411338387`*^9, 3.410699044075333*^9}, {
  3.4107003569753733`*^9, 3.410700361247953*^9}, {3.42640434856488*^9, 
  3.426404386471644*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ss2a", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[ScriptCapitalL]2", "[", 
          RowBox[{"f2a", "[", "y", "]"}], "]"}], "\[Equal]", 
         RowBox[{"-", "a2aF"}]}], ",", 
        RowBox[{
         RowBox[{"f2a", "[", 
          FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"f2a", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], 
      ",", 
      RowBox[{"f2a", "[", "y", "]"}], ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"solf2a", "=", " ", 
  RowBox[{"f2a", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{"y", ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"f2a", "[", "y", "]"}], " ", "/.", " ", "ss2a"}], "]"}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.410700291579397*^9, 3.410700339643463*^9}, {
  3.4107004359196978`*^9, 3.410700465306056*^9}, {3.410764982250455*^9, 
  3.4107649836781178`*^9}, {3.410765047193008*^9, 3.410765049100358*^9}, {
  3.410765389153388*^9, 3.410765394723599*^9}, {3.410765470846292*^9, 
  3.410765511774974*^9}, {3.410766675155202*^9, 3.410766676673588*^9}}],

Cell[BoxData[
 RowBox[{"f2a", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{"y", ",", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "+", 
        SuperscriptBox["C", "2"]}], ")"}], " ", 
      RowBox[{"Cos", "[", "y", "]"}]}], 
     RowBox[{"4", " ", "A", " ", 
      SuperscriptBox["C", "2"]}]]}], "]"}]}]], "Output",
 CellChangeTimes->{{3.410700308856645*^9, 3.4107003407083*^9}, 
   3.410700466098976*^9, 3.410765007413282*^9, 3.4107650500589113`*^9, 
   3.41076532275103*^9, 3.410765395655724*^9, 3.410765478562896*^9, 
   3.410765515890191*^9, 3.41076667756236*^9, 3.4107709589754333`*^9, 
   3.426402546315402*^9, 3.426411131069789*^9, 3.440942683104817*^9, 
   3.441485269208246*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a2b"}]], "Subsubsection",\

 CellChangeTimes->{{3.390990585437857*^9, 3.390990588280686*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2b", "=", 
  RowBox[{"-", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"a2", "  ", ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], ",", "1"}], "]"}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], " ", "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.390967617202271*^9, 3.390967618613621*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "A"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", "C", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], " ", 
     RowBox[{"Sin", "[", "y", "]"}]}], "-", 
    RowBox[{
     RowBox[{"Sin", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f1", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"D", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "y", "]"}]}], " ", 
        RowBox[{
         SuperscriptBox["f1", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f1", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{
  3.390646670722824*^9, {3.390967605299398*^9, 3.390967619673948*^9}, 
   3.410697862481502*^9, 3.410765944359623*^9, 3.410770346376062*^9, 
   3.426404492835259*^9, 3.426411183270194*^9, 3.440942687811004*^9, 
   3.441485270728866*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a2bF", "=", 
  RowBox[{"a2b", " ", "/.", " ", "solf1"}]}], "\[IndentingNewLine]", 
 RowBox[{"a2bFI2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"a2bF", ",", "y"}], "]"}], ",", "y"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.410698480942359*^9, 3.410698487228588*^9}, 
   3.410698691136832*^9, {3.41069872516529*^9, 3.410698739303162*^9}, {
   3.410700601929379*^9, 3.4107006082770576`*^9}, {3.410700643270904*^9, 
   3.4107006678631477`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", "A", " ", "C", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "y"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.4106984889199963`*^9, 3.410698691884403*^9, {3.410698731324956*^9, 
   3.410698740249909*^9}, 3.410700609188251*^9, 3.410700668853064*^9, 
   3.410765947436277*^9, 3.4107706046463737`*^9, 3.426404495908954*^9, 
   3.426411186085528*^9, 3.4409426887082*^9, 3.44148527264717*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", "A", " ", "C", " ", 
  RowBox[{"Cos", "[", 
   RowBox[{"2", " ", "y"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.4106984889199963`*^9, 3.410698691884403*^9, {3.410698731324956*^9, 
   3.410698740249909*^9}, 3.410700609188251*^9, 3.410700668853064*^9, 
   3.410765947436277*^9, 3.4107706046463737`*^9, 3.426404495908954*^9, 
   3.426411186085528*^9, 3.4409426887082*^9, 3.441485272664784*^9}]
}, Open  ]],

Cell["\<\
Solving for h2b = f2b' introducing an integration constant K2b\
\>", "Text",
 CellChangeTimes->{{3.410765841008422*^9, 3.410765881859276*^9}, {
  3.4248036865437*^9, 3.424803687077383*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ss2b", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[ScriptCapitalL]22", "[", 
         RowBox[{"h2b", "[", "y", "]"}], "]"}], "\[Equal]", 
        RowBox[{"a2bFI2", "+", 
         RowBox[{"K2b", " ", "[", "y", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"K2b", "'"}], "[", "y", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"h2b", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"h2b", "[", "\[Pi]", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"h2b", "[", "y", "]"}], ",", 
       RowBox[{"K2b", "[", "y", "]"}]}], "}"}], ",", "y"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.41069925507909*^9, 3.410699259467333*^9}, {
  3.410699294270713*^9, 3.410699358212796*^9}, {3.410699399020556*^9, 
  3.410699421536662*^9}, {3.4106997428118773`*^9, 3.410699924592441*^9}, {
  3.410700219670619*^9, 3.410700252519166*^9}, {3.410700585916245*^9, 
  3.410700639861196*^9}, {3.410700673759774*^9, 3.410700678424116*^9}, {
  3.4107007546852493`*^9, 3.4107007779380198`*^9}, {3.410765574643262*^9, 
  3.410765595177229*^9}, {3.410765755109584*^9, 3.410765836672141*^9}, {
  3.4107659047374277`*^9, 3.41076593249676*^9}, {3.410766410229783*^9, 
  3.410766467022994*^9}, {3.424803727291439*^9, 3.424803750586026*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"h2b", "[", "y", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"4", " ", 
       RowBox[{"EllipticE", "[", 
        FractionBox["1", "2"], "]"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"3", "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "y"}], "]"}]}]], " ", 
        RowBox[{"EllipticE", "[", 
         FractionBox["1", "2"], "]"}], " ", 
        RowBox[{"EllipticF", "[", 
         RowBox[{"y", ",", 
          FractionBox["1", "2"]}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"3", "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", "y"}], "]"}]}]], " ", 
        RowBox[{"EllipticE", "[", 
         RowBox[{"y", ",", 
          FractionBox["1", "2"]}], "]"}], " ", 
        RowBox[{"EllipticK", "[", 
         FractionBox["1", "2"], "]"}]}], "+", 
       RowBox[{
        RowBox[{"EllipticK", "[", 
         FractionBox["1", "2"], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "y"}], "]"}]}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"K2b", "[", "y", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{"3", " ", "A", " ", "C", " ", 
       RowBox[{"EllipticE", "[", 
        FractionBox["1", "2"], "]"}]}], "-", 
      RowBox[{"2", " ", "A", " ", "C", " ", 
       RowBox[{"EllipticK", "[", 
        FractionBox["1", "2"], "]"}]}]}], 
     RowBox[{"2", " ", 
      RowBox[{"EllipticE", "[", 
       FractionBox["1", "2"], "]"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.410766590002252*^9, 3.410770609053508*^9, 
  3.424804032712606*^9, 3.426404563876642*^9, 3.426411190031212*^9, 
  3.440942698842591*^9, 3.441485277023273*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p21", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"h2b", "[", "y", "]"}], " ", "/.", " ", "ss2b"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p22", " ", "=", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"h2b", "[", "y", "]"}], "/", 
       RowBox[{"Sin", "[", 
        RowBox[{"2", " ", "y"}], "]"}]}], " ", "/.", " ", "ss2b"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsArray", "[", 
   RowBox[{"{", 
    RowBox[{"p21", ",", "p22"}], "}"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.41076596994164*^9, 3.410765976755744*^9}, {
  3.410766401730294*^9, 3.410766402856348*^9}, {3.410766472336364*^9, 
  3.410766618134409*^9}, {3.424803731895084*^9, 3.424803734555007*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVmnk4VP8XxxmUbDOWsSelIooi+VZ0PiESqWiRhEiyZCllr6hQSpK9pGwh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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{0, 2 Pi}, {-0.1696869440219626, 0.16968694314174776`}}, {{
         0, 6.283185307179586}, {-0.1696869440219626, 0.16968694314174776`}}],
      
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {192., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV2nc8lV8cB3CZ9xrhXuMSGWn8jOxR4XtSKZRCUXakIRUKpaKNhowyykp2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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0.16},
      DisplayFunction:>Identity,
      PlotRange->
       NCache[{{0, 2 Pi}, {0.15681651813559971`, 0.18636695260848246`}}, {{
         0, 6.283185307179586}, {0.15681651813559971`, 
         0.18636695260848246`}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {576., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.410766584025659*^9, 3.4107666259948053`*^9, 
  3.410770613195224*^9, 3.426404743881853*^9, 3.426411196761207*^9, 
  3.441485280029332*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Reconstruction and check of the second order equation\
\>", "Subsection",
 CellChangeTimes->{{3.390967641046426*^9, 3.390967645102195*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"a2N", " ", "=", " ", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]2", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], "  ", "-", " ", 
    RowBox[{"a2b", "  ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "-", " ", 
    RowBox[{"a2a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}]}]}], ";"}]], "Input",
 CellChangeTimes->{3.440942708245402*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a2N", " ", "-", " ", "a2"}], " ", "]"}]], "Input"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390646744235299*^9, 3.390967650768727*^9, 
  3.390969044639251*^9, 3.410770619793796*^9, 3.426404788422555*^9, 
  3.426411203181597*^9, 3.440942713883214*^9, 3.441485286670872*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rule2", " ", "=", "  ", 
  RowBox[{"\[Psi]2", "  ", "\[Rule]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"f2a", "[", "#3", "]"}], "  ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"#1", ",", "#2"}], "]"}], "2"]}], "+", " ", 
      RowBox[{
       RowBox[{"f2b", "[", "#3", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}]}]}], "&"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.440942718740666*^9, 3.440942725909148*^9}}],

Cell[BoxData[
 RowBox[{"\[Psi]2", "\[Rule]", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f2a", "[", "#3", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"f2b", "[", "#3", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"#1", ",", "#2"}], "]"}]}]}], "&"}], ")"}]}]], "Output",
 CellChangeTimes->{3.390969060109652*^9, 3.4107667448806458`*^9, 
  3.410770623742159*^9, 3.426404803901217*^9, 3.426411207338286*^9, 
  3.440942727798055*^9, 3.441485288758657*^9}]
}, Open  ]],

Cell["\<\
f2a has CosI symmetry
f2b has CosP symmetry
f2c has SinI symmetry\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solf2", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", "solf2a", "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.410766635555735*^9, 3.4107666612097683`*^9}, 
   3.440942782184427*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"f2a", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{"y", ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", "+", 
         SuperscriptBox["C", "2"]}], ")"}], " ", 
       RowBox[{"Cos", "[", "y", "]"}]}], 
      RowBox[{"4", " ", "A", " ", 
       SuperscriptBox["C", "2"]}]]}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.410770626084412*^9, {3.4107709457779417`*^9, 3.410770970369174*^9}, 
   3.42640481294164*^9, 3.426411214176634*^9, 3.440942731355704*^9, 
   3.440942783677562*^9, 3.441485291585814*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 3", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3", " ", "=", " ", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"NS2", ",", "\[Epsilon]", ",", "3"}], "]"}], "   ", "//.", " ", 
    RowBox[{"{", 
     RowBox[{"Rule0", ",", "Rule1", ",", "Rule2"}], "}"}]}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.39096906789037*^9, 3.390969068823168*^9}, {
   3.390969120552609*^9, 3.39096912224926*^9}, {3.390969164299653*^9, 
   3.390969191724323*^9}, {3.426411251705371*^9, 3.426411269113908*^9}, 
   3.426411316296022*^9}],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a31", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a3", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.440942800372793*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "3"]}], ":", " ", 
  "a3a"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"-", "a31"}], "  ", ",", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], "3"]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"C", ",", "A"}], "}"}]}], "]"}]}], " ", ";"}], "\n", 
 RowBox[{"a3aF", "=", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"A", ">", "0"}], ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{"a3a", " ", "/.", " ", 
      RowBox[{"Flatten", "[", 
       RowBox[{"{", 
        RowBox[{"solf1", ",", "solf2"}], "}"}], "]"}]}], "]"}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.390969389182408*^9, 3.39096938946639*^9}, 
   3.390969460591829*^9, 3.426405123723827*^9, 3.426405335252829*^9, {
   3.426411339277001*^9, 3.426411364799176*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["C", "2"]}], ")"}], " ", 
    RowBox[{"Sin", "[", "y", "]"}]}], 
   RowBox[{"2", " ", "A", " ", 
    SuperscriptBox["C", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.410766839820635*^9, 3.4107668580326557`*^9}, 
   3.410767116276455*^9, 3.410777011859469*^9, 3.426405150289885*^9, {
   3.426411346952691*^9, 3.426411366178654*^9}, 3.440942821204609*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ss3a", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[ScriptCapitalL]2", "[", 
          RowBox[{"f3a", "[", "y", "]"}], "]"}], "\[Equal]", 
         RowBox[{"-", "a3aF"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"f3a", "'"}], "[", 
          FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"f3a", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"f3a", "[", "y", "]"}], ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"solf3a", "=", " ", 
  RowBox[{"f3a", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{"y", ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"f3a", "[", "y", "]"}], " ", "/.", " ", "ss3a"}], "]"}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.410700291579397*^9, 3.410700339643463*^9}, {
  3.4107004359196978`*^9, 3.410700465306056*^9}, {3.410764982250455*^9, 
  3.4107649836781178`*^9}, {3.410765047193008*^9, 3.410765049100358*^9}, {
  3.410765389153388*^9, 3.410765394723599*^9}, {3.410765470846292*^9, 
  3.410765511774974*^9}, {3.410766675155202*^9, 3.410766676673588*^9}, {
  3.410766963704053*^9, 3.410767006125278*^9}}],

Cell[BoxData[
 RowBox[{"f3a", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{"y", ",", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["C", "2"]}], ")"}], " ", 
       RowBox[{"Sin", "[", "y", "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["A", "2"], " ", 
       SuperscriptBox["C", "3"]}]]}]}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.410767064630413*^9, 3.410767118449209*^9, {3.410777010529949*^9, 
   3.410777013291484*^9}, 3.42640515613666*^9, 3.426411375505831*^9, 
   3.440942822913076*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", "factor", " ", "of", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a33", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a31", "]"}], ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", "a3b"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3b", "=", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{"A", ">", "0"}], ",", 
     RowBox[{"Collect", "[", 
      RowBox[{
       RowBox[{"Coefficient", "[", 
        RowBox[{
         RowBox[{"-", "a33"}], " ", ",", 
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"D", ",", "C", ",", "A"}], " ", "}"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.390985301711968*^9, 3.390985318490116*^9}, 
   3.426405276664094*^9, 3.426405322462053*^9}],

Cell["\<\
Solvability is satisfied since all contributions can be integrated twice\
\>", "Text",
 CellChangeTimes->{{3.426406066962898*^9, 3.426406068847531*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a3bF", "=", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"A", ">", "0"}], ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"a3b", " ", "/.", " ", "solf1"}], " ", "/.", " ", "solf2"}], 
     "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a3bI2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "y"}], "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "y"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
      ")"}]}], "-", 
    RowBox[{
     RowBox[{"f2b", "'"}], "[", "y", "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a3bI2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a3bF"}], "]"}]}], "Input",\

 CellChangeTimes->{{3.4107671791098747`*^9, 3.410767218230125*^9}, {
  3.410770927608777*^9, 3.410770933791505*^9}, {3.426405370845601*^9, 
  3.426405417801267*^9}, {3.426405453215026*^9, 3.426405458182735*^9}, {
  3.426411419462105*^9, 3.426411429369913*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "y"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "y"}], "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "y"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{"6", "+", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.426405411475401*^9, 3.426405427410841*^9}, 
   3.426405459662071*^9, {3.426411414773842*^9, 3.426411430295947*^9}, 
   3.440942830900833*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.426405411475401*^9, 3.426405427410841*^9}, 
   3.426405459662071*^9, {3.426411414773842*^9, 3.426411430295947*^9}, 
   3.440942830960781*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a3d"}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a3d", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"-", "a31"}], " ", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "A", ",", "C"}], " ", "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.390990791509574*^9, 3.426405956466517*^9, {3.426411509744167*^9, 
   3.426411511134572*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3dF", "=", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"A", ">", "0"}], ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{"a3d", " ", "/.", " ", "solf1"}], " ", "/.", " ", "solf2"}], 
     "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.410767503271936*^9, 3.4107675291710443`*^9}, {
  3.4107760965520353`*^9, 3.410776100033127*^9}, {3.426411513812357*^9, 
  3.426411522849058*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", "A", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"11", " ", 
     RowBox[{"Sin", "[", "y", "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"f2b", "[", "y", "]"}], " ", 
     RowBox[{"Sin", "[", "y", "]"}]}], "-", 
    RowBox[{"9", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", " ", "y"}], "]"}]}], "+", 
    RowBox[{"4", " ", "D", " ", 
     RowBox[{"Cos", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"Sin", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"4", " ", "D", " ", 
     RowBox[{"Cos", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.410767520829235*^9, 3.4107675340833797`*^9}, 
   3.4107761010173807`*^9, 3.426405975366592*^9, {3.426411524025981*^9, 
   3.426411530073437*^9}, 3.440942846945617*^9}]
}, Open  ]],

Cell["Check the first integral", "Text",
 CellChangeTimes->{{3.426406038752332*^9, 3.426406050976831*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3dI", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["11", "4"]}], " ", "A", " ", 
     RowBox[{"Cos", "[", "y", "]"}]}], "+", 
    RowBox[{
     FractionBox["3", "4"], " ", "A", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", "y"}], "]"}]}], "-", 
    RowBox[{"A", " ", 
     RowBox[{"Cos", "[", "y", "]"}], " ", 
     RowBox[{"f2b", "[", "y", "]"}]}], " ", "+", 
    RowBox[{"A", " ", 
     RowBox[{"Sin", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], " ", "+", " ", 
    RowBox[{"A", " ", "D", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]}], 
  ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a3dI", ",", "y"}], "]"}], "-", "a3dF"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.410776109147463*^9, 3.410776242572712*^9, 3.41077629284744*^9, 
   3.410776447611446*^9, {3.410776529532641*^9, 3.410776596855085*^9}, {
   3.410776681175007*^9, 3.410776735245838*^9}, {3.426406011925717*^9, 
   3.426406029475155*^9}, {3.426406289832275*^9, 3.426406310008637*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.410776629815753*^9, 3.410776643222908*^9}, 
   3.41077669583923*^9, {3.410776730050178*^9, 3.410776740325583*^9}, 
   3.426406034524461*^9, 3.426406311171772*^9, 3.426411556363797*^9, 
   3.440942847892627*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a3g"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3g", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"-", "a31"}], ",", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.426406656058572*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f1", "\[Prime]\[Prime]",
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{3.390991551752455*^9, 3.4107680090978527`*^9, 
  3.4107770292780027`*^9, 3.426406657457146*^9, 3.426411618889108*^9, 
  3.440942859463183*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3gF", "=", " ", 
  RowBox[{"a3g", "/.", " ", "solf1"}]}]], "Input",
 CellChangeTimes->{{3.410768014452223*^9, 3.4107680357316217`*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"Sin", "[", "y", "]"}], "C"]}]], "Output",
 CellChangeTimes->{3.4107680364913883`*^9, 3.410777030388565*^9, 
  3.426406666155877*^9, 3.426411623536873*^9, 3.44094286166063*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ss3g", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[ScriptCapitalL]2", "[", 
          RowBox[{"f3g", "[", "y", "]"}], "]"}], "\[Equal]", 
         RowBox[{"-", "a3gF"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"f3g", "'"}], "[", 
          FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{
         RowBox[{"f3g", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
      RowBox[{"f3g", "[", "y", "]"}], ",", "y"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"solf3g", "=", " ", 
  RowBox[{"f3g", "\[Rule]", 
   RowBox[{"Function", "[", 
    RowBox[{"y", ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{"f3g", "[", "y", "]"}], " ", "/.", " ", "ss3g"}], "]"}]}], 
    "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.410700291579397*^9, 3.410700339643463*^9}, {
  3.4107004359196978`*^9, 3.410700465306056*^9}, {3.410764982250455*^9, 
  3.4107649836781178`*^9}, {3.410765047193008*^9, 3.410765049100358*^9}, {
  3.410765389153388*^9, 3.410765394723599*^9}, {3.410765470846292*^9, 
  3.410765511774974*^9}, {3.410766675155202*^9, 3.410766676673588*^9}, {
  3.410766963704053*^9, 3.410767006125278*^9}, {3.4107680687235603`*^9, 
  3.4107681053838873`*^9}}],

Cell[BoxData[
 RowBox[{"f3g", "\[Rule]", 
  RowBox[{"Function", "[", 
   RowBox[{"y", ",", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Sin", "[", "y", "]"}], 
      RowBox[{"A", " ", 
       SuperscriptBox["C", "2"]}]]}]}], "]"}]}]], "Output",
 CellChangeTimes->{3.410768106454791*^9, 3.410777031514567*^9, 
  3.426406679156607*^9, 3.42641162912622*^9, 3.440942863321166*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3N", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a3g"}], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "  ", "-", " ", 
    RowBox[{"a3d", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "-", " ", 
    RowBox[{"a3b", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "-", " ", 
    RowBox[{"a3a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "3"]}], "+", "  ", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]3", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"A", ">", "0"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Together", "[", 
     RowBox[{"Expand", "[", 
      RowBox[{"a3N", "-", "a3"}], " ", "]"}], "]"}], " ", "]"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.426405241108292*^9, 3.426405260537177*^9}, {
  3.426411648748941*^9, 3.426411669188497*^9}, {3.440942868934527*^9, 
  3.440942890244688*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.390991560796636*^9, 3.390991566943182*^9}, 
   3.426406700295746*^9, {3.426411652007099*^9, 3.426411670133687*^9}, 
   3.440942891745288*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rule3", "=", 
   RowBox[{"\[Psi]3", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f3g", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", "  ", 
       RowBox[{
        RowBox[{"f3d", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"f3b", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"f3a", "[", "#3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], "3"]}]}], " ", "&"}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.440942902794273*^9, 3.440942957097921*^9}}],

Cell["\<\
f3a has SinI symmetry
f3b has SinP symmetry
f3c has CosI symmetry
f3d has SinI symmetry
f3e has CosP symmetry
f3f has SinI symmetry
f3g has SinI symmetry
f3h has SinI symmetry\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solf3", "=", 
  RowBox[{"Flatten", "[", 
   RowBox[{"{", 
    RowBox[{"solf3a", ",", "solf3g"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.410767563275056*^9, 3.4107675918794823`*^9}, {
  3.410767826166216*^9, 3.410767829028726*^9}, {3.410767989226519*^9, 
  3.410767991283641*^9}, {3.410768115211185*^9, 3.410768121837709*^9}, {
  3.440942980839522*^9, 3.44094298131911*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f3a", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["C", "2"]}], ")"}], " ", 
         RowBox[{"Sin", "[", "y", "]"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["A", "2"], " ", 
         SuperscriptBox["C", "3"]}]]}]}], "]"}]}], ",", 
   RowBox[{"f3g", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"y", ",", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Sin", "[", "y", "]"}], 
        RowBox[{"A", " ", 
         SuperscriptBox["C", "2"]}]]}]}], "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.4107681265001583`*^9, 3.41076818468102*^9, 3.410768786160281*^9, 
   3.41077699365703*^9, 3.410777044902977*^9, 3.426410638093805*^9, 
   3.426411694585725*^9, {3.440942970606693*^9, 3.440942982570864*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 4", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4", " ", "=", " ", 
   RowBox[{"Assuming", "[", 
    RowBox[{
     RowBox[{"A", ">", "0"}], " ", ",", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"NS2", ",", "\[Epsilon]", ",", "4"}], "]"}], "   ", "//.", " ",
       
      RowBox[{"{", 
       RowBox[{"Rule0", ",", "Rule1", ",", "Rule2", ",", "Rule3"}], "}"}]}]}],
     "  ", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a41", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a4", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "3"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "4"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.390991768917178*^9, 3.426411727833234*^9, {3.440943013357328*^9, 
   3.44094301394366*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "4"]}], ":", " ", 
  "a4a"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4a", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"-", "a41"}], ",", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}], "4"]}], "]"}], " ", ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Assuming", "[", 
  RowBox[{
   RowBox[{"A", ">", "0"}], ",", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"a4a", " ", "/.", " ", "solf1"}], " ", "/.", " ", "solf2"}], 
     " ", "/.", " ", "solf3"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.390991730830499*^9, 3.390991734655882*^9}, {
  3.39099181007766*^9, 3.390991846803842*^9}, {3.426410498545436*^9, 
  3.42641057785931*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"9", "+", 
      RowBox[{"14", " ", 
       SuperscriptBox["C", "2"]}], "+", 
      SuperscriptBox["C", "4"]}], ")"}], " ", 
    RowBox[{"Cos", "[", "y", "]"}]}], 
   RowBox[{"16", " ", 
    SuperscriptBox["A", "2"], " ", 
    SuperscriptBox["C", "3"]}]]}]], "Output",
 CellChangeTimes->{
  3.390991737784405*^9, 3.390991790367811*^9, 3.390991829981018*^9, 
   3.390991929157619*^9, 3.410768243478154*^9, 3.410777092376771*^9, {
   3.42641056325968*^9, 3.426410579075299*^9}, 3.426410647771659*^9, 
   3.426410695260093*^9, 3.426411737324664*^9, 3.440943057108484*^9}]
}, Open  ]],

Cell["Solvability is satisfied for this term", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], "2"]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a42", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a41", ",", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4c"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4c", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"-", "a42"}], ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", "/.", "Rulea"}], ",", 
     RowBox[{"{", 
      RowBox[{"D", ",", "A", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"a4cF", "=", 
  RowBox[{"Assuming", "[", 
   RowBox[{
    RowBox[{"A", ">", "0"}], ",", 
    RowBox[{"Simplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"a4c", " ", "/.", " ", "solf1"}], " ", "/.", " ", "solf2"}], 
      " ", "/.", " ", "solf3"}], "]"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"a4cFFinal", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"+", 
      FractionBox["1", 
       RowBox[{"2", " ", "A", " ", "C"}]]}], 
     RowBox[{"(", 
      RowBox[{"19", "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["C", "2"]}]}], ")"}], 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "+", " ", 
       SuperscriptBox["C", "2"]}], 
      RowBox[{"8", " ", "A", " ", "C"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "+", 
          RowBox[{"9", 
           RowBox[{
            SuperscriptBox["f2b", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "y"}], "]"}]}], " ", "-", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", " ", 
          RowBox[{"3", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "y"}], "]"}]}]}], ")"}], 
        RowBox[{
         SuperscriptBox["f2b", 
          TagBox[
           RowBox[{"(", "4", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], " ", "+", 
    RowBox[{"4", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"3", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "y"}], "]"}]}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"a4cF", "-", "a4cFFinal"}], " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{"solf2a", ",", "solf1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{
  3.426412072116016*^9, 3.426412136730646*^9, {3.426412187132302*^9, 
   3.426412208575502*^9}, {3.426412279500811*^9, 3.426412309048213*^9}, {
   3.440945028378172*^9, 3.44094505372628*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", "A", " ", "C"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"76", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}]}], "+", 
    RowBox[{"20", " ", 
     SuperscriptBox["C", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}]}], "-", 
    RowBox[{"12", " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SuperscriptBox["C", "2"]}], ")"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"32", " ", "A", " ", "C", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"27", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"9", " ", 
     SuperscriptBox["C", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"8", " ", "A", " ", "C", " ", 
     RowBox[{
      SuperscriptBox["f3b", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"24", " ", "A", " ", "C", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["C", "2"], " ", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"9", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["C", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"8", " ", "A", " ", "C", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3b", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.412184631301369*^9, 3.426412140914238*^9, {3.426412188601549*^9, 
   3.42641221240724*^9}, {3.426412286773743*^9, 3.426412311490074*^9}, 
   3.440943077200578*^9, 3.440944944874149*^9, 3.440945058302472*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.412184631301369*^9, 3.426412140914238*^9, {3.426412188601549*^9, 
   3.42641221240724*^9}, {3.426412286773743*^9, 3.426412311490074*^9}, 
   3.440943077200578*^9, 3.440944944874149*^9, 3.44094505839016*^9}]
}, Open  ]],

Cell["Check that the contribution can be integrated twice", "Text",
 CellChangeTimes->{{3.426412830515441*^9, 3.426412849451607*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4cI2", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"-", " ", 
      FractionBox["1", 
       RowBox[{"8", " ", "A", " ", "C"}]]}], 
     RowBox[{"(", 
      RowBox[{"19", "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["C", "2"]}]}], ")"}], 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"Cos", "[", "y", "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Cos", "[", "y", "]"}], 
        RowBox[{
         SuperscriptBox["f3b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], " ", "-", " ", 
       RowBox[{
        RowBox[{"Sin", "[", "y", " ", "]"}], 
        RowBox[{
         SuperscriptBox["f3b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"3", "+", " ", 
       SuperscriptBox["C", "2"]}], 
      RowBox[{"8", " ", "A", " ", "C"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "y"}], "]"}], 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", "y"}], "]"}]}], "+", "1"}], ")"}], 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]}], 
  ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"a4cI2", ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", "a4c"}], "/.", " ", 
   RowBox[{"{", 
    RowBox[{"solf2a", ",", "solf1"}], "}"}]}], " ", "]"}]}], "Input",
 CellChangeTimes->{{3.412187505339949*^9, 3.41218758870533*^9}, {
   3.412187858523164*^9, 3.412187902063158*^9}, {3.412188035380984*^9, 
   3.412188036466055*^9}, {3.412188200432267*^9, 3.412188233026468*^9}, {
   3.412188392380021*^9, 3.412188417199693*^9}, {3.426412461880271*^9, 
   3.426412550123205*^9}, 3.440943123523303*^9, {3.44094338462225*^9, 
   3.440943385086098*^9}, {3.440945089222892*^9, 3.440945090782245*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.440944969772549*^9, 3.440945093403232*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"No", " ", "contribution", " ", "from", " ", "this", " ", "part"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Hence", ",", " ", 
  RowBox[{"there", " ", "is", " ", "no", " ", "term", " ", "like", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", "in", " ", "the", " ", "amplitude", 
   " ", 
   RowBox[{"equation", ".", " ", "Finding"}], " ", "this", " ", "term", " ", 
   "in", " ", "previous", " ", "versions", " ", "of", " ", "this", " ", 
   "calculation", " ", "was", " ", "a", " ", "spurious", " ", "consequence", 
   " ", "of", " ", "the", " ", "singularities", " ", "induced", " ", "by", 
   " ", "vanishing", " ", "viscosity", " ", "at", " ", "the", " ", "center", 
   " ", "of", " ", "the", " ", 
   RowBox[{"jet", "."}]}]}]}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a43", "=", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a41", ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", "a4g"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4g", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"-", "a43"}], ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", "/.", " ", "Rulea"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"a4gF", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a4g", " ", "/.", " ", "solf1"}], " ", "/.", " ", "solf2"}], " ",
     "/.", " ", "solf3"}], " ", "]"}]}]}], "Input",
 CellChangeTimes->{{3.426413993768385*^9, 3.42641401080839*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", "C"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"15", " ", 
     RowBox[{"Cos", "[", "y", "]"}]}], "+", 
    RowBox[{"9", " ", 
     SuperscriptBox["C", "2"], " ", 
     RowBox[{"Cos", "[", "y", "]"}]}], "-", 
    RowBox[{"63", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", "y"}], "]"}]}], "-", 
    RowBox[{"9", " ", 
     SuperscriptBox["C", "2"], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"3", " ", "y"}], "]"}]}], "+", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SuperscriptBox["C", "2"]}], ")"}], " ", 
     RowBox[{"Cos", "[", "y", "]"}], " ", 
     RowBox[{"f2b", "[", "y", "]"}]}], "+", 
    RowBox[{"8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["C", "2"]}], "-", "D"}], ")"}], " ", 
     RowBox[{"Sin", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"32", " ", "C", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3d", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"8", " ", 
     RowBox[{"Cos", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["C", "2"], " ", 
     RowBox[{"Cos", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"8", " ", "D", " ", 
     RowBox[{"Sin", "[", "y", "]"}], " ", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "-", 
    RowBox[{"8", " ", "C", " ", 
     RowBox[{
      SuperscriptBox["f3d", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"24", " ", "C", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3d", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{"8", " ", "C", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "y"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["f3d", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.410769325813365*^9, 3.410786943154357*^9, 
  3.426414013512032*^9, 3.440945111582418*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4gI2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"+", 
      FractionBox["1", 
       RowBox[{"8", " ", "C"}]]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "15"}], " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "-", 
       RowBox[{"9", " ", 
        SuperscriptBox["C", "2"], " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "+", 
       RowBox[{"7", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"3", " ", "y"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["C", "2"], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"3", " ", "y"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", " ", "y"}], "]"}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["f3d", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], "+", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "y"}], "]"}], 
     RowBox[{
      SuperscriptBox["f3d", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}]}], " ", "-", 
    RowBox[{"C", " ", 
     RowBox[{"Cos", "[", "y", "]"}], " ", 
     RowBox[{"f2b", "[", "y", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a4gI1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["D", "C"]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", "y", "]"}]}], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Sin", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "C"], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"f2b", "[", "y", "]"}], " ", 
        RowBox[{"Sin", "[", "y", "]"}]}], " ", "+", 
       RowBox[{
        RowBox[{"Cos", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4gF", "-", 
   RowBox[{"D", "[", 
    RowBox[{"a4gI2", ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "2"}], "}"}]}], "]"}], "-", 
   RowBox[{"D", "[", 
    RowBox[{"a4gI1", ",", "y"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.410787446990378*^9, 3.410787511141399*^9}, 
   3.412483500834536*^9, 3.412483610561392*^9, {3.412483658704401*^9, 
   3.412483673588403*^9}, {3.412483733361854*^9, 3.412483763864362*^9}, {
   3.412483797728818*^9, 3.412483805517194*^9}, {3.412484068069205*^9, 
   3.412484096830549*^9}, 3.412484166994004*^9, {3.412484286437068*^9, 
   3.412484297860714*^9}, {3.426414043965319*^9, 3.426414090394418*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.410787512933648*^9, 3.41248365367172*^9, 3.412484103894163*^9, 
   3.412484179092997*^9, 3.412484252435529*^9, {3.412484287950865*^9, 
   3.412484298836425*^9}, {3.42641404011318*^9, 3.426414051520163*^9}, 
   3.426414091878772*^9, 3.44094511477779*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4h"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4h", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"-", "a43"}], ",", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", "/.", " ", "Rulea"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"a4h", " ", "/.", " ", "solf1"}], " ", "/.", " ", "solf2"}], " ", 
   "/.", " ", "solf3"}], " ", "]"}]}], "Input",
 CellChangeTimes->{{3.426415055462808*^9, 3.426415061609914*^9}, 
   3.426415200807701*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"7", "+", 
      SuperscriptBox["C", "2"]}], ")"}], " ", 
    RowBox[{"Cos", "[", "y", "]"}]}], 
   RowBox[{"2", " ", "A", " ", 
    SuperscriptBox["C", "2"]}]]}]], "Output",
 CellChangeTimes->{3.4107694578648252`*^9, 3.426415065999861*^9, 
  3.426415143540573*^9, 3.426415202277193*^9, 3.440945129734896*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4l"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4l", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"-", "a41"}], ",", "  ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "4"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", "/.", " ", "Rulea"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], " ", "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"a4lF", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a4l", " ", "/.", " ", "solf1"}], " ", "/.", " ", "solf2"}], " ",
     "/.", " ", "solf3"}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.426415732303396*^9, {3.426441449882639*^9, 3.426441458927364*^9}, {
   3.426441532849542*^9, 3.426441549773167*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "C"], 
  RowBox[{"A", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"D", " ", 
      SuperscriptBox[
       RowBox[{"Cos", "[", "y", "]"}], "2"]}], "+", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "y", "]"}], "2"], "-", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      SuperscriptBox["C", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "y"}], "]"}], "+", 
        RowBox[{"4", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "y"}], "]"}], " ", 
         RowBox[{"f2b", "[", "y", "]"}]}], "+", 
        RowBox[{"3", " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "y"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2b", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{
          SuperscriptBox["f2b", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"2", " ", "y"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2b", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.391088486824365*^9, 3.4107696289494867`*^9, 3.4107774959279833`*^9, 
   3.410789945701848*^9, 3.426415734513927*^9, 3.42644145993917*^9, {
   3.426441537366518*^9, 3.426441550730751*^9}, 3.440945134868167*^9}]
}, Open  ]],

Cell["\<\
Eliminate the terms that can be integrated and keep only the contributing \
terms\
\>", "Text",
 CellChangeTimes->{{3.426441645968783*^9, 3.426441672411902*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Expand", "[", 
    RowBox[{"a4lF", " ", "+", "  ", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"A", " ", "C"}], "4"], 
         RowBox[{"Sin", "[", 
          RowBox[{"2", " ", "y"}], "]"}]}], " ", "+", 
        RowBox[{"A", " ", "C", "   ", 
         RowBox[{
          SuperscriptBox["f2b", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ",", "y"}], "]"}]}],
     "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.410790152915148*^9, 3.4107902993538923`*^9}, {
   3.410790375537784*^9, 3.410790486823036*^9}, {3.410790585181375*^9, 
   3.4107905874070187`*^9}, 3.412192882038709*^9, {3.41219291303934*^9, 
   3.412192919647401*^9}, {3.426415754533539*^9, 3.426415758026904*^9}, {
   3.42644157883943*^9, 3.426441618820088*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", "A", " ", "C"}], "2"]}], "+", 
  FractionBox[
   RowBox[{"A", " ", "D", " ", 
    SuperscriptBox[
     RowBox[{"Cos", "[", "y", "]"}], "2"]}], "C"], "-", 
  RowBox[{"2", " ", "A", " ", "C", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "y"}], "]"}], " ", 
   RowBox[{"f2b", "[", "y", "]"}]}], "+", 
  FractionBox[
   RowBox[{"A", " ", 
    SuperscriptBox[
     RowBox[{"Sin", "[", "y", "]"}], "2"]}], "C"], "-", 
  RowBox[{"3", " ", "A", " ", "C", " ", 
   RowBox[{"Cos", "[", "y", "]"}], " ", 
   RowBox[{"Sin", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"A", " ", "C", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "y"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.4107904595055532`*^9, 3.4107904900097*^9, 
  3.4107905890029173`*^9, 3.412192923245654*^9, 3.426415760544276*^9, 
  3.426441584540867*^9, 3.426441620509584*^9, 3.44094513828665*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4m"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4m", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"-", "a41"}], ",", "  ", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]1", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{3.42641559277037*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.391063445860334*^9, 3.410769729702544*^9, 
  3.410777542887699*^9, 3.426415594368111*^9, 3.440945144637612*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4m", " ", "/.", " ", "solf2"}]], "Input",
 CellChangeTimes->{{3.410769735904196*^9, 3.410769740588874*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.4107697416735973`*^9, 3.410777548369779*^9, 
  3.426415614870638*^9, 3.440945147643912*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4n"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4n", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{
      RowBox[{"-", "a41"}], ",", "  ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "]"}], " ", ",", 
    RowBox[{"{", 
     RowBox[{"A", ",", "D"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.426415668246091*^9}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.391063453945049*^9, 3.4107697551733932`*^9, 
  3.410777560956221*^9, 3.426415669693508*^9, 3.426441976671149*^9, 
  3.440945150968499*^9}]
}, Open  ]],

Cell["The firxt term contributes, the second one does not", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], ":", " ", 
  "a4o"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4o", "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{
        RowBox[{"-", "a41"}], ",", "  ", 
        SuperscriptBox[
         RowBox[{
          RowBox[{
           SuperscriptBox["\[CurlyPhi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], " ", "]"}], " ", "/.",
       "Rulea"}], ",", 
     RowBox[{"{", 
      RowBox[{"A", ",", "D", ",", "C"}], " ", "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"a4oF", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"a4o", " ", "/.", " ", "solf1"}], " ", "/.", " ", "solf2"}], " ",
     "/.", " ", "solf3"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.426442043313148*^9, 3.426442051407247*^9}, 
   3.426442538276485*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"8", " ", "C"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["C", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Cos", "[", "y", "]"}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"3", " ", "y"}], "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox["C", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "9"}], " ", 
        RowBox[{"Cos", "[", "y", "]"}]}], "+", 
       RowBox[{"Cos", "[", 
        RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", 
        SuperscriptBox["C", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f2b", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SuperscriptBox["C", "2"]}], "-", 
          RowBox[{"2", " ", "D"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["C", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "y"}], "]"}]}], "+", 
          RowBox[{
           SuperscriptBox["C", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "y"}], "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f2b", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox["C", "2"]}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["C", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "y"}], "]"}]}]}], ")"}], " ", 
        RowBox[{"Sin", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["C", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9"}], " ", 
           RowBox[{"Cos", "[", "y", "]"}]}], "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f2b", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{"Cos", "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "6"}], "-", 
          RowBox[{"9", " ", 
           SuperscriptBox["C", "2"]}], "-", 
          RowBox[{"2", " ", "D"}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["C", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "y"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "5"}], " ", 
              SuperscriptBox["C", "2"]}], "+", 
             RowBox[{"2", " ", "D"}], "+", 
             RowBox[{
              SuperscriptBox["C", "2"], " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", "y"}], "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f2b", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
      ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{
      SuperscriptBox["f2b", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox["C", "2"], " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["C", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9"}], " ", 
           RowBox[{"Cos", "[", "y", "]"}]}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"3", " ", "y"}], "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"Sin", "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["C", "2"]}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["C", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", " ", "y"}], "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["C", "2"], " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "y", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["f2b", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.41076989543836*^9, 3.410769933898334*^9, {3.410788042015571*^9, 
   3.410788048448688*^9}, 3.410788580072839*^9, 3.426442063581363*^9, 
   3.426442541899923*^9, 3.440945160242166*^9}]
}, Open  ]],

Cell["Primitive for the whole expression", "Text",
 CellChangeTimes->{{3.391087781457129*^9, 3.391087814306455*^9}, {
  3.426442272725224*^9, 3.426442290715736*^9}, {3.42644282192096*^9, 
  3.426442831723237*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4oI", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"Sin", "[", "y", "]"}]}], "C"], "+", 
    RowBox[{
     FractionBox["9", "4"], " ", "C", " ", 
     RowBox[{"Sin", "[", "y", "]"}]}], "-", 
    RowBox[{
     FractionBox["3", "4"], " ", "C", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"3", " ", "y"}], "]"}]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Cos", "[", "y", "]"}]}], " ", 
       RowBox[{
        SuperscriptBox["f2b", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "D"}], ")"}], " ", 
       RowBox[{"Sin", "[", "y", "]"}], " ", 
       RowBox[{
        SuperscriptBox["f2b", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"D", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sin", "[", "y", "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cos", "[", "y", "]"}], " ", 
          RowBox[{
           SuperscriptBox["f2b", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], "C"], 
    "-", 
    RowBox[{
     FractionBox["1", "4"], " ", "C", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "6"}], " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "y", "]"}], "2"], " ", 
        RowBox[{"Sin", "[", "y", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f2b", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["f2b", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "9"}], " ", 
           RowBox[{"Cos", "[", "y", "]"}]}], "+", 
          RowBox[{"Cos", "[", 
           RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "y", "]"}], "3"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "9"}], " ", 
              RowBox[{"Cos", "[", "y", "]"}]}], "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f2b", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"2", " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", 
              RowBox[{"Cos", "[", "y", "]"}]}], "+", 
             RowBox[{"Cos", "[", 
              RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", "y", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", 
              RowBox[{"Cos", "[", "y", "]"}]}], "+", 
             RowBox[{
              RowBox[{"Sin", "[", "y", "]"}], " ", 
              RowBox[{
               SuperscriptBox["f2b", 
                TagBox[
                 RowBox[{"(", "3", ")"}],
                 Derivative],
                MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"D", "[", 
    RowBox[{"a4oI", ",", "y"}], "]"}], "-", "a4oF"}], "]"}]}], "Input",
 CellChangeTimes->{{3.410789825212825*^9, 3.410789863564362*^9}, {
  3.426442442253176*^9, 3.426442471907693*^9}, {3.426442524839991*^9, 
  3.426442547522418*^9}, {3.426442845237721*^9, 3.426442875477159*^9}, {
  3.426443089838818*^9, 3.426443091759903*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.410789883225667*^9, 3.426442086364229*^9, 
  3.426442474154828*^9, 3.426442549545282*^9, 3.426442877282216*^9, 
  3.426443093215213*^9, 3.440945166460344*^9}]
}, Open  ]],

Cell["Better expression", "Text",
 CellChangeTimes->{{3.426442885889126*^9, 3.426442889395326*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4oIFinal", "=", " ", 
   RowBox[{
    RowBox[{"3", " ", 
     RowBox[{"Sin", "[", "y", "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "C"], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          FractionBox["D", "3"]}], ")"}]}], "+", " ", 
       RowBox[{"C", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", "y", "]"}], "2"]}]}], ")"}]}], "-", " ", 
    RowBox[{
     FractionBox["1", "C"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cos", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["D", "C"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cos", "[", "y", "]"}], " ", 
        RowBox[{
         SuperscriptBox["f2b", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     FractionBox["1", "4"], " ", "C", " ", 
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "y", "]"}], "3"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["f2b", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "y", "]"}], "3"], " ", 
         RowBox[{
          SuperscriptBox["f2b", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "-", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "9"}], " ", 
            RowBox[{"Cos", "[", "y", "]"}]}], "+", 
           RowBox[{"Cos", "[", 
            RowBox[{"3", " ", "y"}], "]"}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", 
           RowBox[{
            SuperscriptBox["f2b", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "y", "]"}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["f2b", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}]}], ",", "y"}], 
      "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4oIFinal", "-", "a4oI"}], "]"}]}], "Input",
 CellChangeTimes->{{3.412188709392876*^9, 3.41218878743739*^9}, {
   3.41218939166448*^9, 3.412189430955307*^9}, {3.412189483137697*^9, 
   3.412189514605828*^9}, {3.41218962573752*^9, 3.412189673467657*^9}, {
   3.412190283567011*^9, 3.412190378048239*^9}, {3.41219058380963*^9, 
   3.412190601302496*^9}, {3.412190642245406*^9, 3.412190693554783*^9}, {
   3.412190738258823*^9, 3.412190793672367*^9}, {3.412190922748173*^9, 
   3.412190946632805*^9}, {3.412191032598775*^9, 3.412191033713482*^9}, {
   3.41219106428738*^9, 3.412191065373663*^9}, 3.412191124220359*^9, {
   3.412191428759727*^9, 3.412191464267897*^9}, {3.412191654591423*^9, 
   3.412191656531279*^9}, {3.412191688867916*^9, 3.412191690090242*^9}, {
   3.412191731934195*^9, 3.412191798967014*^9}, {3.41219184785917*^9, 
   3.412191894134726*^9}, {3.412191931008231*^9, 3.412191951862144*^9}, {
   3.426442562174313*^9, 3.426442580163187*^9}, {3.426442639900729*^9, 
   3.426442682915199*^9}, {3.426442921087583*^9, 3.426442940122428*^9}, {
   3.426443166972954*^9, 3.426443188291708*^9}, {3.426443287232014*^9, 
   3.426443319502568*^9}, 3.426443377369192*^9, {3.426443426153732*^9, 
   3.426443434718403*^9}, {3.426444262527878*^9, 3.426444269179574*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.412190989029092*^9, {3.412191051396723*^9, 3.412191073720316*^9}, 
   3.412191140858336*^9, 3.412191810278613*^9, {3.412191879063296*^9, 
   3.412191898897582*^9}, 3.412191957915732*^9, 3.426442116626615*^9, 
   3.426442594206478*^9, 3.426442661468977*^9, 3.426442691859787*^9, 
   3.426442943141869*^9, {3.426443171845379*^9, 3.426443189554834*^9}, {
   3.426443311344236*^9, 3.426443322559873*^9}, 3.426443382080514*^9, 
   3.426443438176659*^9, 3.426444270998416*^9, 3.440945169355443*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4NN", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a4o"}], " ", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], "-", 
    RowBox[{"a4n", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "-", " ", 
    RowBox[{"a4l", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a4g", "  ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "+", 
       RowBox[{"a4h", " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], " ", "-", " ", 
    RowBox[{"a4c", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "-", " ", 
    RowBox[{"a4a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "4"]}], "+", "  ", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]4", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"a4NN", "-", "a4"}], " ", "/.", " ", "Rulea"}], " ", "/.", " ", 
    "solf1"}], " ", "/.", " ", "solf2a"}], "]"}]}], "Input",
 CellChangeTimes->{{3.426475945449049*^9, 3.426476030628773*^9}, {
  3.440945193350264*^9, 3.44094536044939*^9}, {3.440945482242711*^9, 
  3.440945503900858*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.440945506661506*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dump", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DumpSave", "[", 
  RowBox[{"\"\<CH-eff1-nu-9b_compact.m6.mx\>\"", ",", "\"\<Global`\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.390644917941404*^9, 3.390644919253133*^9}, {
   3.390991638857469*^9, 3.390991663590071*^9}, {3.410776974832609*^9, 
   3.41077697637125*^9}, {3.426480483057276*^9, 3.426480488417624*^9}, 
   3.44094551664936*^9}],

Cell[BoxData[
 RowBox[{"{", "\<\"Global`\"\>", "}"}]], "Output",
 CellChangeTimes->{3.390991665158176*^9, 3.391089139709158*^9, 
  3.410766723659595*^9, 3.410768196589384*^9, 3.410770041586815*^9, 
  3.410776982658432*^9, 3.410777706606902*^9, 3.410791172151641*^9, 
  3.426476488559952*^9, 3.44094551773166*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "CH-eff1-nu-9b_compact.m6.mx"}]], "Input",
 CellChangeTimes->{{3.390644910684701*^9, 3.390644913799574*^9}, {
   3.390991646447856*^9, 3.390991652955365*^9}, {3.426480494423596*^9, 
   3.426480498822496*^9}, 3.440945521377801*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Amplitude equation", "Section",
 CellChangeTimes->{{3.424837534432367*^9, 3.424837538105882*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Calculation of - ",
 Cell[BoxData[
  FormBox[
   FractionBox["3", "2"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"2", " ", "\[Pi]"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"2", " ", "\[Pi]"}]], 
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", "f2b"}], " ", "sin", " ", "2", 
     "y", 
     RowBox[{"\[DifferentialD]", "y"}]}]}], TraditionalForm]]]
}], "Subsection",
 CellChangeTimes->{{3.412194569484182*^9, 3.412194586765663*^9}, {
  3.424837368034645*^9, 3.424837448294143*^9}, {3.424874839543935*^9, 
  3.424874851272431*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"II", "=", 
  RowBox[{
   RowBox[{"-", 
    FormBox[
     FractionBox["3", "2"],
     TraditionalForm]}], 
   FractionBox["1", 
    RowBox[{"2", " ", "\[Pi]"}]], 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"Evaluate", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "y"}], "]"}], " ", 
        RowBox[{"h2b", "[", "y", "]"}]}], " ", "/.", " ", "ss2b"}], "]"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]}]}], "\n", 
 RowBox[{"N", "[", "II", "]"}]}], "Input",
 CellChangeTimes->{{3.412194593600655*^9, 3.412194672896859*^9}, {
   3.412194711357246*^9, 3.412194752976328*^9}, {3.412194799242806*^9, 
   3.412194799889767*^9}, 3.412196421182211*^9, {3.42480384320743*^9, 
   3.424803843615506*^9}, {3.424837451168363*^9, 3.42483745203454*^9}, 
   3.424874863025697*^9, 3.424875065507171*^9, {3.426476466575965*^9, 
   3.426476470395419*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["3", "4"]}], " ", 
  RowBox[{"(", 
   RowBox[{"2", "-", 
    FractionBox[
     RowBox[{"4", " ", 
      RowBox[{"EllipticK", "[", 
       FractionBox["1", "2"], "]"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"EllipticE", "[", 
       FractionBox["1", "2"], "]"}]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.412194914497802*^9, 3.412196427584334*^9, 
  3.42487503741537*^9, 3.424875086022352*^9, 3.426476381786091*^9, 
  3.42647647254501*^9, 3.441485308636903*^9}],

Cell[BoxData[
 RowBox[{"-", "0.1272660741163003`"}]], "Output",
 CellChangeTimes->{3.412194914497802*^9, 3.412196427584334*^9, 
  3.42487503741537*^9, 3.424875086022352*^9, 3.426476381786091*^9, 
  3.42647647254501*^9, 3.441485308698394*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stability threshold", "Subsection",
 CellChangeTimes->{{3.412196354062988*^9, 3.412196360939881*^9}, {
  3.424837554178761*^9, 3.42483756086553*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DD", "=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "144"], "+", 
    RowBox[{"4", " ", 
     SuperscriptBox["Cs", "2"], 
     RowBox[{"(", 
      RowBox[{"3", " ", "+", " ", 
       RowBox[{"2", " ", "II"}]}], ")"}]}]}], " ", "/.", " ", 
   RowBox[{"Cs", "\[Rule]", "0.008"}]}]}], "\n", 
 SqrtBox[
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", 
      RowBox[{"(", 
       RowBox[{"3", " ", "+", " ", 
        RowBox[{"2", " ", "II"}]}], ")"}], 
      SuperscriptBox["Cs", "2"], " "}]], 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", "12"], "+", " ", 
      SqrtBox["DD"]}], ")"}]}], " ", "/.", " ", 
   RowBox[{"Cs", "\[Rule]", "0.008"}]}]]}], "Input",
 CellChangeTimes->{{3.412196483206635*^9, 3.412196537601499*^9}, {
   3.424874896435283*^9, 3.424874897385016*^9}, 3.424875075528802*^9, {
   3.426476398905372*^9, 3.426476399814597*^9}, {3.42647644528621*^9, 
   3.426476450377551*^9}, {3.441485317092412*^9, 3.441485330631295*^9}}],

Cell[BoxData["0.007647284214496898`"], "Output",
 CellChangeTimes->{{3.412196628798151*^9, 3.412196654129679*^9}, 
   3.412196726737782*^9, 3.424875182436245*^9, 3.426476406355112*^9, 
   3.426476451693728*^9, 3.44148533219788*^9},
 Magnification->1.25],

Cell[BoxData["22.044892727648246`"], "Output",
 CellChangeTimes->{{3.412196628798151*^9, 3.412196654129679*^9}, 
   3.412196726737782*^9, 3.424875182436245*^9, 3.426476406355112*^9, 
   3.426476451693728*^9, 3.441485332213768*^9},
 Magnification->1.25]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{866, 662},
WindowMargins->{{Automatic, 118}, {Automatic, 135}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>"CH-eff.nb.ps",
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {72, 72}}},
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Report.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 182, 4, 180, "Title"],
Cell[775, 29, 290, 12, 259, "Author"],
Cell[CellGroupData[{
Cell[1090, 45, 606, 16, 108, "Subtitle"],
Cell[CellGroupData[{
Cell[1721, 65, 29, 0, 71, "Section 1"],
Cell[CellGroupData[{
Cell[1775, 69, 33, 0, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[1833, 73, 197, 4, 30, "Input",
 InitializationCell->True],
Cell[2033, 79, 604, 11, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2686, 96, 32, 0, 31, "Subsubsection"],
Cell[2721, 98, 118, 3, 30, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[2876, 106, 34, 0, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[2935, 110, 437, 14, 35, "Input",
 InitializationCell->True],
Cell[3375, 126, 580, 16, 51, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4004, 148, 101, 2, 31, "Subsubsection"],
Cell[4108, 152, 32, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[4165, 156, 1199, 38, 60, "Input",
 InitializationCell->True],
Cell[5367, 196, 1167, 36, 58, "Output"]
}, Open  ]],
Cell[6549, 235, 515, 15, 69, "Text"],
Cell[CellGroupData[{
Cell[7089, 254, 3458, 103, 74, "Input",
 InitializationCell->True],
Cell[10550, 359, 3408, 102, 73, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14019, 468, 61, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[14105, 472, 49, 0, 41, "Subsection"],
Cell[14157, 474, 231, 6, 32, "Input",
 InitializationCell->True],
Cell[14391, 482, 357, 10, 32, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[14785, 497, 39, 0, 41, "Subsection"],
Cell[14827, 499, 541, 16, 48, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15405, 520, 114, 1, 41, "Subsection"],
Cell[CellGroupData[{
Cell[15544, 525, 430, 12, 30, "Input"],
Cell[15977, 539, 300, 7, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16338, 553, 56, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[16419, 557, 51, 0, 41, "Subsection"],
Cell[16473, 559, 386, 14, 29, "Text"],
Cell[16862, 575, 1336, 37, 52, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[18235, 617, 31, 0, 41, "Subsection"],
Cell[18269, 619, 865, 23, 34, "Input",
 InitializationCell->True],
Cell[19137, 644, 361, 11, 30, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[19547, 661, 26, 0, 68, "Section"],
Cell[19576, 663, 325, 7, 30, "Input"],
Cell[CellGroupData[{
Cell[19926, 674, 39, 0, 41, "Subsection"],
Cell[CellGroupData[{
Cell[19990, 678, 218, 6, 30, "Input"],
Cell[20211, 686, 423, 9, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20683, 701, 43, 0, 41, "Subsection"],
Cell[CellGroupData[{
Cell[20751, 705, 294, 8, 30, "Input"],
Cell[21048, 715, 281, 4, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21390, 726, 40, 0, 68, "Section"],
Cell[21433, 728, 699, 20, 32, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[22169, 753, 51, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[22245, 757, 607, 19, 35, "Input",
 InitializationCell->True],
Cell[22855, 778, 694, 19, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23586, 802, 274, 8, 30, "Input",
 InitializationCell->True],
Cell[23863, 812, 472, 11, 45, "Output"]
}, Open  ]],
Cell[24350, 826, 538, 14, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24925, 845, 26, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[24976, 849, 412, 11, 30, "Input"],
Cell[25391, 862, 1913, 58, 83, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27341, 925, 72, 0, 41, "Subsection"],
Cell[CellGroupData[{
Cell[27438, 929, 476, 14, 36, "Input"],
Cell[27917, 945, 375, 8, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28329, 958, 476, 14, 36, "Input"],
Cell[28808, 974, 255, 4, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29100, 983, 449, 14, 36, "Input"],
Cell[29552, 999, 387, 8, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29976, 1012, 439, 14, 36, "Input"],
Cell[30418, 1028, 424, 10, 60, "Output"]
}, Open  ]],
Cell[30857, 1041, 1067, 31, 52, "Input"],
Cell[CellGroupData[{
Cell[31949, 1076, 1022, 34, 36, "Input"],
Cell[32974, 1112, 255, 4, 45, "Output"]
}, Open  ]],
Cell[33244, 1119, 137, 1, 29, "Text"],
Cell[33384, 1122, 2540, 72, 129, "Text"],
Cell[35927, 1196, 130, 1, 29, "Text"],
Cell[36060, 1199, 1473, 41, 93, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37570, 1245, 49, 0, 41, "Subsection"],
Cell[CellGroupData[{
Cell[37644, 1249, 404, 13, 36, "Input"],
Cell[38051, 1264, 309, 6, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38409, 1276, 65, 0, 41, "Subsection"],
Cell[38477, 1278, 540, 16, 33, "Input"],
Cell[CellGroupData[{
Cell[39042, 1298, 97, 2, 30, "Input"],
Cell[39142, 1302, 230, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39421, 1311, 43, 0, 41, "Subsection"],
Cell[39467, 1313, 131, 1, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39635, 1319, 39, 0, 41, "Subsection"],
Cell[CellGroupData[{
Cell[39699, 1323, 532, 16, 36, "Input"],
Cell[40234, 1341, 613, 17, 51, "Output"]
}, Open  ]],
Cell[40862, 1361, 36, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[40935, 1366, 111, 1, 41, "Subsection"],
Cell[CellGroupData[{
Cell[41071, 1371, 432, 11, 70, "Input"],
Cell[41506, 1384, 360, 8, 62, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41903, 1397, 375, 9, 30, "Input"],
Cell[42281, 1408, 259, 4, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42601, 1419, 26, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[42652, 1423, 609, 16, 30, "Input"],
Cell[43264, 1441, 7667, 217, 191, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[50968, 1663, 131, 1, 25, "Subsection"],
Cell[CellGroupData[{
Cell[51124, 1668, 455, 13, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[51604, 1685, 577, 18, 36, "Input"],
Cell[52184, 1705, 3962, 122, 106, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56183, 1832, 295, 6, 30, "Input"],
Cell[56481, 1840, 456, 11, 63, "Output"]
}, Open  ]],
Cell[56952, 1854, 284, 6, 48, "Text"],
Cell[CellGroupData[{
Cell[57261, 1864, 1275, 33, 70, "Input"],
Cell[58539, 1899, 721, 17, 64, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[59309, 1922, 408, 12, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[59742, 1938, 641, 18, 36, "Input"],
Cell[60386, 1958, 1260, 38, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61683, 2001, 517, 11, 48, "Input"],
Cell[62203, 2014, 444, 9, 45, "Output"],
Cell[62650, 2025, 448, 9, 77, "Output"]
}, Open  ]],
Cell[63113, 2037, 199, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[63337, 2045, 1445, 32, 48, "Input"],
Cell[64785, 2079, 1788, 52, 177, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66610, 2136, 1177, 32, 65, "Input"],
Cell[67790, 2170, 29780, 503, 168, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97631, 2680, 149, 3, 41, "Subsection"],
Cell[97783, 2685, 829, 26, 34, "Input"],
Cell[CellGroupData[{
Cell[98637, 2715, 102, 2, 30, "Input"],
Cell[98742, 2719, 230, 3, 62, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[99021, 2728, 39, 0, 41, "Subsection"],
Cell[CellGroupData[{
Cell[99085, 2732, 894, 27, 37, "Input"],
Cell[99982, 2761, 937, 28, 69, "Output"]
}, Open  ]],
Cell[100934, 2792, 89, 4, 67, "Text"],
Cell[CellGroupData[{
Cell[101048, 2800, 210, 5, 30, "Input"],
Cell[101261, 2807, 592, 16, 81, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[101914, 2830, 26, 0, 68, "Section"],
Cell[101943, 2832, 514, 12, 30, "Input"],
Cell[CellGroupData[{
Cell[102482, 2848, 65, 0, 41, "Subsection"],
Cell[102550, 2850, 1246, 40, 36, "Input"],
Cell[CellGroupData[{
Cell[103821, 2894, 346, 12, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[104192, 2910, 1058, 31, 54, "Input"],
Cell[105253, 2943, 471, 12, 64, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105761, 2960, 1317, 33, 70, "Input"],
Cell[107081, 2995, 592, 17, 64, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[107722, 3018, 299, 9, 31, "Subsubsection"],
Cell[108024, 3029, 395, 13, 36, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108456, 3047, 527, 18, 31, "Subsubsection"],
Cell[108986, 3067, 774, 23, 36, "Input"],
Cell[109763, 3092, 162, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[109950, 3099, 1534, 46, 89, "Input"],
Cell[111487, 3147, 1020, 34, 51, "Output"],
Cell[112510, 3183, 192, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[112751, 3192, 314, 10, 31, "Subsubsection"],
Cell[113068, 3204, 660, 21, 36, "Input"],
Cell[CellGroupData[{
Cell[113753, 3229, 432, 11, 30, "Input"],
Cell[114188, 3242, 1193, 33, 60, "Output"]
}, Open  ]],
Cell[115396, 3278, 106, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[115527, 3283, 1518, 42, 88, "Input"],
Cell[117048, 3327, 261, 4, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[117358, 3337, 309, 10, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[117692, 3351, 393, 13, 36, "Input"],
Cell[118088, 3366, 285, 6, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118410, 3377, 160, 3, 30, "Input"],
Cell[118573, 3382, 231, 5, 61, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118841, 3392, 1370, 34, 70, "Input"],
Cell[120214, 3428, 383, 10, 62, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[120646, 3444, 37, 0, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[120708, 3448, 1984, 63, 71, "Input"],
Cell[122695, 3513, 192, 3, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[122948, 3523, 30, 0, 38, "Subsection"],
Cell[122981, 3525, 1848, 57, 103, "Input"],
Cell[124832, 3584, 199, 9, 162, "Text"],
Cell[CellGroupData[{
Cell[125056, 3597, 406, 8, 30, "Input"],
Cell[125465, 3607, 947, 27, 69, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[126473, 3641, 26, 0, 68, "Section"],
Cell[126502, 3643, 2221, 70, 75, "Input"],
Cell[CellGroupData[{
Cell[128748, 3717, 346, 12, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[129119, 3733, 1010, 30, 55, "Input"],
Cell[130132, 3765, 655, 17, 69, "Output"]
}, Open  ]],
Cell[130802, 3785, 54, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130893, 3790, 305, 10, 33, "Subsubsection"],
Cell[131201, 3802, 394, 13, 38, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[131632, 3820, 566, 19, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[132223, 3843, 3551, 111, 183, "Input"],
Cell[135777, 3956, 3432, 109, 124, "Output"],
Cell[139212, 4067, 259, 4, 62, "Output"]
}, Open  ]],
Cell[139486, 4074, 133, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[139644, 4079, 2287, 65, 122, "Input"],
Cell[141934, 4146, 92, 1, 62, "Output"]
}, Open  ]],
Cell[142041, 4150, 1224, 30, 98, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143302, 4185, 273, 9, 32, "Subsubsection"],
Cell[143578, 4196, 359, 12, 37, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[143974, 4213, 528, 18, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[144527, 4235, 873, 27, 54, "Input"],
Cell[145403, 4264, 2753, 84, 105, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148193, 4353, 2908, 85, 129, "Input"],
Cell[151104, 4440, 306, 5, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[151459, 4451, 533, 18, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[152017, 4473, 850, 26, 53, "Input"],
Cell[152870, 4501, 396, 11, 64, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[153315, 4518, 315, 10, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[153655, 4532, 955, 29, 53, "Input"],
Cell[154613, 4563, 1526, 42, 93, "Output"]
}, Open  ]],
Cell[156154, 4608, 171, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[156350, 4616, 903, 22, 52, "Input"],
Cell[157256, 4640, 1146, 31, 63, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[158451, 4677, 315, 10, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[158791, 4691, 403, 13, 36, "Input"],
Cell[159197, 4706, 161, 2, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[159395, 4713, 132, 2, 30, "Input"],
Cell[159530, 4717, 141, 2, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[159720, 4725, 315, 10, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[160060, 4739, 535, 17, 36, "Input"],
Cell[160598, 4758, 309, 7, 45, "Output"]
}, Open  ]],
Cell[160922, 4768, 67, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[161026, 4773, 374, 13, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[161425, 4790, 958, 29, 54, "Input"],
Cell[162386, 4821, 6426, 193, 172, "Output"]
}, Open  ]],
Cell[168827, 5017, 213, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[169065, 5024, 4843, 141, 205, "Input"],
Cell[173911, 5167, 208, 3, 45, "Output"]
}, Open  ]],
Cell[174134, 5173, 99, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[174258, 5178, 4268, 108, 194, "Input"],
Cell[178529, 5288, 545, 8, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[179123, 5302, 37, 0, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[179185, 5306, 3157, 102, 94, "Input"],
Cell[182345, 5410, 70, 1, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[182464, 5417, 26, 0, 41, "Subsection"],
Cell[CellGroupData[{
Cell[182515, 5421, 371, 7, 32, "Input"],
Cell[182889, 5430, 312, 5, 45, "Output"]
}, Open  ]],
Cell[183216, 5438, 259, 4, 32, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[183524, 5448, 103, 1, 68, "Section"],
Cell[CellGroupData[{
Cell[183652, 5453, 693, 23, 49, "Subsection"],
Cell[CellGroupData[{
Cell[184370, 5480, 996, 27, 72, "Input"],
Cell[185369, 5509, 522, 15, 98, "Output"],
Cell[185894, 5526, 241, 4, 62, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[186184, 5536, 155, 2, 41, "Subsection"],
Cell[CellGroupData[{
Cell[186364, 5542, 990, 28, 116, "Input"],
Cell[187357, 5572, 253, 4, 75, "Output"],
Cell[187613, 5578, 252, 4, 75, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
