(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1626595,      30050]
NotebookOptionsPosition[   1612452,      29606]
NotebookOutlinePosition[   1613507,      29640]
CellTagsIndexPosition[   1613464,      29637]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Instability of the Kolmogorov flow with modified viscosity
Numerical solution of the perturbation at orders 1 and 2 for f1 and f2b, and \
determination of the threshold \[CapitalDelta]c\
\>", "Title",
 Evaluatable->False,
 CellChangeTimes->{{3.426559805401846*^9, 3.426559815060887*^9}, {
  3.426575468871427*^9, 3.426575500034648*^9}},
 AspectRatioFixed->True],

Cell["version using NDSolve", "Subtitle",
 CellChangeTimes->{{3.39089276484798*^9, 3.390892770096724*^9}, {
  3.426559830563772*^9, 3.426559831201074*^9}}],

Cell[CellGroupData[{

Cell["Various initializations", "Subsection",
 Evaluatable->False,
 CellChangeTimes->{{3.390834863297745*^9, 3.390834870495508*^9}},
 AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Suppression of ennoying messages", "Subsubsection",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
Off[General::spell]
Off[General::spell1]
Off[Union::heads]
Off[NDSolve::ndinn]
Off[NDSolve::berr]
Off[MessageOptions]\
\>", "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.405964608893209*^9, 3.405964620550998*^9}, {
  3.42656908279837*^9, 3.426569084156412*^9}},
 AspectRatioFixed->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Flow2", "=", 
   RowBox[{"\[Theta]", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"#", "+", 
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "#"}], "]"}]}]}], "&"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Flow1", "=", 
   RowBox[{"\[Theta]", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{"#", "&"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow3", "=", 
   RowBox[{"\[Theta]", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"#", "+", 
       RowBox[{
        RowBox[{"1", "/", "4"}], 
        RowBox[{"Sin", "[", 
         RowBox[{"2", " ", "#"}], "]"}]}]}], "&"}], "]"}]}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390765451750462*^9, 3.390765461103569*^9}, 
   3.390852961474019*^9, {3.390932676750446*^9, 3.390932678731513*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution of the 1st order perturbation", "Section"],

Cell["Numerical solution is now performed using NDSolve", "Text",
 CellChangeTimes->{{3.424780888027177*^9, 3.4247809335506687`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Standard problem with presence of \[Mu] term\
\>", "Subsection",
 CellChangeTimes->{{3.390787011430816*^9, 3.390787054261984*^9}}],

Cell[CellGroupData[{

Cell["The two  pieces of the linear operator", "Subsubsection",
 CellChangeTimes->{{3.4246836096556273`*^9, 3.4246836298704243`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Tra", "[", "\[Mu]_", "]"}], ":=", 
   FractionBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Trb", "[", "\[Mu]_", "]"}], " ", ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", 
      RowBox[{"\[Theta]", "[", "y", "]"}]}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}]}], 
   RowBox[{"2", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}]]}]}], "Input",\

 InitializationCell->True,
 CellChangeTimes->{{3.39093417358725*^9, 3.390934177963545*^9}, {
   3.390934275878167*^9, 3.390934314756674*^9}, 3.390934502007769*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["The forms of the linear operator", "Subsubsection",
 CellChangeTimes->{{3.4246838692799997`*^9, 3.424683880679504*^9}}],

Cell["\<\
L0 : standard linear operator
L1 : linear operator integrated once outside
L1d : linear operator integrated once outside and inside
L2 : linear operator integrated twice outside
L2d : linear operator integrated twice outside and onc inside\
\>", "Text",
 CellChangeTimes->{{3.4246838870311193`*^9, 3.4246840130738907`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"L0", "[", 
   RowBox[{"f_", ",", "\[Mu]_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", 
     RowBox[{"y", ",", "y"}]], " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"Tra", "[", "\[Mu]", "]"}], 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], "f"}]}], "  ", ")"}]}], " ", "+", 
   RowBox[{"\[Mu]", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", 
      RowBox[{"y", ",", "y"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Trb", "[", "\[Mu]", "]"}], 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "f"}]}], 
      ")"}]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L1", "[", 
   RowBox[{"f_", ",", "\[Mu]_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "y"], " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"Tra", "[", "\[Mu]", "]"}], 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], "f"}]}], "  ", ")"}]}], " ", "+", 
   RowBox[{"\[Mu]", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Trb", "[", "\[Mu]", "]"}], 
       RowBox[{
        SubscriptBox["\[PartialD]", "y"], "f"}]}], 
      ")"}]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L1d", "[", 
   RowBox[{"f_", ",", "\[Mu]_"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", "y"], " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"Tra", "[", "\[Mu]", "]"}], 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], "f"}]}], "  ", ")"}]}], " ", "+", 
   RowBox[{"\[Mu]", " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Trb", "[", "\[Mu]", "]"}], " ", "f"}], 
      ")"}]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L2", "[", 
   RowBox[{"f_", ",", "\[Mu]_"}], "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Tra", "[", "\[Mu]", "]"}], " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], "f"}]}], "  ", ")"}], " ", "+", 
   RowBox[{"\[Mu]", "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Trb", "[", "\[Mu]", "]"}], 
      RowBox[{
       SubscriptBox["\[PartialD]", "y"], "f"}]}], 
     ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L2d", "[", 
   RowBox[{"f_", ",", "\[Mu]_"}], "]"}], ":=", "  ", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Tra", "[", "\[Mu]", "]"}], " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], "f"}]}], "  ", ")"}], " ", "+", 
   RowBox[{"\[Mu]", "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Trb", "[", "\[Mu]", "]"}], "f"}], ")"}]}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390646997171355*^9, 3.390647006937171*^9}, {
  3.390647038634946*^9, 3.390647104202104*^9}, {3.390647145779026*^9, 
  3.390647171721723*^9}, {3.390791689952537*^9, 3.390791710391271*^9}, {
  3.390800843115415*^9, 3.390800859775495*^9}, {3.390800953733778*^9, 
  3.390800968694843*^9}, {3.390934322949632*^9, 3.390934465446059*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution for h1 and g1", "Subsection",
 CellChangeTimes->{{3.390807326058882*^9, 3.390807335670872*^9}, {
   3.390807751672694*^9, 3.390807843843374*^9}, {3.390808358686959*^9, 
   3.390808362074682*^9}, 3.39088821066412*^9, {3.405929411008354*^9, 
   3.4059294220669537`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
   "Find", " ", "solution", " ", "for", " ", "h1", " ", "where", "   ", 
    FractionBox["1", "C"], " ", "h1"}], "=", " ", 
   RowBox[{
    SubscriptBox["\[PartialD]", "y"], "f1"}]}], " "}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"Since", " ", "f1", " ", "has", " ", 
    RowBox[{"Sin", "[", "y", "]"}], " ", "symmetry"}], ",", " ", 
   RowBox[{"h1", " ", "has", " ", 
    RowBox[{"Cos", "[", "y", "]"}], " ", "symmetry"}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "h1p", " ", "is", " ", "an", " ", "interpolating", " ", "function", " ", 
   "obtained", " ", "for", " ", "a", " ", "value", " ", "of", " ", "\[Mu]", 
   " ", "and", " ", "a", " ", "given", " ", 
   RowBox[{"flow", ".", "\[IndentingNewLine]", "Define"}], " ", "also", " ", 
   "g1", " ", "such", " ", "that", "  ", 
   FractionBox["1", "C"], " ", "g1"}], "=", "f1"}]}], "Text",
 CellChangeTimes->{{3.424684104279633*^9, 3.424684111217903*^9}, {
  3.424684151819121*^9, 3.424684152861205*^9}, {3.4246841858839197`*^9, 
  3.4246842090718107`*^9}, {3.424684261719936*^9, 3.424684295068179*^9}, {
  3.4246843450659533`*^9, 3.424684372764955*^9}, {3.424684410958843*^9, 
  3.4246844775054693`*^9}, {3.424687834228159*^9, 3.42468786895753*^9}, {
  3.424699369153895*^9, 3.4246993757950277`*^9}, {3.424751802889337*^9, 
  3.424751825604611*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h1p", "=", 
   RowBox[{
    RowBox[{"Part", "[", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"L2d", "[", 
             RowBox[{
              RowBox[{"h1", "[", "y", "]"}], ",", "#1"}], "]"}], " ", "==", 
            " ", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}]}], " ", "/.", 
           "#2"}], ",", 
          RowBox[{
           RowBox[{"h1", "[", 
            FractionBox["\[Pi]", "2"], "]"}], "==", "0"}]}], "}"}], ",", "h1",
         ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", "\[Pi]"}], "}"}]}], "]"}], ",", "1", ",",
       "1"}], "]"}], "&"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390801023898732*^9, 3.390801055399089*^9}, {
   3.390801112757135*^9, 3.390801163045885*^9}, {3.390801256929032*^9, 
   3.390801487582233*^9}, {3.39080158066786*^9, 3.39080163264723*^9}, {
   3.390801723301243*^9, 3.390801730917677*^9}, 3.390801775524101*^9, {
   3.390801884825068*^9, 3.390801974466207*^9}, {3.390802056158044*^9, 
   3.390802090782592*^9}, 3.390802124442182*^9, 3.390808287200548*^9, {
   3.390808482408374*^9, 3.390808488706338*^9}, {3.390888081670392*^9, 
   3.390888105207382*^9}, {3.390888209179285*^9, 3.390888220993881*^9}, 
   3.40592935109523*^9, {3.4059294929397097`*^9, 3.4059295145781937`*^9}, {
   3.406148784960529*^9, 3.406148804725895*^9}, {3.406148983159136*^9, 
   3.406148999639734*^9}}],

Cell["\<\
Obsolete versions to obtain g1 as a second step after getting h1\
\>", "Text",
 CellChangeTimes->{{3.405929370519515*^9, 3.4059293859464893`*^9}, {
  3.4059294253668327`*^9, 3.405929453849736*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mg1", "[", 
   RowBox[{
    RowBox[{"s_", "?", "NumberQ"}], ",", "\[Mu]_", ",", "Flow_"}], "]"}], ":=",
   
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"h1", "[", "y", "]"}], " ", "/.", " ", 
     RowBox[{"h1p", "[", 
      RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", "s"}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mgg1", "=", 
   RowBox[{
    RowBox[{"Part", "[", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"g1", "'"}], "[", "y", "]"}], "==", 
            RowBox[{"h1", "[", "y", "]"}]}], " ", "/.", " ", 
           RowBox[{"h1p", "[", 
            RowBox[{"#1", ",", "#2"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"g1", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
        "g1", ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", "1", ",", "1"}], 
     "]"}], "&"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.390801023898732*^9, 3.390801055399089*^9}, {
   3.390801112757135*^9, 3.390801163045885*^9}, {3.390801256929032*^9, 
   3.390801487582233*^9}, {3.39080158066786*^9, 3.39080163264723*^9}, {
   3.390801723301243*^9, 3.390801730917677*^9}, 3.390801775524101*^9, {
   3.390801884825068*^9, 3.390801974466207*^9}, {3.390802056158044*^9, 
   3.390802090782592*^9}, 3.390802124442182*^9, 3.390808287200548*^9, {
   3.390808482408374*^9, 3.390808488706338*^9}, {3.390888081670392*^9, 
   3.390888105207382*^9}, {3.390888209179285*^9, 3.390888220993881*^9}, 
   3.40592935109523*^9}],

Cell["\<\
New version, obtaining g1 directly since NDSolve is now able to handle \
boundary value problems
Notice that no integration constant appear in this problem\
\>", "Text",
 CellChangeTimes->{{3.424747918637571*^9, 3.424748014557916*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mgg1", "=", 
   RowBox[{
    RowBox[{"Part", "[", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"L2d", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"g1", "'"}], "[", "y", "]"}], ",", "#1"}], "]"}], " ", 
            "==", " ", 
            RowBox[{"-", 
             RowBox[{"Sin", "[", 
              RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}]}], " ", "/.", " ", 
           "#2"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"g1", "'"}], "[", 
            FractionBox["\[Pi]", "2"], "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{"g1", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
        "g1", ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", "1", ",", "1"}], 
     "]"}], " ", "&"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390801023898732*^9, 3.390801055399089*^9}, {
   3.390801112757135*^9, 3.390801163045885*^9}, {3.390801256929032*^9, 
   3.390801487582233*^9}, {3.39080158066786*^9, 3.39080163264723*^9}, {
   3.390801723301243*^9, 3.390801730917677*^9}, 3.390801775524101*^9, {
   3.390801884825068*^9, 3.390801974466207*^9}, {3.390802056158044*^9, 
   3.390802090782592*^9}, 3.390802124442182*^9, 3.390808287200548*^9, {
   3.390808482408374*^9, 3.390808488706338*^9}, {3.390888081670392*^9, 
   3.390888105207382*^9}, {3.390888209179285*^9, 3.390888220993881*^9}, {
   3.405929128823539*^9, 3.4059293127431583`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the solution for FloW1, Flow2 and Flow3", "Subsection",
 CellChangeTimes->{{3.390808711533975*^9, 3.390808725237852*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ploth1", "[", "\[Mu]_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"h1p", "[", 
       RowBox[{"\[Mu]", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"R2", "=", 
      RowBox[{"h1p", "[", 
       RowBox[{"\[Mu]", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"R3", "=", 
      RowBox[{"h1p", "[", 
       RowBox[{"\[Mu]", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", "/.", " ", "R1"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", "/.", " ", "R2"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", "/.", " ", "R3"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}]}], "]"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.390791557348885*^9, 3.390791565693898*^9}, {
  3.390791632911671*^9, 3.390791643841945*^9}, {3.390791966234546*^9, 
  3.390792121764349*^9}, {3.390792260952287*^9, 3.390792352236344*^9}, {
  3.390793789073724*^9, 3.390793811774131*^9}, {3.390801030106019*^9, 
  3.390801030722589*^9}, {3.390808562762817*^9, 3.390808577195003*^9}, {
  3.40586196065182*^9, 3.405862014327849*^9}, {3.405862047889805*^9, 
  3.4058620696204844`*^9}, {3.406148825193229*^9, 3.406148847021015*^9}, {
  3.406149007918962*^9, 3.406149014698031*^9}}],

Cell["Following line produces dynamic plot of h1[y] (slow)", "ExerciseText",
 CellChangeTimes->{{3.4059286474611797`*^9, 3.405928687765193*^9}, {
  3.424685435356937*^9, 3.424685448585919*^9}, {3.426560320309976*^9, 
  3.426560343492723*^9}}],

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"z", "=", "0."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Slider", "[", 
      RowBox[{
       RowBox[{"Dynamic", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}], ",", 
     RowBox[{"Dynamic", "[", 
      SuperscriptBox["10", "z"], "]"}], ",", 
     RowBox[{"Dynamic", "[", 
      RowBox[{"Ploth1", "[", 
       SuperscriptBox["10", "z"], "]"}], "]"}]}], "}"}]}], "]"}]], "Input",
 Evaluatable->True,
 CellChangeTimes->{{3.390792476800358*^9, 3.390792513597721*^9}, {
   3.390792551409172*^9, 3.390792638767292*^9}, {3.390793843937636*^9, 
   3.390793899853856*^9}, {3.405862029188878*^9, 3.405862029558745*^9}, {
   3.4058621186228037`*^9, 3.405862172988558*^9}, {3.405864299203003*^9, 
   3.405864308001741*^9}, {3.405864411437261*^9, 3.4058644569257298`*^9}, {
   3.405864567449057*^9, 3.405864571677806*^9}, 3.405864602757778*^9, {
   3.4246845277016497`*^9, 3.424684529353615*^9}}],

Cell[CellGroupData[{

Cell["plot cell for printing", "Subsubsection",
 CellChangeTimes->{{3.425317462982239*^9, 3.425317513664909*^9}, 
   3.42531755028738*^9}],

Cell["\<\
To be used in a separate window in order to get publication type output.\
\>", "Text",
 CellChangeTimes->{{3.425317552340082*^9, 3.425317559910268*^9}, {
  3.425486574130661*^9, 3.425486614681362*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ploth1print", "[", "\[Mu]_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"h1p", "[", 
       RowBox[{"\[Mu]", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"R2", "=", 
      RowBox[{"h1p", "[", 
       RowBox[{"\[Mu]", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"R3", "=", 
      RowBox[{"h1p", "[", 
       RowBox[{"\[Mu]", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", "/.", " ", "R1"}], ",", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", "/.", " ", "R2"}], ",", 
         RowBox[{
          RowBox[{"h1", "[", "x", "]"}], " ", "/.", " ", "R3"}]}], "}"}], ",",
        
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", "Thick", ",", "Dashed"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", "Thick", ",", "Dotted"}], "}"}]}], "}"}]}], 
       ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<y\>\"", ",", "TeXForm"}], "]"}], ",", 
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<C f'_1\>\"", ",", "TeXForm"}], "]"}]}], "}"}]}]}], 
      "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390791557348885*^9, 3.390791565693898*^9}, {
  3.390791632911671*^9, 3.390791643841945*^9}, {3.390791966234546*^9, 
  3.390792121764349*^9}, {3.390792260952287*^9, 3.390792352236344*^9}, {
  3.390793789073724*^9, 3.390793811774131*^9}, {3.390801030106019*^9, 
  3.390801030722589*^9}, {3.390808562762817*^9, 3.390808577195003*^9}, {
  3.40586196065182*^9, 3.405862014327849*^9}, {3.405862047889805*^9, 
  3.4058620696204844`*^9}, {3.406148825193229*^9, 3.406148847021015*^9}, {
  3.406149007918962*^9, 3.406149014698031*^9}, {3.425316714454685*^9, 
  3.42531678580324*^9}, {3.425317056993272*^9, 3.42531708512774*^9}, {
  3.425317222194859*^9, 3.425317378992421*^9}, {3.425317428041879*^9, 
  3.425317428965248*^9}, {3.425317690485705*^9, 3.425317737777264*^9}, {
  3.42531782451235*^9, 3.425317831044113*^9}, {3.425317863833699*^9, 
  3.425317900640439*^9}, {3.425317941354418*^9, 3.425317956259323*^9}, {
  3.425318057341081*^9, 3.425318063009412*^9}, {3.425318287904016*^9, 
  3.425318288168103*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ploth1print", "[", "0.01", "]"}]], "Input",
 CellChangeTimes->{
  3.425489018104373*^9, {3.425489613133831*^9, 3.425489614988422*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Thickness[Large], LineBox[CompressedData["
1:eJwd2Xk8VdsXAHDzvaSkUMicCKkXSRnWSRpEIqFMoUSUqSKFEpHqSdLAy9Bg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     "]]}, 
   {GrayLevel[0], Thickness[Large], Dashing[{Small, Small}], 
    LineBox[CompressedData["
1:eJwd2Xc8Vf8bAHDuxb2kZd17ToX2MAsZ4fOkIZJIyJYRSUJGGUkDLV8plArJ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     "]]}, 
   {GrayLevel[0], Thickness[Large], Dashing[{0, Small}], 
    LineBox[CompressedData["
1:eJwd2Wk4VV8XAHDu5d5zuecWUkiiOWlWJNo7iaRkVhkjkplCg0gppPwNpZCp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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["y", TraditionalForm], 
    FormBox[
     RowBox[{"C", " ", 
       SuperscriptBox[
        SubscriptBox["f", "1"], "\[Prime]", MultilineFunction -> None]}], 
     TraditionalForm]},
  AxesOrigin->{0, 0},
  ImageSize->{241.6, Automatic},
  PlotRange->
   NCache[{{0, Pi}, {-6.6099107146675, 6.609910476348444}}, {{
     0, 3.141592653589793}, {-6.6099107146675, 6.609910476348444}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.42531762424903*^9, 3.425317837114581*^9, {3.425317906122874*^9, 
   3.425317932232426*^9}, 3.425318068186022*^9, {3.425489606063478*^9, 
   3.425489623882609*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plots the functions h1 and g1 for the three selected flows and as a function \
of \[Mu]\
\>", "Subsubsection",
 CellChangeTimes->{{3.424685463711828*^9, 3.424685483949171*^9}, {
  3.424780102572378*^9, 3.424780164759568*^9}}],

Cell["Plot h1", "Text",
 CellChangeTimes->{{3.4247801898009768`*^9, 3.424780192271846*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"Ploth1", "[", "0.01", "]"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.4059286978872337`*^9, 3.405928798123927*^9}, {
   3.405929002103882*^9, 3.40592900719811*^9}, {3.406146293544613*^9, 
   3.406146334757816*^9}, {3.406148059574403*^9, 3.406148076014014*^9}, {
   3.424684557369843*^9, 3.424684618261649*^9}, {3.42469481024259*^9, 
   3.42469481037405*^9}, {3.424702218528343*^9, 3.424702242287977*^9}, 
   3.424702272918407*^9, {3.425303529161957*^9, 3.425303529920518*^9}, {
   3.425488978208959*^9, 3.425488989192414*^9}, {3.425489057766207*^9, 
   3.42548905917648*^9}, {3.425489554538524*^9, 3.425489568258322*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd2Xk8VdsXAHDzvaSkUMicCKkXSRnWSRpEIqFMoUSUqSKFEpHqSdLAy9Bg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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Pi}, {-1.9069316090484734`, 1.9069316090581494`}}, {{
         0, 3.141592653589793}, {-1.9069316090484734`, 1.9069316090581494`}}],
      
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd2Xc8Vf8bAHDuxb2kZd17ToX2MAsZ4fOkIZJIyJYRSUJGGUkDLV8plArJ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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Pi}, {-6.6099107146675, 6.609910476348444}}, {{
         0, 3.141592653589793}, {-6.6099107146675, 6.609910476348444}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd2Wk4VV8XAHDu5d5zuecWUkiiOWlWJNo7iaRkVhkjkplCg0gppPwNpZCp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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Pi}, {-3.7600360860998197`, 3.760036086121812}}, {{
         0, 3.141592653589793}, {-3.7600360860998197`, 3.760036086121812}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{592.8000000000002, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.4059287475558767`*^9, 3.405928799218219*^9}, 
   3.405929008432583*^9, 3.40594984043888*^9, {3.406146296115812*^9, 
   3.406146336021921*^9}, {3.406148064814813*^9, 3.406148078635113*^9}, 
   3.406148854252675*^9, 3.406149020497085*^9, 3.406449166475488*^9, {
   3.424684536512944*^9, 3.4246846192434053`*^9}, 3.4246879044802227`*^9, 
   3.424694811799398*^9, 3.424701948293639*^9, {3.424702219445755*^9, 
   3.4247022439152937`*^9}, 3.42470227475079*^9, 3.424714402435401*^9, {
   3.425303531290392*^9, 3.425303543311015*^9}, 3.425489009867793*^9, 
   3.425489060382698*^9, {3.425489569394286*^9, 3.42548958247752*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"h10", "[", 
    RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"h1", "[", "0", "]"}], " ", "/.", " ", 
    RowBox[{"h1p", "[", 
     RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}]}], ";"}]], "Input"],

Cell["\<\
Notice that  h1[0] increases as - Log[\[Mu]] pour Flow1 et Flow3 et en \
puissance de \[Mu] pour Flow2
Plot now h1[0] as a function of  \[Mu]\
\>", "Text",
 CellChangeTimes->{{3.406450183862941*^9, 3.406450198829912*^9}, {
   3.406450236766685*^9, 3.406450318969998*^9}, {3.424684636218542*^9, 
   3.4246846662031927`*^9}, {3.425487413377699*^9, 3.425487465043599*^9}, 
   3.42548749533651*^9, 3.425531529906992*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"LogLinearPlot", "[", 
    RowBox[{
     RowBox[{"h10", "[", 
      RowBox[{"m", ",", "Flow1"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0.0001", ",", "1."}], "}"}]}], "]"}], ",", 
   RowBox[{"LogLogPlot", "[", 
    RowBox[{
     RowBox[{"h10", "[", 
      RowBox[{"m", ",", "Flow2"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0.0001", ",", "1."}], "}"}]}], "]"}], ",", 
   RowBox[{"LogLinearPlot", "[", 
    RowBox[{
     RowBox[{"h10", "[", 
      RowBox[{"m", ",", "Flow3"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"m", ",", "0.0001", ",", "1."}], "}"}]}], "]"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.406449506550995*^9, 3.406449600462687*^9}, {
  3.406449666683766*^9, 3.406449667484217*^9}, {3.406449751416795*^9, 
  3.40644975228397*^9}, {3.406449863637645*^9, 3.406449959175689*^9}, {
  3.406450074265384*^9, 3.406450078951487*^9}, {3.425486758290914*^9, 
  3.425486767443957*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0Gs01GkABvC5GTPNMLkMw2DGODJ1YotCOnrfLUluTa6tkNS4VdImE1ZH
DmmTSyuXwhalCRuHJTbL+646SZtcyuVsqJ1yNo00iDRp2r8Pz3nO7zzfHsvI
435SColE8iWy0htbo1oaj4jw++i1LjeCGLAr3uUUiBPh5Avx5zYGMqDfGt3N
vTEiHBKh9Qz5M2BiUUvzW6kIs1zWHhuTMGDbSVqzIEKEx4cl1VwvBty2oaop
N0CEuZsCrc8DBvSsGW+IdRVh6+B1UcfEDBhZFlBryRFhNr1+3lmtDUtkcQmP
ai3xru7GGE6xNmTUryvl+ljixLq1sQXO2nDJHLlvmRVivC7hxcwYHSqzUh8W
5goxK2E+pDCZDk09FPLLG4RYrpk59MaMDq/SFM2lJQJ8t3HTbHqbFtQo5TYt
AxY4RUd+nhKkBf/J7gqzMLHAZy58LHFQ02CHga3jgsQci6uXzNuLaZAXMD3A
KzbDF69viF/YQoMJ2gGpUxN8HOM4Gs1/SYX9taxuGx4fF3pPXZP/RIW3Kbzh
pnBTrH6ieaMUUuF5z8TsuiIT/O6x0vFWBwVKtZLd9/bzcG9KafnBUAq8lzj4
aAePh9PckvaMkSnQ6Hnq+xsSYzzkVJmhvEaGyv+ShyTFRlhy7wdBlxsZdiu7
Dxx5wsW+iyZNngoSvB7Z+cmezsU1U9Sd6rMkOJvL9N/lY4hbu9msNDGJ+Pum
pCfTAPsyG1IG8r8BfvJlvdIefUzKS90TO6YBU+3rXxno6+OjVnFDGbYagGYM
93711MOM3X+c/ZbwFegM781yuLQaT5Rgu9CuZfAgpKO1Pp+DKyK0S27Ql0HM
B5t0CU0Xu3e5lxtJvoDl6a19OYVsbFjkTb8gV4Nrjz9EVlFZ2Cy91Hxw7jOw
1/NJ88tj4vjvpynA+zPArl+aQoUM7PPbWLagbgmEee623V5Ix8Bq+NCM5hN4
h6DdX0ItvF/hIlmI+ATOcUdP8vOpOPoN7+VE2yLQf86DHB4F80vzMV+wCK6c
rrUJu03Ci726koKcBRCubpWzHTSor1PXP/jDRxA3dEznF88vqFx76lLQwY/g
csKh5V6rJbSGNeAx9Pc8+H1EbdnJWkAGVxfFd10Jr54M+Fc8h55+d5+U1jEH
Kg0sREmcGbTP+LVQ6jQHKmqMW/Kd3qIi0zNcMpoFGSMBLXppCmQ2ktdV5jML
PFhWBeSLoyiMdr1CMaICJuF9Q8GTPchN8D2bf1wF8gef15qyTyNxDZdkRVWB
x1u/MpV1MlQzW3XCiDCt2jq23UuGMmzAaybhFFmSTWhOEmK0Vz5UUVTgsBnv
ZsWqU2jw1UxuJ2HnqP0VQuaPSDGdaB5C+MH8fYEPOwYZF8/vv0RWgS0PDSfe
e0Uj47bA/kzC9aXS8rycKBST3+N2mvAVV22T/lVStB5I7Q4Qjs/21PdnRqKl
V0/JtoTtHKuYTex9qL3mc8MjkgrwXuw4N58ThI6Sm63/JExNn6RsZgWiTdsy
yxoIj/aIl1uZfqgyJyq7eGVvDx9P1fFA0lsOEYdXdlrVsIa1E2UF/DocTPiO
72Tf2VXbkZu3wMdrxQ9GMjkcZ+QUc9jFnnDwvnAZl22PUu6JG60Jk0d7njnq
i1GtgmptQvi25s6JLB4PdcjGy9iEq8uvFshcfu5M2fxEn0T4f5MLQ4M=
       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-9.210340371976182, 1.0000000700268559`},
    FrameTicks->{{Automatic, Automatic}, {{{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-9.210340371976182, 
         FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
         FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\" \"", TraditionalForm]}, {0, 
         FormBox["\" \"", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}},
    GridLines->{None, None},
    Method->{},
    PlotRange->{{-9.210340371976182, 0.}, {1.0000000700268559`, 
     3.042303518665895}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    Ticks->FrontEndValueCache[{{{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0., 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, Automatic}, {{{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0., 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, Automatic}]], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwB8QQO+yFib1JlAgAAAE4AAAACAAAAMbdmtbFrIsAz6POgWZENQMJuOnU/
aiLAJsbPiA+PDUBSJg41zWgiwPN2fXHFjA1AdJW1tOhlIsD9IIVEMYgNQLhz
BLQfYCLAGL2w/Ah/DUA+MKKyjVQiwKVIqaK4bA1ASqndr2k9IsCvbLZ1GEgN
QGKbVKohDyLA/iPL/tr+DECXd2pwyKohwLPweRQbYAxACK4qmBVNIcC68xxB
8csLQPgdv0Y58SDAB68RHsA6C0DrhXvGk40gwAvCIzpUnQpAGkjip5QwIMAw
95INfQoKQJoE4rSYlx/A5DQr73BrCUD+66cntdEewNe3uiljzwhA2ofCXR4Z
HsBA2SW06D0IQL0TLTb1UB3AOdCPgEKgB0AYVOzRGJYcwE5KLsQvDQdAcAdU
e+neG8Dsxyx/G30GQNCqC8cnGBvAK+rDhubgBUCoAhjWsl4awLDJ7jlETwVA
iEp0h6uVGcAZZtVci7EEQGUFeUZR0BjAFN5G5dsWBEC6dNLIQxgYwNbvv5C+
hgNAFtR77aNQF8C85hbpm+oCQOvnedVQlhbAipjS5QxZAkDH68dfa8wVwPc6
FF6IuwFAoGK+9zIGFcB/ENzyGyEBQPGNCVNHTRTAVGIvMUSRAEBKqaRQyYQT
wCRI8Mck6/8/G3mUEZjJEsDHsgHH8cj+P+m7LOATEhLAFTTVR/2s/T+/7hRR
/UoRwJIdS6Wbefw/DdZRhTOREMDGScjjcVv7P8Ravbeujw/AeClO0x0m+j9o
7yeAUAQOwOupYFVY9/g//Ow7z4uTDMD4jW4q1t33P5/K72KiAwvAqfjUIKCt
9j8yEU19Uo4JwFWYUHPAkvU/wD37slwgCMCBSDPLlX70P11KSS1CkwbAkurd
6E9U8z/qv0AuwSAFwLa937x0P/I/hhXYcxuPA8Ba14NVDRXxPxLUGEAPGALA
mruF2y8A8D+ZeKonXagAwAlEeTwm5e0/Xvq3pwwz/r9/ugLPuqDrP2rVbQ2S
Svu/zb92Lp2H6T+UcGP8zSP4vzphYl8LR+c/s9f6Ib4L9b+cnG48DRflP7MQ
5VThKPK/PDVYm5QS4z+hEx4idg/uv4sJHtqW6eA/nakXtY836L802ZL37djd
P4LXVLURfeK/FH/OqC8B2j9ICyOQAYzYv4BnORFh59U/GV7P1Vflyb+5Ui6N
cSXSP4/S1KoaDHi//ARNqP5OzD/KO/0J66t3v0fljgUNTsw/BKUlabtLd7+D
kXljG03MP3p3didci3a/dVFJIThLzD9kHBiknQp1vzWY0qRxR8w/OGZbnSAJ
cr8TeY3L5D/MP8Tzwx9NDGi/CkCul8swzD85xhTe7UtnvxdBDAraL8w/rphl
nI6LZr9AOhN96C7MP5k9BxnQCmW/thkcZQUtzD9uh0oSUwlivyK1GT0/Kcw/
LjaiCbIMWL8nlcUMsyHMPxjbQ4bzi1a//LuzicEgzD8DgOUCNQtVv07xSgfQ
H8w/2Mko/LcJUr+hi3QE7R3MPwO7Xt17DUi/m6e0BicazD/YBKLW/gtFv8tm
64g1Gcw/rU7lz4EKQr9uP8sLRBjMP63E14QPDzi//kGGE2EWzD9XWF53FQwy
v71uYZhvFcw/AdjJ0zYSKL9+uuUdfhTMP6j+rXGFGBi/bSYTpIwTzD+lnJqQ
dzqJvuKz6SqbEsw/muNKHQ==
       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-9.210340371976182, 0.},
    FrameTicks->{{{{0, 
         FormBox["1", TraditionalForm]}, {
         NCache[
          Log[2], 0.6931471805599453], 
         FormBox["2", TraditionalForm]}, {
         NCache[
          Log[5], 1.6094379124341003`], 
         FormBox["5", TraditionalForm]}, {
         NCache[
          Log[10], 2.302585092994046], 
         FormBox["10", TraditionalForm]}, {
         NCache[
          Log[20], 2.995732273553991], 
         FormBox["20", TraditionalForm]}, {
         NCache[
          Log[50], 3.912023005428146], 
         FormBox["50", TraditionalForm]}, {
         NCache[
          Log[100], 4.605170185988092], 
         FormBox["100", TraditionalForm]}, {
         NCache[
          Log[200], 5.298317366548036], 
         FormBox["200", TraditionalForm]}, {
         NCache[
          Log[500], 6.214608098422191], 
         FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0, 
         FormBox["\" \"", TraditionalForm]}, {
         NCache[
          Log[2], 0.6931471805599453], 
         FormBox["\" \"", TraditionalForm]}, {
         NCache[
          Log[5], 1.6094379124341003`], 
         FormBox["\" \"", TraditionalForm]}, {
         NCache[
          Log[10], 2.302585092994046], 
         FormBox["\" \"", TraditionalForm]}, {
         NCache[
          Log[20], 2.995732273553991], 
         FormBox["\" \"", TraditionalForm]}, {
         NCache[
          Log[50], 3.912023005428146], 
         FormBox["\" \"", TraditionalForm]}, {
         NCache[
          Log[100], 4.605170185988092], 
         FormBox["\" \"", TraditionalForm]}, {
         NCache[
          Log[200], 5.298317366548036], 
         FormBox["\" \"", TraditionalForm]}, {
         NCache[
          Log[500], 6.214608098422191], 
         FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}, {{{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-9.210340371976182, 
         FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
         FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\" \"", TraditionalForm]}, {0, 
         FormBox["\" \"", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}},
    GridLines->{None, None},
    Method->{},
    PlotRange->{{-9.210340371976182, 0.}, {0., 3.6959717344698446`}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    Ticks->FrontEndValueCache[{{{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0., 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0., 
         FormBox["1", TraditionalForm]}, {0.6931471805599453, 
         FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
         FormBox["5", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {2.995732273553991, 
         FormBox["20", TraditionalForm]}, {3.912023005428146, 
         FormBox["50", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {5.298317366548036, 
         FormBox["200", TraditionalForm]}, {6.214608098422191, 
         FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}, {{{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0., 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0., 
         FormBox["1", TraditionalForm]}, {0.6931471805599453, 
         FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
         FormBox["5", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {2.995732273553991, 
         FormBox["20", TraditionalForm]}, {3.912023005428146, 
         FormBox["50", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {5.298317366548036, 
         FormBox["200", TraditionalForm]}, {6.214608098422191, 
         FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}]], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0GlQU1cABWBkD0mIWYDHFl5iFey4Qgki6LvGAhqEAYxClaDDJktrqQqR
UjvayqIooIjiBjSAyGKQJUXZ7mWRABWByBJcGLVDRVAZgwhGzPTx48yZb86/
wwv/OShKX09Pz5/MUm9siFbUxPPR8A8pZaWeOGg/vDmRiOMjVjzrD1cPHASt
Mnfti+EjT96c5IE7Do7lKeono/joUVeR9YQAB/eOGtY7HOSj1QVlRd9sxMHW
DbLa82I+ep7l9L54JQ5E5c+rY7fwUdv1J+eKzXEQfl1cwWPwUYZdN82/zQFc
kcYldFfwUOOtmlN0LReYyr/Nt/DjoXWEt9YTcMGCPfR2/4CjkZbIkqCz9mA6
NaUr9zyOlCrPmsAHdsBmx6uySxtwxKo656ui24Frhq/q8684oAbL74VxPrZA
N13mqBjkIs1OV5lTqg14kt4u4VpzUWpc82+nBqxBC3utYC7AHg2lOKt30a0B
Jn47iF22Q2v8eSf6gjGQYCJOeTNui8Z17h3lt6zAQAVV6YjZomfaq/HS15bg
tj42Uhtmg8zdXrjgAkuQITqWXplnjRJnMqZcpBYgyijZO3AAQ3Vv2b8LWzig
8ZiqezuGIccF7+Y9TA6wHEp5VxxghdK3jzysDGGD6dfJwwGXLdG28rG89XIW
UE4rD8Q/tEC5bpGWinkmKApvnXc2tkAqee8Tug8TfDhP2e3jx0FNZ1zZNSXL
yb9LAnpOs5Hw4IEIzgwD2CZfYub3sBC1oMo3t8YcvGla84LNYqEQcY6Z40k6
gO85gV9FTJR4yLRU6UED9JHAVJcLy5HPGGOXjk0FnftaGuTZDBQt8b0f+pQC
YmYcTwYYmiOBobHk2V1TsPjWoz8zl4Yedu1d8JaZgMLemXCZARWZTcZKa1KN
gTPT70RQFgU1TWZi+aeNANrypTYUN0Uj3JBtXTmGQCLauVaYa4wM5ur+zLtg
AKYgWNeGG6GFtOaCuCp9kGahPmqbbYBoU1sVqpZlgDWEAQamj/6LNHocOKkH
rh6vcJTc1kN+zpUx9xz0QJi2oYzmooPJhODl/UIdETf8E/2i6Asck5Qq/l37
lbiUELHYt2IBrk5MPlR99wtRN6rltVLnoMh+vHnWT0vULZ8Qv3TSQEls5641
nM/EX2wuP4nxHoKX2Z89VPPEzXIrRbbbJFx1rdDryN+fiD9GxQrmiVcwn9sr
z6yeI3ZQV+QsO6eG2qmLdnOyj4R1WP9w8EQP9OxkTiY1zBLZqqEKG9pxmBHc
brqiW0P0enylTFdKYSG7OMKEtGHpytgmXynkuDW2Tis1xK/SJMfQzCTonn42
sZ50pB1WctMsESpzyye8SG+K3n8TpxyBEcLw/pguDdE52+HgR4uBn8r2J8g7
NYR7F2f8ne8hGGmc8s9F0vL8qBtZmdGwwSthpZT01S0m1gNmUVCbaTBEkD6c
LmLtpoTDOJP42cEODbFOIKPU0kJgkFfo/Md2DYE93Z42m7kXVjvIfhwjbXBy
Qt+Vugfm9qgHW0ire5wWGyhBcCFSxk5b2pvCnqfQd0Chcduo1dJuKBvRUb3g
dwVVOxfbNMQd/4n+U2ZC2P1ofeOLJXeOnmYwNkHW6PijctLBIWFSC5ozLMI+
bc4ivUzd81jAcoIdfepbR0jf1t35JRXD4JSvKSWYdOmNaznSzWda0033ZXiQ
/h8z7VUI
       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-9.210340371976182, 1.1721759153593057`},
    FrameTicks->{{Automatic, Automatic}, {{{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-9.210340371976182, 
         FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
         FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\" \"", TraditionalForm]}, {0, 
         FormBox["\" \"", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}},
    GridLines->{None, None},
    Method->{},
    PlotRange->{{-9.210340371976182, 0.}, {1.1721759153593057`, 
     8.11845134144543}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    Ticks->FrontEndValueCache[{{{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0., 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, Automatic}, {{{-9.210340371976182, 
         FormBox[
          TagBox[
           SuperscriptBox[
            TagBox["10", Power, Editable -> True, Selectable -> True], 
            TagBox[
             RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
             True]], 
           InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
           Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0., 
         FormBox["1", TraditionalForm]}, {-8.517193191416238, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-8.111728083308073, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.824046010856292, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.600902459542082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.418580902748127, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.264430222920869, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.1308988302963465`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-7.013115794639964, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, Automatic}]]}], "}"}]], "Output",
 CellChangeTimes->{3.425486925961268*^9}]
}, Open  ]],

Cell["Following line produces dynamic plot of g1[y]  (slow)", "ExerciseText",
 CellChangeTimes->{{3.4059286474611797`*^9, 3.405928687765193*^9}, {
  3.405928977448398*^9, 3.4059289779585*^9}, {3.426560279656819*^9, 
  3.42656030149024*^9}}],

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"z", "=", "0."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Slider", "[", 
      RowBox[{
       RowBox[{"Dynamic", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}], ",", 
     RowBox[{"Dynamic", "[", 
      SuperscriptBox["10", "z"], "]"}], ",", 
     RowBox[{"Dynamic", "[", 
      RowBox[{"Plotg1", "[", 
       SuperscriptBox["10", "z"], "]"}], "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.390792476800358*^9, 3.390792513597721*^9}, {
  3.390792551409172*^9, 3.390792638767292*^9}, {3.390793843937636*^9, 
  3.390793899853856*^9}, {3.405864612807062*^9, 3.4058646494988337`*^9}, {
  3.405928174914188*^9, 3.4059281751002398`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plotg1", "[", "0.000001", "]"}]], "Input",
 CellChangeTimes->{{3.405928990042923*^9, 3.40592901787434*^9}, {
  3.406450505097667*^9, 3.406450506054716*^9}, {3.424699354319714*^9, 
  3.4246993566124697`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0mk4lP0XB3CE0MgW952Hsi+RFlGynF9IRWWrVCgGJS1G5SGl/imUNGkS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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 6.042392532294897}}, {{
       0, 1.5707963267948966`}, {0., 6.042392532294897}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd03k01N8bB/AsWYpRMUR2WSqi7YtGnptCaCEhhUJKZJ/58A35JUWUkKSy
RNE+CCGREqlUsmVLUlRCZtLMZ0R+9/P9457nvM7znHPPfd7nangF7fQRnjNn
zgt8qCryeN6bz+s8zYvYAaPW/QPm2t9rGarnAS6tkL/rza2FqWLDA91pO8BO
Pma1OvcNDMn5kg/S9sHZVS3Mv5x+6LGKe1qQFgT6JxvTxzjj0LEvTTc7LQZM
Q8dVhjh/YecRxZ7MtHNwe0S/aYBDQ6lct9KMtFy4/D1tbT9HFTEabOdZhBWD
yzA//ISaEQo+ut2zNLgSFPdts7OcNEYBlT7Jwlp1sIM+t6U4D1D7NxvJG17P
YJoelt85tQklGvLmPHBtAilXdIz9wRqFrGi6UFfQDIo2jpKvZbeiKW9/9ofA
FqhTn+hQXWKPvGqc7VMOtsLt+Njd9RI7kTenva4uoR2OBOyLk1Tfhc4YVQQV
nuqE7yfUXatlnZFwXYVx3NEuqB7cqnthxgUtXG735mNmD/CzrtvTFu5BW3It
rk2k9YGeQY4rd44bUvjZbBVT0Q9iBkIhYUoe6PLzh0IihwdgvdFjthR9PzJT
2TirfuATZLLlY+Xme6IVAwu+RDMHIb/+/NlvdC907+Yi3/LQz+B29/ejCZo3
iup3b1tx6gvs9rJ5+FT5AAoxM7HLSR+CV7UdL65p+6Cp3M1eP1KGYb96Q0yF
8kHUEnx5f3j+V9DUiKk8p3cImVpr/v2Q9w02XTdJztT0RS8sTW+irO9AN9+w
667CYVRQcsl08M4ISIfNRkZq+CG6lr6fx60fwF/kEEwo+qNWIYlYxUejsMrP
Ol1D5wgqlwgrbHkxBgsrSkwaDQKQPn2Bn1fDOBSLPo9M0gpEP5N5cms6f4Jz
X/nOQYMgpBUfbxjkNwFZBQlqS2WD0eCe3h6LrxPgbrAw78mZYLRlqE1QHsiB
XNFhw7gFISgi1MdXfowD+bevvTZKCkHbH1yxlSe4UC7X2vpcJhSNT/tFifC4
YPWgTVkmKRTlvT9eFhj2C7YuDJoyEglDU74b9v/75xe0xS7w2hgXhlRmUveG
HJ0ENZrbaN9UGBq2TnopIfobticGZU+HM1G9TjOoJv2GQYfA6ppRJvKTKBTV
kOSBtsU3/QP2LPRKOOHspvk8OJkZnT7lwEL6M4flD0rzYLjsoWSKIwv95Bjo
3VnIA05vnGKlMwsxe8vt1inxINclonzajYWi2Q1pNit4wKgp1nQ5zEIpu4bU
Q7fxwOCm4VW74yxUcXXphvpUHjDv0/Jk2Sy0dHZz5JPzPEhY/rrQoQjPu/tU
Pb7Ag5pHgofJxSzkq1S47tElHiyP6pQWK2UhpXTdleV5uJ8es/t7BQtFxS9X
u1HCg5lGS7fYJyxkEWgklPSOB6JvQ3Vn2liI3WwPp9t4sCghpki5g4WWrAiJ
ju/A9z2r3sjoZKHJryWCE908UK4MjWN1sVCB5xpu1CceyKs/+l9/HwtJOP3z
OZDDg66IaMvYIRZ6wzBr2LmQD79+n8hZwGOhxErWHytZPpDTTzdL8VnIel3R
KgadD7UNujNiJAvVrdTM0VLkQ7CO1XWBgIVKNSTCJ9X5ICep+qpthoUyxdv1
Moz4YJulTOydSyDvNv8z3Tv40H3QR6NSlkDq9gVPXzvwYa6KmXCGHIH6mvvJ
J458QII7k6F0Ajk3OvjcduHDrrfbaMsVCLSlytg8ch8fTtHc5c4qEWhlrsiE
chAfMnfO99PRIBDpd8VxfzIf1grkVhcaEOjc0WviMSl8aLxakECsJJBO4p3q
7DQ+SA14N1oaEsjpVrVWbwYfLtb58AeMCHT/a+8vp1w+cMz9DOetJdCRA8rp
dsV8aGFyebrrCTTgnt3+TysftE1on1IsCRQeUJDg1M6HBvHtyuZWBKJF3zNj
dvJhxIFtPoK9IavmekkPH7qevDWBLQS63POBqf+ZD1eXpQn32RJol4sqXXOS
D8ffTv8Y2EGgJvtcJ2l5EjyfjNMXuxLI79lQrfhiErTJzUKXsKVN9PWElUi4
NC1BLt5DoJ1qVVM8FRKKXHvE5fcSqHesNXdAmwTlV3nFou4EGk8UGyldR4J1
dZ1O2X4Cpfzd6sg2JmGPJLdJ25NAa0LPP7ppSsJ2QQqRgR3hqn4uewMJL8sU
JpleBBLWW7823pKEXPctEToHCERvCDi2x4mEYpl/CvYeIlClSdnXXS4k+Iyh
vzXYe+5O2e9wJcFwX5WXmi+Bcs7Ha212J0HxD3fbR2w9r7wmAx8S1oidvufo
RyCz2fZFQiwSUCJKpQUQqD90SdQfgoQrSUvzPLGPD3sO/Y4gwV6VeFSK3fh6
vGIkioRdfE+6UyCBdmRJuLfHkWAW4WZ/JohAXqZmN26kk9BZ3TfSHEKgj+CQ
3JxBQlO9o7N8KIHcrA6yOJkkzN5g5ntgOzumbGJkk3BqblnfD2zbgC8f3xSQ
4Ld4WTcZRqDnYYLGXzdI4Ij+tDFlEmjzURp78W0S5N94XInANo83ifJik/Dj
N2PgF/bqvDOLeQ/w/i+PcvpYBCq6kTerVEWCjp+QrxxBIH32g2GoJuGpfF2t
LbZO9UDZ6cckfJ7LoJVhK3WsdVBpIiGdobvu33ACXey1MbF4ScLuicTiG9hy
gx5qh5pJSDmeKdWBTfuZMFbcQsJW05KD+hE4L8kPpzd3kyA625X/GjtGhht8
uJeEsMwkrV/Y03Tx3ckfSOilfYtT+JdAPM1VOl2fSGCm5Xx3ww5bZiU985kE
Vi45Go09Ybh3UmMY53d6uiUbe8Ts5FP/ERJKOUKMHuxDmy7fShklYX+wyBMe
9hebopTycfzeV2zdRUdxns7dHrNcEirkRC5aYu91H7dc+puEEyJ3c92xu7xF
DGz4JAS9+ZvAxG4NNviT9ocEY0HeTA72jnCLwYoZvI/d3IT72M3RLi/6ZknI
OD86+QzbJu5IsZCwAJi3UzZ2YjcmHr+oIyqAnOz+wGHsTakZx+zEBHA1oDPq
N3bdxTs+wRICmFCK8BeJxP8zp27rhXkC6CyoX78A++H1jjUPpQSwnlY1sgTb
+M6I0keaALIcd0fqYJeVzAqJLhSANJE3aoi9qlLuu56sAHisdHMTbHbtspZt
dAHYO64KAewVDeYVoQoCqJWOiLPEvvnKMeeiogAeXveNsMXWbvU9+WgJtoLI
tu3Y+V3RRz6pCMDpoLWwA7b+qak2DvZNt/OLKD9YE84QVhWA1dVsTcqvkoPn
aWF7yYxtpDy52fvmAWyNs+HRlI9xP8qwsJvHypMoS1x1Cz+J/fTK/UuUVf44
WRVip3wcLqNsVbLly1fsEjHGN8otHg12JHb5O/9JynukLEol1AQgOrJnzk7s
oEOM2GXYJ4SZCpQzVVaq+2OLtaVaUNZ8dTs+Ettbonwr5bsRuj+TsOcnZThT
ftKmXnsXmxGRfpjyyGlZt3FsTW7kGcpM45T6v9hdqanplP9+kVoho459zCeL
siwSmzLErkZb7lDOGYv1RNjZdJf7lPWuzDbZY780XlpF2YxHXgzBFjsgaKDc
eI01exybHijUTNnegXswDTuo4fk7yj53f6wrxRZ1O9dHecLVN7seG66kfKJ8
VHxItB27Udd+mHKyV3/bJHa53ryflBcv2MuYqyEAlWzRX5Tza97n07FbPGp4
lPX9d83TwX4bsHaKcsXidyH/YCu+PDxD2aJxW7cVNjvMfY4jdnPYS+SCnewn
I0LZWcP65iHsKnbMXMoDb+plIrCNEFucsl8UCk/A5qpekaQ8uaymPxN71tZq
PuVj702tbmHvflYkRVni5IN7VdjTie+lKaetXkN/if0jp4ZGWXmgKKoHW3uO
lwzlwrP6X0aw77Cf/edVjFt2f7Cjbg/95/8DR2QDiw==
       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 359.7077788325621}}, {{
       0, 1.5707963267948966`}, {0., 359.7077788325621}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0Hc41f0fx3Eko2zJSU7ZI4SvWxF5f24kNIioJJllVFZSETc/sqLjJMSd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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 18.66343771909057}}, {{
       0, 1.5707963267948966`}, {0., 18.66343771909057}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.405929018740087*^9, 3.405929023223908*^9}, {
   3.405929328326168*^9, 3.4059293325703917`*^9}, 3.405949855300692*^9, {
   3.406450508179663*^9, 3.406450528528898*^9}, {3.424699344692586*^9, 
   3.4246993582774773`*^9}, 3.424714430474472*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Produce printing plots", "Subsubsection",
 CellChangeTimes->{{3.425531501648106*^9, 3.425531506152406*^9}}],

Cell["\<\
Make a linear ramp of  \[Mu] values and using list plot to produce printable \
output\
\>", "Text",
 CellChangeTimes->{{3.424780249969714*^9, 3.424780265723341*^9}, {
  3.42548697398649*^9, 3.425486996151158*^9}, {3.42548746922117*^9, 
  3.425487536171432*^9}, {3.425531517371432*^9, 3.425531522175407*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fac", "=", 
   SuperscriptBox["10", 
    RowBox[{"1", "/", "5"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Mu]ramp0", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"0.0001", " ", 
      SuperscriptBox["fac", 
       RowBox[{"i", "-", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "41"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.406449342290644*^9, 3.406449490119049*^9}, {
   3.42548696446164*^9, 3.425486966993621*^9}, {3.425487022983405*^9, 
   3.425487027280704*^9}, {3.425487168673284*^9, 3.425487169096933*^9}, 
   3.425491194741678*^9, {3.425491283472701*^9, 3.425491288146528*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"h10", "[", 
       RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp0"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p2", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"h10", "[", 
       RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp0"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p3", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"h10", "[", 
       RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp0"}], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.425487052396524*^9, 3.425487092310164*^9}, {
  3.425487122546663*^9, 3.425487269727994*^9}, {3.425491197840723*^9, 
  3.425491205305214*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gg", "=", 
  RowBox[{"GraphicsColumn", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"\[Mu]ramp0", ",", "p1"}], "}"}], "]"}], ",", "26"}], 
          "]"}], ",", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"\[Mu]ramp0", ",", "p3"}], "}"}], "]"}], ",", "26"}], 
          "]"}]}], "}"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Black", ",", "Thick", ",", "Dotted"}], "}"}]}], "}"}]}], 
       ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<\\mu\>\"", ",", "TeXForm"}], "]"}], ",", 
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<C f'_1[0]\>\"", ",", "TeXForm"}], "]"}]}], "}"}]}], 
       ",", 
       RowBox[{"PlotLabel", "\[Rule]", "\"\<(a)\>\""}]}], "]"}], ",", 
     RowBox[{"ListLogLogPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"\[Mu]ramp0", ",", "p2"}], "}"}], "]"}], ",", "26"}], 
          "]"}], ",", " ", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"\[Mu]ramp0", ",", 
              RowBox[{"1.5", " ", 
               SuperscriptBox["\[Mu]ramp0", 
                RowBox[{"-", "0.39"}]]}]}], "}"}], "]"}], ",", "26"}], 
          "]"}]}], "}"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"Black", ",", "Thick", ",", "Dashed"}], "}"}], ",", 
          RowBox[{"{", "Black", "}"}]}], "}"}]}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<\\mu\>\"", ",", "TeXForm"}], "]"}], ",", 
          RowBox[{"ToExpression", "[", 
           RowBox[{"\"\<C f'_1[0]\>\"", ",", "TeXForm"}], "]"}]}], "}"}]}], 
       ",", 
       RowBox[{"PlotLabel", "\[Rule]", "\"\<(b)\>\""}]}], "]"}]}], "}"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.425487317907584*^9, 3.425487340100865*^9}, {
   3.42548753952065*^9, 3.425487573096828*^9}, {3.42548760407105*^9, 
   3.42548761195364*^9}, {3.425487645154865*^9, 3.425487677646212*^9}, {
   3.425488327684043*^9, 3.425488404672798*^9}, {3.425488509268646*^9, 
   3.425488511481356*^9}, {3.42548972876046*^9, 3.425489780846098*^9}, 
   3.425489815127049*^9, {3.425489867197024*^9, 3.425490006411145*^9}, {
   3.425490418356571*^9, 3.425490428604905*^9}, {3.425490473349031*^9, 
   3.425490498206259*^9}, {3.425490537076273*^9, 3.425490602675079*^9}, {
   3.42549120976199*^9, 3.425491238784452*^9}, {3.425525415814714*^9, 
   3.425525536028752*^9}, {3.425525578920587*^9, 3.425525630865249*^9}, {
   3.425525722417223*^9, 3.425525739704904*^9}, {3.425525776502082*^9, 
   3.425525778335586*^9}, {3.425526104358394*^9, 3.425526154996106*^9}, {
   3.425526366488474*^9, 3.425526370995374*^9}, {3.425526405642537*^9, 
   3.42552646546965*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], Thickness[Large], 
        LineBox[{{-9.210340371976182, 3.042303565587896}, {-8.749823353377373,
          2.927380746625578}, {-8.289306334778564, 
         2.8125501971659896`}, {-7.828789316179755, 
         2.6978512130063947`}, {-7.368272297580946, 
         2.583338677832832}, {-6.907755278982137, 
         2.4690885300533454`}, {-6.447238260383328, 
         2.3552048072947125`}, {-5.986721241784519, 
         2.2418283346829124`}, {-5.52620422318571, 
         2.1291471759920437`}, {-5.0656872045869, 
         2.017408556945899}, {-4.605170185988091, 
         1.9069316090581505`}, {-4.144653167389282, 
         1.7981196161338837`}, {-3.684136148790473, 
         1.6914697525662712`}, {-3.223619130191664, 
         1.5875773743149204`}, {-2.7631021115928545`, 
         1.4871315159577674`}, {-2.3025850929940455`, 
         1.3908980699850209`}, {-1.8420680743952365`, 
         1.2996881861307248`}, {-1.3815510557964272`, 
         1.214311665908025}, {-0.9210340371976181, 
         1.1355182613342982`}, {-0.4605170185988088, 1.063933676269315}, {0., 
         1.000000045530538}, {0.4605170185988092, 0.9439301743791055}, {
         0.9210340371976184, 0.8956860123477542}, {1.3815510557964277`, 
         0.8549812610804284}, {1.842068074395237, 0.8213132540988995}, {
         2.302585092994046, 0.7940107551393968}}]}, 
       {GrayLevel[0], Thickness[Large], Dashing[{0, Small}], 
        LineBox[{{-9.210340371976182, 8.118451528347377}, {-8.749823353377373,
          7.661132766434849}, {-8.289306334778564, 
         7.20532449584845}, {-7.828789316179755, 
         6.751695218720181}, {-7.368272297580946, 
         6.301168978558666}, {-6.907755278982137, 
         5.854989927323992}, {-6.447238260383328, 
         5.414780755065172}, {-5.986721241784519, 
         4.982578079293787}, {-5.52620422318571, 
         4.560826944655505}, {-5.0656872045869, 
         4.1523139762211}, {-4.605170185988091, 
         3.7600360861218127`}, {-4.144653167389282, 
         3.38700895278763}, {-3.684136148790473, 
         3.0360431162075923`}, {-3.223619130191664, 
         2.7095271428371084`}, {-2.7631021115928545`, 
         2.4092512738214134`}, {-2.3025850929940455`, 
         2.136304691593408}, {-1.8420680743952365`, 
         1.8910452767321513`}, {-1.3815510557964272`, 
         1.6731460300710261`}, {-0.9210340371976181, 
         1.481686084372062}, {-0.4605170185988088, 1.3152739093630328`}, {0., 
         1.1721758614312763`}, {0.4605170185988092, 1.0504359536551722`}, {
         0.9210340371976184, 0.9479824119475897}, {1.3815510557964277`, 
         0.8627112179181641}, {1.842068074395237, 0.7925516358273892}, {
         2.302585092994046, 0.7355126513165484}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{
        FormBox["\[Mu]", TraditionalForm], 
        FormBox[
         RowBox[{"C", " ", 
           RowBox[{
             SuperscriptBox[
              SubscriptBox["f", "1"], "\[Prime]", MultilineFunction -> None], 
             "(", "0", ")"}]}], TraditionalForm]},
      AxesOrigin->{-9.210340371976182, 0.7355126513165484},
      FrameTicks->{{Automatic, Automatic}, {{{-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-9.210340371976182, 
           FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotLabel->FormBox["\"(a)\"", TraditionalForm],
      PlotRange->{{-9.210340371976182, 2.302585092994046}, {
       0.7355126513165484, 8.118451528347377}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->FrontEndValueCache[{{{-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}, {{{-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}]], {189., -118.66252583997979`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
     GraphicsBox[{{}, {}, 
       {GrayLevel[0], Thickness[Large], Dashing[{Small, Small}], 
        LineBox[{{-9.210340371976182, 
         3.6959718088560893`}, {-8.749823353377373, 
         3.513819736570583}, {-8.289306334778564, 
         3.3318703027726846`}, {-7.828789316179755, 
         3.1501494994243657`}, {-7.368272297580946, 
         2.968689473616708}, {-6.907755278982137, 
         2.7875299366083723`}, {-6.447238260383328, 
         2.606721004030843}, {-5.986721241784519, 
         2.426326342935715}, {-5.52620422318571, 
         2.246427603653306}, {-5.0656872045869, 
         2.0671301498387327`}, {-4.605170185988091, 
         1.8885701101029595`}, {-4.144653167389282, 
         1.710923508958008}, {-3.684136148790473, 
         1.534417670112183}, {-3.223619130191664, 
         1.3593444663402618`}, {-2.7631021115928545`, 
         1.1860757802920867`}, {-2.3025850929940455`, 
         1.015080592857339}, {-1.8420680743952365`, 
         0.8469421346725097}, {-1.3815510557964272`, 
         0.6823735710937944}, {-0.9210340371976181, 
         0.5222285471656798}, {-0.4605170185988088, 0.36750253343276806`}, {
         0., 0.2193177548436371}, {0.4605170185988092, 0.07889003763715194}, {
         0.9210340371976184, -0.052530477246302665`}, {
         1.3815510557964277`, -0.17374352632097148`}, {
         1.842068074395237, -0.283702411267645}, {
         2.302585092994046, -0.3816237404123402}}]}, 
       {GrayLevel[0], 
        LineBox[{{-9.210340371976182, 
         3.9974978531788756`}, {-8.749823353377373, 
         3.81789621592534}, {-8.289306334778564, 
         3.6382945786718044`}, {-7.828789316179755, 
         3.458692941418269}, {-7.368272297580946, 
         3.2790913041647336`}, {-6.907755278982137, 
         3.099489666911198}, {-6.447238260383328, 
         2.9198880296576624`}, {-5.986721241784519, 
         2.7402863924041267`}, {-5.52620422318571, 
         2.560684755150591}, {-5.0656872045869, 
         2.3810831178970555`}, {-4.605170185988091, 
         2.20148148064352}, {-4.144653167389282, 
         2.0218798433899847`}, {-3.684136148790473, 
         1.842278206136449}, {-3.223619130191664, 
         1.6626765688829133`}, {-2.7631021115928545`, 
         1.4830749316293776`}, {-2.3025850929940455`, 
         1.3034732943758423`}, {-1.8420680743952365`, 
         1.1238716571223064`}, {-1.3815510557964272`, 
         0.944270019868771}, {-0.9210340371976181, 
         0.7646683826152354}, {-0.4605170185988088, 0.5850667453616997}, {0., 
         0.4054651081081644}, {0.4605170185988092, 0.22586347085462874`}, {
         0.9210340371976184, 0.04626183360109328}, {
         1.3815510557964277`, -0.13333980365244233`}, {
         1.842068074395237, -0.312941440905978}, {
         2.302585092994046, -0.49254307815951337`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesLabel->{
        FormBox["\[Mu]", TraditionalForm], 
        FormBox[
         RowBox[{"C", " ", 
           RowBox[{
             SuperscriptBox[
              SubscriptBox["f", "1"], "\[Prime]", MultilineFunction -> None], 
             "(", "0", ")"}]}], TraditionalForm]},
      AxesOrigin->{-9.210340371976182, -0.49254307815951337`},
      FrameTicks->{{{{0, 
           FormBox["1", TraditionalForm]}, {
           NCache[
            Log[2], 0.6931471805599453], 
           FormBox["2", TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox["5", TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["10", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["20", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["50", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["100", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["200", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0, 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[2], 0.6931471805599453], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[5], 1.6094379124341003`], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[10], 2.302585092994046], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[20], 2.995732273553991], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[50], 3.912023005428146], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[100], 4.605170185988092], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[200], 5.298317366548036], 
           FormBox["\" \"", TraditionalForm]}, {
           NCache[
            Log[500], 6.214608098422191], 
           FormBox["\" \"", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-9.210340371976182, 
           FormBox["\" \"", TraditionalForm]}, {-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotLabel->FormBox["\"(b)\"", TraditionalForm],
      PlotRange->{{-9.210340371976182, 
       2.302585092994046}, {-0.49254307815951337`, 3.9974978531788756`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->FrontEndValueCache[{{{-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["1", TraditionalForm]}, {0.6931471805599453, 
           FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}, {{{-9.210340371976182, 
           FormBox[
            TagBox[
             SuperscriptBox[
              TagBox["10", Power, Editable -> True, Selectable -> True], 
              TagBox[
               RowBox[{"-", "4"}], Power, Editable -> True, Selectable -> 
               True]], 
             InterpretTemplate[Superscript[#, #2]& ], Editable -> False, 
             Selectable -> False], TraditionalForm]}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0., 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {-8.517193191416238, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-8.111728083308073, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.824046010856292, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.600902459542082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.418580902748127, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.264430222920869, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.1308988302963465`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-7.013115794639964, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{0., 
           FormBox["1", TraditionalForm]}, {0.6931471805599453, 
           FormBox["2", TraditionalForm]}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {2.995732273553991, 
           FormBox["20", TraditionalForm]}, {3.912023005428146, 
           FormBox["50", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {5.298317366548036, 
           FormBox["200", TraditionalForm]}, {6.214608098422191, 
           FormBox["500", TraditionalForm]}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}]], {189., -355.98757751993935`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.42548754418556*^9, 3.425487573979151*^9}, {
   3.425487654487063*^9, 3.425487678633725*^9}, 3.425488347167041*^9, {
   3.425488391919161*^9, 3.425488405674654*^9}, 3.425489321225744*^9, 
   3.425489782067649*^9, 3.425489818522575*^9, {3.425489932285027*^9, 
   3.425490007425245*^9}, 3.425490432280106*^9, {3.425490486186013*^9, 
   3.425490499897615*^9}, {3.425490555379851*^9, 3.425490572794354*^9}, 
   3.425490607577265*^9, 3.425491246677351*^9, 3.425491293814125*^9, 
   3.425525474227108*^9, 3.425525505949673*^9, 3.425525538459947*^9, {
   3.425525583230989*^9, 3.425525632614459*^9}, 3.425525741662115*^9, 
   3.425525779697114*^9, {3.425526121606308*^9, 3.425526157744151*^9}, 
   3.425526413908181*^9, 3.425526467167222*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plotg1", "[", "\[Mu]_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"R2", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"R3", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g1", "[", "x", "]"}], " ", "/.", " ", "R1"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g1", "[", "x", "]"}], " ", "/.", " ", "R2"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g1", "[", "x", "]"}], " ", "/.", " ", "R3"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.390791557348885*^9, 3.390791565693898*^9}, {
  3.390791632911671*^9, 3.390791643841945*^9}, {3.390791966234546*^9, 
  3.390792121764349*^9}, {3.390792260952287*^9, 3.390792352236344*^9}, {
  3.390793789073724*^9, 3.390793811774131*^9}, {3.390801030106019*^9, 
  3.390801030722589*^9}, {3.390808562762817*^9, 3.390808577195003*^9}, {
  3.4059281698552847`*^9, 3.4059281704910393`*^9}, {3.406450514277207*^9, 
  3.406450516735062*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution to the second order perturbation problem for f2b", "Section",
 CellChangeTimes->{{3.390832659453377*^9, 3.390832659935775*^9}, {
  3.424781133121643*^9, 3.4247811348314457`*^9}}],

Cell[CellGroupData[{

Cell["Generation of the source functions", "Subsection",
 CellChangeTimes->{3.390824007168673*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Src2b1", "=", 
   FractionBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Src2b2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      RowBox[{"g1", "'"}], "[", "y", "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "  ", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "[", "y", "]"}], " ", 
     RowBox[{"g1", "[", "y", "]"}]}]}]}], " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Src2b3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{
      RowBox[{"g1", "'"}], "[", "y", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], "2"]}], "+", " ", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Theta]", "'"}], "[", "y", "]"}], " ", 
        RowBox[{
         RowBox[{"g1", "''"}], "[", "y", "]"}]}], " ", "-", "  ", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Theta]", "''"}], "[", "y", "]"}], " ", 
        RowBox[{
         RowBox[{"g1", "'"}], "[", "y", "]"}]}]}], ")"}]}]}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390824025072091*^9, 3.390824026434683*^9}, 
   3.390824062148377*^9, {3.390824102133749*^9, 3.390824125587481*^9}, {
   3.390824157596013*^9, 3.390824245551654*^9}, {3.390824282609142*^9, 
   3.390824390401586*^9}, {3.390824422447238*^9, 3.390824483928824*^9}, {
   3.390824538208563*^9, 3.390824561189319*^9}, {3.390824612407697*^9, 
   3.390824630863946*^9}, {3.39082479020385*^9, 3.39082483464885*^9}, {
   3.390824867792556*^9, 3.390824939269808*^9}, {3.390825033857929*^9, 
   3.390825037612255*^9}, 3.390827068911792*^9, {3.390827229799818*^9, 
   3.390827243300935*^9}, {3.390827439136636*^9, 3.390827442616699*^9}, {
   3.390829195896935*^9, 3.390829212491218*^9}, 3.390829281382955*^9, {
   3.390829323724258*^9, 3.390829343805745*^9}, {3.390829510316487*^9, 
   3.390829566044941*^9}, {3.390829797884266*^9, 3.390829802711456*^9}, {
   3.390829866147372*^9, 3.390829874606209*^9}, {3.405888782362731*^9, 
   3.405888787809689*^9}, {3.424715485129615*^9, 3.424715499398815*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "The", " ", "problem", " ", "to", " ", "be", " ", "solved", " ", "at", " ", 
   "this", " ", "order", " ", "is"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L0", 
   RowBox[{"(", "f2b", ")"}]}], "=", " ", 
  RowBox[{
   RowBox[{
    SubscriptBox["\[PartialD]", 
     SuperscriptBox["y", "2"]], " ", "Src2b1"}], " ", "+", " ", 
   RowBox[{
    FractionBox["1", "C"], 
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", "Src2b2"}]}], " ", "+", 
   RowBox[{
    FractionBox[
     RowBox[{" ", "D"}], "C"], " ", 
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", "Src2b3"}]}]}]}]}], "Definition",
 CellChangeTimes->{{3.424715120658424*^9, 3.424715193357429*^9}, {
  3.424715323695444*^9, 3.424715402998071*^9}, {3.424715436788885*^9, 
  3.424715444711733*^9}, {3.42471550870722*^9, 3.42471554949109*^9}, {
  3.424747365588253*^9, 3.424747367884864*^9}, {3.424752057324991*^9, 
  3.424752057591082*^9}, {3.424752115115873*^9, 3.424752146401735*^9}, {
  3.424848125213518*^9, 3.424848125558683*^9}}],

Cell["\<\
Notice that Src2b2 and Src2b3 vanish for Flow1 and \[Mu] = 1, when \
\[Theta][y]=y and g1[y]=Sin[y]\
\>", "Text",
 CellChangeTimes->{{3.4059298898914127`*^9, 3.405929922820973*^9}, {
  3.424785629000312*^9, 3.424785686801332*^9}}],

Cell[CellGroupData[{

Cell["Plot of the source term", "Subsubsection",
 CellChangeTimes->{{3.390890499286446*^9, 3.390890506547625*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotSrc2b", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3", ",", "c1", ",", "c2", ",", "c3"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"Src2b1", " ", "/.", 
            RowBox[{"{", 
             RowBox[{"Flow1", ",", 
              RowBox[{"\[Mu]", "\[Rule]", "\[Mu]0"}]}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", 
             FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"Src2b1", " ", "/.", " ", 
            RowBox[{"{", 
             RowBox[{"Flow2", ",", 
              RowBox[{"\[Mu]", "\[Rule]", "\[Mu]0"}]}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", 
             FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{"Src2b1", " ", "/.", " ", 
            RowBox[{"{", 
             RowBox[{"Flow3", ",", 
              RowBox[{"\[Mu]", "\[Rule]", "\[Mu]0"}]}], "}"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", 
             FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Src2b2", " ", "/.", " ", "R1"}], " ", "/.", " ", 
            "Flow1"}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", 
             FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Src2b2", " ", "/.", " ", "R2"}], " ", "/.", " ", 
            "Flow2"}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", 
             FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Src2b2", " ", "/.", " ", "R3"}], " ", "/.", " ", 
            "Flow3"}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", 
             FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Src2b3", "/.", "  ", "R1"}], " ", "/.", " ", "Flow1"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", 
             FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Src2b3", " ", "/.", " ", "R2"}], " ", "/.", " ", 
            "Flow2"}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", 
             FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Plot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Src2b3", " ", "/.", " ", "R3"}], " ", "/.", " ", 
            "Flow3"}], ",", 
           RowBox[{"{", 
            RowBox[{"y", ",", "0", ",", 
             FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], 
        "\[IndentingNewLine]", "}"}]}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390827628396154*^9, 3.390827770365142*^9}, {
   3.390827870372647*^9, 3.390827925696509*^9}, 3.390828909105881*^9, {
   3.390829601394354*^9, 3.39082964654712*^9}, {3.39082974227179*^9, 
   3.390829747713359*^9}, {3.390829810576995*^9, 3.390829829729966*^9}, {
   3.390829890404864*^9, 3.390829998743718*^9}, {3.39083004629658*^9, 
   3.39083016814121*^9}, {3.390830321786316*^9, 3.39083032700509*^9}, {
   3.39083051312603*^9, 3.390830522765489*^9}, {3.390830555834429*^9, 
   3.390830589128285*^9}, {3.390830753467661*^9, 3.390830789715912*^9}, {
   3.390831755422801*^9, 3.390832058444846*^9}, {3.3908327569219*^9, 
   3.39083285606158*^9}, {3.390887475049467*^9, 3.390887490737751*^9}, {
   3.405888794018796*^9, 3.405888816395094*^9}, {3.405929661743672*^9, 
   3.405929753172964*^9}, 3.405949866147489*^9}],

Cell["\<\
Reactivate following line to get dynamic plot of the source terms \
\>", "ExerciseText",
 CellChangeTimes->{{3.4059286474611797`*^9, 3.405928687765193*^9}, {
  3.405928977448398*^9, 3.4059289779585*^9}, {3.4059298289784718`*^9, 
  3.4059298345943537`*^9}}],

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"z", "=", "0."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Slider", "[", 
      RowBox[{
       RowBox[{"Dynamic", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}], ",", 
     RowBox[{"Dynamic", "[", 
      SuperscriptBox["10", "z"], "]"}], ",", 
     RowBox[{"Dynamic", "[", 
      RowBox[{"PlotSrc2b", "[", 
       SuperscriptBox["10", "z"], "]"}], "]"}]}], "}"}]}], 
  "]"}]], "Definition",
 CellChangeTimes->{{3.390792476800358*^9, 3.390792513597721*^9}, {
  3.390792551409172*^9, 3.390792638767292*^9}, {3.390793843937636*^9, 
  3.390793899853856*^9}, {3.39083213408223*^9, 3.390832137368048*^9}, {
  3.405864885250111*^9, 3.405864946388008*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotSrc2b", "[", "0.00001", "]"}]], "Input",
 CellChangeTimes->{{3.4059298441489162`*^9, 3.405929885945882*^9}, {
  3.424699950307537*^9, 3.424699969148636*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd1Qk0VdsfB3BJkamZJ6U0oChJHoW+uonoNan0Cg3KdC5lqOeFvBRFvcRV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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {0., 1.9999999999999991`}}, {{
         0, 1.5707963267948966`}, {0., 1.9999999999999991`}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF1nk4Fe/7B3BrqXBQtFOSiEokkrxP0iItPpWoiKTk2LPLFpFSkpCQLSFZ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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {0., 3.9999999999999876`}}, {{
         0, 1.5707963267948966`}, {0., 3.9999999999999876`}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1gk01c0bB3D7T5KlXKU3srQIaVHoT76/JHmT0r6gRYvuFVmSkhRvSom4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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {0., 2.9999999999999947`}}, {{
         0, 1.5707963267948966`}, {0., 2.9999999999999947`}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8Vc8bB/BrC321SCopVJLSRmS/H6GijSgqZInsZSlJSEm0kCwVZUtI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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {-1.1752582143153417`*^-20, 
         1.9597869767716307`}}, {{
         0, 1.5707963267948966`}, {-1.1752582143153417`*^-20, 
         1.9597869767716307`}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd13k4Vd/XAPBbJFNlTEoi0UClIhmydiVjZLr3SGQeUpkrSVIhJCGEyhSS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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {0., 95.0373991293108}}, {{
         0, 1.5707963267948966`}, {0., 95.0373991293108}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd13k8Vc/7APCbbFmKQtkOUtqEkiTcZ5KUSKKkQhKVJaFQIvtaJGQrWUNk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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {0., 7.7568619379697745`}}, {{
         0, 1.5707963267948966`}, {0., 7.7568619379697745`}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd13k4VO8XAHAzo2ixRkkqQilUQtacm2StkLUIWSLJviVJSJKsZcueLClk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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {-5.071823531135273*^-7, 
         2.437391066640365}}, {{
         0, 1.5707963267948966`}, {-5.071823531135273*^-7, 
         2.437391066640365}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8ld8fAHCraKcQKiFRVirbvfdzSGREZWdl73WVkZGGVUgyk5GtIdmV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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {0., 303.26946593170203`}}, {{
         0, 1.5707963267948966`}, {0., 303.26946593170203`}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl1nc8Vf8bAHArJEJG9lZknZsySvf5FGkoI6OvkBFlVSgjEUpWkRSJhMyK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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{0, 0},
      PlotRange->
       NCache[{{0, Rational[1, 2] Pi}, {-1.0227817518019015`*^-12, 
         17.165617443263365`}}, {{
         0, 1.5707963267948966`}, {-1.0227817518019015`*^-12, 
         17.165617443263365`}}],
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.40592985555276*^9, 3.405929874683791*^9}, 
   3.405949876987155*^9, 3.406084901777708*^9, {3.424699953431794*^9, 
   3.42469997176014*^9}}]
}, Open  ]],

Cell["\<\
Notice that Src2b2 and Src2b3 vanish for Flow1 and \[Mu] = 1\
\>", "Text",
 CellChangeTimes->{{3.4059298898914127`*^9, 3.405929922820973*^9}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution using NDSolve", "Subsection"],

Cell[BoxData[{
 RowBox[{"The", " ", "solution", " ", "is"}], "\[IndentingNewLine]", 
 RowBox[{"f2b", " ", "=", "  ", 
  RowBox[{"g2b1", " ", "+", 
   RowBox[{
    FractionBox["1", "C"], "  ", "g2b2"}], " ", "+", " ", 
   RowBox[{
    FractionBox[
     RowBox[{" ", "D"}], "C"], "  ", "g2b3"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
   "Since", " ", "only", " ", "the", " ", "derivative", " ", "of", " ", "f2b",
     " ", "is", " ", "needed", " ", "to", " ", "get", " ", "the", " ", 
    "amplitude", " ", "equation"}], ",", " ", 
   RowBox[{"we", " ", "define"}]}], " "}], "\[IndentingNewLine]", 
 RowBox[{"and", " ", "calculate"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"h2b1", " ", "=", " ", 
   RowBox[{"g2b1", "'"}]}], ",", " ", 
  RowBox[{"h2b2", " ", "=", " ", 
   RowBox[{"g2b2", "'"}]}], ",", " ", 
  RowBox[{"h2b3", "=", 
   RowBox[{"g2b3", "'"}]}]}]}], "Definition",
 CellChangeTimes->{{3.424715120658424*^9, 3.424715193357429*^9}, {
  3.424715323695444*^9, 3.424715402998071*^9}, {3.424715436788885*^9, 
  3.424715444711733*^9}, {3.42471550870722*^9, 3.42471554949109*^9}, {
  3.424747365588253*^9, 3.424747367884864*^9}, {3.424747509396184*^9, 
  3.424747611981361*^9}, {3.424748130212551*^9, 3.42474813967565*^9}, {
  3.424752245668258*^9, 3.42475229463878*^9}, {3.424780601546352*^9, 
  3.424780687437716*^9}, {3.424781004013953*^9, 3.42478100571649*^9}, {
  3.424848129709225*^9, 3.424848129974321*^9}}],

Cell[CellGroupData[{

Cell["Solution of the problem for h2b1 and g2b1", "Subsubsection",
 CellChangeTimes->{{3.390889118505316*^9, 3.390889152048175*^9}, {
  3.390934245962984*^9, 3.39093425068413*^9}}],

Cell["\<\
Solution for h2b1 with an auxilliary integration constant K such that the \
solvability condition and the boundary conditions are satisfied
The integration constant appears here because  h2b1 has Sin 2 y symmetry \
resulting in a constant contribution by the product with Trb\
\>", "Text",
 CellChangeTimes->{{3.405928577701933*^9, 3.40592863627282*^9}, 
   3.424747581891338*^9, {3.42474764785063*^9, 3.424747654845586*^9}, {
   3.424747813155859*^9, 3.424747816909537*^9}, {3.424748084129539*^9, 
   3.424748112213708*^9}, {3.424748154099059*^9, 3.424748229997991*^9}, {
   3.424748531488153*^9, 3.42474853291617*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h2b1p", "=", 
   RowBox[{
    RowBox[{"Part", "[", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"L2d", "[", 
             RowBox[{
              RowBox[{"h2b1", "[", "y", "]"}], ",", "#1"}], "]"}], " ", "==", 
            " ", 
            RowBox[{"Src2b1", " ", "-", " ", 
             RowBox[{"K", "[", "y", "]"}]}]}], "/.", " ", 
           RowBox[{"{", 
            RowBox[{"#2", ",", 
             RowBox[{"\[Mu]", "\[Rule]", "#1"}]}], "}"}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"K", "'"}], "[", "y", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"h2b1", "[", "0", "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{"h2b1", "[", 
            FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}]}], "}"}], ",",
         
        RowBox[{"{", 
         RowBox[{"h2b1", ",", "K"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", "1", ",", "1"}], 
     "]"}], "&"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390801023898732*^9, 3.390801055399089*^9}, {
   3.390801112757135*^9, 3.390801163045885*^9}, {3.390801256929032*^9, 
   3.390801487582233*^9}, {3.39080158066786*^9, 3.39080163264723*^9}, {
   3.390801723301243*^9, 3.390801730917677*^9}, 3.390801775524101*^9, {
   3.390801884825068*^9, 3.390801974466207*^9}, {3.390802056158044*^9, 
   3.390802090782592*^9}, 3.390802124442182*^9, 3.390808287200548*^9, {
   3.390808482408374*^9, 3.390808488706338*^9}, {3.390832670072963*^9, 
   3.390832723227988*^9}, {3.390832882722431*^9, 3.39083294357612*^9}, {
   3.390833029878882*^9, 3.390833131441482*^9}, {3.39083345612856*^9, 
   3.390833477728499*^9}, {3.390833551999039*^9, 3.390833563955723*^9}, {
   3.390833629502198*^9, 3.390833650716105*^9}, {3.390833973915081*^9, 
   3.390834034535696*^9}, {3.390834092044357*^9, 3.390834125425942*^9}, {
   3.390834165805316*^9, 3.390834180865196*^9}, {3.390834396666789*^9, 
   3.390834426476449*^9}, {3.390834470027936*^9, 3.390834470289657*^9}, {
   3.3908530954117*^9, 3.390853104393309*^9}, {3.390853962187764*^9, 
   3.390854005997462*^9}, 3.390854036047404*^9, {3.390887576182898*^9, 
   3.390887681563766*^9}, {3.390887888838058*^9, 3.390887899323179*^9}, {
   3.390888003528389*^9, 3.390888053044771*^9}, {3.390888350219621*^9, 
   3.390888362198221*^9}, {3.390889006164184*^9, 3.390889030404093*^9}, {
   3.390889929386098*^9, 3.390889934252199*^9}, {3.405891985878149*^9, 
   3.405891987745144*^9}}],

Cell["\<\
This provides directly g2b1 with the trick that g2b1 is the derivative of a \
function with same symmetries as h2b1 in order to impose the solvability \
condition in a way that NDSolve understands \
\>", "Text",
 CellChangeTimes->{{3.424748282447604*^9, 3.424748289252749*^9}, {
  3.424748320526171*^9, 3.424748418541406*^9}, {3.424748494140414*^9, 
  3.424748522470102*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mgg2b1", "=", 
   RowBox[{
    RowBox[{"Part", "[", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"L2d", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"g2b1", "'"}], "[", "y", "]"}], ",", "#1"}], "]"}], 
            " ", "==", " ", 
            RowBox[{"Src2b1", " ", "-", " ", 
             RowBox[{"K", "[", "y", "]"}]}]}], "/.", " ", 
           RowBox[{"{", 
            RowBox[{"#2", ",", 
             RowBox[{"\[Mu]", "\[Rule]", "#1"}]}], "}"}]}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"K", "'"}], "[", "y", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"g2b1", "'"}], "[", "0", "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"g2b1", "'"}], "[", 
            FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"IG", "'"}], "[", "y", "]"}], "==", 
           RowBox[{"g2b1", "[", "y", "]"}]}], ",", 
          RowBox[{
           RowBox[{"IG", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"IG", "[", 
            FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}]}], "}"}], ",",
         
        RowBox[{"{", 
         RowBox[{"g2b1", ",", "K", ",", "IG"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", "1", ",", "1"}], 
     "]"}], "&"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390801023898732*^9, 3.390801055399089*^9}, {
   3.390801112757135*^9, 3.390801163045885*^9}, {3.390801256929032*^9, 
   3.390801487582233*^9}, {3.39080158066786*^9, 3.39080163264723*^9}, {
   3.390801723301243*^9, 3.390801730917677*^9}, 3.390801775524101*^9, {
   3.390801884825068*^9, 3.390801974466207*^9}, {3.390802056158044*^9, 
   3.390802090782592*^9}, 3.390802124442182*^9, 3.390808287200548*^9, {
   3.390808482408374*^9, 3.390808488706338*^9}, {3.390832670072963*^9, 
   3.390832723227988*^9}, {3.390832882722431*^9, 3.39083294357612*^9}, {
   3.390833029878882*^9, 3.390833131441482*^9}, {3.39083345612856*^9, 
   3.390833477728499*^9}, {3.390833551999039*^9, 3.390833563955723*^9}, {
   3.390833629502198*^9, 3.390833650716105*^9}, {3.390833973915081*^9, 
   3.390834034535696*^9}, {3.390834092044357*^9, 3.390834125425942*^9}, {
   3.390834165805316*^9, 3.390834180865196*^9}, {3.390834396666789*^9, 
   3.390834426476449*^9}, {3.390834470027936*^9, 3.390834470289657*^9}, {
   3.3908530954117*^9, 3.390853104393309*^9}, {3.390853962187764*^9, 
   3.390854005997462*^9}, 3.390854036047404*^9, {3.390887576182898*^9, 
   3.390887681563766*^9}, {3.390887888838058*^9, 3.390887899323179*^9}, {
   3.390888003528389*^9, 3.390888053044771*^9}, {3.390888350219621*^9, 
   3.390888362198221*^9}, {3.390889006164184*^9, 3.390889030404093*^9}, {
   3.390889929386098*^9, 3.390889934252199*^9}, {3.405891985878149*^9, 
   3.405891987745144*^9}, {3.405928335356947*^9, 3.4059284591812143`*^9}, {
   3.4059510974606457`*^9, 3.40595115176621*^9}, {3.405951187593349*^9, 
   3.405951188021175*^9}, {3.4059512550170107`*^9, 3.405951278346922*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the solution for h2b1 and g2b1 ", "Subsubsection",
 CellChangeTimes->{{3.390890674031211*^9, 3.390890700396829*^9}, 
   3.390892499745577*^9, {3.424780585735614*^9, 3.424780593564994*^9}, {
   3.424781035078455*^9, 3.424781035456008*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ploth2b1", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"h2b1p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"h2b1p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"h2b1p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h2b1", "[", "y", "]"}], "/.", " ", "R1"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h2b1", "[", "y", "]"}], "/.", " ", "R2"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h2b1", "[", "y", "]"}], " ", "/.", " ", "R3"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.390827628396154*^9, 3.390827770365142*^9}, {
   3.390827870372647*^9, 3.390827925696509*^9}, 3.390828909105881*^9, {
   3.390829601394354*^9, 3.39082964654712*^9}, {3.39082974227179*^9, 
   3.390829747713359*^9}, {3.390829810576995*^9, 3.390829829729966*^9}, {
   3.390829890404864*^9, 3.390829998743718*^9}, {3.39083004629658*^9, 
   3.39083016814121*^9}, {3.390830321786316*^9, 3.39083032700509*^9}, {
   3.39083051312603*^9, 3.390830522765489*^9}, {3.390830555834429*^9, 
   3.390830589128285*^9}, {3.390830753467661*^9, 3.390830789715912*^9}, {
   3.390831755422801*^9, 3.390832058444846*^9}, {3.3908327569219*^9, 
   3.39083285606158*^9}, {3.390887475049467*^9, 3.390887490737751*^9}, {
   3.390889434926512*^9, 3.390889475071848*^9}, {3.39088951166508*^9, 
   3.390889696051436*^9}, {3.390889754924179*^9, 3.390889766231898*^9}, {
   3.390890024236448*^9, 3.390890057082224*^9}, {3.390892504444662*^9, 
   3.390892521187431*^9}, {3.40595141340939*^9, 3.405951464048923*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plotg2b1", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"mgg2b1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"mgg2b1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"mgg2b1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g2b1", "[", "y", "]"}], "/.", " ", "R1"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g2b1", "[", "y", "]"}], "/.", " ", "R2"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g2b1", "[", "y", "]"}], " ", "/.", " ", "R3"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.390827628396154*^9, 3.390827770365142*^9}, {
   3.390827870372647*^9, 3.390827925696509*^9}, 3.390828909105881*^9, {
   3.390829601394354*^9, 3.39082964654712*^9}, {3.39082974227179*^9, 
   3.390829747713359*^9}, {3.390829810576995*^9, 3.390829829729966*^9}, {
   3.390829890404864*^9, 3.390829998743718*^9}, {3.39083004629658*^9, 
   3.39083016814121*^9}, {3.390830321786316*^9, 3.39083032700509*^9}, {
   3.39083051312603*^9, 3.390830522765489*^9}, {3.390830555834429*^9, 
   3.390830589128285*^9}, {3.390830753467661*^9, 3.390830789715912*^9}, {
   3.390831755422801*^9, 3.390832058444846*^9}, {3.3908327569219*^9, 
   3.39083285606158*^9}, {3.390887475049467*^9, 3.390887490737751*^9}, {
   3.390889434926512*^9, 3.390889475071848*^9}, {3.39088951166508*^9, 
   3.390889696051436*^9}, {3.390889754924179*^9, 3.390889766231898*^9}, {
   3.390890024236448*^9, 3.390890057082224*^9}, {3.390892504444662*^9, 
   3.390892521187431*^9}}],

Cell["\<\
Following line produces dynamic plot of the solution (very slow)\
\>", "Text",
 CellChangeTimes->{{3.426560388981947*^9, 3.426560429154038*^9}}],

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"z", "=", "0."}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Slider", "[", 
      RowBox[{
       RowBox[{"Dynamic", "[", "z", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}], ",", 
     RowBox[{"Dynamic", "[", 
      SuperscriptBox["10", "z"], "]"}], ",", 
     RowBox[{"Dynamic", "[", 
      RowBox[{"Plotg2b1", "[", 
       SuperscriptBox["10", "z"], "]"}], "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.390792476800358*^9, 3.390792513597721*^9}, {
  3.390792551409172*^9, 3.390792638767292*^9}, {3.390793843937636*^9, 
  3.390793899853856*^9}, {3.39083213408223*^9, 3.390832137368048*^9}, {
  3.390890140755794*^9, 3.390890149524491*^9}, {3.405893146063142*^9, 
  3.405893266985288*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ploth2b1", "[", "0.001", "]"}]], "Input",
 CellChangeTimes->{{3.405950987095038*^9, 3.405950998902658*^9}, {
  3.40595104799238*^9, 3.405951066285643*^9}, {3.4059514770216722`*^9, 
  3.405951507045491*^9}, {3.406105970368289*^9, 3.40610603136271*^9}, {
  3.406106063076052*^9, 3.40610606400657*^9}, {3.406106104856927*^9, 
  3.406106115135327*^9}, {3.425303449919911*^9, 3.425303480841938*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8V/sfB/CikIpU0jIiUlSkjIwXpYEGRdIVhVwpIquMVLayRyIpKdTN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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 0.7436511428066201}}, {{
       0, 1.5707963267948966`}, {0., 0.7436511428066201}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4Fe/7B3CpfEgKRWklLYqSlOxv/ErK2qFEJaRIZUuRrbShspY2Fdkl
SXJQSKtIUrZUliRxZjpn5liSxO/5/jHXXK8/Znnuue/3M0qu3px9oiIiIj/J
8b/zxKdT6r6vczEM6PzUJlvrbLikr0JvwSWg9uICo9F6Q4w8UHdrTbCGV5bZ
45J6K/yY6THMTdgDJTuZ7Cv1TvhseuZ5RoI3+nNcF5+t90LTnoRltxJOoKz0
1a6g+jBwDil8vpYQizslsfsP18cgXrir8EpCMpJ6+u3M6m9D79WWKSZHHsB5
fOXXAqkH8Amycin0KUHb7FWykq3FOFyyL0ZUuRLLXtlaOYU8RWPvZoks15dQ
CYyqkuh6gfPqQyJchzf4tSWrzaGiCr6qbxIrM2rxPYGxtaTfYmTvwfttXvVQ
SdvByxeth2v5dpu4/R8h0vXkoj71AXvZxsrKyEZERi/ukBxtwMXVxd6Z55rx
7eDvjJzeJohWFq8/E/QJDVqmHodqWiCzwryu49pn3Ny99PmNhlaYJZukMQlf
IaEz1Kxd8gWzBLWmJ4rboSAdV+j4og03qh5PmHigE8ObhZo2zzugP994XNHt
G6gU+ziJuk6odkp3h/p34f75tsjl774hL1vWo8jvO1Yqv8w0Le1CSPvuBtVz
3YgPnG96nPsdvvra5rcv/0DHts68utxujCRvcKXienA+/fZapegfqPe54RyQ
+hNDJnWrckJ6oLNp0VjbnV7wYBz6avtPVG/UyTa62Qd/y1OKi5f2IqPguk5X
Lg91duLPJo71Qk5ZzdMph0L9+cx9d8r68HGC+CmFMhoqqnNvCIJ5KBI/kllf
/QtruMfuBStT6AkJ/1Xx7hfsGs1/VSyhMJuNXZv34RfWrrn3WESFQkjrvedR
rb9gkSQ2eEKNwoa7Pe0mfb8QldFXfmgdhY/mjrOKxPl4pcXRGTOlwMQYR17f
xMe8M4r7BzwoLJpo8z7CnA9Gq2N48kEKdgFO8ses+UhpbemUO0yhZE9wOsee
j2XbN+es9qVwYnVRpaQ7H79F+H1bj1OY9lHlT+g5PvQeLbxkHEVBTU7a0/UV
H+un/FaryqIwI//JvYxqPiy95vpWkXWPmLkLet/xsdCD8nuVS+FNSIW/dzN5
H0FG+uN8Cm7dh06E/OTjiISaf1QxhVuF1ZevSAjwT8N7D/c1eR7n9NMaSwGi
2oN1tL9TGKRWiU7jCPDSdnc0r5vC17OfN2zdLoBLWbzBjR4Kd0s1alqcBFh4
dDiD7aNgqtTZ2O0tgFpXp95JhkIYo88bixeg5ZhXusI/CoKYoZmazQL4BOZ4
LZ5Jg2YWPF/5WYAar5vf3ORo8DibvFXaBQhovpKWKk+jW/5a9fweAR4cUBSX
V6Dx+bZOmPiQAIP3//79Mp+Gq31FP38KA41poR+/LaXhEsnZQk9l0KjhXTG4
jIZzaU9K3zQGMfExr8WW09g9d7pVtyyD1c558xRVaezo2JPdOodBOLfpuLo6
DUv3CbtfrmDALl/yolyLhsW1xMJnagxUuRsf31lPY0v18ilPVzGYwxtIOKVN
w0yVU1y6hsF4mv1nXV0aJoJUmXxdBuu/XnM8a0DDWHG9xz19Bt6Lrv+2NqRh
tPVtRY4hgxWvP+2YBRoGhf0H000YzAj3crhpREM7YMPr61sYiBs70WH/R2N9
9qd5Vy0YFApebFDfQEOr9dCRy1YMArtmbfhKrKmXqBjLYWCz5t5SNVMaq8Z/
BJ1xZLDZ0ksszYyG2uqgD+G7GFQZr1DS3kxD1WWaygknBrzk2GfVxCovtJqO
uzIYCWo41bWFhnJEhLq3JwPP1pxLfRY0/JrXhrkeYhBt0DDd2ZJG5ZKu2m1e
DOhs7swGYqeX+p76fgw22M7PuW9FI28Gr0Tdn4Gab+vqWdY0Rl2v/qd8jIGm
3TONEOIbE4TpEkEMQpedi9WzodFnk9w/GsygYCipO5FYO8XChAll8MPMOo0m
bjbM6mgOZ7BsbNwydiuNJTF2q2pOM0iTnbHmC7F/24TQ8rMMctlyb2UODdmQ
XXPSoxgwCwU92cQubyUOXL3AwD9gfFYP8YM5xcXnoxnI3H0Sv9CWxvgBN7Gw
WAa/nvRabyO2KpXZ5hvPYHmBuVUE8S3xp2lul0i9onMii4hp+0NC+0QGnO1V
Ix3EelkKxuZXGZyd5pkiZkfj/NDrWMPrDDIfbz+6nLh1o3+7RhKDVifOUTNi
lUSllUtuMTAaV7q5lziguy54djIDkZTzP4KIX2uG1EjeYaC3catlDLHc6eUK
46kM5Pp1398idvvY7C5MJ/XKm+qeQ1yodIb7I5PU9/gF6QJiUV+Nya3ZDMod
QqoeEW+tbLetvcvgiG16xP+cMv1i6tN7DI57vrF4QCxw0mEf3if9nponm01s
eL8HmQ9IP4soNCURR/+7FHP9IYPXke9jLxB/tTBuu/iIzNOThzoBxKo3+aon
uQxUZO+1OBEHUUlBR0oYLFxzxtmEuFp3c/X+x6T+R7++VyKefX5olmMZA52/
tkr/SP3cW9P2W1YwyCmPtGkk5qpsLTKqJOtJnOqQRTw5cGzi2ucMjF/7aB0j
tqvK5Sx7ycAg0bTbiFi4T4yResMgb8HF5GryfY2LCg0n1DAYdFmQHkEcN8kl
euAtqcdud3dj4lVpT1Z8ec9gXo/t7GzSP6FCj+N1H8j9tUdH7YhrjeXfPGtg
cFPKN+Yf6T/PTp992S0MUvOfZRgTl6oveJTUSvpR8/aiNtLP4ifeisZ+YXA5
y0zXnzhz/tKUox0kX1ylVRLJPHQ5fvls8pPMg3lT2B0yT1MN7LOc+0h9+1Ii
pIjXLWw4EkYxEMSFavub04j8XjP1sYDBnQyjYA0yj+qHHhtqDJN6yER1eW4i
eWWlJWk9wuDuAp+oXDLvp1Y/bDk0ysBJlp/Ts5HMy0COT7YIi4pyPyMLkg8h
oddTF0qweGm/TamR5EvmHjlvA0kWcQlHhT9J/rw3jtfbKcVik2TptCGST4vE
ohqvyLAY0iqSmUDy601MoNi0OSyOh8ukfiB5J5di7zm6glzflNlhT/LS8FSD
1pyVLKTMgwqkVtHwcLOeqK3OQrY2yK9cjUaZyqabRzRZuGzcnzdlBcnrAq06
nh6LUo0bnjsX07j/XG5NqwWLFZs+qnyYReNTevzYkBULhRA3J2WS/xMipN7O
3Mri7qipmjfZL+zMJ7vZbGOxTnRvcL80jb8NA4lVu1nUdkba3pcgefyj4U+R
Fwv64MHLvX8ohKrGBOf7sOhxLmUGf1N46Gv2L9uPBX9Wnv+/QQpzx8pEbh4j
9wf/+whLgS+f+d+pMBZJhiMD98l+dtksUM4qhkXVgYLG4RYK1TFrrm6KY8l/
YdDvzCYKY430bOMEFkefmk+xbqDg7uIyb+0VFgW2//VfrKOgG7RFec5tFqKT
/hx9+pJCZ+48jZ48FsIinRejZD+WEzY/7MhnUe7qE26WR2GLdvza1gIWt/a+
E425S6Hw5WTt2iIW7xXMNoplUDjXxjd8WM5ips6DuNzr5H9g+jOLsHcsdNMl
o6rCKQT67fOQ/8XiEmcsWteSQqQ5311XwGL9H/dO780Uri4OcHdiWcy1rMy9
tZECtzlyf+Ygi+1BfnldBhT6de+5aY2xaHK0dZJdRcFrYr/z9ulC5G9Zly8u
RWHv5ZMOVzSE6DSXDHV4xYPfYQmHx5pCxLfvO5NcycMp04Qd7euEGHx7VKP9
CQ8pw2n2S3WF2FN1MWLjQx7ad1Vt45oI4fidE152m4cdS6Zxmm2FULkWrmV9
jAcrbtIW+WNCmN8Vs1umyINHv+u4XKAQ9gc4V/vm8HB69YpHckFCCH/nDGbI
8VByt2S+XJgQujbfZktJ8rAouYmZcU4Ip9NrYhMH+zAUMf2qzBUhPv79b+BS
dR9uO5z+PpUrxM89tho+h/vAH/UMmTgkhNpKXbPZmb240xL+yOtIP97Ji6SO
Mz0Y8TBwPv63H18utxzI5XVj/r/4nb5BA6h+/fystrALPZsu1IhPGoRDism1
Va878WJpLRZcGMQ3pd1OJcZt8BTPnKQkMYTMe8FpEmhFccpigxfxQ5AtZvM4
PxpRp6f/iiPzG1cOD/4NbqrHsGeSrXPMb/SXLrm74lE13tgkb5OSH4Zq8/Oc
ldLP4Kqjn5V1eRhl3KgCHZGHSP0Ueujb/D94MmyX0cV1htq5kQaW2E+8TF7M
3xlczQA90QV/cEpeOXK5hjPexvhMUSZWt+1q6ty+BwMb9ma7Eb89McdlFLth
WmDW/ZN4qvb5AE1ZB/CiZuziL/yDwwru6Xe4NvBfH/dijFihdm1E72objHVP
VZ2u+AcXhiY1Om23xgwjsRF14q/RenuCYAn9oeGrvsTqgdlHC2Q2I8a1vWGA
+OLvk6kLuUaYLb1Tb7LSH9xoXl/vuA1ILW9JlSN+mH945zFDAxTP/uCrRczK
tfrmSeugs+7F9EDiIbv823OLVsMzxCggkrgvrtrWS38lBpaXt18jznVc65kx
bTnEz3LzSonNr0hcnVGoiIQ1mnI1xPOlex0TpyhgXmd+yGfiqpKyiIn50siM
VuvmEfdbLDrwPVMEGno55n+J1TM4WgZGJyv+H3KtWdQ=
       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-1.210788937212972*^-7, 
       0.8853401085096305}}, {{
       0, 1.5707963267948966`}, {-1.210788937212972*^-7, 
       0.8853401085096305}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd13k8VVsbB3BjKBElUoYmDZREs/y6JZkSZbyZopDIkKSQW0qTZErSrNBw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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-1.4147665351925079`*^-7, 
       0.8789388792230319}}, {{
       0, 1.5707963267948966`}, {-1.4147665351925079`*^-7, 
       0.8789388792230319}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.425303456282958*^9, 3.425303486181412*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plotg2b1", "[", "0.5", "]"}]], "Input",
 CellChangeTimes->{{3.405950987095038*^9, 3.405950998902658*^9}, {
  3.40595104799238*^9, 3.405951066285643*^9}, {3.4059514770216722`*^9, 
  3.405951518736595*^9}, {3.405951559229371*^9, 3.405951569753879*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk0VVscB3DhIYkkwkOGDBnLEEI/yRAaDEWFBpEhmcoQmkSk8swVMpU5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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-0.11847673764553744`, 
       0.1354397648577014}}, {{
       0, 1.5707963267948966`}, {-0.11847673764553744`, 0.1354397648577014}}],
    
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk01dsXAPBIkQgveiizJHMhyrAlKfQrkcpYpMhUSAqVMjaQsQzPlEzJ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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-0.17335428610029097`, 
       0.15032867003631145`}}, {{
       0, 1.5707963267948966`}, {-0.17335428610029097`, 
       0.15032867003631145`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4FWscB3CkuBJJKsruypYSoqifJELdqGwhUoQiayRyI0sp+1pZy77v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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-0.16363938280764864`, 
       0.15687800453956902`}}, {{
       0, 1.5707963267948966`}, {-0.16363938280764864`, 
       0.15687800453956902`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.405951004115321*^9, 3.405951019949992*^9}, {
   3.405951050376143*^9, 3.405951067951201*^9}, 3.405951161586254*^9, 
   3.405951315594796*^9, 3.405951520245123*^9, {3.405951562865906*^9, 
   3.4059515722468777`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Verification against the case \[Mu] = 1, \[Theta][y] = y\
\>", "Subsubsection",
 CellChangeTimes->{{3.42484949515049*^9, 3.424849552377415*^9}, {
  3.426560613866487*^9, 3.426560615269189*^9}}],

Cell["\<\
Solution for the case \[Mu] = 1, \[Theta][y] = y extracted from CH - eff1 - \
nu - 9 _compact\
\>", "Text",
 CellChangeTimes->{{3.424850582944625*^9, 3.424850639905148*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h2b", "[", "y_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"4", " ", 
     RowBox[{"EllipticE", "[", 
      FractionBox["1", "2"], "]"}]}]], 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{"3", "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "y"}], "]"}]}]], " ", 
      RowBox[{"EllipticE", "[", 
       FractionBox["1", "2"], "]"}], " ", 
      RowBox[{"EllipticF", "[", 
       RowBox[{"y", ",", 
        FractionBox["1", "2"]}], "]"}]}], "-", 
     RowBox[{"2", " ", 
      SqrtBox[
       RowBox[{"3", "+", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "y"}], "]"}]}]], " ", 
      RowBox[{"EllipticE", "[", 
       RowBox[{"y", ",", 
        FractionBox["1", "2"]}], "]"}], " ", 
      RowBox[{"EllipticK", "[", 
       FractionBox["1", "2"], "]"}]}], "+", 
     RowBox[{
      RowBox[{"EllipticK", "[", 
       FractionBox["1", "2"], "]"}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "y"}], "]"}]}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.424849646332184*^9, 3.424849652201832*^9}, {
   3.424849987082816*^9, 3.424849988382875*^9}, 3.424850127605752*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"R1", "=", 
   RowBox[{"h2b1p", "[", 
    RowBox[{"1", ",", "Flow1"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ff", "=", 
   RowBox[{"Function", "[", 
    RowBox[{"y", ",", 
     RowBox[{
      RowBox[{"h2b1", "[", "y", "]"}], "/.", " ", "R1"}]}], " ", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.424849981566661*^9, 3.424850000541365*^9}, {
  3.424850496531711*^9, 3.42485053672075*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ff", "[", "y", "]"}], " ", "-", " ", 
     RowBox[{"h2b", "[", "y", "]"}]}], " ", ",", 
    RowBox[{"{", 
     RowBox[{"y", ",", "0", ",", 
      FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.424849935675865*^9, 3.424849936194241*^9}, {
  3.424850018960696*^9, 3.424850019851893*^9}, {3.424850158682564*^9, 
  3.424850188092146*^9}, {3.424850547214411*^9, 3.424850549577952*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwk2Xk8VVsUB/BLkohMCUloIIQoQ7RIMpRMyXQNdzDPVFQkyZQkVIoUlamk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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->
   NCache[{{0, Rational[1, 2] Pi}, {-1.466125648663663*^-7, 
     6.435462501785949*^-8}}, {{
     0, 1.5707963267948966`}, {-1.466125648663663*^-7, 
     6.435462501785949*^-8}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.424850024561009*^9, {3.424850170560324*^9, 3.424850188939758*^9}, 
   3.424850551514107*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"h2b", "[", "y", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.424850052856507*^9, 3.424850106931959*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VV0bBnBJJY2GREllShS9ZMpwlzca9J4KlZKZSAqRMkeJJiEhJXOG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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->
   NCache[{{0, Rational[1, 2] Pi}, {0., 0.16968694128607817`}}, {{
     0, 1.5707963267948966`}, {0., 0.16968694128607817`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.42485007815925*^9, 3.424850108077694*^9}, 
   3.424850150504092*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution for h2b2 and g2b2", "Subsubsection",
 CellChangeTimes->{{3.390890323750639*^9, 3.39089034671313*^9}, {
  3.424781058832217*^9, 3.424781061225998*^9}}],

Cell["\<\
Because there is only only derivative in front of Scr2b2, we solve the linear \
operator L1d and we do not need to introduce an integration constant here\
\>", "Text",
 CellChangeTimes->{{3.424749421002291*^9, 3.424749491022549*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h2b2p", "=", 
   RowBox[{
    RowBox[{"Part", "[", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"L1d", "[", 
              RowBox[{
               RowBox[{"h2b2", "[", "y", "]"}], ",", "#1"}], "]"}], " ", "==",
              " ", "Src2b2"}], "/.", " ", 
            RowBox[{"mgg1", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}]}], "/.", " ", "#2"}], ",", 
          RowBox[{
           RowBox[{"h2b2", "[", "0", "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{"h2b2", "[", 
            FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}]}], "}"}], ",",
         "h2b2", ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", "1", ",", "1"}], 
     "]"}], "&"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390801023898732*^9, 3.390801055399089*^9}, {
   3.390801112757135*^9, 3.390801163045885*^9}, {3.390801256929032*^9, 
   3.390801487582233*^9}, {3.39080158066786*^9, 3.39080163264723*^9}, {
   3.390801723301243*^9, 3.390801730917677*^9}, 3.390801775524101*^9, {
   3.390801884825068*^9, 3.390801974466207*^9}, {3.390802056158044*^9, 
   3.390802090782592*^9}, 3.390802124442182*^9, 3.390808287200548*^9, {
   3.390808482408374*^9, 3.390808488706338*^9}, {3.390832670072963*^9, 
   3.390832723227988*^9}, {3.390832882722431*^9, 3.39083294357612*^9}, {
   3.390833029878882*^9, 3.390833131441482*^9}, {3.39083345612856*^9, 
   3.390833477728499*^9}, {3.390833551999039*^9, 3.390833563955723*^9}, {
   3.390833629502198*^9, 3.390833650716105*^9}, {3.390833973915081*^9, 
   3.390834034535696*^9}, {3.390834092044357*^9, 3.390834125425942*^9}, {
   3.390834165805316*^9, 3.390834180865196*^9}, {3.390834396666789*^9, 
   3.390834426476449*^9}, {3.390834470027936*^9, 3.390834470289657*^9}, {
   3.3908530954117*^9, 3.390853104393309*^9}, {3.390853962187764*^9, 
   3.390854005997462*^9}, 3.390854036047404*^9, {3.390887576182898*^9, 
   3.390887681563766*^9}, {3.390887888838058*^9, 3.390887899323179*^9}, {
   3.390888003528389*^9, 3.390888053044771*^9}, {3.390888350219621*^9, 
   3.390888362198221*^9}, {3.390889006164184*^9, 3.390889030404093*^9}, {
   3.390889929386098*^9, 3.390889934252199*^9}, {3.390890740854603*^9, 
   3.390890755943317*^9}, {3.390890829197119*^9, 3.390890861689534*^9}, {
   3.390890906201876*^9, 3.390890936673196*^9}, 3.390890988364144*^9, {
   3.390891905360502*^9, 3.390891911993486*^9}, {3.40589373710656*^9, 
   3.405893740368979*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mgg2b2", "=", 
   RowBox[{
    RowBox[{"Part", "[", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"L1d", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"g2b2", "'"}], "[", "y", "]"}], ",", "#1"}], "]"}], 
             " ", "==", " ", "Src2b2"}], "/.", " ", 
            RowBox[{"mgg1", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}]}], "/.", " ", "#2"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"g2b2", "'"}], "[", "0", "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"g2b2", "'"}], "[", 
            FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"IG", "'"}], "[", "y", "]"}], "==", 
           RowBox[{"g2b2", "[", "y", "]"}]}], ",", 
          RowBox[{
           RowBox[{"IG", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"IG", "[", 
            FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}]}], "}"}], ",",
         
        RowBox[{"{", 
         RowBox[{"g2b2", ",", "IG"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", "1", ",", "1"}], 
     "]"}], "&"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390801023898732*^9, 3.390801055399089*^9}, {
   3.390801112757135*^9, 3.390801163045885*^9}, {3.390801256929032*^9, 
   3.390801487582233*^9}, {3.39080158066786*^9, 3.39080163264723*^9}, {
   3.390801723301243*^9, 3.390801730917677*^9}, 3.390801775524101*^9, {
   3.390801884825068*^9, 3.390801974466207*^9}, {3.390802056158044*^9, 
   3.390802090782592*^9}, 3.390802124442182*^9, 3.390808287200548*^9, {
   3.390808482408374*^9, 3.390808488706338*^9}, {3.390832670072963*^9, 
   3.390832723227988*^9}, {3.390832882722431*^9, 3.39083294357612*^9}, {
   3.390833029878882*^9, 3.390833131441482*^9}, {3.39083345612856*^9, 
   3.390833477728499*^9}, {3.390833551999039*^9, 3.390833563955723*^9}, {
   3.390833629502198*^9, 3.390833650716105*^9}, {3.390833973915081*^9, 
   3.390834034535696*^9}, {3.390834092044357*^9, 3.390834125425942*^9}, {
   3.390834165805316*^9, 3.390834180865196*^9}, {3.390834396666789*^9, 
   3.390834426476449*^9}, {3.390834470027936*^9, 3.390834470289657*^9}, {
   3.3908530954117*^9, 3.390853104393309*^9}, {3.390853962187764*^9, 
   3.390854005997462*^9}, 3.390854036047404*^9, {3.390887576182898*^9, 
   3.390887681563766*^9}, {3.390887888838058*^9, 3.390887899323179*^9}, {
   3.390888003528389*^9, 3.390888053044771*^9}, {3.390888350219621*^9, 
   3.390888362198221*^9}, {3.390889006164184*^9, 3.390889030404093*^9}, {
   3.390889929386098*^9, 3.390889934252199*^9}, {3.390890740854603*^9, 
   3.390890755943317*^9}, {3.390890829197119*^9, 3.390890861689534*^9}, {
   3.390890906201876*^9, 3.390890936673196*^9}, 3.390890988364144*^9, {
   3.390891905360502*^9, 3.390891911993486*^9}, {3.40589373710656*^9, 
   3.405893740368979*^9}, {3.405951666352757*^9, 3.405951743091242*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the solution for h2b2 and g2b2", "Subsubsection",
 CellChangeTimes->{{3.390890674031211*^9, 3.390890700396829*^9}, 
   3.390892370528961*^9, {3.424781042460785*^9, 3.4247810556085777`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ploth2b2", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"h2b2p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"h2b2p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"h2b2p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h2b2", "[", "y", "]"}], "/.", " ", "R1"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h2b2", "[", "y", "]"}], "/.", " ", "R2"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h2b2", "[", "y", "]"}], " ", "/.", " ", "R3"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.390827628396154*^9, 3.390827770365142*^9}, {
   3.390827870372647*^9, 3.390827925696509*^9}, 3.390828909105881*^9, {
   3.390829601394354*^9, 3.39082964654712*^9}, {3.39082974227179*^9, 
   3.390829747713359*^9}, {3.390829810576995*^9, 3.390829829729966*^9}, {
   3.390829890404864*^9, 3.390829998743718*^9}, {3.39083004629658*^9, 
   3.39083016814121*^9}, {3.390830321786316*^9, 3.39083032700509*^9}, {
   3.39083051312603*^9, 3.390830522765489*^9}, {3.390830555834429*^9, 
   3.390830589128285*^9}, {3.390830753467661*^9, 3.390830789715912*^9}, {
   3.390831755422801*^9, 3.390832058444846*^9}, {3.3908327569219*^9, 
   3.39083285606158*^9}, {3.390887475049467*^9, 3.390887490737751*^9}, {
   3.390889434926512*^9, 3.390889475071848*^9}, {3.39088951166508*^9, 
   3.390889696051436*^9}, {3.390889754924179*^9, 3.390889766231898*^9}, {
   3.390890024236448*^9, 3.390890057082224*^9}, {3.390892504444662*^9, 
   3.390892521187431*^9}, {3.40595141340939*^9, 3.405951464048923*^9}, {
   3.405951872190446*^9, 3.405951897494011*^9}, {3.424715830120546*^9, 
   3.424715839373069*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plotg2b2", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"mgg2b2", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"mgg2b2", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"mgg2b2", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g2b2", "[", "y", "]"}], "/.", " ", "R1"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g2b2", "[", "y", "]"}], "/.", " ", "R2"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g2b2", "[", "y", "]"}], " ", "/.", " ", "R3"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.390827628396154*^9, 3.390827770365142*^9}, {
   3.390827870372647*^9, 3.390827925696509*^9}, 3.390828909105881*^9, {
   3.390829601394354*^9, 3.39082964654712*^9}, {3.39082974227179*^9, 
   3.390829747713359*^9}, {3.390829810576995*^9, 3.390829829729966*^9}, {
   3.390829890404864*^9, 3.390829998743718*^9}, {3.39083004629658*^9, 
   3.39083016814121*^9}, {3.390830321786316*^9, 3.39083032700509*^9}, {
   3.39083051312603*^9, 3.390830522765489*^9}, {3.390830555834429*^9, 
   3.390830589128285*^9}, {3.390830753467661*^9, 3.390830789715912*^9}, {
   3.390831755422801*^9, 3.390832058444846*^9}, {3.3908327569219*^9, 
   3.39083285606158*^9}, {3.390887475049467*^9, 3.390887490737751*^9}, {
   3.390889434926512*^9, 3.390889475071848*^9}, {3.39088951166508*^9, 
   3.390889696051436*^9}, {3.390889754924179*^9, 3.390889766231898*^9}, {
   3.390890024236448*^9, 3.390890057082224*^9}, {3.390891988127688*^9, 
   3.390892032076948*^9}, {3.390892333351078*^9, 3.390892377615972*^9}, {
   3.424715790852458*^9, 3.424715816508198*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ploth2b2", "[", "0.00000001", "]"}]], "Input",
 CellChangeTimes->{{3.405951910585219*^9, 3.4059519241870193`*^9}, {
  3.40610614084341*^9, 3.406106171412542*^9}, {3.406106211072358*^9, 
  3.406106213668606*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4Vd0XB/AMFX4lkkiJiFQKqUS0kAhJJUklkqFIpRTJUFHGN1IiQpKp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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-1.2844622639787058`, 0.}}, {{
       0, 1.5707963267948966`}, {-1.2844622639787058`, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVk3c81t8bxq0KibIlRQrfKEoi4ZYUUVJWg8iIbEIqo5KyQhIqWSEVZWRk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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->{All, All},
    PlotRangeClipping->True,
    PlotRangePadding->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VdsXAHBUosyZUgpX9x4RFRoeWSppMKV5QikRISI9GVKJJkSmJE9C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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-12.33251320105344, 0.}}, {{
       0, 1.5707963267948966`}, {-12.33251320105344, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.405951926419648*^9, {3.405974930989541*^9, 3.405974941565282*^9}, 
   3.406085134432457*^9, {3.406106150532683*^9, 3.406106182311337*^9}, 
   3.406106225125866*^9, 3.424715821650589*^9, 3.424715863619396*^9, 
   3.42474924859985*^9, 3.424749430631849*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ploth2b2", "[", "0.00000001", "]"}]], "Input",
 CellChangeTimes->{{3.405951910585219*^9, 3.4059519241870193`*^9}, {
  3.40610614084341*^9, 3.406106171412542*^9}, {3.406106211072358*^9, 
  3.406106213668606*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k4Vd0XB/AMFX4lkkiJiFQKqUS0kAhJJUklkqFIpRTJUFHGN1IiQpKp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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-1.2844622639787058`, 0.}}, {{
       0, 1.5707963267948966`}, {-1.2844622639787058`, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVk3c81t8bxq0KibIlRQrfKEoi4ZYUUVJWg8iIbEIqo5KyQhIqWSEVZWRk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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->{All, All},
    PlotRangeClipping->True,
    PlotRangePadding->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VdsXAHBUosyZUgpX9x4RFRoeWSppMKV5QikRISI9GVKJJkSmJE9C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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-12.33251320105344, 0.}}, {{
       0, 1.5707963267948966`}, {-12.33251320105344, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{3.424749297543513*^9, 3.424749405417442*^9, 
  3.424749525820075*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plotg2b2", "[", "0.000000001", "]"}]], "Input",
 CellChangeTimes->{{3.390892297108622*^9, 3.390892297674911*^9}, {
  3.390892393476129*^9, 3.390892401687624*^9}, {3.405893708003933*^9, 
  3.405893709311838*^9}, {3.406106243277531*^9, 3.406106249878696*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1Hk01N8bB3BE2YqIQpaxVCgqhGZ4NIniqyzfqFBSJMpaWaKkSIlsZVSy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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-0.8201342664558536, 
       0.3928895013556431}}, {{0, 1.5707963267948966`}, {-0.8201342664558536, 
       0.3928895013556431}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c41d8fAHCrKLOiRMnIKNKQFnl/UikpIyEhohDZGUmljKjo2oWse61k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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->{All, All},
    PlotRangeClipping->True,
    PlotRangePadding->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1Hk01VsbB3CcX6iEEjqnyNAtGd8M4ZJnR2RYiRQVIkOZwiGJNKhIJUmU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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-6.695842793522497, 
       2.5344026693233954`}}, {{0, 1.5707963267948966`}, {-6.695842793522497, 
       2.5344026693233954`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.390890973341443*^9, {3.390891900225972*^9, 3.390891917912607*^9}, {
   3.390892299113816*^9, 3.390892312079354*^9}, {3.390892411831379*^9, 
   3.390892433864377*^9}, 3.405893714981978*^9, {3.405893841300246*^9, 
   3.405893854960117*^9}, {3.405951752517642*^9, 3.405951792617073*^9}, {
   3.406106250907769*^9, 3.406106272709903*^9}, 3.424715882292675*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solution for h2b3 and g2b3", "Subsubsection",
 CellChangeTimes->{{3.390890323750639*^9, 3.39089034671313*^9}, {
  3.390892559129636*^9, 3.390892559754873*^9}, {3.424781091292183*^9, 
  3.424781094137512*^9}}],

Cell["\<\
Again, because there is only only derivative in front of Scr2b2, we solve the \
linear operator L1d and we do not need to introduce an integration constant \
here\
\>", "Text",
 CellChangeTimes->{{3.424749421002291*^9, 3.424749491022549*^9}, {
  3.424749570210347*^9, 3.424749577913611*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"h2b3p", "=", 
   RowBox[{
    RowBox[{"Part", "[", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"L1d", "[", 
              RowBox[{
               RowBox[{"h2b3", "[", "y", "]"}], ",", "#1"}], "]"}], " ", "==",
              " ", "Src2b3"}], "/.", " ", 
            RowBox[{"mgg1", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}]}], "/.", " ", "#2"}], ",", 
          RowBox[{
           RowBox[{"h2b3", "[", "0", "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{"h2b3", "[", 
            FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}]}], "}"}], ",",
         "h2b3", ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", "1", ",", "1"}], 
     "]"}], "&"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390801023898732*^9, 3.390801055399089*^9}, {
   3.390801112757135*^9, 3.390801163045885*^9}, {3.390801256929032*^9, 
   3.390801487582233*^9}, {3.39080158066786*^9, 3.39080163264723*^9}, {
   3.390801723301243*^9, 3.390801730917677*^9}, 3.390801775524101*^9, {
   3.390801884825068*^9, 3.390801974466207*^9}, {3.390802056158044*^9, 
   3.390802090782592*^9}, 3.390802124442182*^9, 3.390808287200548*^9, {
   3.390808482408374*^9, 3.390808488706338*^9}, {3.390832670072963*^9, 
   3.390832723227988*^9}, {3.390832882722431*^9, 3.39083294357612*^9}, {
   3.390833029878882*^9, 3.390833131441482*^9}, {3.39083345612856*^9, 
   3.390833477728499*^9}, {3.390833551999039*^9, 3.390833563955723*^9}, {
   3.390833629502198*^9, 3.390833650716105*^9}, {3.390833973915081*^9, 
   3.390834034535696*^9}, {3.390834092044357*^9, 3.390834125425942*^9}, {
   3.390834165805316*^9, 3.390834180865196*^9}, {3.390834396666789*^9, 
   3.390834426476449*^9}, {3.390834470027936*^9, 3.390834470289657*^9}, {
   3.3908530954117*^9, 3.390853104393309*^9}, {3.390853962187764*^9, 
   3.390854005997462*^9}, 3.390854036047404*^9, {3.390887576182898*^9, 
   3.390887681563766*^9}, {3.390887888838058*^9, 3.390887899323179*^9}, {
   3.390888003528389*^9, 3.390888053044771*^9}, {3.390888350219621*^9, 
   3.390888362198221*^9}, {3.390889006164184*^9, 3.390889030404093*^9}, {
   3.390889929386098*^9, 3.390889934252199*^9}, {3.390890740854603*^9, 
   3.390890755943317*^9}, {3.390890829197119*^9, 3.390890861689534*^9}, {
   3.390890906201876*^9, 3.390890936673196*^9}, 3.390890988364144*^9, {
   3.390891905360502*^9, 3.390891911993486*^9}, {3.390892562286647*^9, 
   3.390892585289459*^9}, {3.390892671813596*^9, 3.390892673137279*^9}, {
   3.405952157984441*^9, 3.405952158531342*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mgg2b3", "=", 
   RowBox[{
    RowBox[{"Part", "[", 
     RowBox[{
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"L1d", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"g2b3", "'"}], "[", "y", "]"}], ",", "#1"}], "]"}], 
             " ", "==", " ", "Src2b3"}], "/.", " ", 
            RowBox[{"mgg1", "[", 
             RowBox[{"#1", ",", "#2"}], "]"}]}], "/.", " ", "#2"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"g2b3", "'"}], "[", "0", "]"}], "==", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"g2b3", "'"}], "[", 
            FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"IG", "'"}], "[", "y", "]"}], "==", 
           RowBox[{"g2b3", "[", "y", "]"}]}], ",", 
          RowBox[{
           RowBox[{"IG", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"IG", "[", 
            FractionBox["\[Pi]", "2"], "]"}], "\[Equal]", "0"}]}], "}"}], ",",
         
        RowBox[{"{", 
         RowBox[{"g2b3", ",", "IG"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", "1", ",", "1"}], 
     "]"}], "&"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390801023898732*^9, 3.390801055399089*^9}, {
   3.390801112757135*^9, 3.390801163045885*^9}, {3.390801256929032*^9, 
   3.390801487582233*^9}, {3.39080158066786*^9, 3.39080163264723*^9}, {
   3.390801723301243*^9, 3.390801730917677*^9}, 3.390801775524101*^9, {
   3.390801884825068*^9, 3.390801974466207*^9}, {3.390802056158044*^9, 
   3.390802090782592*^9}, 3.390802124442182*^9, 3.390808287200548*^9, {
   3.390808482408374*^9, 3.390808488706338*^9}, {3.390832670072963*^9, 
   3.390832723227988*^9}, {3.390832882722431*^9, 3.39083294357612*^9}, {
   3.390833029878882*^9, 3.390833131441482*^9}, {3.39083345612856*^9, 
   3.390833477728499*^9}, {3.390833551999039*^9, 3.390833563955723*^9}, {
   3.390833629502198*^9, 3.390833650716105*^9}, {3.390833973915081*^9, 
   3.390834034535696*^9}, {3.390834092044357*^9, 3.390834125425942*^9}, {
   3.390834165805316*^9, 3.390834180865196*^9}, {3.390834396666789*^9, 
   3.390834426476449*^9}, {3.390834470027936*^9, 3.390834470289657*^9}, {
   3.3908530954117*^9, 3.390853104393309*^9}, {3.390853962187764*^9, 
   3.390854005997462*^9}, 3.390854036047404*^9, {3.390887576182898*^9, 
   3.390887681563766*^9}, {3.390887888838058*^9, 3.390887899323179*^9}, {
   3.390888003528389*^9, 3.390888053044771*^9}, {3.390888350219621*^9, 
   3.390888362198221*^9}, {3.390889006164184*^9, 3.390889030404093*^9}, {
   3.390889929386098*^9, 3.390889934252199*^9}, {3.390890740854603*^9, 
   3.390890755943317*^9}, {3.390890829197119*^9, 3.390890861689534*^9}, {
   3.390890906201876*^9, 3.390890936673196*^9}, 3.390890988364144*^9, {
   3.390891905360502*^9, 3.390891911993486*^9}, {3.390892562286647*^9, 
   3.390892585289459*^9}, {3.390892671813596*^9, 3.390892673137279*^9}, {
   3.4059521323718767`*^9, 3.4059522392708797`*^9}, 3.405952351984722*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of the solution for h2b3 and g2b3", "Subsubsection",
 CellChangeTimes->{{3.390890674031211*^9, 3.390890700396829*^9}, 
   3.390892370528961*^9, {3.424781100528051*^9, 3.424781108811784*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ploth2b3", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"h2b3p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"h2b3p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"h2b3p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h2b3", "[", "y", "]"}], "/.", " ", "R1"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h2b3", "[", "y", "]"}], "/.", " ", "R2"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"h2b3", "[", "y", "]"}], " ", "/.", " ", "R3"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.390827628396154*^9, 3.390827770365142*^9}, {
   3.390827870372647*^9, 3.390827925696509*^9}, 3.390828909105881*^9, {
   3.390829601394354*^9, 3.39082964654712*^9}, {3.39082974227179*^9, 
   3.390829747713359*^9}, {3.390829810576995*^9, 3.390829829729966*^9}, {
   3.390829890404864*^9, 3.390829998743718*^9}, {3.39083004629658*^9, 
   3.39083016814121*^9}, {3.390830321786316*^9, 3.39083032700509*^9}, {
   3.39083051312603*^9, 3.390830522765489*^9}, {3.390830555834429*^9, 
   3.390830589128285*^9}, {3.390830753467661*^9, 3.390830789715912*^9}, {
   3.390831755422801*^9, 3.390832058444846*^9}, {3.3908327569219*^9, 
   3.39083285606158*^9}, {3.390887475049467*^9, 3.390887490737751*^9}, {
   3.390889434926512*^9, 3.390889475071848*^9}, {3.39088951166508*^9, 
   3.390889696051436*^9}, {3.390889754924179*^9, 3.390889766231898*^9}, {
   3.390890024236448*^9, 3.390890057082224*^9}, {3.390892504444662*^9, 
   3.390892521187431*^9}, {3.40595141340939*^9, 3.405951464048923*^9}, {
   3.405951872190446*^9, 3.405951897494011*^9}, {3.406084984682135*^9, 
   3.406085013396489*^9}, 3.424715907571421*^9, 3.42474744516212*^9, 
   3.424749613169159*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ploth2b3", "[", "0.0000001", "]"}]], "Input",
 CellChangeTimes->{{3.406085039128793*^9, 3.406085054394031*^9}, {
   3.406106303549303*^9, 3.406106305676553*^9}, 3.406106349056363*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VV0XAHCkSJPeMlaGzKWIJC9ZSCQNGqQUIsk8JCmJSIaURJE5Tcob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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-1.838963088860246, 0.}}, {{
       0, 1.5707963267948966`}, {-1.838963088860246, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VV0XAHAhL96ilKGBSPGGIkODoYUmpSRDSrjGcMlF3HMSaSREyFSJ
UkhJKmPU3SWRZCbUNStJiXvODSnf/v44z3l+z/ln7bXXcJRcWVYeggICAv34
+f9biCPeMKjnsu2zROLEFpnhF2u/vjBQuApwYzFBtNtVcWYKNd27Eg/A1L0L
Zg/sWjnDS72mShIZIDHgr5ViN8jp3nXhVXYiC9ZqjmfE2PE47YxE1ZuJ4VC0
4dauCDshZOW7rDst8QpwRf45ct5uCUqYdHiakpgJQ2r+3WfslJFB9V5x0xOF
4C22sLNcVRf5h1i4PPUvA62MeVL1E0boeJlHnKAygnzGWQfr6u2obWSPWK7r
a3jEdC9tnTZD0Zp8gZIjtdDwckHzkfb9KEC9Nhll18P6sA8TQZcPohk3nwKu
XxM4ydeIjijZINfnhyzjj7UAr4h7szv6EHKbaEPoUhs0Sfjue6t6BF3WKmXl
RHSAku5rd920o0gQlW6+ENIJFzSzjuyYdUSL1cwbetO64b+nV94r7XVGZpmm
d34mfgKlF7Zy3HAXJDtevyu8tAd0j8nbRzW6ous1z+YJeffBI9ua1L9y7shQ
3mRO0b0f6tI0mOr7PJB636KhsKAB+GIuNaN/7Rh6eE/KqzhwEBQ6vg/PNnqi
0B7HVvWIIdhfPjycoOiNAgy3mGckDYPVVaK5k8lEM5k7XL/Ffwb2eIvpmwwf
1OR/3ZnI+gK731QKu475oq27V//l3h6BtYJ2364q+6G3O7feM07/Cm6BLscP
2bBQ9uNrWwcejMLcbUlrkwP+SFpZg+mU9w2OWmmfWfjVH7XMEz23rHIMljld
K3e5EoCKRU/kNL39DklHfyXoaQciDelFTNfqH3BAxHBbzNtANB7HX6rTMQ7f
3yhLD/qeQMqRkZos5k/4knul5JhwEBqw/9ht+uUnrAvRyS1ODUJmw63TxX4T
YJxVZXBfLxiRgR5eMt8nQG+59t7oN8HIouTGXhn2JARy+FLXGWz0Y5YZKsSf
hBKFjeTICBvd/nC2yO8ED3xXVsc5eRLoc7VWb1wwDzrQkL2PN4E0inrFHhE8
eHuvaQvhQ6CSeCPG+CkeOMw3WX2ZRaD6PdNi/hd4kJbVe+I+QaCpCn9GQDIP
DhuPbi+NJJDFLYZ4UCkPirLDRQRzCZQUJ6GXVM6D6DPDfWP3CNQV+pxRVMGD
7tumFzruE8j9yIpiisOD47T6ipwCAp2U+sAIruXBa4dFRptKCHT3gkUxu4sH
kQaFrbLVBJrxMnI++ZsHdQr5qK6fQHsr1IyD//Dgzg01E59BAt1YKKcYMMeD
7Cez9uLDBDJ8MtnrJUSBVIyfxY4RAp3+ncs4/C8F0e/iuDk/CCQUJ8XYvIKC
tWmqdcq/CbTg6RdHWp8CTnpd0JAUiRzmtxtNGFLw/uJ46sGlJHpo90r++zYK
lBfIDVRKk8hiNp07ZEqBs3VEd6wcieJ3Wjm27aXg5Mv6ATkFEi3trHR4ak+B
XUiDc+N/JJL/k3A0IISChVpfh24YkshsYH95aigFZVcXn+UakSioRkz2xWkK
Lj4Y0F0JJKpLONsifp6CuZoPr+NNSMRWCdhzN4aC3a1VD2x3kajpgOXmD+kU
LGK1e+8+QKLfuguS/2RQwID+skOWJFJZXjupfJuCxolv11wPkih0CAr8symQ
4zeNsaxJtO6k5lrxAgoGxek6hh2JzmVJLDHiUPAz+/yDGCd83sg6f7eXFDTM
KzrNYJCo0zeiIaqKglXHXxprOpNow+a/UR01FLzdPun2yoVEH999F/BvoiAx
q6y32J1EIo/znFJaKDDw4g56epBIO8WjsrKNArd5NCF9jESXnLmEWBcF85R8
5d08SaRL1//I6sf3k1I9+cabRIzuS/veDlJQdL9kgQ2TRNGcHffHhylo9VTf
/wm7L6rSw3CUgpGxdLEeHxL9yyKrXMco0D6u5G3nS6JNNrpKUT8ouH9Bs+Qd
dqxC/qf2SQr0D73m3j1OojIhL/1ZioI80L8u5keioRHltNW/KGD5CIh6Y0s2
9NJm0xRwLcpkq7D1n96wZv2mYKzncrksi0QeaXaPk/9Q0PknknsMOz5siWTl
HAX+fqdOFGJXuDb6DsyjYf33OSaF/Xl3TJ2oMA0fHgY91fYnkau5s+JaERrO
joSZMLG5FnpsE1Ea9PPSddOxD1uJ1zuK05CUxwqtxW6z7VUKWUDDxUP2ouPY
lkeKiBQJGnYOxNdIBpDonUPU+yeLaIAYwTw17F3OTsqNUjTEcz1uAPYrN52T
35bSEPefXqwF9jZP0cZ/ZGlYal7ga4ddzuSuWbOMhs6AZlV7bF2/JyHGK2hY
pMDIP4RdGBDZ5CBP433X82Uftnqwg8rJVTSwu+JqDLFzyI2hyUo0sH77b1HB
Xh0q0vJYGZ+nwVhVDPtm+EfVhrU0RCexzwzj+OXOF4aNqtJAzt+lVYGdFHGx
VUSNhuTom6ujsSWj7dcpa9Bw6bbKdivs6FjNcNhAw2yhadgSbJEE4fajWjTI
VItVvsf5PZvUpUZq05B+2mz0DPZsasGZJF0aHNPCJzWwyRvnOwo30bByavBF
M75PKuOwxvstOL47DltZ2Kys9ee+6uP4Us+bz8cezRbsnG9EQ0R8Rs9VXC/H
8j6sXw00CAk++bgceyA///w2ExpKJhnq13F9ORae7bLfToN15kzxYmybUvWL
V3fT4NSTtOIrrtemZwIfH+2hwf/b5WozbPMX7Vr15vh8L5zNbuF6N60O/yRs
SYOX+MvATV4kelFro61kRYOEVMjnINwfW+vXXTKyoUHH1uPdfdw/Wq2tOuzD
NOQFrwybxf2W33EvKtGehlELuSVy2KrdYb0FDjQEqOTlq7mRSKFfNeaLMw2S
Rx+QurhfF4yfGjjsjfMTam38wQH346TllmAfnP/dgy9zj5JIiL82LuE4DcdM
rh/2syfRzGzj1roAGqZ2bN7FxfNiRHxNgkEIjneSH7vNikTuEtOf7UJpyC/P
VK3E86d3cYNh0GkaTMeF6zfg+dQhR47kn6PBUmMwZ9KcRFUq9aAQg+vrrmPO
zx0k2hvXu1cmFtezk5qsznacL3rSVuIKDbGV0X+ZeP71vF7m+zeRhloyr/AZ
npdTrp5pPddpSBG2FuvQI9HpupA7Hen4vgTINKRDovnacQUNGbie9SYTMzeS
SGpe8esXWTSs8w001F9PIo1MwYmM+zQclijz6VEm0RMRmdmUfBp0XRJdvZRw
vv3W/XOlAOfPoyFjGM/zXUaW8uFPaPCsttpXvoxELh9v7mE8o+H9EHftSwkS
pchuzVpVR8PmwK+cDXwCrQzf91C2ngaDKbu/XZMEuvOZUSbZQIPqzldDweME
KiyOaJhrpsH4kwR1Gu+nd9ZtM71dNIyo+y5u7iKQVcWX+Z0faTCqCYmcbSdQ
5+rfi5q4NGhuPrBRtgXv7wklVdRPQ7iWoPOyOgIJxLOsb32l4eDda53m5QSK
+HXOKe0bnj/d0hnfigi0kJHiHf+dBm1di0UnCwm0fMPz8DMTNMRQmToOeF/r
1YvnO0/TENi7dNYoiUBM0RxhJTE+bDyQ/3A7E8cneCl2+798eBbg+1DDHf8v
/PGWObaQD/r/OgTOOhJofGL9fw8W8yF5/7DNgYMECvpYbK63nA9P1a24FZsI
FFZQnbhHnQ++5SrZYbNs1HMvd4Xvej4M+DellVJsZHwn6m6cJh8ETKY628bY
SDBtf0mrDh825M7ElH1io4iz7V2OhnwQ84oyUKxgo3ibYcXA/XyIHNQzsQ5k
owmLmrykA3yIXu8j/tiLjaz25GmXHuSD4s3Xxj+d2Eh62/Eds7Z8mO1JaJIy
Z6PrqrRnhBMffq6wXDaixEZ3Z4QfXWfxYWVPYHLX22BUemuNUVUCH2xb5itl
CQWjNXM7Tr28yoe21VfbdX8FoXhHj3JOMh8+3W+5XDgahLyW5+hVXsPn4xVP
uTUHoeVJqhuKb/MhO63v1cubQSg0Um1V7mM+7FbcmZqkHYRM/bTmxTTj75Nj
75ItTqAGA8Nqq8W/IO2Q+5saRgCaYt6wdo77BcdNTv3zI5eJai0zbRfKTIGc
j/DVuqcuyHWrYW5u0hQ4R8j57cmzQlmdYb798tPwbj+MlR8VQBoRM60T2B79
WyvMZQRQiQ5hIKgwDSqDXksrbs9x3sX5iytjnxKxthS8/JdD7XC7547NmlOp
jXee5ex6bDb0Bbvz0vvSh2JTnNGoJQ4/Vk3Dn7h1GxpLf3CCNsdX/cU+Mb2Y
KZP1nfN3aIG6pOI0MG1nsh0vj3GWGIvMaGJzmuvkx5xHOYb8qdQAbL3NPgvF
xD9z4lx7WilsdS/rrotl3Ry5RUcN5itNg8Oj1QeXxnZysp5/yJLG5g1O1Ga5
dHBK5ZoDNmHb/LpSxhFv4fQ1VEmS2G3LUzV55a84zFBj4hK25AnvbYpvKjnU
uuc9adjSUXfl7eWKOKIXSx6WY/elt/T5fb7ISdTWka7Dzix6INVflQor+x6F
dmM/CO+rCzV6CDmxGkOj2Lcz9CIu7CuFjQZ55r+xhWJ+5+yd4cD/AMBxUpM=

       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-391.08451062979066`, 
       0.12491289688800226`}}, {{
       0, 1.5707963267948966`}, {-391.08451062979066`, 
       0.12491289688800226`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4VV8XB3BTplAycw/KlEKTQoYlKVNFpGSIRGXKkAwlDSRDCUmSkCGF
UKZQ3Z1SKskvUpGQOSHcc++5xne/f93n85znuWftvdde37Pa3d/Wk4uDg2M/
JwfH/3+56YIt/VuPGt2ILGNVvbr+UmX0pb78TYCNaxpH3lv50GfLN3j8SLEG
F63DDolW5+iD4iep6hRXkDlzwSvAKoHeuTu6oSDFH6Qy5vPcrO7Sv7qmqN1L
uQAqOu9z7K2K6ba+Mp3pKTfAUynkzE6renrytHNFWko2aBjKpvBZfaTrN1oK
mpwuB93RcN6v/j/pAWf3Ha0IeAaXNJf75sgP0v2eeSZyKSF4EP9D06xvjN4+
YiFQ6P4GBPn+22ecMUWP38DkqD7cBKmZ14YFeEh64PqmW6igGcx3vIqwrqLo
s8d8SrtPtUIILPM+YDdPd39x0Cbp+BdAj05wcT9Zoh+bakcoth0q2q4auxZx
omsba/wfxHRAvtI/9x4nbsSFanSiz36HovJ1Io7cy5DoOquWnvROGI1RiJlp
5kXm2SZ5/1J+wlKTQQd5hh9JTTbvvlDzC5K/7Fk0NhZEGe/qOLm9esE57VbC
maXlyIDYsaTo0QfO4xlJHfeE0frelQPng3/Dqy37e3icV6DHD1edrArqh5M+
B44kRKxEEb9c2tbHDABbT0HAylEUBRroWmWlDoKU/IuZyk2r0Gy2qftY0hA0
PLys40GtQq0BGW6hucNwsjlVXOSTGNIzW7PYfX8EbB1/8KMkcfR+l95D48xR
4FTp/XN/rwQqeHJH73fxH9hZN57dJSmJJJQ0vI88GgOvlTYFLS2S6Asn/2WZ
538hjzEbeyVZClXxn37Q+n4cpIp4PfytpJGGxEpv98YJ4NNnHrk3I40mE5ni
WzomYY0cKXw/TwYpXb26wd/7H2wV2Da+Y4cs+u3Y1Wky/A+6RI7qv2uXReaD
beyqU1Mw9G2GEvaVQ2FBniclx6dA23zSf2RSDu2rvmspGTINshUJkU6naWhi
3juCmzkNem+kM9v7aOiwg5U6mzUNxXJveX37aehNxfqOCfY07HF6lsM1SEN3
vP9u6FyYhifvitw0R2jI9Ltff/myGbju6cMTPkFDdysCLI9IzMDC65TQkVka
MvcOka7VngEPg8NdymIEuv/tUuWp0zOQaj76mTIm0FDjxp7EMzOwrbRDJsSE
QBqVPQJloTMQpfrEYnongaqTDF0nz81ASpivw/BuAjVbsAUComfATThL/s0e
AlH1Aa6Bt2aga/vyJ2YOBNqX4yoYXDMD/vIxfYGnCJSaKLI1tXYGmjcOXv3g
T6AfES9cK+tnINF6fH51IIE8DstVMegzsL77l/Wn0wQKX/XN9UzTDIQynaIk
wgmUH72vKuTHDIiag79PFIFmTxq6hc/NgMBbRq7abQJZ1q8zPrOA/29wxsQ0
nUB3haUVA5dmQFpApMH1DoEMnk73nORmQMebCsebdwkUOVfo6rCcAQ6S8X1/
swnEnbjKVUeOATMWRvdPPiSQUMWwC7mdAXHfWrLOPyOQ87KvhlMGDFijG14e
XEugx4caiHEjBsDAj1jvOrze+czuARMGTA+di7d9TqCkXbYu7ZYMuHthV50Y
IpD49+fOFY4M2ONVvdLxHYGIhWSnwLMMuBYynPivnUDmv/fW3o5gwL41TO7W
rwQKficg9TKSATZGe0YedxDoQ/KlL4JRDJBTFpr1+E6gENVAi/wEBlxhKymi
LgK1WtvofMtkgGQ7l4f6bwLNaQvdWshiwPZ3zvqT2KqyTdNK9xmwO3P7qYp+
AkUMQGlAAQOUJw/3bRskkHr4BhXBUgasU837rj5CoMu5ImKGdAYcuTTX93Ic
r/fqh4BjrxhQZGba5jVBoO++MS1xrxkgSCsUFJskkJbOYlzHOwYsr1HY7faP
QF0fxzkCWhmQJG/YNDhNIG2yeSK3jwFcdrLVd1kEcu2M3fO+nwElawVd1lEE
iqebFk0OMuCXZMvmGuzeuOeeBn8Y4Pev1uMjm0DX5Ut+fp1mQGzxYnX3HO5X
s4QP/DwkeF/8XflwiUDuVm6KKrwkzKtdj5LikEfd+7aG7OAnoUrAOzwau92+
Z/VZIRK65fzaHTjlUcOxLeFj4iRsLOaQG+OSR0Yn+D/zSZHAOFfBtOSWR7Xe
3crKMiTYFL/++xC7PPBqqzNBwtZqz9WuPPLo3oUutRYVEsxEhSMrl8kj6ajy
83/USJD5JLXIwyuPUmOutPGuI+GioniCHXb89Q0XQIuE0S/zb/5g8ybzfHXa
SMI604BTW/jk0aXUH+vCNpOQf66fOIsddjeqo3wbCSt76q5y8ssjRpaDxidd
EnoNk41MsP1zNS+Pbieh5qUV4yL28UffNNcACUEc2vYU9oGa9VdumpFgMlFY
2yIgj1rrOLrKLEg4eSlWewnb6uXXjc1WJJytS8nWFJRHJo0XfvLYkNDVnWQU
jf2y6cDm1bYkqHtUnirB1mtWjzU8QIK4n9vVL9gb29q2hDjgeiJveEsvl0cl
HQ/jUhxJOFC8dpMutlrn+Z5SZxLeN4R+t8fO7bbd+vEICb6Ol44EYsv3qSUM
u5HgJmn2Kh47Y2C+l/sYCYma7xbvY0uM/LdN0ZOEO+Nz4jXYSWMPrhmcwO9L
7uL8gC00ee63gxcJYkmHX3dix07b6J7xIQFJnDg0is3NVElM9iNBKW66nsSO
ZM/2P/bH+8kxPLGEPTv/We9DIF5v9foJPiF5FMJRcGPoNAk78vNqhLGnuM8O
coWQkHtcy0IU25fPWl8hjIRdtQ9zVmGPCCon658lIY0aq///cw8R9tChCBLM
xz6li2D3iLYYBEeSYH1ecasAtqNEXkrSRRKezT5J5MTukA4bKblMAk/l3jwW
rmc/ba/R+2jcz1H1AWPYzQprUgdjSNijRmf8xDZXYo1yxpHgLCyt2Yz9WrUZ
5BNI0HK/LFWLbZnYYyl5Hdf7S1+7ALuVnLYXuUFCwLJGqxvYh1x4j/Im4/Xr
GjmHYv96I+O7mELC9dg3x1ywPTQ0Q5mpJPx3K8htB/bYTePLE2kk3PZ3s1HC
ptxPpP/KwOtV2MPVh88/8sPZvI5MEgoTvNBz7GWbE0tbskh4MMjrnYa9irPq
zctcEs7n9IXuxE4/2fS5Op8E23LV75LYCq1dnaUPcH03ZuVGcD9qZHNNZRWR
kNOntzsa+ymv5HxaCQnM8ptrrbH1Tqnz3Sgl4W+6w5AU9m5DG+LCUxJezHaN
5eJ+/5R/bG1oJQl6B/02eP6//4VCt/hXkzBnsXK3CvbRrnsWrnUkSFxePpCF
79eIyZMDh56TIHhZ9oQD9qmiN67WL0nYK/yocgV2RPjYGWggwYV57UEovq9p
Unq5Ch9IsMjILNTA9512Yc9jqWbs0+PG7Xge5A25PlvRQkLxwnhKOHZ5VUzL
0n8kVDq1HHqB58dHu/bZnh8k+C30KanjeWNbP7zsexcJHr9zdrzE8+j7mrmV
rd0knO42X7Yfe2hqtRrqI4FVlBfsj+cXR5K/Xc4oCfLxb0tvLBIohnX5SPoY
Ce3mGjWi2MKuaV5J43gepBfvT14gkKzWiwsXp0hgb3q+OW6eQFubBUvc2CSQ
XbHOTrME8uZ/wLNagAm6YZdmY0gCfeSKvb5zORNcY669/8LA+b/gJXlcmAm7
/l2Ml8OenNJcWyzKhPwd8W15eJ4Hd1VZbZVlQsNpQ9kbeP6fL21MsVjPBD0z
sTWfcH78elgo56vJhPp2usXQMIGM8+LyEzcwYSnVS2V+iEBc6Xur27YwocyJ
NkLg/Im59PWHiwETzq/qVdbrw/l5YFAxaC9+Pj5R8gHn3dS+d49SrZlwcapu
xeNvBLK1eLS5Zj8TlJOmexJwPkoY+ZnO2zOhsaK8ygjnaYYaeSLmCBOi9bXL
wj7j74dZnrIMfya8JxYi9BoJtIwc0nkRyATbxUfHe18T6PhkE+o5zYQD/G2+
UQ04DweufVEOY0Ly1YZnL+gEKv0kziy9yAT/O+squHDe1+QoG75OZsK8Dlvt
/WMCKS+Znnt1E9cTYh5nWYLrd/Gspd9iwrQIfWtTEYFOyj7Y+vwOExyTIp2e
FeLzSVXTqrrPhHP+NmY+93EeX12nUPiECVfKDvdKphJoZNDSpaCCCaufCgU4
phDI3tTnbl4VEzSKG6fvJOG85SyRyqllgl2BR63QdQL1nNVceecVE0z7ee6j
KwQyObWRM+E/JhhecznoHILrb7aBuDYmcE+prHcOJpDc+sDzV78yof1uzLVD
QQRiDD9hR/1gwqchnR/G+Hut4OiW6Yg+Juz/Etj205NA/Pbb+k9NMaEof0fH
lgMEatE3aLQVZcFhfXKbqibO72dn5naLscBGm9Z/ax2BzLaWbdKXYIGZXdoe
jrUEQlprspRkWCC17e3mxjUEqljNH8pQZAHbUnyXiDSB0vna16ZtZIFXp/xk
Kideb7Swa/xmFpyOujNavEjD88TsVqQ2C/bf/MD5Yo6GEmZrOU/oskD64C7X
TyQNRY5nd+oYswDlLqQUjNLQsTafaz+sWcCf0HNNvZWGFG0KGj7tZ8E1a+up
n8009LP5F/XKjgXGzXIVce9p6ODb/Z5Fh1gwe9tT5nMD/l6u1TE658oCRqDd
FF8VDWllc/+j+bNgZN9/+irpNER537VzS2TBvK6aTLYDDd04m8d3IYkFi347
5rkP0JBqfHH9vRQW/I6VzjtiTUP2j+qVutJYcCf25xfGLhp6Otw1Y5/Ngk7T
/17f30xDvh60VKtyFhRGUpUDAjTEHaxs7v2UBVmXZtPSeWgoI0pjPraSBXyf
J9yNl+TQ+1wDj7fP8P67r9jow5BDqn3O2jtesaBJtBep/5JDvS732rd9YcEW
Ra0H6mVyKNSvINa+nQVPayxbBR/JIZHzjw2CO1iQH/M2uDtXDhlmvsh/0smC
kIrQkINpciijsztYo58F/TsJrZQIOXTgkLzEGgYLPj9ffM+9Ww412WTbC0tS
kO3ONar5URZ5vxl8ySdNQeOTuetHX8siYV2NtVyyFJxtjS65VC+LbBVqZ5kE
BRNe9ZtjimVR1/iX7F4VCnRG2oTS42XRRDzvn4qtFAg+DlNKM5VFSYt77Ep1
KKiYlQvy0ZdFW4JuPn+oR4H5z78taptlUdhhxRv3DClQ9ZzgP6Agi7jWbte+
uosCswXl7acoGSTR6BfpaE/B9lWEhGGBDHqmWzl84BAFG0Z5WZYZMsixZNbG
+jAFe8L/NerckEFZN68qmbpQcKFENb04TAatdb/fpOmJ388vMTliIYMMltpX
cZ6hYF+gvJfIoDT6FSQXMRdCgTJjxODpN2l0aejoIBlGgdxLg1m1D9Lo7aeJ
mj8RFOTWPx2OLpVG1pn8Lu3RFPSV6doOBEsjdz2DwsJUCl6T+4JWsqRQD+xP
bE6joLZ+/s6nASnkvPv4mal0Cqa1HufpfZFCB+2Sdurfo2BMwUlTvEQKWfoN
9LQUUBDqy06LdpJC706z384UUnD06TJun91SyPSsSKl0EQVJ9zptRzZKIaOr
uhHupRSkWzcFpfNIoc33r0kzqyl83o8IhweSqKzw/pJsLQXjS/lw8bok0iit
HoJ6CoJuZ2XJBksi1freyjg6BQ3GASKJIIlkv2rvJ5ooWAwZMClvkUC3uyx0
TT5Q0N+ROVFSLoHEfx9RONGM91OcrOtJlkAik7Hj5a0U1NuZ2b/cL4G4BLrj
TH9QkAJjd4XeiqMLK6YDvLooGMwdtfPJEUfzEnwOid0UiPLNbrsZLo6Yazap
fu+j4HbG8flxNXF0Wn238EI/BWmuc9Ez82Lo3wYnxuohCrbVV0wfbxVDfwyu
NPj8wf1pknNLIUgMndiZ8SjpL67vmp+IorEYGrAoS6qawOerot3CLSSGfh38
cWRpmoJU0k+3JnMVcnKZ2KVMUvBRrMFP6ugq9P0Yt6YFi4LCWVW/8DWr0JcA
zbmUObw/xsGZcxmiyDrU5HfNAu7/GyJW9vtFUfP5Q+9/LlHgeGVknsYtiiyi
fcs5udiwSs7Ko75sJXobf+m2Kg/208YX4QdXop3JaZFWvGw4KpY9+O/vCoRu
F3sG8LNh1+jSv53ECmSYhfbcEmTD9UsXhjfoi6C6/K9b6oTY0JXDpGvtFEY6
xX9ke0TYwBTxkcncKIQqnyxx8oiyoWCB6au1IIg2PRMfXSvGBtVHec5SOQKo
9KV6614JNnQ0Xp8/J8SP1jca1QRJsSF8i/LjO1q86OFHu6zbMmyo4DjdIDjE
jVS+nLzyXI4NgX6zo0FsDpT7/bxvH8EGo7y1u2QpNl0jZrZtCjstQQWJlLHp
1VtC9bnk2WDXsSJaw5NN/5gYIKiErffU0KqjhaIzTI899MBWKXwuEHWbRd/9
xHxgGDtK6tgtyzkGvfVIoxWFHVkya2SUx6A7CplU8CuwYTxuT4aqJYPuf0L/
sjr26u+GYR9SZ+jphJaiD/a1890ussQ0/U+cmPMEts8ZRhv93zg9WCfp9SJ2
XEvX02BinL44ILR+hSIbMirDrMbN/tLFjHlnN2BbSTbTt6X9oRswqduB2NMN
Y5F10sP0RPdfbQzsulm3wv6zPXTplU76y1az4eFAXx1/ajc998W3XAnsuq2b
EkSLuug10v8FbsMOy9bQOfPpG7235fWKMOydpVOi0uOf6d4RxqGx2G8e2uTG
sz7SGeovfqVj8+bTnjYtvqPzX6l+XIutXdS+3WsZoqds3iLxAdtMT/OWx/Jn
dFpvWUQndvg+rkxVgXL6g+saA3+wI6/f4xURzKFv0n9kNYetXloUNaScb/Q/
gUWhEw==
       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-7.511789808557585, 
       6.003422251174583*^-7}}, {{
       0, 1.5707963267948966`}, {-7.511789808557585, 6.003422251174583*^-7}}],
    
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{3.424749596111721*^9, 3.42474964292693*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Plotg2b3", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"mgg2b3", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"mgg2b3", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"mgg2b3", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g2b3", "[", "y", "]"}], "/.", " ", "R1"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g2b3", "[", "y", "]"}], "/.", " ", "R2"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"g2b3", "[", "y", "]"}], " ", "/.", " ", "R3"}], " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.390827628396154*^9, 3.390827770365142*^9}, {
   3.390827870372647*^9, 3.390827925696509*^9}, 3.390828909105881*^9, {
   3.390829601394354*^9, 3.39082964654712*^9}, {3.39082974227179*^9, 
   3.390829747713359*^9}, {3.390829810576995*^9, 3.390829829729966*^9}, {
   3.390829890404864*^9, 3.390829998743718*^9}, {3.39083004629658*^9, 
   3.39083016814121*^9}, {3.390830321786316*^9, 3.39083032700509*^9}, {
   3.39083051312603*^9, 3.390830522765489*^9}, {3.390830555834429*^9, 
   3.390830589128285*^9}, {3.390830753467661*^9, 3.390830789715912*^9}, {
   3.390831755422801*^9, 3.390832058444846*^9}, {3.3908327569219*^9, 
   3.39083285606158*^9}, {3.390887475049467*^9, 3.390887490737751*^9}, {
   3.390889434926512*^9, 3.390889475071848*^9}, {3.39088951166508*^9, 
   3.390889696051436*^9}, {3.390889754924179*^9, 3.390889766231898*^9}, {
   3.390890024236448*^9, 3.390890057082224*^9}, {3.390891988127688*^9, 
   3.390892032076948*^9}, {3.390892333351078*^9, 3.390892377615972*^9}, {
   3.390892633722047*^9, 3.390892656427548*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plotg2b3", "[", "0.5", "]"}]], "Input",
 CellChangeTimes->{{3.390892297108622*^9, 3.390892297674911*^9}, {
  3.390892393476129*^9, 3.390892401687624*^9}, {3.390892665725964*^9, 
  3.390892666228182*^9}, {3.390898448317875*^9, 3.390898454344493*^9}, {
  3.405964549385953*^9, 3.40596458117431*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk0VV8bB3BTZkmGooSUZExRRD0ZIqlQ0YCSoWQqlGRIinPkZyapjJUp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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-0.011641662218597427`, 
       0.011327915171995911`}}, {{
       0, 1.5707963267948966`}, {-0.011641662218597427`, 
       0.011327915171995911`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk0Ve0XB3AkNCCVRK+5QZEG82vYQsYGEiopQzL0pi5JoZkokQxpdC9l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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-0.1135693541981864, 
       0.1246452671748403}}, {{0, 1.5707963267948966`}, {-0.1135693541981864, 
       0.1246452671748403}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk01U0YB3Dk5SraKcoeWaKUNfQIUVqQJFt5tUmlLFHRTkpe2deyxLVm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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-0.07488446291683808, 
       0.07931317034365395}}, {{
       0, 1.5707963267948966`}, {-0.07488446291683808, 0.07931317034365395}}],
    
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.390890973341443*^9, {3.390891900225972*^9, 3.390891917912607*^9}, {
   3.390892299113816*^9, 3.390892312079354*^9}, {3.390892411831379*^9, 
   3.390892433864377*^9}, 3.39089271505113*^9, 3.390898345067449*^9, 
   3.4059523723043118`*^9, 3.405964371101464*^9, {3.405964545171821*^9, 
   3.405964591633886*^9}, 3.405964641555265*^9, 3.406085109140552*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Contributions to the turbulent viscosity", "Section",
 CellChangeTimes->{{3.390899697333582*^9, 3.390899717451183*^9}, {
  3.42474971363569*^9, 3.424749738466436*^9}}],

Cell[CellGroupData[{

Cell["Contribution of the zero and first order terms", "Subsection",
 CellChangeTimes->{{3.390934035318733*^9, 3.390934066689117*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Term", " ", "in"}], " ", "<", 
   FractionBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
    SqrtBox[
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]], ">"}], ",", 
  " ", 
  RowBox[{
  "in", " ", "factor", " ", "of", " ", "A", " ", "C"}]}]], "Subsubsection",
 CellChangeTimes->{{3.390934090307262*^9, 3.390934092425826*^9}, {
  3.390934553796169*^9, 3.390934598743944*^9}, {3.390934647435653*^9, 
  3.390934651051157*^9}, {3.390934817409546*^9, 3.390934820407151*^9}, {
  3.424749761269517*^9, 3.424749769902*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"I1", "[", 
   RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], " ", ":=", 
  RowBox[{
   FractionBox["2", "\[Pi]"], 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Tra", "[", "\[Mu]", "]"}], " ", "/.", " ", "Flow"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390934659402538*^9, 3.390934778880406*^9}, {
  3.424878767270785*^9, 3.424878831194323*^9}, {3.42487901397307*^9, 
  3.424879016281162*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["How does it look and example", "Subsubsection",
 CellChangeTimes->{{3.42478126189989*^9, 3.424781273271839*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p1", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Tra", "[", "#", "]"}], " ", "/.", " ", "Flow1"}], " ", ",", 
        
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Tra", "[", "#", "]"}], " ", "/.", " ", "Flow2"}], " ", ",", 
        
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Tra", "[", "#", "]"}], " ", "/.", " ", "Flow3"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}], "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"p1", "[", "0.5", "]"}]}], "Input",
 CellChangeTimes->{{3.405967310740175*^9, 3.405967435955467*^9}, {
  3.405967466854363*^9, 3.405967537598727*^9}, {3.405967666408267*^9, 
  3.405967670604388*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd1nk4VV0bBnBTJVF5S4MylAYyNAovdUsZKxkqZSgpkahQKVGpUIqEipJ5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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0.8},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0.7071067811865495, 
       1.9999999999999987`}}, {{0, 1.5707963267948966`}, {0.7071067811865495, 
       1.9999999999999987`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxF13k4VN8bAHAka4y9okUpkSV7KrxDQpQ1tNgVoUQJWStlS0IIlS37ljVk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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 1.},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0.7068319436531837, 
       3.9999999999999867`}}, {{0, 1.5707963267948966`}, {0.7068319436531837, 
       3.9999999999999867`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c81d8fB3CrLhL5Sck3IxqSRFllvD9UZiGyyigNQkLZK6VQyEqS7JWy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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 1.},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0.7071067811865476, 
       2.9999999999999942`}}, {{0, 1.5707963267948966`}, {0.7071067811865476, 
       2.9999999999999942`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.405967333044793*^9, 3.405967341446525*^9}, {
  3.40596741202334*^9, 3.40596743659015*^9}, {3.405967515664612*^9, 
  3.405967543563504*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I1", "[", 
  RowBox[{"0.5", ",", "Flow1"}], "]"}]], "Input",
 CellChangeTimes->{{3.390934784914485*^9, 3.390934794907011*^9}, {
  3.405967142493556*^9, 3.405967165270087*^9}}],

Cell[BoxData["1.399199201290621`"], "Output",
 CellChangeTimes->{
  3.390934796759899*^9, {3.405967137497263*^9, 3.405967166057699*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Term in < g1[y] Sin[\[Theta][y]] >, in factor of  -",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{" ", "A"}], "C"], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.390934831537264*^9, 3.390934869753419*^9}, {
  3.424749852429428*^9, 3.424749883952116*^9}, {3.424752330401788*^9, 
  3.424752341209107*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"I2", "[", 
   RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], " ", ":=", 
  RowBox[{
   FractionBox["2", "\[Pi]"], 
   RowBox[{"NIntegrate", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"g1", "[", "y", "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", "/.", " ", 
       RowBox[{"mgg1", "[", 
        RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}], " ", "/.", " ", "Flow"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.39093487666101*^9, 3.390934931546866*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["How does it look and example", "Subsubsection",
 CellChangeTimes->{{3.424781388169448*^9, 3.424781399419855*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p2", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"g1", "[", "y", "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", "/.", "R1"}], 
          " ", "/.", " ", "Flow1"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"g1", "[", "y", "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", "/.", "R2"}], 
          " ", "/.", " ", "Flow2"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"g1", "[", "y", "]"}], " ", 
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", "/.", "R3"}], 
          " ", "/.", " ", "Flow3"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"p2", "[", "0.5", "]"}]}], "Input",
 CellChangeTimes->{{3.40596784096609*^9, 3.405967973064653*^9}, {
  3.405968017498025*^9, 3.405968029746004*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk41UsYB/CkK0l7KsoWSZY2a+F8hUhuRYqylV1ElkqJRIk2WSIpW9lK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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 1.1758807047331121`}}, {{
       0, 1.5707963267948966`}, {0., 1.1758807047331121`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd1nk4VWsbBnBTkVIhijJTylCKJHJLUhIpoWJXlDJExpSkJFPkIBmPqTIP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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 1.5648631058076288`}}, {{
       0, 1.5707963267948966`}, {0., 1.5648631058076288`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwd1mc81u8XB3ArkZEGIYpUZBdKGR8/SUVFAw1UpESRXaJQRmnIKkSEyIrs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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 1.446312933603259}}, {{
       0, 1.5707963267948966`}, {0., 1.446312933603259}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.405967729413082*^9, 3.405967908330491*^9, {3.405967938817933*^9, 
   3.405967974499836*^9}, 3.405968031993293*^9, 3.405968203959248*^9, 
   3.405973094352774*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I2", "[", 
  RowBox[{"0.5", ",", "Flow3"}], "]"}]], "Input",
 CellChangeTimes->{{3.390934959561856*^9, 3.390934967651764*^9}, {
  3.390935003469356*^9, 3.390935003824377*^9}, {3.390937086441985*^9, 
  3.390937107332823*^9}, {3.406084093017435*^9, 3.406084122268006*^9}}],

Cell[BoxData["0.7984046584677946`"], "Output",
 CellChangeTimes->{
  3.390934968773633*^9, 3.390935004929893*^9, {3.390937090852147*^9, 
   3.390937109314876*^9}, {3.406084096767598*^9, 3.40608412451083*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Term in < g1'[y] Cos[\[Theta][y]] \[Theta]'[y] >, in factor of  - ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"A", " ", "D"}], "C"], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.390936851947116*^9, 3.390936889610799*^9}, {
  3.424749994018899*^9, 3.424749997783638*^9}, {3.424750028766831*^9, 
  3.424750047688335*^9}, {3.424752346548456*^9, 3.42475235735962*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"I3", "[", 
   RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], " ", ":=", 
  RowBox[{
   FractionBox["2", "\[Pi]"], 
   RowBox[{"NIntegrate", "[", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"g1", "'"}], "[", "y", "]"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], 
        RowBox[{
         RowBox[{"\[Theta]", "'"}], "[", "y", "]"}]}], " ", "/.", " ", 
       RowBox[{"mgg1", "[", 
        RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}], " ", "/.", " ", "Flow"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390936900694564*^9, 3.390936921635734*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["How does it look and example", "Subsubsection",
 CellChangeTimes->{{3.424781458348234*^9, 3.424781467711331*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p3", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"mgg1", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"g1", "'"}], "[", "y", "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
            RowBox[{
             RowBox[{"\[Theta]", "'"}], "[", "y", "]"}]}], "/.", "R1"}], " ", 
          "/.", " ", "Flow1"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"g1", "'"}], "[", "y", "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
            RowBox[{
             RowBox[{"\[Theta]", "'"}], "[", "y", "]"}]}], "/.", "R2"}], " ", 
          "/.", " ", "Flow2"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"g1", "'"}], "[", "y", "]"}], " ", 
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
            RowBox[{
             RowBox[{"\[Theta]", "'"}], "[", "y", "]"}]}], "/.", "R3"}], " ", 
          "/.", " ", "Flow3"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"p3", "[", "0.5", "]"}]}], "Input",
 CellChangeTimes->{{3.40596784096609*^9, 3.405967973064653*^9}, {
  3.405968017498025*^9, 3.405968029746004*^9}, {3.405973217071289*^9, 
  3.405973306850355*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc41t0fB3DkMUo7GUVGMpqyw/cthdCwJSNZmWXGIylCg+yMyurJLKtk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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 1.0991611163004196`}}, {{
       0, 1.5707963267948966`}, {0., 1.0991611163004196`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8ld8fAHDKuBRKSGRESUZkF/f5XL6SUWY0kCiZZWSUWXZLiLKyslf2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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-1.1058078370992316`*^-38, 
       3.1207239921699035`}}, {{
       0, 1.5707963267948966`}, {-1.1058078370992316`*^-38, 
       3.1207239921699035`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k0VV8fBvBrCJmiqJAhTUIpQ2Q4z00qQyFjkQZliCKzDBUSKTJTmSMy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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 2.0944618421523646`}}, {{
       0, 1.5707963267948966`}, {0., 2.0944618421523646`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.405973222565979*^9, 3.405973316926511*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"I3", "[", 
  RowBox[{"0.5", ",", "Flow3"}], "]"}]], "Input",
 CellChangeTimes->{{3.390936952348787*^9, 3.390936980949509*^9}, {
  3.406084081109793*^9, 3.406084081738611*^9}, {3.406084131576004*^9, 
  3.406084135456602*^9}}],

Cell[BoxData["0.7937146620258568`"], "Output",
 CellChangeTimes->{{3.39093697151341*^9, 3.390936982633417*^9}, 
   3.405973327709433*^9, {3.406084073815799*^9, 3.406084084462347*^9}, 
   3.406084137366523*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition : the famous function G ", "Subsection",
 CellChangeTimes->{{3.390899721647328*^9, 3.390899740854059*^9}, {
   3.424750240874121*^9, 3.424750251114017*^9}, 3.424750809524071*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"G", "[", 
   RowBox[{"y_", ",", "\[Mu]_", ",", "Flow_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"2", 
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], 
    RowBox[{"Cos", "[", 
     RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}], 
       RowBox[{" ", 
        SqrtBox[
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           SuperscriptBox[
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"Cos", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}], "2"]}]}]]}]], "+", 
      RowBox[{
       FractionBox["1", 
        RowBox[{"2", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Mu]", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"Cos", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Mu]", "  ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "-", " ", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{
            RowBox[{"\[Theta]", "'"}], "[", "y", "]"}], "2"], " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{
            RowBox[{"\[Theta]", "'"}], "[", "y", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}], 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}]}], ")"}]}]}], 
     ")"}]}], " ", "/.", " ", "Flow"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390932812046382*^9, 3.390932874060859*^9}, {
   3.390932909444059*^9, 3.390932929499487*^9}, {3.405973638443369*^9, 
   3.4059736415786*^9}, 3.424750265219801*^9, 3.42475045165173*^9}],

Cell["\<\
One can easily check that this expression is identical to  the following one, \
\
\>", "Text",
 CellChangeTimes->{{3.424750778986778*^9, 3.424750831701616*^9}, 
   3.426560715273539*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}]}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]", "+", 
         RowBox[{"2", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}]}], 
      "+", 
      RowBox[{
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
             MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], " ", 
       
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], 
   ")"}]}]], "Definition",
 CellChangeTimes->{{3.405973884020123*^9, 3.40597389403785*^9}, {
  3.405973955326855*^9, 3.40597399995483*^9}, {3.424750741451124*^9, 
  3.424750769137054*^9}}],

Cell["or this one taken from CH - eff1 - nu - 8. m6.nb", "Text",
 CellChangeTimes->{{3.424852015153836*^9, 3.424852018394565*^9}, {
  3.424852070380079*^9, 3.424852095806764*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "[", "y", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox[
        RowBox[{"Cos", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", "\[Mu]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], " ", 
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "y", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Sin", "[", 
             RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"Sin", "[", 
               RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"]}]}], ")"}]}], 
         "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Cos", "[", 
            RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "3"], " ", 
          RowBox[{
           SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}]}], ")"}]}],
    ")"}], "/", 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
   RowBox[{"3", "/", "2"}]]}]], "Definition"],

Cell["or this one in the paper", "Text",
 CellChangeTimes->{{3.424924472922214*^9, 3.424924501934907*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Cos", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], "2"]}]}], ")"}], 
     RowBox[{"3", "/", "2"}]]}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], ",", "y"}], "]"}], "4"],
       ",", "y"}], "]"}], "+", " ", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"D", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], "2"], ",", "y"}], "]"}], 
     
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", 
        RowBox[{"Sin", "[", 
         RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", "2"}], "}"}]}], "]"}]}], "-", 
       SuperscriptBox[
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "y", "]"}], "]"}], ",", "y"}], "]"}], 
        "2"]}], ")"}]}]}], ")"}]}]], "Definition",
 CellChangeTimes->{{3.424924408101912*^9, 3.424924464009442*^9}, {
  3.424924576324092*^9, 3.424924612572983*^9}}],

Cell[CellGroupData[{

Cell["Plots", "Subsubsection",
 CellChangeTimes->{{3.424781533112011*^9, 3.424781533512595*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotG", "[", "\[Mu]_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"G", "[", 
         RowBox[{"y", ",", "\[Mu]", ",", "Flow1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"G", "[", 
         RowBox[{"y", ",", "\[Mu]", ",", "Flow2"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"G", "[", 
         RowBox[{"y", ",", "\[Mu]", ",", "Flow3"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"y", ",", "0", ",", 
          FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.390932958121773*^9, 3.390933129890848*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotG", "[", "0.0000001", "]"}]], "Input",
 CellChangeTimes->{{3.390932883907116*^9, 3.390932939805545*^9}, {
  3.390933143617531*^9, 3.390933149522216*^9}, {3.406105781849006*^9, 
  3.406105784448065*^9}, {3.406112764919405*^9, 3.406112769504617*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1Xk0Vd0bB/BQaFSkpISUBlKR8JJHilIUil4VGRKpTCUSbzSRSlxSKXqp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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-1.9999628929505395`, 0.}}, {{
       0, 1.5707963267948966`}, {-1.9999628929505395`, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VF8bAHBrtNrNkD2VXyRJpPBEEq2ylSJLlkKiZAspZS1JikhEtpSy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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-6.051650449965183, 0.}}, {{
       0, 1.5707963267948966`}, {-6.051650449965183, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk4lF8bB3C7mUfZQpJKpRSSX0q0uCOhpE1aKSnJTiVlaZEiIilLKFGW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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-3.3863420707854046`, 0.}}, {{
       0, 1.5707963267948966`}, {-3.3863420707854046`, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.390932947681147*^9, 3.390933151656854*^9, 3.405974076383745*^9, {
   3.406105784977708*^9, 3.406105791622698*^9}, 3.406112771076172*^9, {
   3.424750907786127*^9, 3.42475091936217*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Contribution of the terms in f2b", "Subsection",
 CellChangeTimes->{{3.390933654621255*^9, 3.390933665013702*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution < h2b1[y] G[y] >, in factor of   2 ",
 Cell[BoxData[
  FormBox[
   FractionBox["A", "C"], TraditionalForm]]]
}], "Subsubsection",
 CellChangeTimes->{{3.390933194868613*^9, 3.390933227475682*^9}, {
  3.424750405650175*^9, 3.424750410408307*^9}, {3.424750935913244*^9, 
  3.424750970512442*^9}, {3.424752372361383*^9, 3.424752382436232*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ib1", "[", 
   RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["2", "\[Pi]"], 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"h2b1", "[", "y", "]"}], " ", 
       RowBox[{"G", "[", 
        RowBox[{"y", ",", "\[Mu]", ",", "Flow"}], "]"}]}], " ", "/.", " ", 
      RowBox[{"Evaluate", "[", 
       RowBox[{"h2b1p", "[", 
        RowBox[{"\[Mu]", ",", "Flow"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390933243836283*^9, 3.39093340537776*^9}, {
  3.390933459516095*^9, 3.390933466189825*^9}, {3.390933509203082*^9, 
  3.390933509740634*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["How does it look and example", "Subsubsection",
 CellChangeTimes->{{3.424781613765307*^9, 3.4247816313243713`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"p2b1", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"h2b1p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"h2b1p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"h2b1p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"h2b1", "[", "y", "]"}], " ", 
           RowBox[{"G", "[", 
            RowBox[{"y", ",", "\[Mu]0", ",", "Flow1"}], "]"}]}], "/.", "R1"}],
          " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"h2b1", "[", "y", "]"}], " ", 
           RowBox[{"G", "[", 
            RowBox[{"y", ",", "\[Mu]0", ",", "Flow2"}], "]"}]}], "/.", "R2"}],
          " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"h2b1", "[", "y", "]"}], " ", 
           RowBox[{"G", "[", 
            RowBox[{"y", ",", "\[Mu]0", ",", "Flow3"}], "]"}]}], "/.", "R3"}],
          " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.40596784096609*^9, 3.405967973064653*^9}, {
   3.405968017498025*^9, 3.405968029746004*^9}, {3.405973217071289*^9, 
   3.405973306850355*^9}, {3.405974183693894*^9, 3.405974407606592*^9}, {
   3.405974510489808*^9, 3.405974523520543*^9}, 3.406105641695412*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2b1", "[", "0.00000001", "]"}]], "Input",
 CellChangeTimes->{{3.40596784096609*^9, 3.405967973064653*^9}, {
  3.405968017498025*^9, 3.405968029746004*^9}, {3.405973217071289*^9, 
  3.405973306850355*^9}, {3.405974183693894*^9, 3.405974407606592*^9}, {
  3.405974510489808*^9, 3.405974523520543*^9}, {3.406105641695412*^9, 
  3.406105669679151*^9}, {3.406105701278578*^9, 3.406105726459983*^9}, {
  3.406105918856463*^9, 3.406105921709215*^9}, {3.406112798847788*^9, 
  3.406112813228948*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc8V+8XAPBLkqRB0bRLymqQFB3hZzaUqMyiCMkq+lpNo5RkRMgqIyJC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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-2.1101579231049183`, 0.}}, {{
       0, 1.5707963267948966`}, {-2.1101579231049183`, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8VG8XAHD7jKWUIkSWLCUpZKnoFJKlSIWEZCklhCwt0iZK/WxRKlvJ
lsi+z32uLbIlVJYsM2NLkSwzl6L3vv/MfL6fmXnmnHPPOXNHzuXSsbNcHBwc
F8iH/z9zI4F2ppbzPtn3Gi/W1G2kKX7H9m56DHD7b4WNkcNXbCl/h1tvrCWk
L9136bdnYwUs+Lw2zxYG89mdKocE0Oj680RprBOc6SqSTrTfgB5JNK3Kq3IF
kcy7TXdAHmVscUjhyHMHa9tEj1FjFYTrzOw8nnoRtFbd+0bQ1VGfcWhteuwl
MHZztLOy10FLKkIqwbW+8DGly+RqlD4K1/jil151GaJaSwq1wQCt35Na1V4c
AHtOP+MWXW+MXh7w4CFyg0BvNz3G2tgMqZnuOiKXeRXOnpVTZn22QFVHV+LN
Uq/DR7v+7dfoVuizU6xyUuxNuPpeIfzmKVtUoKmmy2y4BU+abjC5HE+hIJ3H
34Jqb8Pmah2zHZGOiAccFV9W3YWvDjfV9+1zQc0GtR+0ykPh3tavpa1SbijG
WNm7ufgedGpwS74VOYc2WfwuncsNh2DjQTM7Iw80YmVjf//NffjhEkpXuOWJ
cqyr/kllPoCu25MTel3eSNfxnolx6kNQumCXkzHki455SvQlxEbBoWh71bO2
QUhIF9CTQ9Hwopy5x6PzCpqp8F1Lb4iGC2t2/hK2u4ZKaV9KAmpjgIfHW3DP
gxvIsCF1JbnqMTzK2Rt2Zc8dpHSo6+j33XHQ9Gux1FfpLhL4wJumWR4HU/+u
5+qIh6KOVo9DTcXxYBOz+4fyqjDk2L0r+nfuUyi6XLcYoReB9tu4M/aqJsAM
6zet3+YhUuh5tivsTQI8C/jFmg98hCb7V3okM5+B9w2JsyFNkSiI2SRnlPoC
ZPiUfnr1xKCYWYeiJ7EpULgpbJuY+VP0n+hzPXxVKgDrjYO+WALqLLgno3Us
FYq8ZCTqRxKQ/aTD6Kb+VPCRf6Ux/fA58rYX9J39+RKWpG09MriSUZz++fvP
1rwGF7EX4k+aXqHe3uMXV1uT5pz9xGuahjYFgsXdZ68hFDZ8kW1JQ5l5Yuu9
5NPhk+Df67bdr1GlTEPK/l0ZcHNeWB1bykBDnPJl47ZZQJMruab4NAcpJK96
7pCYBcirYEpO4y06v2cx+NNwFvQUvtpa3/4Wzfp1GFRdyIasYdcrhFAe4hkJ
aY+8/gYeS/i3R1jkI5X3/aNaKW9BhUeHf4S3CO1tMBMwuJwPG0J3/eJZU4HW
dGd81HmcD4eU7/154lOBRhhc8duL8mHbycDWvk8VKJKjSkZiLh/efR+fDHxS
iRh7t2nN+BXAj9Re8z/K1eh+oeCZZL9CYMTZLvN4IvQlpbVkybcYvp0SFDbe
W4dy8rZcn4kphvWNXfsCAuvQLVro/rGCYjB3dytaLKhDW/v1Wj79LobUCwd/
cKrUo2Cx3OEs3xJwxySFhTY1oM3//Sdo61sKbVNXT0+KNiKfaxbORT7lcOXb
1YEhwxZk5q2XRY0uByLRw1H8fgva7KLyy/FdOZx8EZ2b3NqCvpjy3aBOl0Nk
1ah6nE0r0pfAEhwvVoBo77bJTd5tSKB8ewflXCXYR8Y8fZzzEaUvCIGDfTVM
hNWsub6jE3mVn43k2oyDskig6D3Lr+Q8W8ly7sLBNSvdyjfkK5rp1Sv8Z4SD
5lXmzXu5X5H/n3Vf/p7DgatKxEBRqAdd21crzX6Dw45NsgehpQeF1W/K/aFR
A9PqHXr1R/tQasfXlm6DWoj9U3/g4JUB1D1hyp/pUg8zIhv+05dgoIgdLI5S
uyYwO4LJWFG+I99tTfF4eisc4OJJC0+bQUuuF/MGvDuAXyC2L+rHPHKh2RyN
PtcJZ6fOTOQvE8j1dzeO3++GrvZPO1zsltGjnWWXMsK+gHhTJZWVzIFz4WU6
odd6YESH78t7Ny58rYp5+1BCH9D7TOyEpXnwMUrK2qbUPnC9E3SSZzMPXjk6
eyI/qw+GMq9VLmzhwd1ePu+/Vd4Hk5UGyW27ePBy8ckJuZ4+kO3akWV1mAc/
TXnA7bahH0astcezrvHgb0fe607E94O1gEzMvW4e3CTFIG0m9hvkBRytiAjm
xcObOgbuvPgG/TFDxXO3efH3v0+Li77+BnVNAnTbcF78oNH1/3aXfIPNeqO1
a2N5cYPvRUF3vn6DwitKl80zeXE9TcXD66UGwLOHVdfdwYvvbKQs6KQPgGnd
xyp1WT780kz8jubcAeAgFlb+KvDheRIKHg6lA5A0raJdt5UP3+65f+hW4wD4
pHFe26/Jh6usvfrhw/cB4Jn9vGXlIB+uYD+ZZK82CMtMoYpQDz58w69W45tl
g3AlNosoeseHJ8Qg5+9oEP41P7RqLOLDxXcVBh9vGoS+ErGUz2Wkrz4tVO4d
hIFd+9YxER8uye2yqWNpELYHq++r+ciHb9rAXpDdNwRx9ttePJjmw5VALr22
fggS/hhNG2yh4Bn0dbhq2xC4HOYqLtxGwZVC+fqffB6CqMH3h6V3UHDlDz/W
XBwbAv/U+TmGFgWP22qP8fMMQ+hlT86dhhT8SZGiSqHiMDQUx53rcKDgzxsr
ObkvDEOYKo+T4iMKPjOcf/WX5zBMu1F3YZEU/NBSxu9+n2GQ5w8JOBZDwedV
H9OLrwzD8RMb9byeUHCL2Is15+4PQ6qqUtvFVArO5Sh1uzlzGA4s1OQ+KqLg
JwNFFktzhqGn3lj6WwkFfxdF9U17Nwx2zTlzSuUU3KF2/kxw2TBwJ/7tyqum
4KXKbfvVGoehqPmafXgDBb84e4MjdmwY+HcNH7P/QsFrBf2vhEwOw/eNaJ1z
DwUXV/SY8Zgeho0HBXVd+ij4e1ubYUPWMMxznXxjM0jBZWlq+AIvHYzP7dSg
jlHw7vChm3aKdHgeJlbx3zwFV3n5mX1wKx2QdWeaKYuC365suaSxnQ5Zuckz
HAQFV5sqcxLUokPoX7t85z8U/P6xaKAZ0UHkm1vTD04qrid94J+sGx0O8Lc4
y6+m4iYO3X4u5+nAzG27XyRMxU+8cB9L86QDUbrPANZS8YsSkW1KAXQI1ODw
Ml5PxZ+L9r9QDaND6VxmxjpJKp5xwlvYO4IO/aG5Z69upOKFjznvvoukw+VN
keW9UlT8w9otHhpP6cD+2ioZIUPFiVUBurpZdMhWsOrJVqDiPEeob6++pYP0
RVX9EUUqvubRC5mqfDqc6+XSlVCm4soCtXz7KuhwXWp0xm8rFbfhE/5s2Ey+
P3/2yuh2Ku5y8JXJvXY6eMZRns6rUXHvUK3q95104BwbPbKyg4rf43JIM+2n
Q5Las3BODSpevJLla/mTDqNDWdqNWlQc19cbjZ6hQzq9XilHm4q3Bn882TlP
h12PFIoe6FBx5tICWC/Twe1B8ivt3VR8eveDoiecDKixLOPj3UPFl65IKffw
MkDo9Rr+dtIibIPV9qsZYDKQPGmpR8U3aX+5nSjCgF7j8WaqPhVXCbiwMCDG
AM2DT82rSR+Yi/p2RoYBXd2+O9cBFff59e3NuZ0M4GPdSLh1gIoHq/lsytrF
gNazjo9WG1Dx+17csd91GaD89pLiU9IpP7Ze9TzAgJXQOtMEQyr+RoX2M/cg
A2wnbL6sMaLipReOnvllyoCnNbhAKOn28cBDfscYcOvlV69TB6l4n5JAVZEN
A45MTybRSI+eTVJbOMWAd3teXtloTMVnXu98pe3EgIM8xSuXSf9l1olecWXA
n6NDOxtJUzfbPqhwJ+PLpQuLHqLi610m/y5dZIDf9uBER9LbhteM3PBngFNA
RM0gaYtx2drAKwzwvnMJX2dC5ju9M/VSMAPaj4nKGJGOXdgfcv4WA+KY8oOX
SBf/PergHMqAzWIHVp6Q/sLtvOfUfbK+7yRvVZAmBHzFjz9igLGNg9tX0pIi
t1nm0QyYeFycM0NaTyKm2yiOAdGfumx4Tan4admXhfoJDNh/0vOcKOlbygXR
2okMwC01+mVJv1Kr8d6RyoDbtP4SZdL1Wp8Ob3nNgC93ZdlbSY/p0VXkshjw
7Uxlyv9fpxr9pkq+ZUDKlFv+/z+vYs45LpLPgPVJA1v/f/7hY2sbBIsZsLOK
KfT/7/e2k0vjKWfAyEXdU/+PL/qM+u3lKgbseJMs8v/4C90POLEQA2QP9Wv/
P79ubyv9X3UMGJ4obvx//qwA540TjQyo5J9v+H99xG/4Lg63MECa7aLx//rt
Cb39tfcjA1I72latJ+3wMKaks4sBguFcdkNk/UNiXz5u+Ur267uO9RmkU58V
+Nb3k/E8pRicJ12bWmNJG2JAGv0qXZH0SOan7aVMMr/Mv3OD5PXme0cXfDdO
Xp9P5649Jr2l9Pf3zB8MCBCJCTAk7Vm/NuPZHOmnMW3xZD9FtsiFxrIZQFWX
V9Ulnd+p7vLwDwN8Isa5vpD9OD9stekGNxPqixKkeEiLTTj/DaAwwVrwiHMc
2c+6v3z7vAWZsLijUU6WdPByzJMz65iww7JAQoXs/2SeV/52G5hAZbKPZZHz
ggsWHju2kQk3/QsE5UnzSHauNtrMBPkF/X+U/VT8kbZIuLImE8qszvAnk/OX
py9/VlaHCR+Cv5wkyHntMNIwlNjLhHUXvHZYkF5//Ng/AUMm9AsvBPwk5zvx
UmzQ9DEmbMmLCp0j9wMW+Mp63IYJS0ubt6qQHr5RqDl8igmb9807OJD7ROFR
569PLkzIMgsMLNpFxXOzRM6X+DGh4WxSpKo6FQ/9jA5wBzHhvsm/tm07yevF
5bXR6joTLP42DSuS+0vAobH9510mqDhvDRMg99054WAthXgmTAsWseO3UHHZ
wFGux2VMeG84UlG6iYqzX8V+G65iwg++H/2u0uS8f4RSNZwJh3cXTgiS+/jG
1ucXmpuY4Nf/uumwBDn/3yw6OPuYsJb7flvMOioeZ1ie5POXCbpW2UdUKOT+
9zkbhHGMwMufu3vCeKm4QZKIlRDvCCwprHIf5Kbiv1mePFmrRmBCTDEhhIOc
7zdyF4c2jcBrKfWgu4sUnLr2oa7FgRGQftCcmTpJwYMHHbu2hY3AH9YDDa0P
5O/zIf2ksxEjUBJwQ4WjkYJ7Fki5p0SOgGJLwcP39RTcPrR/SeTpCMisEYs5
iFPwPSp28kuZI3Aso6pPqIyCLwac8G36MAJ1JT58tWkUPHCVufDZVaMQ8EZp
uesqBZ8OVOlNXjsKFzQVq4WDKPi5Yf60HtFRaOM8InfIn4LbFDVpH940Clml
m8ayvCm4lp3xac0do0ChmMXqupLxvT6Qy2k1ChseRetHmFNwXz1d8+S4UdD0
M/bllaDgHN5xN6MSRiFQafTtrCgFj0yZKbqVOAprz+21+yZCwd9wZUu5vh4F
29fygulCFJzRJDGtXDwKkkEpvEIcFPyE9Z/ogq5RiFd/PKY+xodre2Nf6kXG
QLDDeN0keX+2lGLk8iN6DHwCUav/bj58H1s/Vj1+DOx3v3bQ1eLDb1vo1AY9
GwPhzCozYicfTl3eKs/zagwqkp6ae23hw0VPCTOkisZgbm+rkuoGPnzn+j5n
i89j0DVzMfjfHC9+9v4l5wKJcfjGvJu4OocX7/B5fibo1Tic8LtMcRbmxXcf
kl8ZeDkBLPtuJq2NG/9wcHfW/sTv8PlfK/2pHxeeXvBsNyNnEl47nJ+zHObA
RTerepzO/gFhtWcuzhetoE5O6h2J6p+Q9lPwMNXuDyqhXs7o+DAFPqGfeS3W
EUhVdI2HS8M0yOwaTauSWEC/IlnrNb/8Ass8Rc2H3LNoc3j4jkseMxDj6t1b
kjiNGKf6+wzGZ4BTNdDItuA7MhntWizx/g0xfmVmkj0j6Irf2fNiU79h+4sE
L/GOYWRR+sJMLHAWTGockvf+60XTfz2CuVmzwP1ReK3jjy5kd9J86yJ7FqKk
W07f/dyF6ou2fZlenAVXrZRP5agLPfP4uaNveRY+XpiWsorrQkY9Xsx83jnQ
1f+PV2dfF3pR5GN2WnQOKGWajM9xncjEI1C8YtccqOQ1Zhw+8gm9/Hq72Pvy
HKyMB9hMdLehsYadQ5EBc6Cv4uR6P7cNqRYP8b8LmoO7bnz7zcLaUGm0vtOv
63NgUClnoKnbhlpNF/l9Qudg1lf81LOkVkRU+Tj5xs/BNe8A9VzvFmSR6iTg
XzYHjh9TlHO2fkBxkau14irmYGJmMcqX7wPqDaY5FVfNQfWtlWsnmU3IzW5j
yTyag/CTn3PCk5rQVZGvTgFNc1AQ6r7HY10Teh1qURLYOwdGlbNLWryNaOm8
/pmrf8jvw7eLxnM0ILMqlf0By3OAnvNVXmDWoxerxGV9/82B6G9VN7v39Uiv
cHboPPc8DGn3JD94VI9C/mQ6nRScJ/+/dTxQlaxH3JEiTjob52FzOOK7vKcO
CRWNOy7smYc86pn4ssga5MD7Wf+33jxYmCYe7vGvQbm2tdJT++YhrE4tX8S+
Bln8TRwYMZiH7fsrLLqVa1D0wWOO3WbzoGbJzn5Qi6P1PdUORafmoeG2QObZ
RYSkl2Psfa/NQ+GNGV17Cg2ZMI5UPA2eB98Zt/jVX6qRfyP/BixkHkbfTLQu
va5GzTG3OwXuzoPJdhmrG4bVKFDJ1/T1w3lQDQswVb5bhTosj+p8TZyHqMjd
2JxQJbrzavU6fTQPSglUhRjTMpQb3uzjWjMP+mcPseVlylCPZ1j7g7p5mMFW
3n6fL0VqOisPvjTOw0RQtr7oy1LU3zLF4dMxD7csI13of0rQroXW6Vf0eSim
vEQ7q4rR2KGHzVSeBYj3emZY61SIXMzPyCryLUDzif5FW71CNGChFXiAugA/
YuVeSUkUom7rIblrQgtg9NHykEZXAap11bz6Y/0CrOqqsX9oWoCSbvYrtysu
wJ1XRxV79uWjE2Xb7j0+tAAKJUXaP+Pfoo5Kjv53pgvAxSd10vrUW2SOfd7Z
ar4Am5el5NbLvEUGDTe/8RxdAKqbWXJMdg7a2dWlGXhyAbalpLNDa98goV/X
GScvLMCE4VMuEZ5sVKfUCpseLoCgHr1ooi4dmUUOmYn9twBhbrcdO+PTUcfC
rPXqqAWon3RR/ueejgbrJTxXYhdA72qBttyqdES4uCcMPl+Anj+7eW+feo1U
U7h+J78hX4+ScLjBmYaebNj9SqZ5AWL5HvB9CklFUjcP525oXQD+mx/u5Z1M
RWljTuXC7QsQw/WwvVEjFeWXhLX/+7QA+749iLL7mIJajncvDfUugA+DuuZy
VjLiiL50PPX7AsQ1Jz4/4pOIPKgZPHL8LAj1UnfhOZ6AWrju/2coyILJRGR1
TTgBqS5fEDu3igUvvwlRLrQ+Rb9+b9+Ss5YFz/PflOceeor8+0vMtSRZ8O2d
333M8Am6kdcQa7qNBc79uxTNreJQ9IlRWb8jLFin3L+dtzoa/bZozI6zZEGF
Y3/Twr1odMw0W6PMigW/OQf4DY9GI9F9XkZ/rVkwIVszNdgShZ4rL7iHnWZB
PddB+rhKJHq9xPPu+SUW1Lk8dE+kPkRlqQr6dTEsKNrIc1Fe+x5S+Gd0veYx
C2TXhVTcYYaiaMezFSieBW+PqNywiwlF5yUztKqfsUCZpfzuwvRdJBmnrFby
kgXafSoronl3UHC4ikxmARl/sEGfkNEtNDFq5phexIKsi0Zo6fdNZG108UVa
CQvWuk/1DDrcRGqcbzekVrCA4ssbj2mFoKFr29c8q2GB6d7ItiPz15GB907O
h59YMPud99dYVhDKaz0KD7rI/LrE1okrBqGN23xvhH8m87l78Ejiq0A0P16w
eLeXBYIbhraWvgxA6c6as8F08vxSoq8n/zISwY/vvM5kQfiB/frmupdRyCZ/
76ujZP3zCaP9NX7Ipr94MuA7C46tr/Bu+uqLqNbaTO/fLIhq7XpP3+CD/Its
5LzmWJCe3aLKsr2E6GuDnC4usKDD7alV8F1vVNle1u++yIK48oLB1BFPdNFk
d/cZTjY8Vd3WvvjxAmrfq9dwbC0b2tXfBu+wcEMR5QF/jNexYXbztujBfFd0
SOud+l5RNox6zpyYEHNFuJp88mYJNuiNv6xZ+emMiuSoQfOybDjVN8/rc9sJ
+SQfyJ2QZ0PP2/bE0OunkerG68xvCmwI4fpetnTdEWWsn7Zs2MIGzibt5NYo
e5RA6d7yZCcbIn6Mr5PiPImsQ1c5RWiwQSovcPqkqi0S4TwUH7KLDQJ7Dm12
dbRBD5cqON112aD+YzoqvOMEMgma07Hfw4aba/GT/iInEM+8qrelHhtee9lW
dNkdRyFTKX06+9mgc/De0QjCCu3x6F2jasCGTfJKGfmWVog9JnJI1ogNlz/K
jo/nHEU+w/eKqCZs0Ljq3mIyZoFcuy4+6rVkQ/LPLm8xfzMkezS9ts2KDa2d
KbZ0L1P0rXWQqDnOBkUBM00tHxNk897q7BtbNlQmZPx9858xEjF8+CLZjg1I
5I2Ye9ZB9BHVf4q1J89/1hY13GyETCp09l13YkNN/YlwQyVDxKvt63/JmQ3+
eQPizacNUG3hmzeurmwoubzf2CT5ANr7VnrDYXc2MNTdvS+q70dqKdwzUpfY
cDiSeO9ovBdNbtRXWuvLBsNjSmkvpfagzIRAB97L5Pt7rwWwlnWRbOz3pqlA
NowoPTK5OayNBlZv/ke/wobClZOOq+ha6PlDB60v18h8A/qzzvzYhdbd+/gS
C2GDRXmftLSUJurg5O8pvMUGFdfe6KkDGuhRiMHqzDts+EEtarLyUUd8V0qu
RYWxoXfqcJNnyw5EeLw4fiaSDRIJZzu+26igqGtplJvRZP/Vure94tqKlCJy
qpJi2fB+q+FkCk0ZWWdXbe5/wgalFUJ8nZMi+lle93UxgQ2frtwK8zBSQKFN
LQ/FX7BBrkoqp0l7Myoc75+zTiHjOX1/MWK/HDJlMzP9X7JB9Qnbc9ZGFg3z
/bR/nMaGK7/cZdpnNiFhpb91HZls4AuJNrcu2YgytHiu/Mpmg0ml967dWpJo
30Eh1dVv2XAuYot0XaM48nSTijPPZ8Nc38u+dDkxxO2vYOJRSF4Ph2I8ZHw9
en5X9e/9YjasmHj4LFevQx9e6bm9LyfjjxP4pxW3Fp0pNBIfrWRDSvO7p6/j
1iCi5nArN42sZ/MfPSMjYaREd9h1oIasH2215o86QUSbcZtwqmNDXf2yrJOS
ADrB4ZUY0sAGSbXX5reSqeiuzA2e6g9s6LL7x93Rwoskd9wr72shbX3thuRN
HlS47z/PxTY2dH/64m9qxI2GHZO6tTvZULBlJmmegxMFeaXft+5mw8+fr8Jz
p/5hq2/k6vl/YQP8uu/3ibWM6SfSXhf0sSHpUe3je/ZLWHdOw8mOb2woy1Xi
cC0mMM+qNqFfg2Q++gvndyuysed9A/6qTDJesTOZ/GbzmPrk6BbzUTasKbgh
XPNnFmtanPp2YZwN9x7eTvqB/8bO8LOi739ng+fhEsPwhBmMLb5ilPmDDc3j
Jdp7uX9hkVv4Fhum2JAWyjMRxvqJKemuzh35xQbZFo7Wnfw/sBO2m0Tl58n+
/unSwRU2jv04p/RhP4sNNlE8baumRrE7gWo3nAg2COsUKu31GsEkw7TVQ5bY
gJnXjW3lZWIF8ftGE/+yIXvSlT+iiI6ZpBs/q1phw5O1460bg4ax4WKLI30c
BHgy41edThrEVnefLtnAS8Bfj46E9x59WDrz3AVtCgEnClfd7AntwfTmvKWt
+Qkw3tYWFYF9wbq5gj5dFiSgYEqng1fsM3ZR5Oa92FUENFjFHH/4oAvjkg/f
XSBMQFujq9rlDZ3Yc/WoqY9rCWiR3n15G9aBNR1NsV4lRsDt9rsW9qmtmEf9
KEYRJ0DMQKL+SXwztkpXdQuXJAFJpv1yL942Yfk5fjF/NxJwpTUi1J/5Hjsm
U7HEkibgq9YBHxPdBmw+9p/rbxkCNrk2F5/IrsOe8Bm3/ZAjIG9Z3WF6Vy3W
P9WZMqxIQIe7+cKGbQgLcZbg71cmgK3QomT2sRqT/ezk93krAdI3XcbHEyux
WpOM/o/bCOgpVdh6LqYcc6v+adS8nQDeo73Cjm9KMb6dmnn1OwhwWG4+EjZa
jGWnXd2A1AmgKbRHV+0vwqYj+CaLtAjy/uND7SHLfCx65fDxPB0CPur9NPmw
nItp+j2uztpNxstRfWF7ZA72ZbRXMW0vAe9a/aihh7OxK3ayUUn6BGTzc7fV
a2Vikm3niKdAQPOH2AfrD6VjtP25zrEHCFCLO8aqvZGGcW3Zsyv8IAGzzYOW
Rlap2OsXt5JuHyLgZPi2bfOdSdgh4Ua+YFPyPD/9/NS9L7DJO6t8As0JoK9s
W53Uk4A9Yh3v9TlCgKboWKh2xhNMzeO5wUVLAhL7np1ZSI3DOgaGc85aESA5
bNP8rCEWE23wCjllTQC1NdZJgzMKK9ctHj9hS4CKLM2ZIf8IO/V26ailHQFL
Vz69N77zAPsrc6DS1J6A74ZqX8slw7Hkx+GbjRzJ8zcuS9DHQ7H9lPZH+5xI
T8w0FI7ewZjX1rN0nQnYd8nLw33NbSxs+pSTpisBqt4lSQtNIdgWl5dN288S
cKpIWsiCdh1r/jyuvsWdgHXZfu417CuYl6naC/kLBIiLp3Nn+gVia2j+PNIX
CfhVqXqftsUfK9xZ5bXBiwBL55RIBVE/7MRrzq9rLxHQR+VPsNH0wdgbTPYL
+RKgf/rIa+MVT+z5w8hsvssEdMVLnTjx/QKm969bhDOAgBdBasffyLpjg34b
g/8EEhDnvqSTleSG3R5zHl24QoCIuvbUjlMumMKpLIuZawQUFoTxJh09g71v
my6bDCZgSExow1W2A3b+gJbcaAgB3IaqMRG5dphAyfWIoVsEOPYtL6ZW2mBv
t9TO9d4hYKXMhJohdgKzTKQ6docSoJR6F22vtMJmhS3ft4eR8ZzZGN+tZ4nF
3Y3f8eE+ATxXkNyBa+aYNrs/oS6CgAFFqeU9ciZYj4c8F/aInHeriO+2ygex
a4PnL5ZHEmD4V7BE7K4BJn3sXXdhNFn/h5cftW3bj+ENC/q5sQQ8/jUwpKGp
h7ns1svMjCP7OVLXPylCFxsCq8jWJwQ84X2SqblGC3MwPhfwO4GsJ8eUIRe/
BtZ7+LqD2Asyn9G2Z9s/qmE2x6MN9yaR9f3rJtQIKliXXbrKmRQCcEZq3D4L
Jezomcq1914SEHFe443luDzWdu4jkZ1GANNTx/PZnAxm5jUy1J5OgPdCp1zv
T0ms8fLi+7lMsh9SjonppohhRtdW54m/IeD6W+eAjFkRrObW5nj9twSs1fi4
pyJNGNsXrhvskkfAmuyNZUonBLCq/464hueT9UhciA79zIvpxrmYvS0koPgk
VtAowIWVPA9S/1RM7r/zTyaXipdpGi8fibNKyfnVO+Xf4UDQ3mW+/CdZQYAP
sbjJbGyOpppXOgZV5H5sT0or2jFDyy5uaXOjESCw99zhtzqTNKWq4eIHiNwX
ku3NI/KjtLSahRd5NWR+lqmW0QvDNNkmgbtddeT+8D13InN9Py2pXcaDaCDj
OXVy1PPOZ5rk511W0k0E3PD5Jzi53EF72m+qa9BMQNGf5U9xBc209YzTMu6t
BPyc5P7z7ms9LWbiMt+jdgK2yPG4CKritNW/7k/ldxAQLVa/+eR0Oe3hQlL3
504CZlhZuV6iRTTq38KqpW4CFGanyq9z5NLucTW9kvlK2tjMdHEgncbFP/DA
qJcAfiv1/COnUmk3hWd9LvST+/1dlDEXJND+ilJORg6Q8yZ4Y9W+jzG0q1JS
UDREABES3nhi4gGNJa+u1EMn6z9w2rkx/Q7t8lbjVctMAlqfKghlP7xGm9lh
Py83RoBgaU6Ua44fzUvbp994ggDX9mX30Z8XaJN692ovThKwXHF7YAp3prkb
Ps+O/knA3jID/5R5W9qI6bvokmmyX7XXy8a1W9Kcj9YH9c0QYNZS4tKLjGiD
Nr2n/82S86k7XxcetYdm7zh9UGGBAFPfhS+bM3bSely5t5uyCUgXaxa2PqdA
s/YQX++9SMBUW4HzISdxWqfP9j+xfwjIGtKW9j8qRLMMMmCULROwOpU4Lcz4
V916w/bDt38E2H/IXX3A+ne1aahnPifXIshO9LNdpBnV7yNuP1XiWYSbF73/
ssU7qw1jnoSY8y3CwdjSoO8qNdX405yzPtRF+C4rs/9MTl61fjJ+OF5gEYZM
7mRZhj2rrnz9WbNSaBECMyNtz4XdrdbJmZQcWr0IBRKvM66yPaqLC/5x8qxd
BO0h3c7V549W52FbO46ILkLh7pcMdohQ9aueG5506UUYWL+3t/sSpUo1bKnr
N+npcr6iJF6eqlLNoL1cmxZhz9WpM3XCnFUtkT4Cm0kf0/wgdymeqJw3cs1y
Iz14Z3m0M3ui0rjAZGT8/65+/NFqU0Pl5IN1DtMyi/DjWInqel/3Sn+d6LoV
0n6rBXuL1zhXrowIbROWXQT6lhdjX56crFy3n29pB2nG972mx3NMKvVYxFNf
0ke/3DvWLaNYGeky2DVPOiDJUSjkcmOF+Br7vbxyixDDVVKb/ay84hXt6ytR
0rYybx/b5GVVlIl/8tUmLZrVeXpR/l7FcHud8BXS0h/33PS9olzhEbw/6D7p
3DU5Ix+KqBXzW2mDCaTLhZJ1ypVHy6n3SnMrSNvMHD9/KDy8PFZDU7SZtPhE
aP2fPQfLpYbfBfeRVvP2+TyTMF6W8Z/qyCTpjS/fSMhNGpep7802/0O6glMD
hVg57/offRXHEw==
       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-3.0357245737836633`, 
       2.2071766217738748`*^-56}}, {{
       0, 1.5707963267948966`}, {-3.0357245737836633`, 
       2.2071766217738748`*^-56}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nk0VVscB/BjqFDGUlHmSoYiSgr9kEgkEkV4KJkzZEqGBkIkZKxMlSmZ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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-2.068180185364567, 0.}}, {{
       0, 1.5707963267948966`}, {-2.068180185364567, 0.}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.405974419399376*^9, 3.405974526287395*^9, {3.406105626256132*^9, 
   3.406105674515099*^9}, {3.406105705576167*^9, 3.406105729379448*^9}, 
   3.406105924422227*^9, {3.406112805260666*^9, 3.406112817272407*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ib1", "[", 
  RowBox[{"0.5", ",", "Flow1"}], "]"}]], "Input",
 CellChangeTimes->{{3.390933420823439*^9, 3.39093343440346*^9}, {
  3.39093355255863*^9, 3.390933617084193*^9}, {3.406105547289208*^9, 
  3.406105600037333*^9}, {3.40610590551004*^9, 3.4061059105663*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.2015074101003533`"}]], "Output",
 CellChangeTimes->{
  3.390933438680966*^9, 3.390933473108998*^9, 3.390933518649139*^9, {
   3.390933554924037*^9, 3.390933618364195*^9}, 3.405974546220596*^9, {
   3.406105550458219*^9, 3.406105601247245*^9}, 3.406105911994473*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution < h2b2[y] G[y] >, in factor of    2 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", " "}], TraditionalForm]]],
 "C"
}], "Subsubsection",
 CellChangeTimes->{{3.390933194868613*^9, 3.390933227475682*^9}, {
  3.39093374552825*^9, 3.390933747234977*^9}, {3.424750983804744*^9, 
  3.42475101092953*^9}, {3.424752392429156*^9, 3.424752395757589*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ib2", "[", 
   RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["2", "\[Pi]"], 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"h2b2", "[", "y", "]"}], " ", 
       RowBox[{"G", "[", 
        RowBox[{"y", ",", "\[Mu]", ",", "Flow"}], "]"}]}], " ", "/.", " ", 
      RowBox[{"Evaluate", "[", 
       RowBox[{"h2b2p", "[", 
        RowBox[{"\[Mu]", ",", "Flow"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390933243836283*^9, 3.39093340537776*^9}, {
  3.390933459516095*^9, 3.390933466189825*^9}, {3.390933509203082*^9, 
  3.390933509740634*^9}, {3.39093370330609*^9, 3.390933714661408*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["How does it look and example", "Subsubsection",
 CellChangeTimes->{{3.424781947660836*^9, 3.424781955831332*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"p2b2", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"h2b2p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"h2b2p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"h2b2p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"h2b2", "[", "y", "]"}], " ", 
           RowBox[{"G", "[", 
            RowBox[{"y", ",", "\[Mu]0", ",", "Flow1"}], "]"}]}], "/.", "R1"}],
          " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"h2b2", "[", "y", "]"}], " ", 
           RowBox[{"G", "[", 
            RowBox[{"y", ",", "\[Mu]0", ",", "Flow2"}], "]"}]}], "/.", "R2"}],
          " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"h2b2", "[", "y", "]"}], " ", 
           RowBox[{"G", "[", 
            RowBox[{"y", ",", "\[Mu]0", ",", "Flow3"}], "]"}]}], "/.", "R3"}],
          " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.40596784096609*^9, 3.405967973064653*^9}, {
   3.405968017498025*^9, 3.405968029746004*^9}, {3.405973217071289*^9, 
   3.405973306850355*^9}, {3.405974183693894*^9, 3.405974407606592*^9}, {
   3.405974510489808*^9, 3.405974523520543*^9}, {3.405974613717195*^9, 
   3.405974633164468*^9}, {3.405975002820735*^9, 3.405975003348265*^9}, {
   3.4060852056102*^9, 3.406085209444148*^9}, 3.424751058726697*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p2b2", "[", "0.5", "]"}]], "Input",
 CellChangeTimes->{{3.40596784096609*^9, 3.405967973064653*^9}, {
   3.405968017498025*^9, 3.405968029746004*^9}, {3.405973217071289*^9, 
   3.405973306850355*^9}, {3.405974183693894*^9, 3.405974407606592*^9}, {
   3.405974510489808*^9, 3.405974523520543*^9}, {3.405974613717195*^9, 
   3.405974633164468*^9}, {3.405975002820735*^9, 3.405975003348265*^9}, {
   3.4060852056102*^9, 3.406085209444148*^9}, 3.424751058726697*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV1nc81d8fB3CrjBQlhOyKjBYi4/OSZKSyisykZJUipZCojHCFlGigMkOy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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-2.438126130410344*^-15, 
       0.014658680552098952`}}, {{
       0, 1.5707963267948966`}, {-2.438126130410344*^-15, 
       0.014658680552098952`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c8Vf8fx4WEjCilkkIhJDPknvNGMkJJKZuMspKVPUpZKSszEtl7j4jM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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-2.733106882445529*^-60, 
       0.3717840503403435}}, {{
       0, 1.5707963267948966`}, {-2.733106882445529*^-60, 
       0.3717840503403435}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8FV8fB3DCLyFSVERZSiUkSxTmU5I9UfatyJYtS6hslSVKsoVUqGSp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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-1.248785846716774*^-16, 
       0.16731753526022344`}}, {{
       0, 1.5707963267948966`}, {-1.248785846716774*^-16, 
       0.16731753526022344`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{3.40597463875679*^9, 3.405974805981676*^9, 
  3.405974885313631*^9, 3.405975009335952*^9, 3.406085216126293*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ib2", "[", 
  RowBox[{"0.5", ",", "Flow1"}], "]"}]], "Input",
 CellChangeTimes->{{3.390933420823439*^9, 3.39093343440346*^9}, {
  3.39093355255863*^9, 3.390933617084193*^9}, {3.390933719864239*^9, 
  3.390933721000769*^9}}],

Cell[BoxData["0.007089651511525556`"], "Output",
 CellChangeTimes->{
  3.390933438680966*^9, 3.390933473108998*^9, 3.390933518649139*^9, {
   3.390933554924037*^9, 3.390933618364195*^9}, 3.390933723208034*^9, 
   3.405974643681249*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Contribution < h2b3[y] G[y] >, in factor of   2 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"A", " "}], TraditionalForm]]],
 "D"
}], "Subsubsection",
 CellChangeTimes->{{3.390933194868613*^9, 3.390933227475682*^9}, {
  3.390933750771718*^9, 3.390933751557885*^9}, {3.424751173136087*^9, 
  3.424751190665143*^9}, {3.424751307202576*^9, 3.424751311967*^9}, {
  3.424752403839846*^9, 3.424752406045937*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ib3", "[", 
   RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], ":=", 
  RowBox[{
   FractionBox["2", "\[Pi]"], 
   RowBox[{"NIntegrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"h2b3", "[", "y", "]"}], " ", 
       RowBox[{"G", "[", 
        RowBox[{"y", ",", "\[Mu]", ",", "Flow"}], "]"}]}], " ", "/.", " ", 
      RowBox[{"Evaluate", "[", 
       RowBox[{"h2b3p", "[", 
        RowBox[{"\[Mu]", ",", "Flow"}], "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390933243836283*^9, 3.39093340537776*^9}, {
  3.390933459516095*^9, 3.390933466189825*^9}, {3.390933509203082*^9, 
  3.390933509740634*^9}, {3.39093370330609*^9, 3.390933714661408*^9}, {
  3.390933760907673*^9, 3.390933770893869*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["How dos it look and example", "Subsubsection",
 CellChangeTimes->{{3.4247819934507923`*^9, 3.424782005172265*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"p2b3", "[", "\[Mu]0_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"R1", ",", "R2", ",", "R3"}], "}"}], ",", "\[IndentingNewLine]", 
    
    RowBox[{
     RowBox[{"R1", "=", 
      RowBox[{"h2b3p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow1"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R2", "=", 
      RowBox[{"h2b3p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow2"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"R3", "=", 
      RowBox[{"h2b3p", "[", 
       RowBox[{"\[Mu]0", ",", "Flow3"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"h2b3", "[", "y", "]"}], " ", 
           RowBox[{"G", "[", 
            RowBox[{"y", ",", "\[Mu]0", ",", "Flow1"}], "]"}]}], "/.", "R1"}],
          " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"h2b3", "[", "y", "]"}], " ", 
           RowBox[{"G", "[", 
            RowBox[{"y", ",", "\[Mu]0", ",", "Flow2"}], "]"}]}], "/.", "R2"}],
          " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"h2b3", "[", "y", "]"}], " ", 
           RowBox[{"G", "[", 
            RowBox[{"y", ",", "\[Mu]0", ",", "Flow3"}], "]"}]}], "/.", "R3"}],
          " ", ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", "0", ",", 
           FractionBox["\[Pi]", "2"]}], "}"}]}], "]"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"p2b3", "[", "0.5", "]"}]}], "Input",
 CellChangeTimes->{{3.40596784096609*^9, 3.405967973064653*^9}, {
  3.405968017498025*^9, 3.405968029746004*^9}, {3.405973217071289*^9, 
  3.405973306850355*^9}, {3.405974183693894*^9, 3.405974407606592*^9}, {
  3.405974510489808*^9, 3.405974523520543*^9}, {3.405974649532476*^9, 
  3.405974649995011*^9}, {3.405975031222164*^9, 3.405975051418691*^9}, {
  3.40608522903587*^9, 3.406085237798752*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13c8Vf8fB3CjMiqjiSJkhYwyw3lJWSnJSJklUoqyUllRQkp2SNx7y0pW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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 0.03640079358140886}}, {{
       0, 1.5707963267948966`}, {0., 0.03640079358140886}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3c8V/8Xx0VJiMxQVkV9bdn6fO6RZG+VspMoZCWbhhENISQqlJW9Z0ai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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {-7.983234136858012*^-60, 
       1.3138945686176906`}}, {{
       0, 1.5707963267948966`}, {-7.983234136858012*^-60, 
       1.3138945686176906`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV13k8FW8bBnCkUkSUSopokaVEkYq5CokWSSghIWTJVpZEK0mWbNmyh0Rk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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{0, Rational[1, 2] Pi}, {0., 0.5208621034792924}}, {{
       0, 1.5707963267948966`}, {0., 0.5208621034792924}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{3.405975065889528*^9, 3.406085249723721*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Ib3", "[", 
  RowBox[{"0.5", ",", "Flow1"}], "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390933420823439*^9, 3.39093343440346*^9}, {
  3.39093355255863*^9, 3.390933617084193*^9}, {3.390933719864239*^9, 
  3.390933721000769*^9}, {3.390933783214298*^9, 3.390933783600309*^9}}],

Cell[BoxData["0.01816156783505905`"], "Output",
 CellChangeTimes->{
  3.405975082123477*^9, 3.4247838273027487`*^9, 3.424849368702169*^9, {
   3.424877836437176*^9, 3.424877864373922*^9}, 3.424891796910375*^9, 
   3.425286208107796*^9, 3.425303435999391*^9, 3.425316649611688*^9, 
   3.425486558452818*^9, 3.425524280087769*^9, 3.426569090340869*^9, 
   3.441480983317863*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Ib3", "[", 
   RowBox[{"0.5", ",", "Flow1"}], "]"}], "/", 
  RowBox[{"Ib2", "[", 
   RowBox[{"0.5", ",", "Flow1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.406084415886893*^9, 3.406084541468006*^9}, {
  3.406084620766569*^9, 3.406084697484922*^9}}],

Cell[BoxData["2.56170106605861`"], "Output",
 CellChangeTimes->{
  3.406084458214591*^9, {3.40608449095235*^9, 3.40608451176203*^9}, 
   3.406084548051042*^9, 3.406084652130989*^9, {3.406084686143966*^9, 
   3.406084700232223*^9}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Large-scale instability", "Section",
 CellChangeTimes->{{3.39093504940084*^9, 3.390935071506817*^9}, {
  3.390936801351065*^9, 3.390936809704891*^9}, {3.424752473145993*^9, 
  3.424752490035965*^9}, {3.424752535707493*^9, 3.424752537277401*^9}}],

Cell["\<\
The turbulent viscosity \[Nu]T is such that\
\>", "Text",
 CellChangeTimes->{{3.42475256002876*^9, 3.424752573542046*^9}, {
  3.424753030228199*^9, 3.42475303684025*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   FractionBox["1", "A"], "\[Nu]T"}], "=", " ", 
  RowBox[{
   RowBox[{
    FractionBox["1", "C"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "I2"}], " ", "+", " ", "Ib2"}], ")"}]}], "+", "  ", 
   RowBox[{"C", " ", 
    RowBox[{"(", 
     RowBox[{"I1", " ", "+", "  ", "Ib1"}], ")"}]}], " ", "+", " ", 
   RowBox[{
    FractionBox["D", "C"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "I3"}], "+", "Ib3"}], ")"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"=", " ", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[CapitalDelta]", 
     RowBox[{"2", " "}]], "Cs", 
    RowBox[{"(", 
     RowBox[{"Cs", 
      RowBox[{"(", 
       RowBox[{"I1", " ", "+", "  ", "Ib1"}], ")"}]}], " ", ")"}]}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"12", " ", "Cs"}]], 
    RowBox[{"(", 
     RowBox[{"Ib3", "-", "I3"}], ")"}]}], "+", " ", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"Cs", " ", 
      SuperscriptBox["\[CapitalDelta]", 
       RowBox[{"2", " "}]]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "I2"}], " ", "+", "  ", "Ib2"}], 
     ")"}]}]}]}]}], "Definition",
 CellChangeTimes->{{3.424752595253077*^9, 3.424752613042092*^9}, {
  3.424752644428143*^9, 3.424752653439409*^9}, {3.42475274996734*^9, 
  3.424752816374545*^9}, {3.4247529404295*^9, 3.424752966514854*^9}, {
  3.424752997680114*^9, 3.424753051272174*^9}, {3.424753168091524*^9, 
  3.42475317173901*^9}, {3.424753288014192*^9, 3.424753420102862*^9}, {
  3.424875378559699*^9, 3.424875459614814*^9}, {3.424875554138467*^9, 
  3.424875579766811*^9}, {3.426569241024618*^9, 3.426569278708734*^9}, {
  3.42656931610825*^9, 3.426569362832141*^9}}],

Cell[CellGroupData[{

Cell["\<\
Verifications with respect to the analytical case for Flow1 and \[Mu]=1\
\>", "Subsection",
 CellChangeTimes->{{3.424784114308251*^9, 3.424784117330329*^9}, {
  3.4247842406539507`*^9, 3.424784269598839*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"I1", "[", 
  RowBox[{"1", ",", "Flow1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"I2", "[", 
  RowBox[{"1", ",", "Flow1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"I3", "[", 
  RowBox[{"1", ",", "Flow1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.424877630320401*^9, 3.424877675706872*^9}}],

Cell[BoxData["1.500000000000002`"], "Output",
 CellChangeTimes->{3.424877646140162*^9, 3.424877677351867*^9}],

Cell[BoxData["0.4999999878368575`"], "Output",
 CellChangeTimes->{3.424877646140162*^9, 3.424877677805216*^9}],

Cell[BoxData["0.49999998783685756`"], "Output",
 CellChangeTimes->{3.424877646140162*^9, 3.424877678341054*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Ib1", "[", 
  RowBox[{"1", ",", "Flow1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Ib2", "[", 
  RowBox[{"1", ",", "Flow1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Ib3", "[", 
  RowBox[{"1", ",", "Flow1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.424877696186792*^9, 3.424877725897798*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.1272660809930173`"}]], "Output",
 CellChangeTimes->{3.424877727533091*^9}],

Cell[BoxData["1.4231884318957852`*^-9"], "Output",
 CellChangeTimes->{3.424877728056521*^9}],

Cell[BoxData[
 RowBox[{"-", "6.176900332889404`*^-9"}]], "Output",
 CellChangeTimes->{3.424877729454789*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Definitions", "Subsection",
 CellChangeTimes->{{3.424891535852895*^9, 3.424891543433916*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"B1", "[", 
   RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"I1", "[", 
    RowBox[{"\[Mu]", ",", "Flow"}], "]"}], "+", 
   RowBox[{"Ib1", "[", 
    RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B2", "[", 
   RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"I2", "[", 
     RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}], "+", 
   RowBox[{"Ib2", "[", 
    RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"B3", "[", 
   RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{"I3", "[", 
      RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}], "+", 
    RowBox[{"Ib3", "[", 
     RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}], "12"]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.426569410229902*^9, 3.426569523751713*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", 
    RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"B3", "[", 
       RowBox[{"\[Mu]", ",", "Flow"}], "]"}], "2"], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["Cs", "2"], 
      RowBox[{"B1", "[", 
       RowBox[{"\[Mu]", ",", "Flow"}], "]"}], 
      RowBox[{"B2", "[", 
       RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}]}], "/.", " ", 
    RowBox[{"Cs", "\[Rule]", "0.008"}]}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.424879294351208*^9, 3.424879296357896*^9}, {
  3.424879329943789*^9, 3.424879361026343*^9}, {3.424879415187254*^9, 
  3.424879585613367*^9}, {3.424888556231603*^9, 3.424888556840285*^9}, {
  3.424890449972973*^9, 3.424890453017546*^9}, {3.426569542186159*^9, 
  3.426569629270863*^9}, {3.426569747111691*^9, 3.426569753053564*^9}, {
  3.441481192695865*^9, 3.441481195162931*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalGamma]c", "[", 
    RowBox[{"\[Mu]_", ",", "Flow_"}], "]"}], ":=", " ", 
   RowBox[{
    SqrtBox[
     FractionBox[
      RowBox[{
       RowBox[{"-", 
        RowBox[{"B3", "[", 
         RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}], "+", 
       SqrtBox[
        RowBox[{"DD", "[", 
         RowBox[{"\[Mu]", ",", "Flow"}], "]"}]]}], 
      RowBox[{"2", 
       SuperscriptBox["Cs", "2"], 
       RowBox[{"B1", "[", 
        RowBox[{"\[Mu]", ",", "Flow"}], "]"}]}]]], "/.", " ", 
    RowBox[{"Cs", "\[Rule]", "0.008"}]}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.424879805962367*^9, 3.424879904383046*^9}, 
   3.424880108535913*^9, {3.42488857089148*^9, 3.424888575850184*^9}, 
   3.424890454925531*^9, {3.426569644819799*^9, 3.426569743796045*^9}, 
   3.428925121458321*^9, {3.441481197860693*^9, 3.441481199183123*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots", "Subsection",
 CellChangeTimes->{{3.424784904309182*^9, 3.424784905123457*^9}}],

Cell[CellGroupData[{

Cell["Plots with lists", "Subsubsection",
 CellChangeTimes->{{3.424891366979334*^9, 3.424891372404396*^9}}],

Cell["\<\
Make a logatithmic sample of \[Mu] values\
\>", "Text",
 CellChangeTimes->{{3.42489139197918*^9, 3.424891442250744*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"fac", "=", 
   SuperscriptBox["10", 
    RowBox[{"1", "/", "5"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Mu]ramp", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"0.001", " ", 
      SuperscriptBox["fac", 
       RowBox[{"i", "-", "1"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "31"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.424884690396222*^9, 3.424884765854498*^9}, {
   3.424884797460774*^9, 3.424884802952326*^9}, {3.424885140399212*^9, 
   3.424885140817892*^9}, 3.424889011906961*^9, {3.425303688948634*^9, 
   3.425303740898337*^9}}],

Cell["\<\
Plot integrals I1, I2 and I3 as a function of \[Mu] and Flow\
\>", "Text",
 CellChangeTimes->{{3.424891446826866*^9, 3.424891474004988*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ListLogLinearPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"\[Mu]ramp", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"I1", "[", 
               RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
      RowBox[{"ListLogLinearPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"\[Mu]ramp", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"I1", "[", 
               RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
      RowBox[{"ListLogLinearPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"\[Mu]ramp", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"I1", "[", 
               RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}], ",", "  ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ListLogLinearPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"\[Mu]ramp", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"I2", "[", 
               RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ListLogLinearPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"\[Mu]ramp", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"I2", "[", 
               RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ListLogLinearPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"\[Mu]ramp", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"I2", "[", 
               RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ListLogLinearPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"\[Mu]ramp", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"I3", "[", 
               RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ListLogLinearPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"\[Mu]ramp", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"I3", "[", 
               RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ListLogLinearPlot", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"\[Mu]ramp", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"I3", "[", 
               RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
            "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.424889051915507*^9, 3.424889217020938*^9}, {
  3.424890284306138*^9, 3.424890301628561*^9}, {3.424891806877654*^9, 
  3.424891807240038*^9}, {3.425491341021571*^9, 3.425491350829753*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{{-6.907755278982137, 
          1.2735570760901485`}, {-6.447238260383328, 
          1.2737422132033596`}, {-5.986721241784519, 
          1.2740348770263827`}, {-5.52620422318571, 
          1.2744969990483497`}, {-5.0656872045869, 
          1.2752255582238363`}, {-4.605170185988091, 
          1.2763717017787848`}, {-4.144653167389282, 
          1.2781695323094766`}, {-3.684136148790473, 
          1.2809786843765056`}, {-3.223619130191664, 
          1.2853458879665274`}, {-2.7631021115928545`, 
          1.2920915007179947`}, {-2.3025850929940455`, 
          1.3024269916787141`}, {-1.8420680743952365`, 
          1.318108001891539}, {-1.3815510557964272`, 
          1.3416245341519346`}, {-0.9210340371976181, 
          1.3764254189411664`}, {-0.4605170185988088, 1.4271701237546273`}, {
          0., 1.500000000000002}, {0.4605170185988092, 1.6028261300147493`}, {
          0.9210340371976184, 1.7456431180958605`}, {1.3815510557964277`, 
          1.9408952983857597`}, {1.842068074395237, 2.2039390370029057`}, {
          2.302585092994046, 2.5536572423043546`}, {2.763102111592855, 
          3.0132880887293463`}, {3.2236191301916644`, 3.611531592572402}, {
          3.6841361487904734`, 4.383999906983969}, {4.144653167389283, 
          5.375084664661503}, {4.605170185988092, 6.640330363039047}, {
          5.065687204586901, 8.249427598008388}, {5.52620422318571, 
          10.289973974733202`}, {5.986010431625279, 12.868208330028}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{-6.907755278982137, 1.2735570760901485`},
       FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
            FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
            FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["0.1`", TraditionalForm]}, {0, 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{-6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
            FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["\" \"", TraditionalForm]}, {0, 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}},
       GridLines->{None, None},
       Method->{},
       PlotRange->{{-6.907755278982137, 6.907755278982137}, {
        1.2735570760901485`, 12.868208330028}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]},
       Ticks->{{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}], {193.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{{-6.907755278982137, 
          1.280936737534017}, {-6.447238260383328, 
          1.2834038557191245`}, {-5.986721241784519, 
          1.2866637557632512`}, {-5.52620422318571, 
          1.290971954323764}, {-5.0656872045869, 
          1.296666544971485}, {-4.605170185988091, 
          1.3041948856397616`}, {-4.144653167389282, 
          1.3141488341672425`}, {-3.684136148790473, 
          1.3273111730850828`}, {-3.223619130191664, 
          1.3447166026857669`}, {-2.7631021115928545`, 
          1.3677315543197226`}, {-2.3025850929940455`, 
          1.398158077841155}, {-1.8420680743952365`, 
          1.438368137106895}, {-1.3815510557964272`, 
          1.4914757307620186`}, {-0.9210340371976181, 
          1.561555232940417}, {-0.4605170185988088, 1.653915144330834}, {0., 
          1.7754370870755936`}, {0.4605170185988092, 1.9349906786795352`}, {
          0.9210340371976184, 2.143936589306371}, {1.3815510557964277`, 
          2.4167337996189477`}, {1.842068074395237, 2.771674221825156}, {
          2.302585092994046, 3.231779496167884}, {2.763102111592855, 
          3.8259110314212905`}, {3.2236191301916644`, 4.5901640879511385`}, {
          3.6841361487904734`, 5.569638088761073}, {4.144653167389283, 
          6.820697158405507}, {4.605170185988092, 8.41385769138277}, {
          5.065687204586901, 10.43746627337202}, {5.52620422318571, 
          13.002365517754564`}, {5.986721241784519, 16.247791651269132`}, {
          6.047942594424183, 16.792982951018494`}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{-6.907755278982137, 1.280936737534017},
       FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
            FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
            FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["0.1`", TraditionalForm]}, {0, 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{-6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
            FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["\" \"", TraditionalForm]}, {0, 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}},
       GridLines->{None, None},
       Method->{},
       PlotRange->{{-6.907755278982137, 6.907755278982137}, {
        1.280936737534017, 16.792982951018494`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]},
       Ticks->{{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}], {580.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{{-6.907755278982137, 
          1.2744290901274729`}, {-6.447238260383328, 
          1.2750822865647171`}, {-5.986721241784519, 
          1.2760772466994204`}, {-5.52620422318571, 
          1.2775797851839779`}, {-5.0656872045869, 
          1.2798277729743779`}, {-4.605170185988091, 
          1.2831581933287584`}, {-4.144653167389282, 
          1.28804287363}, {-3.684136148790473, 
          1.2951354215291861`}, {-3.223619130191664, 
          1.3053325957098418`}, {-2.7631021115928545`, 
          1.3198541085221918`}, {-2.3025850929940455`, 
          1.3403456310080635`}, {-1.8420680743952365`, 
          1.3690104477284035`}, {-1.3815510557964272`, 
          1.40877568999165}, {-0.9210340371976181, 
          1.4634993051108878`}, {-0.4605170185988088, 1.538223953713803}, {0.,
           1.6394841811498664`}, {0.4605170185988092, 1.775674154696138}, {
          0.9210340371976184, 1.9574860291966993`}, {1.3815510557964277`, 
          2.198434757960508}, {1.842068074395237, 2.515494678339484}, {
          2.302585092994046, 2.9298863178719396`}, {2.763102111592855, 
          3.468067337946128}, {3.2236191301916644`, 4.162997591082878}, {
          3.6841361487904734`, 5.055763784004024}, {4.144653167389283, 
          6.197664747597499}, {4.605170185988092, 7.652876168144659}, {
          5.065687204586901, 9.501837279512202}, {5.52620422318571, 
          11.84553480444368}, {5.986721241784519, 14.810904188555902`}, {
          6.024431324255851, 15.117709856307885`}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{-6.907755278982137, 1.2744290901274729`},
       FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
            FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
            FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["0.1`", TraditionalForm]}, {0, 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{-6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
            FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["\" \"", TraditionalForm]}, {0, 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}},
       GridLines->{None, None},
       Method->{},
       PlotRange->{{-6.907755278982137, 6.907755278982137}, {
        1.2744290901274729`, 15.117709856307885`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]},
       Ticks->{{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}], {967.5, -119.58957682310462`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{{-6.907755278982137, 
          1.4740004602414154`}, {-6.447238260383328, 
          1.4014026261212404`}, {-5.986721241784519, 
          1.3290813243709092`}, {-5.52620422318571, 
          1.2571352382101393`}, {-5.0656872045869, 
          1.1856918825678469`}, {-4.605170185988091, 
          1.114912565979447}, {-4.144653167389282, 
          1.0449963584837054`}, {-3.684136148790473, 
          0.9761815456613712}, {-3.223619130191664, 
          0.9087435291746592}, {-2.7631021115928545`, 
          0.842987066515287}, {-2.3025850929940455`, 
          0.7792324784387801}, {-1.8420680743952365`, 
          0.7177952806709859}, {-1.3815510557964272`, 
          0.6589612444702977}, {-0.9210340371976181, 
          0.6029612123639754}, {-0.4605170185988088, 0.5499508067524739}, {0.,
           0.49999998783685684`}, {0.4605170185988092, 
          0.45309784851222373`}, {0.9210340371976184, 0.4091700268370285}, {
          1.3815510557964277`, 0.368106259556425}, {1.842068074395237, 
          0.3297890355594972}, {2.302585092994046, 0.2941162207394867}, {
          2.763102111592855, 0.26101321967613833`}, {3.2236191301916644`, 
          0.23043199049577703`}, {3.6841361487904734`, 0.2023413401391821}, {
          4.144653167389283, 0.17671182271716218`}, {4.605170185988092, 
          0.15350240751522745`}, {5.065687204586901, 0.13264920558966864`}, {
          5.52620422318571, 0.11406135515227528`}, {5.986721241784519, 
          0.09762098301378058}, {6.447238260383328, 0.08318725140403746}, {
          6.907755278982137, 0.07060262559813602}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{-6.907755278982137, 0.},
       FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
            FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
            FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["0.1`", TraditionalForm]}, {0, 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{-6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
            FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["\" \"", TraditionalForm]}, {0, 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}},
       GridLines->{None, None},
       Method->{},
       PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
        1.4740004602414154`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]},
       Ticks->{{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}], {193.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{{-6.907755278982137, 
          11.369567859333781`}, {-6.447238260383328, 
          9.439316537716422}, {-5.986721241784519, 
          7.83572938928081}, {-5.52620422318571, 
          6.503800108695906}, {-5.0656872045869, 
          5.397781375147376}, {-4.605170185988091, 
          4.479623811010995}, {-4.144653167389282, 
          3.717678473638395}, {-3.684136148790473, 
          3.085616662449863}, {-3.223619130191664, 
          2.5615321498126677`}, {-2.7631021115928545`, 
          2.1271932009285206`}, {-2.3025850929940455`, 
          1.7674225329797495`}, {-1.8420680743952365`, 
          1.4695786361771306`}, {-1.3815510557964272`, 
          1.2231288313977322`}, {-0.9210340371976181, 
          1.0192922160080715`}, {-0.4605170185988088, 0.8507450597244486}, {
          0., 0.7113779861440878}, {0.4605170185988092, 0.5960949931109334}, {
          0.9210340371976184, 0.5006488114263523}, {1.3815510557964277`, 
          0.4215051593049431}, {1.842068074395237, 0.3557317766884182}, {
          2.302585092994046, 0.30090585783856527`}, {2.763102111592855, 
          0.25503649895902236`}, {3.2236191301916644`, 
          0.21649905537338998`}, {3.6841361487904734`, 
          0.18397749880906486`}, {4.144653167389283, 0.15641338536614474`}, {
          4.605170185988092, 0.13296040650404173`}, {5.065687204586901, 
          0.1129436711393154}, {5.52620422318571, 0.09582377165224691}, {
          5.986721241784519, 0.08116657000642168}, {6.447238260383328, 
          0.06861805956919839}, {6.907755278982137, 0.05788486211039264}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{-6.907755278982137, 0.},
       FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
            FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
            FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["0.1`", TraditionalForm]}, {0, 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{-6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
            FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["\" \"", TraditionalForm]}, {0, 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}},
       GridLines->{None, None},
       Method->{},
       PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
        11.369567859333781`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]},
       Ticks->{{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}], {580.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{{-6.907755278982137, 
          3.901356486570876}, {-6.447238260383328, 
          3.5944368632790886`}, {-5.986721241784519, 
          3.2931985208269055`}, {-5.52620422318571, 
          2.9993760591426137`}, {-5.0656872045869, 
          2.714940890731279}, {-4.605170185988091, 
          2.4420029801143555`}, {-4.144653167389282, 
          2.1826692256636546`}, {-3.684136148790473, 
          1.938878116066956}, {-3.223619130191664, 
          1.712241632370749}, {-2.7631021115928545`, 
          1.503917380905659}, {-2.3025850929940455`, 
          1.314535792170693}, {-1.8420680743952365`, 
          1.1441843556959994`}, {-1.3815510557964272`, 
          0.9924463410266121}, {-0.9210340371976181, 
          0.8584776689238}, {-0.4605170185988088, 0.7411053232428255}, {0., 
          0.6389324341086319}, {0.4605170185988092, 0.5504383115513909}, {
          0.9210340371976184, 0.47406593295190247`}, {1.3815510557964277`, 
          0.4082934545331406}, {1.842068074395237, 0.35168901515695367`}, {
          2.302585092994046, 0.30294792739634635`}, {2.763102111592855, 
          0.26091518206594133`}, {3.2236191301916644`, 
          0.22459347961610432`}, {3.6841361487904734`, 
          0.19313954091428795`}, {4.144653167389283, 0.1658518458216765}, {
          4.605170185988092, 0.1421520871770242}, {5.065687204586901, 
          0.12156411744936677`}, {5.52620422318571, 0.10369301184575207`}, {
          5.986721241784519, 0.08820629380125011}, {6.447238260383328, 
          0.07481835767185013}, {6.907755278982137, 0.06327963155877814}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{-6.907755278982137, 0.},
       FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
            FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
            FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["0.1`", TraditionalForm]}, {0, 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{-6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
            FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["\" \"", TraditionalForm]}, {0, 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}},
       GridLines->{None, None},
       Method->{},
       PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
        3.901356486570876}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]},
       Ticks->{{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}], {967.5, -358.7687304693139}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996207`}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{{-6.907755278982137, 
          1.4740004431674054`}, {-6.447238260383328, 
          1.4014026031868727`}, {-5.986721241784519, 
          1.3290813243709094`}, {-5.52620422318571, 
          1.2571352382101395`}, {-5.0656872045869, 
          1.1856918682122954`}, {-4.605170185988091, 
          1.1149125498762726`}, {-4.144653167389282, 
          1.0449963584837056`}, {-3.684136148790473, 
          0.9761815456613713}, {-3.223619130191664, 
          0.9087435291746593}, {-2.7631021115928545`, 
          0.842987066515287}, {-2.3025850929940455`, 
          0.7792324784387802}, {-1.8420680743952365`, 
          0.7177952806709859}, {-1.3815510557964272`, 
          0.6589612444702977}, {-0.9210340371976181, 
          0.6029612123639754}, {-0.4605170185988088, 0.5499508067524739}, {0.,
           0.49999998783685684`}, {0.4605170185988092, 0.4530978485122238}, {
          0.9210340371976184, 0.4091700268370286}, {1.3815510557964277`, 
          0.368106259556425}, {1.842068074395237, 0.3297890355594972}, {
          2.302585092994046, 0.29411622073948673`}, {2.763102111592855, 
          0.26101321967613833`}, {3.2236191301916644`, 
          0.23043199049577703`}, {3.6841361487904734`, 
          0.20234134013918215`}, {4.144653167389283, 0.17671182271716218`}, {
          4.605170185988092, 0.15350240751522745`}, {5.065687204586901, 
          0.13264920558966864`}, {5.52620422318571, 0.11406135515227529`}, {
          5.986721241784519, 0.09762098421254495}, {6.447238260383328, 
          0.08318726133266809}, {6.907755278982137, 0.07060262774672178}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{-6.907755278982137, 0.},
       FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
            FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
            FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["0.1`", TraditionalForm]}, {0, 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{-6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
            FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["\" \"", TraditionalForm]}, {0, 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}},
       GridLines->{None, None},
       Method->{},
       PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
        1.4740004431674054`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]},
       Ticks->{{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}], {193.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{{-6.907755278982137, 
          10.290325810232407`}, {-6.447238260383328, 
          8.580321919738218}, {-5.986721241784519, 
          7.1561485085428505`}, {-5.52620422318571, 
          5.970017207664098}, {-5.0656872045869, 
          4.982161339725415}, {-4.605170185988091, 
          4.159485604071565}, {-4.144653167389282, 
          3.4744432622899275`}, {-3.684136148790473, 
          2.9041000524376632`}, {-3.223619130191664, 
          2.429356341520353}, {-2.7631021115928545`, 
          2.0342978787484407`}, {-2.3025850929940455`, 
          1.7056568808026527`}, {-1.8420680743952365`, 
          1.432360988264859}, {-1.3815510557964272`, 
          1.2051609644915455`}, {-0.9210340371976181, 
          1.016319734095791}, {-0.4605170185988088, 0.8593556804614323}, {0., 
          0.7288320205312776}, {0.4605170185988092, 0.6201838492975345}, {
          0.9210340371976184, 0.5295783130652391}, {1.3815510557964277`, 
          0.4538018830476881}, {1.842068074395237, 0.39017019625361476`}, {
          2.302585092994046, 0.336455165138273}, {2.763102111592855, 
          0.29082431396366587`}, {3.2236191301916644`, 0.2517894158941708}, {
          3.6841361487904734`, 0.2181591285746555}, {4.144653167389283, 
          0.1889942649635258}, {4.605170185988092, 0.1635645379964798}, {
          5.065687204586901, 0.14130684014149114`}, {5.52620422318571, 
          0.12178638497072868`}, {5.986721241784519, 0.10466292972298535`}, {
          6.447238260383328, 0.08966238662372072}, {6.907755278982137, 
          0.07655577177713492}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{-6.907755278982137, 0.},
       FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
            FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
            FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["0.1`", TraditionalForm]}, {0, 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{-6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
            FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["\" \"", TraditionalForm]}, {0, 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}},
       GridLines->{None, None},
       Method->{},
       PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
        10.290325810232407`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]},
       Ticks->{{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}], {580.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}], InsetBox[
      GraphicsBox[{{}, {}, 
        {Hue[0.67, 0.6, 0.6], 
         LineBox[{{-6.907755278982137, 
          3.6439417073537212`}, {-6.447238260383328, 
          3.363650806124881}, {-5.986721241784519, 
          3.0884429693706505`}, {-5.52620422318571, 
          2.819868327157697}, {-5.0656872045869, 
          2.5596903697610007`}, {-4.605170185988091, 
          2.309799756110288}, {-4.144653167389282, 
          2.0720895883529855`}, {-3.684136148790473, 
          1.8483091304858763`}, {-3.223619130191664, 
          1.6399231853233784`}, {-2.7631021115928545`, 
          1.4479971207184574`}, {-2.3025850929940455`, 
          1.2731294711116914`}, {-1.8420680743952365`, 
          1.115434247199399}, {-1.3815510557964272`, 
          0.9745708222906425}, {-0.9210340371976181, 
          0.8498081151265615}, {-0.4605170185988088, 0.7401084926785721}, {0.,
           0.6442193830638951}, {0.4605170185988092, 0.5607625671619177}, {
          0.9210340371976184, 0.4883147044233318}, {1.3815510557964277`, 
          0.42547588451229285`}, {1.842068074395237, 0.3709250531251281}, {
          2.302585092994046, 0.323460006512643}, {2.763102111592855, 
          0.2820237192962708}, {3.2236191301916644`, 0.2457156430215716}, {
          3.6841361487904734`, 0.213789713634602}, {4.144653167389283, 
          0.18564179407774065`}, {4.605170185988092, 0.16078897596074854`}, {
          5.065687204586901, 0.13884532473753913`}, {5.52620422318571, 
          0.11949762730983278`}, {5.986721241784519, 0.10248382365207793`}, {
          6.447238260383328, 0.0875759272900484}, {6.907755278982137, 
          0.07456862679949579}}]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{-6.907755278982137, 0.},
       FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
            FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
            FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["0.1`", TraditionalForm]}, {0, 
            FormBox["1", TraditionalForm]}, {2.302585092994046, 
            FormBox["10", TraditionalForm]}, {4.605170185988092, 
            FormBox["100", TraditionalForm]}, {6.907755278982137, 
            FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}, {{-6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
            FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
            FormBox["\" \"", TraditionalForm]}, {0, 
            FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
            FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
            FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
            FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.809142990314028, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.521460917862246, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-5.115995809754082, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.961845129926823, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.8283137373023015`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-4.710530701645918, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.506557897319982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-3.2188758248682006`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.8134107167600364`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.659260036932778, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.5257286443082556`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-2.4079456086518722`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-1.203972804325936, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.916290731874155, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.5108256237659905, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.3566749439387323, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.2231435513142097, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {-0.10536051565782628`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {0.6931471805599453, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.0986122886681098`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.3862943611198906`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.6094379124341003`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.791759469228055, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {1.9459101490553132`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.0794415416798357`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.1972245773362196`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {2.995732273553991, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.4011973816621555`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.6888794541139363`, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {3.912023005428146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.0943445622221, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.248495242049359, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.382026634673881, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {4.499809670330265, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.298317366548036, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.703782474656201, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {5.991464547107982, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.214608098422191, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.396929655216146, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.551080335043404, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.684611727667927, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}, {6.802394763324311, 
            FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
             Thickness[0.001]}}}}},
       GridLines->{None, None},
       Method->{},
       PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
        3.6439417073537212`}},
       PlotRangeClipping->True,
       PlotRangePadding->{
         Scaled[0.02], 
         Scaled[0.02]},
       Ticks->{{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, Automatic}], {967.5, -597.9478841155232}, 
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996215`}]}}, {}},
  ContentSelectable->True,
  ImageSize->{604.8000000000001, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.424891928829255*^9, 3.425306505279359*^9, 
  3.426569979653521*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
Plot integrals Ib1, Ib2 and Ib3 as a function of \[Mu] and Flow\
\>", "Text",
 CellChangeTimes->{{3.424891446826866*^9, 3.424891474004988*^9}, {
  3.424891669093254*^9, 3.424891671752541*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Ib1", "[", 
              RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Ib1", "[", 
              RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Ib1", "[", 
              RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Ib2", "[", 
              RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Ib2", "[", 
              RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Ib2", "[", 
              RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Ib3", "[", 
              RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Ib3", "[", 
              RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Ib3", "[", 
              RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.424889303603925*^9, 3.424889310548273*^9}, {
  3.424890355200005*^9, 3.424890366917762*^9}, {3.424916854259739*^9, 
  3.424916924763473*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, -0.7154928685862963}, \
{-6.447238260383328, -0.6920440301164876}, {-5.986721241784519, \
-0.6666765017885324}, {-5.52620422318571, -0.6392004468672763}, \
{-5.0656872045869, -0.6094214599332799}, {-4.605170185988091, \
-0.5771507766403002}, {-4.144653167389282, -0.542220385541814}, \
{-3.684136148790473, -0.5045052375376966}, {-3.223619130191664, \
-0.4639526350425953}, {-2.7631021115928545`, -0.42061839209130397`}, \
{-2.3025850929940455`, -0.37470680023477465`}, {-1.8420680743952365`, \
-0.32660803945697886`}, {-1.3815510557964272`, -0.2769234070781438}, \
{-0.9210340371976181, -0.22646473633144096`}, {-0.4605170185988088, \
-0.1762181689293778}, {0., -0.12726608099301664`}, {
         0.4605170185988092, -0.08067531224318518}, {
         0.9210340371976184, -0.03737354501230109}, {1.3815510557964277`, 
         0.0019573732423156047`}, {1.842068074395237, 
         0.036942420235025204`}, {2.302585092994046, 0.06751604687886906}, {
         2.763102111592855, 0.0938723298558203}, {3.2236191301916644`, 
         0.11638297346158355`}, {3.6841361487904734`, 0.1355101004897093}, {
         4.144653167389283, 0.15173341138270063`}, {4.605170185988092, 
         0.16550119867105537`}, {5.065687204586901, 0.177205525227599}, {
         5.52620422318571, 0.18717553104446294`}, {5.986721241784519, 
         0.1956817333385738}, {6.447238260383328, 0.20294511606170085`}, {
         6.907755278982137, 0.20914715250051885`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.7154928685862963},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.7154928685862963, 0.20914715250051885`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, -1.1848686915643256`}, \
{-6.447238260383328, -1.1684186944801385`}, {-5.986721241784519, \
-1.1491076923475259`}, {-5.52620422318571, -1.126510002931191}, \
{-5.0656872045869, -1.1001632183135146`}, {-4.605170185988091, \
-1.0695764707452822`}, {-4.144653167389282, -1.034244358455156}, \
{-3.684136148790473, -0.993667984249961}, {-3.223619130191664, \
-0.9473861950482912}, {-2.7631021115928545`, -0.8950172547701691}, \
{-2.3025850929940455`, -0.8363127616016327}, {-1.8420680743952365`, \
-0.7712218564187521}, {-1.3815510557964272`, -0.6999630992844347}, \
{-0.9210340371976181, -0.623094180665061}, {-0.4605170185988088, \
-0.5415686344432474}, {0., -0.4567600743319901}, {
         0.4605170185988092, -0.3704365018997221}, {
         0.9210340371976184, -0.2846684761337994}, {
         1.3815510557964277`, -0.20166796103219797`}, {
         1.842068074395237, -0.12357133433582315`}, {
         2.302585092994046, -0.05220582157264549}, {2.763102111592855, 
         0.011114850508475778`}, {3.2236191301916644`, 0.06571227308521285}, {
         3.6841361487904734`, 0.11155603707734044`}, {4.144653167389283, 
         0.14917019380410398`}, {4.605170185988092, 0.17946687080817128`}, {
         5.065687204586901, 0.20355722115199604`}, {5.52620422318571, 
         0.222583476133253}, {5.986721241784519, 0.23759923590210197`}, {
         6.447238260383328, 0.24950387170340302`}, {6.907755278982137, 
         0.25902238494795804`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -1.1848686915643256`},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-1.1848686915643256`, 0.25902238494795804`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, -1.1848686915643256`}, \
{-6.447238260383328, -1.1684186944801385`}, {-5.986721241784519, \
-1.1491076923475259`}, {-5.52620422318571, -1.126510002931191}, \
{-5.0656872045869, -1.1001632183135146`}, {-4.605170185988091, \
-1.0695764707452822`}, {-4.144653167389282, -1.034244358455156}, \
{-3.684136148790473, -0.993667984249961}, {-3.223619130191664, \
-0.9473861950482912}, {-2.7631021115928545`, -0.8950172547701691}, \
{-2.3025850929940455`, -0.8363127616016327}, {-1.8420680743952365`, \
-0.7712218564187521}, {-1.3815510557964272`, -0.6999630992844347}, \
{-0.9210340371976181, -0.623094180665061}, {-0.4605170185988088, \
-0.5415686344432474}, {0., -0.4567600743319901}, {
         0.4605170185988092, -0.3704365018997221}, {
         0.9210340371976184, -0.2846684761337994}, {
         1.3815510557964277`, -0.20166796103219797`}, {
         1.842068074395237, -0.12357133433582315`}, {
         2.302585092994046, -0.05220582157264549}, {2.763102111592855, 
         0.011114850508475778`}, {3.2236191301916644`, 0.06571227308521285}, {
         3.6841361487904734`, 0.11155603707734044`}, {4.144653167389283, 
         0.14917019380410398`}, {4.605170185988092, 0.17946687080817128`}, {
         5.065687204586901, 0.20355722115199604`}, {5.52620422318571, 
         0.222583476133253}, {5.986721241784519, 0.23759923590210197`}, {
         6.447238260383328, 0.24950387170340302`}, {6.907755278982137, 
         0.25902238494795804`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -1.1848686915643256`},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-1.1848686915643256`, 0.25902238494795804`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, 
         0.25153203522219303`}, {-6.447238260383328, 
         0.22438172776665613`}, {-5.986721241784519, 
         0.19822758032411567`}, {-5.52620422318571, 
         0.17318141321894936`}, {-5.0656872045869, 
         0.14936493194270606`}, {-4.605170185988091, 
         0.1269079367857649}, {-4.144653167389282, 
         0.10594508480004804`}, {-3.684136148790473, 
         0.08661093419386034}, {-3.223619130191664, 
         0.06903300885971066}, {-2.7631021115928545`, 
         0.05332302844961233}, {-2.3025850929940455`, 
         0.03956654522291713}, {-1.8420680743952365`, 
         0.027812259306032455`}, {-1.3815510557964272`, 
         0.018061619191755654`}, {-0.9210340371976181, 
         0.010261017312414869`}, {-0.4605170185988088, 
         0.004297389943076081}, {0., 1.4231885628610834`*^-9}, {
         0.4605170185988092, -0.0028513993261587147`}, {
         0.9210340371976184, -0.004511687489134973}, {
         1.3815510557964277`, -0.005249653992809293}, {
         1.842068074395237, -0.00532601865329913}, {
         2.302585092994046, -0.004973291010505306}, {
         2.763102111592855, -0.004381983766361946}, {
         3.2236191301916644`, -0.003694801980007395}, {
         3.6841361487904734`, -0.0030084491947749608`}, {
         4.144653167389283, -0.0023806256044965743`}, {
         4.605170185988092, -0.001839486427470078}, {
         5.065687204586901, -0.0013929814492159999`}, {
         5.52620422318571, -0.0010367934232276617`}, {
         5.986721241784519, -0.0007602355722384426}, {
         6.447238260383328, -0.000550228482773657}, {
         6.907755278982137, -0.00039370183265854025`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.00532601865329913},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.00532601865329913, 0.25153203522219303`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.051759846894027, 
         3.0944307581849544`}, {-5.986721241784519, 
         2.981969280587535}, {-5.52620422318571, 
         2.3429034199398386`}, {-5.0656872045869, 
         1.8315933823482433`}, {-4.605170185988091, 
         1.4239017690868256`}, {-4.144653167389282, 
         1.1000848846992533`}, {-3.684136148790473, 
         0.8440085114814841}, {-3.223619130191664, 
         0.642502319891887}, {-2.7631021115928545`, 
         0.48482826254490463`}, {-2.3025850929940455`, 
         0.3622431493392064}, {-1.8420680743952365`, 
         0.2676382281530602}, {-1.3815510557964272`, 
         0.19524392026735246`}, {-0.9210340371976181, 
         0.14038617994978722`}, {-0.4605170185988088, 0.09928692439470771}, {
         0., 0.06890014329707249}, {0.4605170185988092, 
         0.04677758867261656}, {0.9210340371976184, 0.030959002626189006`}, {
         1.3815510557964277`, 0.01988294146205432}, {1.842068074395237, 
         0.012314991574919896`}, {2.302585092994046, 0.007289501574439024}, {
         2.763102111592855, 0.00406190027063357}, {3.2236191301916644`, 
         0.002069706470695927}, {3.6841361487904734`, 0.000898606954432853}, {
         4.144653167389283, 0.0002527828537903966}, {
         4.605170185988092, -0.00007153435072951792}, {
         5.065687204586901, -0.00020915940510326852`}, {
         5.52620422318571, -0.00024545655182110266`}, {
         5.986721241784519, -0.0002319251054555976}, {
         6.447238260383328, -0.00019792503671234773`}, {
         6.907755278982137, -0.00015907199611196415`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.00024545655182110266`},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.00024545655182110266`, 3.0944307581849544`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, 
         1.4486780648482132`}, {-6.447238260383328, 
         1.2714313154551002`}, {-5.986721241784519, 
         1.1032997340696435`}, {-5.52620422318571, 
         0.9455927483084833}, {-5.0656872045869, 
         0.7995751419931963}, {-4.605170185988091, 
         0.6663574354518501}, {-4.144653167389282, 
         0.5467806570751766}, {-3.684136148790473, 
         0.44132002393271696`}, {-3.223619130191664, 
         0.3500268074105517}, {-2.7631021115928545`, 
         0.2725194321338391}, {-2.3025850929940455`, 
         0.20802349706282675`}, {-1.8420680743952365`, 
         0.155450916813198}, {-1.3815510557964272`, 
         0.11349993438052859`}, {-0.9210340371976181, 
         0.08075746908453267}, {-0.4605170185988088, 0.055792991668041324`}, {
         0., 0.037232406412262886`}, {0.4605170185988092, 
         0.023811009349677052`}, {0.9210340371976184, 
         0.014406009284296398`}, {1.3815510557964277`, 
         0.008052302640091177}, {1.842068074395237, 0.003945653431637279}, {
         2.302585092994046, 0.0014362925533462942`}, {2.763102111592855, 
         0.00001712979342607544}, {
         3.2236191301916644`, -0.000693041146249709}, {
         3.6841361487904734`, -0.0009686887741759283}, {
         4.144653167389283, -0.0009982116419841726}, {
         4.605170185988092, -0.0009039590176845609}, {
         5.065687204586901, -0.000760436694595713}, {
         5.52620422318571, -0.0006094521584125154}, {
         5.986721241784519, -0.00047185901659235627`}, {
         6.447238260383328, -0.0003559517700364472}, {
         6.907755278982137, -0.0002631098366265245}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.0009982116419841726},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.0009982116419841726, 1.4486780648482132`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, 
         0.5223808669258958}, {-6.447238260383328, 
         0.46902968454716826`}, {-5.986721241784519, 
         0.4173703398022572}, {-5.52620422318571, 
         0.3676096856026034}, {-5.0656872045869, 
         0.3199665612761861}, {-4.605170185988091, 
         0.2746785230629045}, {-4.144653167389282, 
         0.23199831513688213`}, {-3.684136148790473, 
         0.192187770841431}, {-3.223619130191664, 
         0.15550097227020865`}, {-2.7631021115928545`, 
         0.12218252283129177`}, {-2.3025850929940455`, 
         0.09244382900249755}, {-1.8420680743952365`, 
         0.06643767094463987}, {-1.3815510557964272`, 
         0.04425002507839244}, {-0.9210340371976181, 
         0.025874640057872576`}, {-0.4605170185988088, 
         0.011199422970509259`}, {0., -5.9601618106357985`*^-9}, {
         0.4605170185988092, -0.008055606447746746}, {
         0.9210340371976184, -0.013389190132856655`}, {
         1.3815510557964277`, -0.016479737641729785`}, {
         1.842068074395237, -0.017822697340818427`}, {
         2.302585092994046, -0.017889138578577025`}, {
         2.763102111592855, -0.017092170072076956`}, {
         3.2236191301916644`, -0.015767656687397873`}, {
         3.6841361487904734`, -0.014170479883637545`}, {
         4.144653167389283, -0.012480940162963403`}, {
         4.605170185988092, -0.010818628276782493`}, {
         5.065687204586901, -0.009256593346530196}, {
         5.52620422318571, -0.007834901016185052}, {
         5.986721241784519, -0.00657113490759271}, {
         6.447238260383328, -0.005468109817351031}, {
         6.907755278982137, -0.004519475099190792}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.017889138578577025`},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.017889138578577025`, 0.5223808669258958}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, 9.351037593926831}, {-6.447238260383328,
          7.667002441869427}, {-5.986721241784519, 
         6.269717993555571}, {-5.52620422318571, 
         5.111363493741565}, {-5.0656872045869, 
         4.152148118721249}, {-4.605170185988091, 
         3.358924771881668}, {-4.144653167389282, 
         2.704099945409551}, {-3.684136148790473, 
         2.16466838686687}, {-3.223619130191664, 
         1.7214577409033465`}, {-2.7631021115928545`, 
         1.3584767490140122`}, {-2.3025850929940455`, 
         1.0623774016307237`}, {-1.8420680743952365`, 
         0.8220151956431818}, {-1.3815510557964272`, 
         0.6280584936502873}, {-0.9210340371976181, 
         0.47271102158936174`}, {-0.4605170185988088, 0.3494230253275123}, {
         0., 0.2526923999871994}, {0.4605170185988092, 0.1778630225631642}, {
         0.9210340371976184, 0.12098027118628615`}, {1.3815510557964277`, 
         0.07866000132448436}, {1.842068074395237, 0.04799383027564357}, {
         2.302585092994046, 0.026479004792002468`}, {2.763102111592855, 
         0.011975890506663726`}, {3.2236191301916644`, 
         0.0026844801406166346`}, {
         3.6841361487904734`, -0.00286990915738165}, {
         4.144653167389283, -0.005854612759624771}, {
         4.605170185988092, -0.007155500088424094}, {
         5.065687204586901, -0.0074144330436636844`}, {
         5.52620422318571, -0.007075071546828055}, {
         5.986721241784519, -0.006429021809350379}, {
         6.447238260383328, -0.005658707506453881}, {
         6.907755278982137, -0.004871884717580104}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.0074144330436636844`},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.0074144330436636844`, 9.351037593926831}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, 
         2.5308353151135528`}, {-6.447238260383328, 
         2.275565855568527}, {-5.986721241784519, 
         2.0279065426780676`}, {-5.52620422318571, 
         1.789520081738564}, {-5.0656872045869, 
         1.5622238816928649`}, {-4.605170185988091, 
         1.3478716769270678`}, {-4.144653167389282, 
         1.1482198069747729`}, {-3.684136148790473, 
         0.9647838832985536}, {-3.223619130191664, 
         0.7987048242443485}, {-2.7631021115928545`, 
         0.6506581085188327}, {-2.3025850929940455`, 
         0.5208143349102756}, {-1.8420680743952365`, 
         0.40883668362718384`}, {-1.3815510557964272`, 
         0.31396762769686765`}, {-0.9210340371976181, 
         0.23507624631831486`}, {-0.4605170185988088, 0.17078541118061297`}, {
         0., 0.11954005061941937`}, {0.4605170185988092, 
         0.07970363633023105}, {0.9210340371976184, 0.049614546799508594`}, {
         1.3815510557964277`, 0.027646236356300185`}, {1.842068074395237, 
         0.012251944156861018`}, {2.302585092994046, 
         0.0020104893082169653`}, {
         2.763102111592855, -0.004345086437531076}, {
         3.2236191301916644`, -0.007892377830483382}, {
         3.6841361487904734`, -0.009508158003407574}, {
         4.144653167389283, -0.009871083344687366}, {
         4.605170185988092, -0.009478887116699563}, {
         5.065687204586901, -0.008677711295418724}, {
         5.52620422318571, -0.007695010105892763}, {
         5.986721241784519, -0.00667187481770114}, {
         6.447238260383328, -0.005689756102326311}, {
         6.907755278982137, -0.0047912680945903455`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.009871083344687366},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.009871083344687366, 2.5308353151135528`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic},
      ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.42489246772495*^9, 3.424925079016284*^9, 
  3.425307253739716*^9}]
}, Open  ]],

Cell["\<\
Plot integrals B1, B2 and B3 as a function of \[Mu] and Flow\
\>", "Text",
 CellChangeTimes->{{3.424891446826866*^9, 3.424891474004988*^9}, {
  3.424891669093254*^9, 3.424891671752541*^9}, {3.426569968295788*^9, 
  3.426569976972571*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"B1", "[", 
              RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"B1", "[", 
              RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"B1", "[", 
              RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"B2", "[", 
              RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"B2", "[", 
              RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"B2", "[", 
              RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"B3", "[", 
              RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"B3", "[", 
              RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ListLogLinearPlot", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"\[Mu]ramp", ",", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"B3", "[", 
              RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
           "]"}]}], "}"}], "]"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}]}], 
  "}"}]], "Input",
 CellChangeTimes->{{3.424889303603925*^9, 3.424889310548273*^9}, {
  3.424890355200005*^9, 3.424890366917762*^9}, {3.424916854259739*^9, 
  3.424916924763473*^9}, {3.426570016648416*^9, 3.426570045195274*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, 
         0.5580642075038521}, {-6.447238260383328, 
         0.5816981830868727}, {-5.986721241784519, 
         0.607358375505083}, {-5.52620422318571, 
         0.6352965521810734}, {-5.0656872045869, 
         0.6658040982905564}, {-4.605170185988091, 
         0.6992209251384846}, {-4.144653167389282, 
         0.7359491467676627}, {-3.684136148790473, 
         0.776473446838809}, {-3.223619130191664, 
         0.8213932529239321}, {-2.7631021115928545`, 
         0.8714731086266907}, {-2.3025850929940455`, 
         0.9277201914439395}, {-1.8420680743952365`, 
         0.9914999624345602}, {-1.3815510557964272`, 
         1.064701127073791}, {-0.9210340371976181, 
         1.1499606826097255`}, {-0.4605170185988088, 1.2509519548252497`}, {
         0., 1.3727339190069854`}, {0.4605170185988092, 
         1.5221508177715641`}, {0.9210340371976184, 1.7082695730835593`}, {
         1.3815510557964277`, 1.9428526716280754`}, {1.842068074395237, 
         2.240881457237931}, {2.302585092994046, 2.621173289183224}, {
         2.763102111592855, 3.1071604185851665`}, {3.2236191301916644`, 
         3.7279145660339856`}, {3.6841361487904734`, 4.519510007473678}, {
         4.144653167389283, 5.526818076044203}, {4.605170185988092, 
         6.805831561710103}, {5.065687204586901, 8.426633123235987}, {
         5.52620422318571, 10.477149505777666`}, {5.986721241784519, 
         13.067875731978715`}, {6.13890527202751, 14.148468858038354`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, 0.},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
       14.148468858038354`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, 
         0.09606804596969143}, {-6.447238260383328, 
         0.11498516123898606`}, {-5.986721241784519, 
         0.13755606341572535`}, {-5.52620422318571, 
         0.16446195139257314`}, {-5.0656872045869, 
         0.19650332665797032`}, {-4.605170185988091, 
         0.23461841489447943`}, {-4.144653167389282, 
         0.27990447571208654`}, {-3.684136148790473, 
         0.3336431888351219}, {-3.223619130191664, 
         0.3973304076374756}, {-2.7631021115928545`, 
         0.47271429954955346`}, {-2.3025850929940455`, 
         0.5618453162395224}, {-1.8420680743952365`, 
         0.667146280688143}, {-1.3815510557964272`, 
         0.7915126314775839}, {-0.9210340371976181, 
         0.938461052275356}, {-0.4605170185988088, 1.1123465098875864`}, {0., 
         1.3186770127436034`}, {0.4605170185988092, 1.5645541767798137`}, {
         0.9210340371976184, 1.8592681131725715`}, {1.3815510557964277`, 
         2.21506583858675}, {1.842068074395237, 2.648102887489333}, {
         2.302585092994046, 3.1795736745952388`}, {2.763102111592855, 
         3.8370258819297662`}, {3.2236191301916644`, 4.655876361036351}, {
         3.6841361487904734`, 5.681194125838413}, {4.144653167389283, 
         6.9698673522096115`}, {4.605170185988092, 8.593324562190942}, {
         5.065687204586901, 10.641023494524017`}, {5.52620422318571, 
         13.224948993887816`}, {5.986721241784519, 16.485390887171235`}, {
         6.447238260383328, 20.59831356816878}, {6.907755278982137, 
         25.784695224073005`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, 0.},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
       25.784695224073005`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, 
         0.09606804596969143}, {-6.447238260383328, 
         0.11498516123898606`}, {-5.986721241784519, 
         0.13755606341572535`}, {-5.52620422318571, 
         0.16446195139257314`}, {-5.0656872045869, 
         0.19650332665797032`}, {-4.605170185988091, 
         0.23461841489447943`}, {-4.144653167389282, 
         0.27990447571208654`}, {-3.684136148790473, 
         0.3336431888351219}, {-3.223619130191664, 
         0.3973304076374756}, {-2.7631021115928545`, 
         0.47271429954955346`}, {-2.3025850929940455`, 
         0.5618453162395224}, {-1.8420680743952365`, 
         0.667146280688143}, {-1.3815510557964272`, 
         0.7915126314775839}, {-0.9210340371976181, 
         0.938461052275356}, {-0.4605170185988088, 1.1123465098875864`}, {0., 
         1.3186770127436034`}, {0.4605170185988092, 1.5645541767798137`}, {
         0.9210340371976184, 1.8592681131725715`}, {1.3815510557964277`, 
         2.21506583858675}, {1.842068074395237, 2.648102887489333}, {
         2.302585092994046, 3.1795736745952388`}, {2.763102111592855, 
         3.8370258819297662`}, {3.2236191301916644`, 4.655876361036351}, {
         3.6841361487904734`, 5.681194125838413}, {4.144653167389283, 
         6.9698673522096115`}, {4.605170185988092, 8.593324562190942}, {
         5.065687204586901, 10.641023494524017`}, {5.52620422318571, 
         13.224948993887816`}, {5.986721241784519, 16.485390887171235`}, {
         6.447238260383328, 20.59831356816878}, {6.907755278982137, 
         25.784695224073005`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, 0.},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
       25.784695224073005`}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, -1.2224684250192224`}, \
{-6.447238260383328, -1.1770208983545842`}, {-5.986721241784519, \
-1.1308537440467936`}, {-5.52620422318571, -1.08395382499119}, \
{-5.0656872045869, -1.0363269506251407`}, {-4.605170185988091, \
-0.9880046291936821}, {-4.144653167389282, -0.9390512736836574}, \
{-3.684136148790473, -0.8895706114675108}, {-3.223619130191664, \
-0.8397105203149485}, {-2.7631021115928545`, -0.7896640380656746}, \
{-2.3025850929940455`, -0.739665933215863}, {-1.8420680743952365`, \
-0.6899830213649534}, {-1.3815510557964272`, -0.6408996252785414}, \
{-0.9210340371976181, -0.5927001950515605}, {-0.4605170185988088, \
-0.5456534168093978}, {0., -0.4999999864136683}, {
         0.4605170185988092, -0.45594924783838253`}, {
         0.9210340371976184, -0.4136817143261635}, {
         1.3815510557964277`, -0.3733559135492343}, {
         1.842068074395237, -0.3351150542127963}, {
         2.302585092994046, -0.29908951174999154`}, {
         2.763102111592855, -0.2653952034425003}, {
         3.2236191301916644`, -0.2341267924757838}, {
         3.6841361487904734`, -0.20534978933395712`}, {
         4.144653167389283, -0.17909244832165874`}, {
         4.605170185988092, -0.15534189394269754`}, {
         5.065687204586901, -0.13404218703888465`}, {
         5.52620422318571, -0.11509814857550293`}, {
         5.986721241784519, -0.09838121858601903}, {
         6.447238260383328, -0.08373747988681111}, {
         6.907755278982137, -0.07099632743079455}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -1.2224684250192224`},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-1.2224684250192224`, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, -6.601777576900246}, \
{-6.447238260383328, -5.6610444415446235`}, {-5.986721241784519, \
-4.853760108693275}, {-5.52620422318571, -4.160896688756124}, \
{-5.0656872045869, -3.566187992799133}, {-4.605170185988091, \
-3.055722041924169}, {-4.144653167389282, -2.617593588938859}, \
{-3.684136148790473, -2.2416081509683856`}, {-3.223619130191664, \
-1.9190298299207806`}, {-2.7631021115928545`, -1.6423649383836159`}, \
{-2.3025850929940455`, -1.405179383640543}, {-1.8420680743952365`, \
-1.2019404080240697`}, {-1.3815510557964272`, -1.0278849111303798`}, \
{-0.9210340371976181, -0.8789060360582843}, {-0.4605170185988088, \
-0.7514581353297409}, {0., -0.6424778428470153}, {
         0.4605170185988092, -0.5493174044383168}, {
         0.9210340371976184, -0.4696898088001633}, {
         1.3815510557964277`, -0.40162221784288876`}, {
         1.842068074395237, -0.3434167851134983}, {
         2.302585092994046, -0.29361635626412624`}, {
         2.763102111592855, -0.2509745986883883}, {
         3.2236191301916644`, -0.21442934890269405`}, {
         3.6841361487904734`, -0.183078891854632}, {
         4.144653167389283, -0.15616060251235434`}, {
         4.605170185988092, -0.13303194085477124`}, {
         5.065687204586901, -0.11315283054441867`}, {
         5.52620422318571, -0.09606922820406802}, {
         5.986721241784519, -0.08139849511187727}, {
         6.447238260383328, -0.06881598460591073}, {
         6.907755278982137, -0.05804393410650461}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -6.601777576900246},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-6.601777576900246, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, -2.452678421722762}, \
{-6.447238260383328, -2.323005547823988}, {-5.986721241784519, \
-2.1898987867801316`}, {-5.52620422318571, -2.0537833101755845`}, \
{-5.0656872045869, -1.9153657487380826`}, {-4.605170185988091, \
-1.7756455446625052`}, {-4.144653167389282, -1.6358885685884788`}, \
{-3.684136148790473, -1.497558092134239}, {-3.223619130191664, \
-1.3622148249601964`}, {-2.7631021115928545`, -1.2313979487718199`}, \
{-2.3025850929940455`, -1.1065122951078668`}, {-1.8420680743952365`, \
-0.9887334388828014}, {-1.3815510557964272`, -0.8789464066460836}, \
{-0.9210340371976181, -0.7777201998392673}, {-0.4605170185988088, \
-0.6853123315747842}, {0., -0.6017000276963693}, {
         0.4605170185988092, -0.5266273022017138}, {
         0.9210340371976184, -0.45965992366760605`}, {
         1.3815510557964277`, -0.40024115189304943`}, {
         1.842068074395237, -0.3477433617253164}, {
         2.302585092994046, -0.30151163484300003`}, {
         2.763102111592855, -0.2608980522725153}, {
         3.2236191301916644`, -0.22528652076235403`}, {
         3.6841361487904734`, -0.1941082296884639}, {
         4.144653167389283, -0.16685005746366066`}, {
         4.605170185988092, -0.14305604619470877`}, {
         5.065687204586901, -0.12232455414396248`}, {
         5.52620422318571, -0.10430246400416458`}, {
         5.986721241784519, -0.08867815281784247}, {
         6.447238260383328, -0.07517430944188658}, {
         6.907755278982137, -0.06354274139540465}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -2.452678421722762},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-2.452678421722762, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, -0.07930163135345913}, \
{-6.447238260383328, -0.07769774321997537}, {-5.986721241784519, \
-0.07597591538072102}, {-5.52620422318571, -0.07412713139462404}, \
{-5.0656872045869, -0.0721437755780091}, {-4.605170185988091, \
-0.07001950223444733}, {-4.144653167389282, -0.06774983694556863}, \
{-3.684136148790473, -0.06533281456832835}, {-3.223619130191664, \
-0.06277021307537088}, {-2.7631021115928545`, -0.06006704901036367}, \
{-2.3025850929940455`, -0.05723238739711523}, {-1.8420680743952365`, \
-0.054279800435203224`}, {-1.3815510557964272`, -0.05122593494932543}, \
{-0.9210340371976181, -0.048090547217628524`}, {-0.4605170185988088, \
-0.04489594864849705}, {0., -0.041666666149751765`}, {
         0.4605170185988092, -0.03842945456749623}, {
         0.9210340371976184, -0.03521326808082377}, {
         1.3815510557964277`, -0.03204883309984623}, {
         1.842068074395237, -0.02896764440893553}, {
         2.302585092994046, -0.026000446515489085`}, {
         2.763102111592855, -0.023175449145684607`}, {
         3.2236191301916644`, -0.02051663673342102}, {
         3.6841361487904734`, -0.01804265137742674}, {
         4.144653167389283, -0.0157660635733438}, {
         4.605170185988092, -0.013693419649686693`}, {
         5.065687204586901, -0.011825483244683237`}, {
         5.52620422318571, -0.010158021347371694`}, {
         5.986721241784519, -0.008682676593344804}, {
         6.447238260383328, -0.007387947709747867}, {
         6.907755278982137, -0.0062601752371593804`}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.07930163135345913},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.07930163135345913, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, -0.07827403021397883}, \
{-6.447238260383328, -0.07610995709604247}, {-5.986721241784519, \
-0.07386920983907919}, {-5.52620422318571, -0.07155445162639706}, \
{-5.0656872045869, -0.06916776841701384}, {-4.605170185988091, \
-0.0667134033632818}, {-4.144653167389282, -0.06419527356806738}, \
{-3.684136148790473, -0.06161929814077072}, {-3.223619130191664, \
-0.05899155005141722}, {-2.7631021115928545`, -0.056318427490979574`}, \
{-2.3025850929940455`, -0.05360662326432741}, {-1.8420680743952365`, \
-0.050862149413059866`}, {-1.3815510557964272`, -0.048091872570104846`}, \
{-0.9210340371976181, -0.045300726042202435`}, {-0.4605170185988088, \
-0.04249438792782667}, {0., -0.039678301712006515`}, {
         0.4605170185988092, -0.03686006889453085}, {
         0.9210340371976184, -0.03404983682324607}, {
         1.3815510557964277`, -0.03126182295374584}, {
         1.842068074395237, -0.028514697164830932`}, {
         2.302585092994046, -0.025831346696095315`}, {
         2.763102111592855, -0.023237368593109323`}, {
         3.2236191301916644`, -0.020758744646129514`}, {
         3.6841361487904734`, -0.01841908647766976}, {
         4.144653167389283, -0.016237406207257783`}, {
         4.605170185988092, -0.014226669840408657`}, {
         5.065687204586901, -0.012393439432096235`}, {
         5.52620422318571, -0.010738454743607191`}, {
         5.986721241784519, -0.009257662627694644}, {
         6.447238260383328, -0.007943424584514662}, {
         6.907755278982137, -0.006785638041226252}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.07827403021397883},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.07827403021397883, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}], ",", 
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], 
        LineBox[{{-6.907755278982137, -0.09275886616524394}, \
{-6.447238260383328, -0.09067374587969615}, {-5.986721241784519, \
-0.08837803555771524}, {-5.52620422318571, -0.0858623521014023}, \
{-5.0656872045869, -0.08312220733901132}, {-4.605170185988091, \
-0.08016067326526835}, {-4.144653167389282, -0.07698914978933237}, \
{-3.684136148790473, -0.0736271039322769}, {-3.223619130191664, \
-0.07010153009347365}, {-2.7631021115928545`, -0.06644491768330206}, \
{-2.3025850929940455`, -0.06269292821092926}, {-1.8420680743952365`, \
-0.05888313119342693}, {-1.3815510557964272`, -0.05505026658895971}, \
{-0.9210340371976181, -0.05122765573402055}, {-0.4605170185988088, \
-0.047443590224389744`}, {0., -0.04372327770366431}, {
         0.4605170185988092, -0.040088244240444146`}, {
         0.9210340371976184, -0.03655834649425331}, {
         1.3815510557964277`, -0.03315247046640568}, {
         1.842068074395237, -0.02988942574767784}, {
         2.302585092994046, -0.026787459767035504`}, {
         2.763102111592855, -0.023864067144483487`}, {
         3.2236191301916644`, -0.02113400196368087}, {
         3.6841361487904734`, -0.018608156073274318`}, {
         4.144653167389283, -0.016292739785202334`}, {
         4.605170185988092, -0.01418898814829643}, {
         5.065687204586901, -0.01229358633607982}, {
         5.52620422318571, -0.01059938645131046}, {
         5.986721241784519, -0.009096308205814922}, {
         6.447238260383328, -0.0077721402826978914`}, {
         6.907755278982137, -0.006613324400271959}}]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->True,
      AxesOrigin->{-6.907755278982137, -0.09275886616524394},
      FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm]}, {0, 
           FormBox["1", TraditionalForm]}, {2.302585092994046, 
           FormBox["10", TraditionalForm]}, {4.605170185988092, 
           FormBox["100", TraditionalForm]}, {6.907755278982137, 
           FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}, {{-6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
           FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
           FormBox["\" \"", TraditionalForm]}, {0, 
           FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
           FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
           FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
           FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.809142990314028, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.521460917862246, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-5.115995809754082, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.961845129926823, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.8283137373023015`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-4.710530701645918, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.506557897319982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-3.2188758248682006`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.8134107167600364`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.659260036932778, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.5257286443082556`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-2.4079456086518722`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-1.203972804325936, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.916290731874155, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.5108256237659905, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.3566749439387323, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.2231435513142097, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {-0.10536051565782628`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {0.6931471805599453, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.0986122886681098`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.3862943611198906`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.6094379124341003`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.791759469228055, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {1.9459101490553132`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.0794415416798357`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.1972245773362196`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {2.995732273553991, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.4011973816621555`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.6888794541139363`, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {3.912023005428146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.0943445622221, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.248495242049359, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.382026634673881, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {4.499809670330265, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.298317366548036, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.703782474656201, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {5.991464547107982, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.214608098422191, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.396929655216146, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.551080335043404, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.684611727667927, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}, {6.802394763324311, 
           FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
            Thickness[0.001]}}}}},
      GridLines->{None, None},
      Method->{},
      PlotRange->{{-6.907755278982137, 
       6.907755278982137}, {-0.09275886616524394, 0.}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]},
      Ticks->{{{-6.907755278982137, 
          FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
          FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
          FormBox["0.1`", TraditionalForm]}, {0, 
          FormBox["1", TraditionalForm]}, {2.302585092994046, 
          FormBox["10", TraditionalForm]}, {4.605170185988092, 
          FormBox["100", TraditionalForm]}, {6.907755278982137, 
          FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.809142990314028, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.521460917862246, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-5.115995809754082, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.961845129926823, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.8283137373023015`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-4.710530701645918, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.506557897319982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-3.2188758248682006`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.8134107167600364`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.659260036932778, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.5257286443082556`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-2.4079456086518722`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-1.203972804325936, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.916290731874155, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.5108256237659905, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.3566749439387323, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.2231435513142097, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {-0.10536051565782628`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {0.6931471805599453, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.0986122886681098`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.3862943611198906`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.6094379124341003`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.791759469228055, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {1.9459101490553132`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.0794415416798357`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.1972245773362196`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {2.995732273553991, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.4011973816621555`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.6888794541139363`, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {3.912023005428146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.0943445622221, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.248495242049359, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.382026634673881, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {4.499809670330265, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.298317366548036, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.703782474656201, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {5.991464547107982, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.214608098422191, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.396929655216146, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.551080335043404, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.684611727667927, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}, {6.802394763324311, 
          FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
           Thickness[0.001]}}}, Automatic}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.426570625277624*^9}]
}, Open  ]],

Cell["\<\
Plot the discriminant as a function of \[Mu] and Flow\
\>", "Text",
 CellChangeTimes->{{3.424891715574697*^9, 3.42489173368573*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ListLogLinearPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"\[Mu]ramp", ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"DD", "[", 
            RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
         "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListLogLinearPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"\[Mu]ramp", ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"DD", "[", 
            RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
         "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListLogLinearPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"\[Mu]ramp", ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"DD", "[", 
            RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
         "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.424890421409757*^9, 3.424890428723513*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{{-6.907755278982137, 0.05240654173706196}, {-6.447238260383328,
        0.05232069336017952}, {-5.986721241784519, 
       0.05220228383920215}, {-5.52620422318571, 
       0.0520463634440462}, {-5.0656872045869, 
       0.051848097763163896`}, {-4.605170185988091, 
       0.05160307602769542}, {-4.144653167389282, 
       0.05130799370011878}, {-3.684136148790473, 
       0.0509615866805651}, {-3.223619130191664, 
       0.050566020421333215`}, {-2.7631021115928545`, 
       0.05012840822082224}, {-2.3025850929940455`, 
       0.049662870398101924`}, {-1.8420680743952365`, 
       0.04919268298332078}, {-1.3815510557964272`, 
       0.0487520754195983}, {-0.9210340371976181, 
       0.048387638583477076`}, {-0.4605170185988088, 0.0481584738938885}, {0.,
        0.04813451626970269}, {0.4605170185988092, 0.04839281296141905}, {
       0.9210340371976184, 0.04901153451038345}, {1.3815510557964277`, 
       0.0500625138087133}, {1.842068074395237, 0.05160355472801011}, {
       2.302585092994046, 0.053672086913922466`}, {2.763102111592855, 
       0.056281783311021495`}, {3.2236191301916644`, 0.05942252874877521}, {
       3.6841361487904734`, 0.06306377419662168}, {4.144653167389283, 
       0.06715981809369846}, {4.605170185988092, 0.07165630943211236}, {
       5.065687204586901, 0.07649568697915957}, {5.52620422318571, 
       0.08162205990504351}, {5.986721241784519, 0.08698421609859326}, {
       6.447238260383328, 0.09253725609418366}, {6.907755278982137, 
       0.09824302439995126}}]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-6.907755278982137, 0.04813451626970269},
    FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
         FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\" \"", TraditionalForm]}, {0, 
         FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
         FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
         FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}},
    GridLines->{None, None},
    Method->{},
    PlotRange->{{-6.907755278982137, 6.907755278982137}, {0.04813451626970269,
      0.09824302439995126}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    Ticks->{{{-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0, 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.3566749439387323, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{{-6.907755278982137, 0.04900008713551764}, {-6.447238260383328,
        0.04979600646266565}, {-5.986721241784519, 
       0.05059075557442032}, {-5.52620422318571, 
       0.05137934072231363}, {-5.0656872045869, 
       0.05215608374310685}, {-4.605170185988091, 
       0.0529150557283154}, {-4.144653167389282, 
       0.05364994164149233}, {-3.684136148790473, 
       0.0543547948160548}, {-3.223619130191664, 
       0.05502425292781366}, {-2.7631021115928545`, 
       0.055654336137263075`}, {-2.3025850929940455`, 
       0.05624342762761853}, {-1.8420680743952365`, 
       0.05679337516568681}, {-1.3815510557964272`, 
       0.05731109922976708}, {-0.9210340371976181, 
       0.057809925821199044`}, {-0.4605170185988088, 0.05831138499462198}, {
       0., 0.058846491175768276`}, {0.4605170185988092, 
       0.05945659502855624}, {0.9210340371976184, 0.060193071025586034`}, {
       1.3815510557964277`, 0.06111559023625042}, {1.842068074395237, 
       0.06228872942074588}, {2.302585092994046, 0.06377691744035419}, {
       2.763102111592855, 0.06563850698623351}, {3.2236191301916644`, 
       0.06791982735807174}, {3.6841361487904734`, 0.07065047735461288}, {
       4.144653167389283, 0.07384075647663096}, {4.605170185988092, 
       0.07748181533020693}, {5.065687204586901, 0.08154818369370269}, {
       5.52620422318571, 0.08600183386903396}, {5.986721241784519, 
       0.09079719856269149}, {6.447238260383328, 0.09588564030257206}, {
       6.907755278982137, 0.10121925706029264`}}]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-6.907755278982137, 0.04900008713551764},
    FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
         FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\" \"", TraditionalForm]}, {0, 
         FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
         FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
         FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}},
    GridLines->{None, None},
    Method->{},
    PlotRange->{{-6.907755278982137, 6.907755278982137}, {0.04900008713551764,
      0.10121925706029264`}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    Ticks->{{{-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0, 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.3566749439387323, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{{-6.907755278982137, 0.05144746836264911}, {-6.447238260383328,
        0.05198302143147986}, {-5.986721241784519, 
       0.05251335968037789}, {-5.52620422318571, 
       0.05302984607396757}, {-5.0656872045869, 
       0.053522649971536385`}, {-4.605170185988091, 
       0.05398142021492877}, {-4.144653167389282, 
       0.05439611244592228}, {-3.684136148790473, 
       0.05475790661186536}, {-3.223619130191664, 
       0.05506048246677036}, {-2.7631021115928545`, 
       0.05530131709615017}, {-2.3025850929940455`, 
       0.05548322106971701}, {-1.8420680743952365`, 
       0.05561603242972409}, {-1.3815510557964272`, 
       0.05571782723720716}, {-0.9210340371976181, 
       0.05581667791777628}, {-0.4605170185988088, 0.055951179765717576`}, {
       0., 0.05617079136678535}, {0.4605170185988092, 0.0565347081942672}, {
       0.9210340371976184, 0.05710953395980679}, {1.3815510557964277`, 
       0.05796527303200796}, {1.842068074395237, 0.059170098686982406`}, {
       2.302585092994046, 0.060784358971889864`}, {2.763102111592855, 
       0.06285486317985813}, {3.2236191301916644`, 0.06541045435732105}, {
       3.6841361487904734`, 0.06845972165093767}, {4.144653167389283, 
       0.07199145568604849}, {4.605170185988092, 0.07597731634350044}, {
       5.065687204586901, 0.08037622437655553}, {5.52620422318571, 
       0.08513943563962141}, {5.986721241784519, 0.09021538580483919}, {
       6.447238260383328, 0.09555326295597677}, {6.907755278982137, 
       0.10110629381869587`}}]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-6.907755278982137, 0.05144746836264911},
    FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
         FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\" \"", TraditionalForm]}, {0, 
         FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
         FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
         FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}},
    GridLines->{None, None},
    Method->{},
    PlotRange->{{-6.907755278982137, 6.907755278982137}, {0.05144746836264911,
      0.10110629381869587`}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    Ticks->{{{-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0, 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.3566749439387323, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{3.424892928111224*^9, 3.425306390665242*^9, 
  3.426571205905881*^9}]
}, Open  ]],

Cell["\<\
Plot the critical length as a function of \[Mu] and Flow\
\>", "Text",
 CellChangeTimes->{{3.424891715574697*^9, 3.424891751117406*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ListLogLinearPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"\[Mu]ramp", ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]c", "[", 
            RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
         "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListLogLinearPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"\[Mu]ramp", ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]c", "[", 
            RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
         "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ListLogLinearPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"\[Mu]ramp", ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalGamma]c", "[", 
            RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], 
         "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.424890421409757*^9, 3.424890428723513*^9}, {
  3.42489049688799*^9, 3.424890502717987*^9}, {3.428925142961579*^9, 
  3.428925149719149*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{{-6.907755278982137, 4.0423551801075215`}, {-6.447238260383328,
        3.9478615989854218`}, {-5.986721241784519, 
       3.8510579655178616`}, {-5.52620422318571, 
       3.7518589878625153`}, {-5.0656872045869, 
       3.65020471090242}, {-4.605170185988091, 
       3.5460604549558994`}, {-4.144653167389282, 
       3.4394200500987564`}, {-3.684136148790473, 
       3.330306383562659}, {-3.223619130191664, 
       3.218770792205995}, {-2.7631021115928545`, 
       3.1048730244166083`}, {-2.3025850929940455`, 
       2.9886657471105833`}, {-1.8420680743952365`, 
       2.8701730424490326`}, {-1.3815510557964272`, 
       2.7493620151120894`}, {-0.9210340371976181, 
       2.6261416418290016`}, {-0.4605170185988088, 2.500391333803746}, {0., 
       2.372032767371313}, {0.4605170185988092, 2.241145675651554}, {
       0.9210340371976184, 2.1080976341928737`}, {1.3815510557964277`, 
       1.973640538815524}, {1.842068074395237, 1.838924764067585}, {
       2.302585092994046, 1.70540717226496}, {2.763102111592855, 
       1.5746765746265687`}, {3.2236191301916644`, 1.4482519180795086`}, {
       3.6841361487904734`, 1.327417136648593}, {4.144653167389283, 
       1.2131256717278247`}, {4.605170185988092, 1.1059817445461642`}, {
       5.065687204586901, 1.00627170616951}, {5.52620422318571, 
       0.9140261732659919}, {5.986721241784519, 0.829086267819778}, {
       6.447238260383328, 0.7511637766648663}, {6.907755278982137, 
       0.6798896190438858}}]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-6.907755278982137, 0.6798896190438858},
    FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
         FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\" \"", TraditionalForm]}, {0, 
         FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
         FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
         FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}},
    GridLines->{None, None},
    Method->{},
    PlotRange->{{-6.907755278982137, 6.907755278982137}, {0.6798896190438858, 
     4.0423551801075215`}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    Ticks->{{{-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0, 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.3566749439387323, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{{-6.907755278982137, 9.60610818052614}, {-6.447238260383328, 
       8.774960935965515}, {-5.986721241784519, 
       8.016541798144882}, {-5.52620422318571, 
       7.324544770686909}, {-5.0656872045869, 
       6.693186138849609}, {-4.605170185988091, 
       6.117206400416243}, {-4.144653167389282, 
       5.591783912058282}, {-3.684136148790473, 
       5.112521185329832}, {-3.223619130191664, 
       4.675382814644134}, {-2.7631021115928545`, 
       4.276660575080645}, {-2.3025850929940455`, 
       3.912940822217655}, {-1.8420680743952365`, 
       3.5810637733700035`}, {-1.3815510557964272`, 
       3.2781099934922815`}, {-0.9210340371976181, 
       3.00135436944646}, {-0.4605170185988088, 2.748269253274141}, {0., 
       2.516506573846703}, {0.4605170185988092, 2.303909756652561}, {
       0.9210340371976184, 2.1085217645293546`}, {1.3815510557964277`, 
       1.9286054281245395`}, {1.842068074395237, 1.7626590401551487`}, {
       2.302585092994046, 1.6094229436711942`}, {2.763102111592855, 
       1.467866735211849}, {3.2236191301916644`, 1.3371563654719345`}, {
       3.6841361487904734`, 1.2166051715897324`}, {4.144653167389283, 
       1.1056203028980625`}, {4.605170185988092, 1.0036562925514223`}, {
       5.065687204586901, 0.9101832387363141}, {5.52620422318571, 
       0.8246712035116419}, {5.986721241784519, 0.7465882378689336}, {
       6.447238260383328, 0.6754051193647809}, {6.907755278982137, 
       0.6106033012445088}}]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-6.907755278982137, 0.},
    FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
         FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\" \"", TraditionalForm]}, {0, 
         FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
         FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
         FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}},
    GridLines->{None, None},
    Method->{},
    PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
     9.60610818052614}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    Ticks->{{{-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0, 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.3566749439387323, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], 
      LineBox[{{-6.907755278982137, 6.048996065078709}, {-6.447238260383328, 
       5.81656690294152}, {-5.986721241784519, 
       5.57771978522926}, {-5.52620422318571, 
       5.3330912561725325`}, {-5.0656872045869, 
       5.083660995529088}, {-4.605170185988091, 
       4.830773831222596}, {-4.144653167389282, 
       4.576093808185019}, {-3.684136148790473, 
       4.321513110622855}, {-3.223619130191664, 
       4.069033530837282}, {-2.7631021115928545`, 
       3.8206237385035458`}, {-2.3025850929940455`, 
       3.578088633810803}, {-1.8420680743952365`, 
       3.3429704243436564`}, {-1.3815510557964272`, 
       3.1164613065181737`}, {-0.9210340371976181, 
       2.8993997797534456`}, {-0.4605170185988088, 2.692263787102441}, {0., 
       2.495232346311145}, {0.4605170185988092, 2.3082512308077794`}, {
       0.9210340371976184, 2.131125928649174}, {1.3815510557964277`, 
       1.9636068778142721`}, {1.842068074395237, 1.8054618100249367`}, {
       2.302585092994046, 1.6565147196290437`}, {2.763102111592855, 
       1.5166526953781014`}, {3.2236191301916644`, 1.385796508040003}, {
       3.6841361487904734`, 1.2638576318374057`}, {4.144653167389283, 
       1.1506973397244553`}, {4.605170185988092, 1.0460997149217959`}, {
       5.065687204586901, 0.9497651471183611}, {5.52620422318571, 
       0.8613198916534947}, {5.986721241784519, 0.7803349613009718}, {
       6.447238260383328, 0.7063466564611766}, {6.907755278982137, 
       0.6388771788908144}}]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{-6.907755278982137, 0.},
    FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
         FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
         FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["0.1`", TraditionalForm]}, {0, 
         FormBox["1", TraditionalForm]}, {2.302585092994046, 
         FormBox["10", TraditionalForm]}, {4.605170185988092, 
         FormBox["100", TraditionalForm]}, {6.907755278982137, 
         FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
         FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
         FormBox["\" \"", TraditionalForm]}, {0, 
         FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
         FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
         FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
         FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.809142990314028, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.521460917862246, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-5.115995809754082, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.961845129926823, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.8283137373023015`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-4.710530701645918, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.506557897319982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.659260036932778, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.203972804325936, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659905, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.3566749439387323, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6931471805599453, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.6094379124341003`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.9459101490553132`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.995732273553991, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.4011973816621555`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.912023005428146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.248495242049359, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.382026634673881, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.499809670330265, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.298317366548036, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.703782474656201, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {5.991464547107982, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.214608098422191, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.396929655216146, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.551080335043404, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.684611727667927, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {6.802394763324311, 
         FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}},
    GridLines->{None, None},
    Method->{},
    PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
     6.048996065078709}},
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]},
    Ticks->{{{-6.907755278982137, 
        FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
        FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
        FormBox["0.1`", TraditionalForm]}, {0, 
        FormBox["1", TraditionalForm]}, {2.302585092994046, 
        FormBox["10", TraditionalForm]}, {4.605170185988092, 
        FormBox["100", TraditionalForm]}, {6.907755278982137, 
        FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.809142990314028, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.521460917862246, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-5.115995809754082, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.961845129926823, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.8283137373023015`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-4.710530701645918, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.506557897319982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.659260036932778, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.203972804325936, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659905, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.3566749439387323, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6931471805599453, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.6094379124341003`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.9459101490553132`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.995732273553991, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.4011973816621555`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.912023005428146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.248495242049359, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.382026634673881, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.499809670330265, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.298317366548036, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.703782474656201, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {5.991464547107982, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.214608098422191, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.396929655216146, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.551080335043404, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.684611727667927, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {6.802394763324311, 
        FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{3.424893826905694*^9, 3.425305506840788*^9, 
  3.42657254753125*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Produce printing plots", "Subsubsection",
 CellChangeTimes->{{3.425531335647607*^9, 3.425531344038675*^9}, {
  3.425531385162336*^9, 3.425531386520633*^9}, {3.425531425204352*^9, 
  3.425531428191239*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"q1", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalGamma]c", "[", 
       RowBox[{"#", ",", "Flow1"}], "]"}], "&"}], ",", "\[Mu]ramp"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q2", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalGamma]c", "[", 
       RowBox[{"#", ",", "Flow2"}], "]"}], "&"}], ",", "\[Mu]ramp"}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"q3", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[CapitalGamma]c", "[", 
       RowBox[{"#", ",", "Flow3"}], "]"}], "&"}], ",", "\[Mu]ramp"}], "]"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.425492594769479*^9, 3.425492645646095*^9}, {
  3.428925158731032*^9, 3.428925166138958*^9}}],

Cell["Let us print to make plots at a later stage", "Text",
 CellChangeTimes->{{3.425531353274261*^9, 3.425531374393469*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"q1", "\[IndentingNewLine]", "q2", "\[IndentingNewLine]", \
"q3"}], "Input",
 CellChangeTimes->{{3.425497337534492*^9, 3.425497356748871*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "47.28257784760713`", ",", "45.84844695141114`", ",", "44.37726255147321`", 
   ",", "42.86782428028812`", ",", "41.31954989473787`", ",", 
   "39.73238179057725`", ",", "38.10685200648799`", ",", 
   "36.444095974399126`", ",", "34.74594770480177`", ",", 
   "33.01448891162936`", ",", "31.251940010371488`", ",", 
   "29.460496760282467`", ",", "27.641903871011916`", ",", 
   "25.797812026044884`", ",", "23.930596571795974`", ",", 
   "22.044892644209597`", ",", "20.14966842327096`", ",", 
   "18.260138551586998`", ",", "16.398540768862233`", ",", 
   "14.592987918037048`", ",", "12.874284916791115`", ",", 
   "11.271524273467596`", ",", "9.80784368501927`", ",", "8.49760973708331`", 
   ",", "7.345503518216519`", ",", "6.347406164651336`", ",", 
   "5.492399259156113`", ",", "4.765299508577772`", ",", "4.149082695670043`",
    ",", "3.62682618772824`", ",", "3.1829890903503406`"}], "}"}]], "Output",
 CellChangeTimes->{3.425497358113675*^9, 3.42657353541981*^9, 
  3.441484514417881*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "113.20193627383895`", ",", "102.05985327543526`", ",", 
   "91.95655489316762`", ",", "82.7998862815422`", ",", "74.50484896439966`", 
   ",", "66.99467796302777`", ",", "60.19858833553462`", ",", 
   "54.05232120654386`", ",", "48.49666764735779`", ",", "43.47708165445877`",
    ",", "38.943233279461005`", ",", "34.84831270528717`", ",", 
   "31.149303500767747`", ",", "27.805854815869633`", ",", 
   "24.781089208232537`", ",", "22.041278926631378`", ",", 
   "19.55659983646459`", ",", "17.30133086113823`", ",", 
   "15.254334764198783`", ",", "13.39910274292078`", ",", 
   "11.723409021457684`", ",", "10.218336459695925`", ",", 
   "8.876837076402603`", ",", "7.692079259836858`", ",", "6.656040115495349`",
    ",", "5.758652210721824`", ",", "4.987691770730866`", ",", 
   "4.329323440863164`", ",", "3.7690189426076066`", ",", 
   "3.2925333020761918`", ",", "2.886686739238628`"}], "}"}]], "Output",
 CellChangeTimes->{3.425497358113675*^9, 3.42657353541981*^9, 
  3.441484514439585*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "75.06830773899121`", ",", "71.48093995154939`", ",", "67.80596828984415`", 
   ",", "64.05722613166806`", ",", "60.2540798322643`", ",", 
   "56.42176737288244`", ",", "52.59032024115657`", ",", 
   "48.792739127824085`", ",", "45.06285629612044`", ",", 
   "41.43280296461557`", ",", "37.930816003261945`", ",", 
   "34.579942366937125`", ",", "31.396434687451237`", ",", 
   "28.390591830460302`", ",", "25.566688313368648`", ",", 
   "22.924846120782124`", ",", "20.462384481479308`", ",", 
   "18.175818383664563`", ",", "16.06222958790718`", ",", 
   "14.120148914225162`", ",", "12.3494168189507`", ",", 
   "10.750410955987771`", ",", "9.322442892866654`", ",", 
   "8.062308778399858`", ",", "6.963283904638537`", ",", "6.014877857290173`",
    ",", "5.20341192284512`", ",", "4.5131548266230785`", ",", 
   "3.927679159680956`", ",", "3.4310807180689387`", ",", 
   "3.008863463447038`"}], "}"}]], "Output",
 CellChangeTimes->{3.425497358113675*^9, 3.42657353541981*^9, 
  3.441484514547417*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLogLinearPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"\[Mu]ramp", ",", "q1"}], "}"}], "]"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"\[Mu]ramp", ",", "q2"}], "}"}], "]"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"\[Mu]ramp", ",", "q3"}], "}"}], "]"}]}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Black", ",", "Thick"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Thick", ",", "Dashed"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Black", ",", "Thick", ",", "Dotted"}], "}"}]}], "}"}]}], ",", 
   
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ToExpression", "[", 
       RowBox[{"\"\<\\mu\>\"", ",", "TeXForm"}], "]"}], ",", 
      RowBox[{"ToExpression", "[", 
       RowBox[{"\"\<\\Gamma_c\>\"", ",", "TeXForm"}], "]"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.424890421409757*^9, 3.424890428723513*^9}, {
  3.42489049688799*^9, 3.424890502717987*^9}, {3.425524311531318*^9, 
  3.42552437212536*^9}, {3.425524462688011*^9, 3.425524526160057*^9}, {
  3.425524574305666*^9, 3.425524588555791*^9}, {3.425524655222858*^9, 
  3.42552465591427*^9}, {3.425524703604943*^9, 3.425524744385344*^9}, {
  3.428925238873928*^9, 3.428925241288549*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {GrayLevel[0], Thickness[Large], 
    LineBox[{{-6.907755278982137, 47.28257784760713}, {-6.447238260383328, 
     45.84844695141114}, {-5.986721241784519, 
     44.37726255147321}, {-5.52620422318571, 
     42.86782428028812}, {-5.0656872045869, 
     41.31954989473787}, {-4.605170185988091, 
     39.73238179057725}, {-4.144653167389282, 
     38.10685200648799}, {-3.684136148790473, 
     36.444095974399126`}, {-3.223619130191664, 
     34.74594770480177}, {-2.7631021115928545`, 
     33.01448891162936}, {-2.3025850929940455`, 
     31.251940010371488`}, {-1.8420680743952365`, 
     29.460496760282467`}, {-1.3815510557964272`, 
     27.641903871011916`}, {-0.9210340371976181, 
     25.797812026044884`}, {-0.4605170185988088, 23.930596571795974`}, {0., 
     22.044892644209597`}, {0.4605170185988092, 20.14966842327096}, {
     0.9210340371976184, 18.260138551586998`}, {1.3815510557964277`, 
     16.398540768862233`}, {1.842068074395237, 14.592987918037048`}, {
     2.302585092994046, 12.874284916791115`}, {2.763102111592855, 
     11.271524273467596`}, {3.2236191301916644`, 9.80784368501927}, {
     3.6841361487904734`, 8.49760973708331}, {4.144653167389283, 
     7.345503518216519}, {4.605170185988092, 6.347406164651336}, {
     5.065687204586901, 5.492399259156113}, {5.52620422318571, 
     4.765299508577772}, {5.986721241784519, 4.149082695670043}, {
     6.447238260383328, 3.62682618772824}, {6.907755278982137, 
     3.1829890903503406`}}]}, 
   {GrayLevel[0], Thickness[Large], Dashing[{Small, Small}], 
    LineBox[{{-6.907755278982137, 113.20193627383895`}, {-6.447238260383328, 
     102.05985327543526`}, {-5.986721241784519, 
     91.95655489316762}, {-5.52620422318571, 
     82.7998862815422}, {-5.0656872045869, 
     74.50484896439966}, {-4.605170185988091, 
     66.99467796302777}, {-4.144653167389282, 
     60.19858833553462}, {-3.684136148790473, 
     54.05232120654386}, {-3.223619130191664, 
     48.49666764735779}, {-2.7631021115928545`, 
     43.47708165445877}, {-2.3025850929940455`, 
     38.943233279461005`}, {-1.8420680743952365`, 
     34.84831270528717}, {-1.3815510557964272`, 
     31.149303500767747`}, {-0.9210340371976181, 
     27.805854815869633`}, {-0.4605170185988088, 24.781089208232537`}, {0., 
     22.041278926631378`}, {0.4605170185988092, 19.55659983646459}, {
     0.9210340371976184, 17.30133086113823}, {1.3815510557964277`, 
     15.254334764198783`}, {1.842068074395237, 13.39910274292078}, {
     2.302585092994046, 11.723409021457684`}, {2.763102111592855, 
     10.218336459695925`}, {3.2236191301916644`, 8.876837076402603}, {
     3.6841361487904734`, 7.692079259836858}, {4.144653167389283, 
     6.656040115495349}, {4.605170185988092, 5.758652210721824}, {
     5.065687204586901, 4.987691770730866}, {5.52620422318571, 
     4.329323440863164}, {5.986721241784519, 3.7690189426076066`}, {
     6.447238260383328, 3.2925333020761918`}, {6.907755278982137, 
     2.886686739238628}}]}, 
   {GrayLevel[0], Thickness[Large], Dashing[{0, Small}], 
    LineBox[{{-6.907755278982137, 75.06830773899121}, {-6.447238260383328, 
     71.48093995154939}, {-5.986721241784519, 
     67.80596828984415}, {-5.52620422318571, 
     64.05722613166806}, {-5.0656872045869, 
     60.2540798322643}, {-4.605170185988091, 
     56.42176737288244}, {-4.144653167389282, 
     52.59032024115657}, {-3.684136148790473, 
     48.792739127824085`}, {-3.223619130191664, 
     45.06285629612044}, {-2.7631021115928545`, 
     41.43280296461557}, {-2.3025850929940455`, 
     37.930816003261945`}, {-1.8420680743952365`, 
     34.579942366937125`}, {-1.3815510557964272`, 
     31.396434687451237`}, {-0.9210340371976181, 
     28.390591830460302`}, {-0.4605170185988088, 25.566688313368648`}, {0., 
     22.924846120782124`}, {0.4605170185988092, 20.462384481479308`}, {
     0.9210340371976184, 18.175818383664563`}, {1.3815510557964277`, 
     16.06222958790718}, {1.842068074395237, 14.120148914225162`}, {
     2.302585092994046, 12.3494168189507}, {2.763102111592855, 
     10.750410955987771`}, {3.2236191301916644`, 9.322442892866654}, {
     3.6841361487904734`, 8.062308778399858}, {4.144653167389283, 
     6.963283904638537}, {4.605170185988092, 6.014877857290173}, {
     5.065687204586901, 5.20341192284512}, {5.52620422318571, 
     4.5131548266230785`}, {5.986721241784519, 3.927679159680956}, {
     6.447238260383328, 3.4310807180689387`}, {6.907755278982137, 
     3.008863463447038}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\[Mu]", TraditionalForm], 
    FormBox[
     SubscriptBox["\[CapitalGamma]", "c"], TraditionalForm]},
  AxesOrigin->{-6.907755278982137, 0.},
  FrameTicks->{{Automatic, Automatic}, {{{-6.907755278982137, 
       FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
       FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm]}, {0, 
       FormBox["1", TraditionalForm]}, {2.302585092994046, 
       FormBox["10", TraditionalForm]}, {4.605170185988092, 
       FormBox["100", TraditionalForm]}, {6.907755278982137, 
       FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.3566749439387323, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}, {{-6.907755278982137, 
       FormBox["\" \"", TraditionalForm]}, {-4.605170185988091, 
       FormBox["\" \"", TraditionalForm]}, {-2.3025850929940455`, 
       FormBox["\" \"", TraditionalForm]}, {0, 
       FormBox["\" \"", TraditionalForm]}, {2.302585092994046, 
       FormBox["\" \"", TraditionalForm]}, {4.605170185988092, 
       FormBox["\" \"", TraditionalForm]}, {6.907755278982137, 
       FormBox["\" \"", TraditionalForm]}, {-6.214608098422191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.809142990314028, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.521460917862246, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-5.115995809754082, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.961845129926823, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.8283137373023015`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-4.710530701645918, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.912023005428146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.506557897319982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-3.2188758248682006`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.8134107167600364`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.659260036932778, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.5257286443082556`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-2.4079456086518722`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.6094379124341003`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-1.203972804325936, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.916290731874155, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.6931471805599453, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.5108256237659905, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.3566749439387323, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.2231435513142097, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {-0.10536051565782628`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {0.6931471805599453, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.0986122886681098`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.3862943611198906`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.6094379124341003`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.791759469228055, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {1.9459101490553132`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.0794415416798357`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.1972245773362196`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {2.995732273553991, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.4011973816621555`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.6888794541139363`, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {3.912023005428146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.0943445622221, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.248495242049359, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.382026634673881, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {4.499809670330265, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.298317366548036, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.703782474656201, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {5.991464547107982, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.214608098422191, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.396929655216146, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.551080335043404, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.684611727667927, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}, {6.802394763324311, 
       FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
        Thickness[0.001]}}}}},
  GridLines->{None, None},
  Method->{},
  PlotRange->{{-6.907755278982137, 6.907755278982137}, {0., 
   113.20193627383895`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{{{-6.907755278982137, 
      FormBox["0.001`", TraditionalForm]}, {-4.605170185988091, 
      FormBox["0.01`", TraditionalForm]}, {-2.3025850929940455`, 
      FormBox["0.1`", TraditionalForm]}, {0, 
      FormBox["1", TraditionalForm]}, {2.302585092994046, 
      FormBox["10", TraditionalForm]}, {4.605170185988092, 
      FormBox["100", TraditionalForm]}, {6.907755278982137, 
      FormBox["1000", TraditionalForm]}, {-6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.809142990314028, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.521460917862246, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-5.115995809754082, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.961845129926823, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.8283137373023015`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-4.710530701645918, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.506557897319982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-3.2188758248682006`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.8134107167600364`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.659260036932778, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.5257286443082556`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-2.4079456086518722`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.6094379124341003`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-1.203972804325936, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.916290731874155, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.5108256237659905, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.3566749439387323, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.2231435513142097, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {-0.10536051565782628`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {0.6931471805599453, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.0986122886681098`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.3862943611198906`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.6094379124341003`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.791759469228055, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {1.9459101490553132`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.0794415416798357`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.1972245773362196`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {2.995732273553991, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.4011973816621555`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.6888794541139363`, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {3.912023005428146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.0943445622221, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.248495242049359, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.382026634673881, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {4.499809670330265, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.298317366548036, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.703782474656201, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {5.991464547107982, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.214608098422191, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.396929655216146, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.551080335043404, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.684611727667927, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}, {6.802394763324311, 
      FormBox["\" \"", TraditionalForm], {0.00375, 0.}, {
       Thickness[0.001]}}}, Automatic}]], "Output",
 CellChangeTimes->{3.426573537000821*^9, 3.428925245763762*^9, 
  3.441484531323427*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->{"RulerBar", "EditBar"},
Evaluator->"Local",
WindowSize->{1018, 721},
WindowMargins->{{117, Automatic}, {Automatic, 17}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"Magnification"->1,
"PaperOrientation"->"Portrait",
"PaperSize"->{597.562, 842.375},
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "d51", "legras", 
   "bbu", "math"}, "bch.nb.ps", CharacterEncoding -> "ISO8859-1"],
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->True,
"PrintingMargins"->{{54, 54}, {72, 72}}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Classroom.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 371, 8, 330, "Title",
 Evaluatable->False],
Cell[942, 31, 155, 2, 49, "Subtitle"],
Cell[CellGroupData[{
Cell[1122, 37, 157, 3, 55, "Subsection",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1304, 44, 103, 2, 45, "Subsubsection",
 Evaluatable->False],
Cell[1410, 48, 308, 11, 176, "Input",
 InitializationCell->True],
Cell[1721, 61, 943, 29, 126, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2713, 96, 57, 0, 69, "Section"],
Cell[2773, 98, 133, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[2931, 103, 140, 3, 55, "Subsection"],
Cell[CellGroupData[{
Cell[3096, 110, 133, 1, 45, "Subsubsection"],
Cell[3232, 113, 2060, 62, 241, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[5329, 180, 125, 1, 45, "Subsubsection"],
Cell[5457, 183, 333, 7, 175, "Text"],
Cell[5793, 192, 3138, 98, 177, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8980, 296, 283, 4, 55, "Subsection"],
Cell[9266, 302, 1387, 30, 132, "Text"],
Cell[10656, 334, 1599, 38, 107, "Input",
 InitializationCell->True],
Cell[12258, 374, 207, 4, 32, "Text"],
Cell[12468, 380, 1762, 46, 111, "Input"],
Cell[14233, 428, 245, 5, 68, "Text"],
Cell[14481, 435, 1660, 41, 170, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[16178, 481, 135, 1, 55, "Subsection"],
Cell[16316, 484, 1914, 46, 151, "Input"],
Cell[18233, 532, 242, 3, 32, "ExerciseText"],
Cell[18478, 537, 1058, 25, 58, "Input",
 Evaluatable->True],
Cell[CellGroupData[{
Cell[19561, 566, 138, 2, 45, "Subsubsection"],
Cell[19702, 570, 211, 4, 32, "Text"],
Cell[19916, 576, 2798, 63, 196, "Input"],
Cell[CellGroupData[{
Cell[22739, 643, 158, 3, 57, "Input"],
Cell[22900, 648, 39604, 665, 227, 30037, 506, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[62553, 1319, 235, 5, 34, "Subsubsection"],
Cell[62791, 1326, 91, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[62907, 1331, 699, 11, 58, "Input"],
Cell[63609, 1344, 41315, 695, 200, 31028, 526, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[104939, 2042, 269, 8, 58, "Input"],
Cell[105211, 2052, 426, 8, 68, "Text"],
Cell[CellGroupData[{
Cell[105662, 2064, 986, 26, 82, "Input"],
Cell[106651, 2092, 66498, 1216, 198, "Output"]
}, Open  ]],
Cell[173164, 3311, 240, 3, 32, "ExerciseText"],
Cell[173407, 3316, 815, 21, 58, "Input"],
Cell[CellGroupData[{
Cell[174247, 3341, 231, 4, 58, "Input"],
Cell[174481, 3347, 11265, 204, 199, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[185795, 3557, 113, 1, 45, "Subsubsection"],
Cell[185911, 3560, 317, 6, 32, "Text"],
Cell[186231, 3568, 693, 17, 85, "Input"],
Cell[186927, 3587, 843, 27, 105, "Input"],
Cell[CellGroupData[{
Cell[187795, 3618, 3647, 88, 305, "Input"],
Cell[191445, 3708, 76126, 1332, 570, 59991, 1067, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[267586, 5043, 1915, 48, 212, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[269562, 5098, 193, 2, 69, "Section"],
Cell[CellGroupData[{
Cell[269780, 5104, 98, 1, 55, "Subsection"],
Cell[269881, 5107, 3452, 90, 185, "Input",
 InitializationCell->True],
Cell[273336, 5199, 1054, 26, 114, "Definition"],
Cell[274393, 5227, 240, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[274658, 5236, 114, 1, 45, "Subsubsection"],
Cell[274775, 5239, 4872, 124, 660, "Input"],
Cell[279650, 5365, 266, 5, 31, "ExerciseText"],
Cell[279919, 5372, 821, 22, 57, "Definition"],
Cell[CellGroupData[{
Cell[280765, 5398, 185, 3, 57, "Input"],
Cell[280953, 5403, 77843, 1338, 566, "Output"]
}, Open  ]],
Cell[358811, 6744, 152, 3, 31, "Text"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[359012, 6753, 44, 0, 55, "Subsection"],
Cell[359059, 6755, 1447, 31, 186, "Definition"],
Cell[CellGroupData[{
Cell[360531, 6790, 180, 2, 45, "Subsubsection"],
Cell[360714, 6794, 630, 10, 116, "Text"],
Cell[361347, 6806, 2687, 57, 168, "Input",
 InitializationCell->True],
Cell[364037, 6865, 385, 7, 56, "Text"],
Cell[364425, 6874, 3338, 71, 222, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[367800, 6950, 252, 3, 45, "Subsubsection"],
Cell[368055, 6955, 2554, 59, 285, "Input"],
Cell[370612, 7016, 2512, 59, 285, "Input"],
Cell[373127, 7077, 154, 3, 32, "Text"],
Cell[373284, 7082, 861, 22, 58, "Input"],
Cell[CellGroupData[{
Cell[374170, 7108, 418, 6, 58, "Input"],
Cell[374591, 7116, 19242, 338, 183, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[393870, 7459, 274, 4, 58, "Input"],
Cell[394147, 7465, 17931, 317, 157, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[412127, 7788, 203, 4, 45, "Subsubsection"],
Cell[412333, 7794, 183, 4, 32, "Text"],
Cell[412519, 7800, 1195, 36, 198, "Input"],
Cell[413717, 7838, 452, 13, 81, "Input"],
Cell[CellGroupData[{
Cell[414194, 7855, 499, 12, 72, "Input"],
Cell[414696, 7869, 59288, 982, 275, 39243, 651, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[474021, 8856, 269, 7, 72, "Input"],
Cell[474293, 8865, 5901, 104, 315, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[480243, 8975, 165, 2, 34, "Subsubsection"],
Cell[480411, 8979, 243, 4, 56, "Text"],
Cell[480657, 8985, 2660, 53, 186, "Input",
 InitializationCell->True],
Cell[483320, 9040, 3210, 67, 168, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[486567, 9112, 203, 2, 45, "Subsubsection"],
Cell[486773, 9116, 2710, 62, 246, "Input"],
Cell[489486, 9180, 2641, 61, 212, "Input"],
Cell[CellGroupData[{
Cell[492152, 9245, 235, 4, 57, "Input"],
Cell[492390, 9251, 19964, 346, 171, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[512391, 9602, 235, 4, 57, "Input"],
Cell[512629, 9608, 19773, 343, 171, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[532439, 9956, 281, 4, 57, "Input"],
Cell[532723, 9962, 16973, 297, 170, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[549745, 10265, 214, 3, 34, "Subsubsection"],
Cell[549962, 10270, 301, 6, 56, "Text"],
Cell[550266, 10278, 2757, 54, 186, "Input",
 InitializationCell->True],
Cell[553026, 10334, 3287, 68, 168, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[556350, 10407, 201, 2, 45, "Subsubsection"],
Cell[556554, 10411, 2700, 62, 212, "Input"],
Cell[CellGroupData[{
Cell[559279, 10477, 207, 3, 57, "Input"],
Cell[559489, 10482, 19645, 345, 175, "Output"]
}, Open  ]],
Cell[579149, 10830, 2608, 60, 246, "Input"],
Cell[CellGroupData[{
Cell[581782, 10894, 321, 5, 57, "Input"],
Cell[582106, 10901, 17950, 317, 151, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[600129, 11226, 173, 2, 69, "Section"],
Cell[CellGroupData[{
Cell[600327, 11232, 134, 1, 55, "Subsection"],
Cell[CellGroupData[{
Cell[600486, 11237, 1398, 39, 97, "Subsubsection"],
Cell[601887, 11278, 585, 16, 111, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[602509, 11299, 118, 1, 45, "Subsubsection"],
Cell[CellGroupData[{
Cell[602652, 11304, 1141, 33, 165, "Input"],
Cell[603796, 11339, 25252, 435, 180, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[629085, 11779, 199, 4, 57, "Input"],
Cell[629287, 11785, 136, 2, 56, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[629472, 11793, 347, 9, 46, "Subsubsection"],
Cell[629822, 11804, 711, 21, 111, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[630570, 11830, 119, 1, 45, "Subsubsection"],
Cell[CellGroupData[{
Cell[630714, 11835, 2190, 62, 360, "Input"],
Cell[632907, 11899, 17756, 312, 190, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[650700, 12216, 294, 5, 57, "Input"],
Cell[650997, 12223, 208, 3, 56, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[651254, 12232, 412, 9, 46, "Subsubsection"],
Cell[651669, 12243, 808, 24, 111, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[652514, 12272, 119, 1, 45, "Subsubsection"],
Cell[CellGroupData[{
Cell[652658, 12277, 2563, 72, 360, "Input"],
Cell[655224, 12351, 25131, 433, 183, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[680392, 12789, 248, 5, 57, "Input"],
Cell[680643, 12796, 209, 3, 56, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[680913, 12806, 195, 2, 55, "Subsection"],
Cell[681111, 12810, 3254, 87, 369, "Input",
 InitializationCell->True],
Cell[684368, 12899, 196, 5, 32, "Text"],
Cell[684567, 12906, 2630, 75, 153, "Definition"],
Cell[687200, 12983, 179, 2, 32, "Text"],
Cell[687382, 12987, 2469, 71, 120, "Definition"],
Cell[689854, 13060, 106, 1, 32, "Text"],
Cell[689963, 13063, 1778, 55, 126, "Definition"],
Cell[CellGroupData[{
Cell[691766, 13122, 96, 1, 45, "Subsubsection"],
Cell[691865, 13125, 1036, 30, 165, "Input"],
Cell[CellGroupData[{
Cell[692926, 13159, 276, 4, 57, "Input"],
Cell[693205, 13165, 25841, 444, 180, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[719107, 13616, 120, 1, 55, "Subsection"],
Cell[CellGroupData[{
Cell[719252, 13621, 370, 8, 57, "Subsubsection"],
Cell[719625, 13631, 794, 22, 111, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[720456, 13658, 121, 1, 45, "Subsubsection"],
Cell[720580, 13661, 2172, 60, 338, "Input"],
Cell[CellGroupData[{
Cell[722777, 13725, 517, 8, 57, "Input"],
Cell[723297, 13735, 31038, 530, 167, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[754372, 14270, 290, 5, 57, "Input"],
Cell[754665, 14277, 296, 5, 56, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[755010, 14288, 372, 9, 34, "Subsubsection"],
Cell[755385, 14299, 839, 22, 111, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[756261, 14326, 119, 1, 45, "Subsubsection"],
Cell[756383, 14329, 2316, 62, 335, "Input"],
Cell[CellGroupData[{
Cell[758724, 14395, 486, 7, 57, "Input"],
Cell[759213, 14404, 38351, 652, 176, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[797601, 15061, 247, 5, 57, "Input"],
Cell[797851, 15068, 235, 4, 56, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[798135, 15078, 419, 10, 34, "Subsubsection"],
Cell[798557, 15090, 888, 23, 111, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[799482, 15118, 120, 1, 45, "Subsubsection"],
Cell[CellGroupData[{
Cell[799627, 15123, 2329, 63, 326, "Input"],
Cell[801959, 15188, 39047, 661, 184, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[841043, 15854, 320, 6, 79, "Input",
 InitializationCell->True],
Cell[841366, 15862, 376, 6, 78, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[841779, 15873, 284, 7, 58, "Input"],
Cell[842066, 15882, 231, 4, 57, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[842370, 15894, 251, 3, 69, "Section"],
Cell[842624, 15899, 180, 4, 32, "Text"],
Cell[842807, 15905, 1683, 48, 148, "Definition"],
Cell[CellGroupData[{
Cell[844515, 15957, 218, 4, 55, "Subsection"],
Cell[CellGroupData[{
Cell[844758, 15965, 316, 7, 105, "Input"],
Cell[845077, 15974, 109, 1, 57, "Output"],
Cell[845189, 15977, 110, 1, 57, "Output"],
Cell[845302, 15980, 111, 1, 57, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[845450, 15986, 319, 7, 105, "Input"],
Cell[845772, 15995, 105, 2, 57, "Output"],
Cell[845880, 15999, 92, 1, 59, "Output"],
Cell[845975, 16002, 108, 2, 59, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[846132, 16010, 99, 1, 34, "Subsection"],
Cell[846234, 16013, 947, 29, 160, "Input",
 InitializationCell->True],
Cell[847184, 16044, 949, 23, 79, "Input",
 InitializationCell->True],
Cell[848136, 16069, 901, 24, 142, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[849074, 16098, 93, 1, 55, "Subsection"],
Cell[CellGroupData[{
Cell[849192, 16103, 107, 1, 45, "Subsubsection"],
Cell[849302, 16106, 130, 3, 32, "Text"],
Cell[849435, 16111, 646, 17, 108, "Input"],
Cell[850084, 16130, 150, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[850259, 16137, 4569, 126, 266, "Input"],
Cell[854831, 16265, 209391, 3542, 508, 186165, 3159, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[1064237, 19810, 202, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[1064464, 19818, 4394, 126, 243, "Input"],
Cell[1068861, 19946, 207552, 3587, 514, "Output"]
}, Open  ]],
Cell[1276428, 23536, 248, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[1276701, 23545, 4431, 126, 243, "Input"],
Cell[1281135, 23673, 182217, 3158, 521, "Output"]
}, Open  ]],
Cell[1463367, 26834, 142, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[1463534, 26841, 1393, 41, 105, "Input"],
Cell[1464930, 26884, 58903, 1051, 173, "Output"]
}, Open  ]],
Cell[1523848, 27938, 146, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[1524019, 27945, 1532, 43, 105, "Input"],
Cell[1525554, 27990, 58701, 1051, 185, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1584304, 29047, 211, 3, 45, "Subsubsection"],
Cell[1584518, 29052, 824, 26, 126, "Input"],
Cell[1585345, 29080, 125, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[1585495, 29085, 156, 2, 126, "Input"],
Cell[1585654, 29089, 1043, 18, 123, "Output"],
Cell[1586700, 29109, 1044, 18, 123, "Output"],
Cell[1587747, 29129, 1047, 19, 123, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1588831, 29153, 1514, 38, 126, "Input"],
Cell[1590348, 29193, 22052, 407, 353, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
