(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    371003,       8842]
NotebookOptionsPosition[    357153,       8372]
NotebookOutlinePosition[    358263,       8413]
CellTagsIndexPosition[    358220,       8410]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Large-scale linear instability of the generalized Kolmogorov flow - viscous \
version with a general parallel flow\
\>", "Title",
 CellChangeTimes->{{3.426480892291388*^9, 3.426480893649936*^9}, {
  3.42648093558738*^9, 3.426480949600088*^9}}],

Cell["\<\
Bernard Legras
Laboratoire de Meteorologie Dynamique
Ecole Normale Superieure
24 rue Lhomond 
F-75231 PARIS Cedex 05
E-mail: legras@lmd.ens.fr
Barbara Villone
Istituto di Fisica dello Spazio Interplanetario
Corso Fiume, 4
I-10137 TORINO
E-mail: villone@to.infn.it \
\>", "Author"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["U of ",
  FontFamily->"Bitstream Vera Sans",
  FontSize->22],
 Cell[BoxData[
  RowBox[{
   StyleBox[
    RowBox[{"any", " ", "shape"}],
    FontFamily->"Bitstream Vera Sans"], 
   StyleBox[",",
    FontFamily->"Bitstream Vera Sans"], 
   StyleBox[" ",
    FontFamily->"Bitstream Vera Sans"], 
   RowBox[{
    StyleBox["periodic",
     FontFamily->"Bitstream Vera Sans"], 
    StyleBox[" ",
     FontFamily->"Bitstream Vera Sans"], 
    StyleBox["within",
     FontFamily->"Bitstream Vera Sans"], 
    StyleBox[" ",
     FontFamily->"Bitstream Vera Sans"], 
    StyleBox["the",
     FontFamily->"Bitstream Vera Sans"], 
    StyleBox[" ",
     FontFamily->"Bitstream Vera Sans"], 
    RowBox[{
     StyleBox["interval",
      FontFamily->"Bitstream Vera Sans"], 
     StyleBox[" ",
      FontFamily->"Bitstream Vera Sans"], 
     StyleBox["[",
      FontFamily->"Bitstream Vera Sans"], 
     RowBox[{
      StyleBox["0",
       FontFamily->"Bitstream Vera Sans"], 
      StyleBox[",",
       FontFamily->"Bitstream Vera Sans"], 
      RowBox[{
       StyleBox["2",
        FontFamily->"Bitstream Vera Sans"], 
       StyleBox[" ",
        FontFamily->"Bitstream Vera Sans"], "\[Pi]"}]}], "]"}]}]}]], 
  "Subtitle",
  CellChangeTimes->{{3.390680494242618*^9, 3.390680516400674*^9}, {
   3.390680636702491*^9, 3.390680688368319*^9}, {3.390680789791472*^9, 
   3.390680887673188*^9}},
  FontFamily->"Bitstream Vera Sans",
  FontSize->22],
 "\nwith the condition that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"2", " ", "\[Pi]"}]], 
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], 
      RowBox[{"\[DifferentialD]", "y"}]}]}], "=", "0"}], TraditionalForm]]],
 "\nStreamfunction defined as u=",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "y"], " ", "\[Psi]"}], ",", " ", 
    RowBox[{"v", "=", 
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["\[PartialD]", "x"], " ", "\[Psi]"}]}]}]}], 
   TraditionalForm]]]
}], "Subtitle",
 CellChangeTimes->{{3.390680524403904*^9, 3.390680524798521*^9}, 
   3.390680948926961*^9, {3.390680990757941*^9, 3.390681023342249*^9}, {
   3.390681107773295*^9, 3.39068112166876*^9}, {3.390682874160303*^9, 
   3.390682898126305*^9}, 3.39071539424611*^9, {3.424677408712554*^9, 
   3.424677417974085*^9}, 3.42502769441629*^9, {3.42503012978772*^9, 
   3.425030210829448*^9}, {3.426480974019255*^9, 3.426481016403617*^9}, {
   3.426481047110705*^9, 3.426481051509052*^9}}],

Cell[CellGroupData[{

Cell["Settings", "Section"],

Cell[CellGroupData[{

Cell["Last use", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateList", "[", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390664513231506*^9, 3.390664515612058*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2009", ",", "1", ",", "14", ",", "16", ",", "13", ",", 
   "15.80521`7.95137525564826"}], "}"}]], "Output",
 CellChangeTimes->{
  3.390664521734768*^9, 3.390682912749357*^9, {3.425027798133309*^9, 
   3.425027803437934*^9}, {3.426482180293307*^9, 3.426482183317142*^9}, {
   3.435242479294246*^9, 3.435242480307911*^9}, {3.44093479493312*^9, 
   3.440934795813716*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["General", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell1"}], "]"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Laplacian", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalDelta]", " ", "=", 
  RowBox[{
   RowBox[{"-", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], 
       RowBox[{
        SubscriptBox["\[PartialD]", 
         RowBox[{"X", ",", "X"}]], " ", "#"}]}], "+", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], "#"}]}], ")"}]}], "&"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Epsilon]", "2"], " ", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"X", ",", "X"}]], "#1"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{"y", ",", "y"}]], "#1"}]}], ")"}]}], "&"}]], "Output",
 CellChangeTimes->{3.390664533044221*^9, 3.39068291318328*^9, 
  3.425027798996962*^9, 3.426482180736617*^9, 3.435242479430207*^9, 
  3.440934795085541*^9}]
}, Open  ]],

Cell["Beware of the sign in the definition", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the dissipation", "Subsubsection"],

Cell["Standard viscosity", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DS", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", " ", "\[Nu]"}], " ", 
    RowBox[{"\[CapitalDelta]", "[", 
     RowBox[{"\[CapitalDelta]", "[", "#", "]"}], "]"}]}], "&"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.390664536069645*^9, 3.390664537994036*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "\[Nu]"}], " ", 
   RowBox[{"\[CapitalDelta]", "[", 
    RowBox[{"\[CapitalDelta]", "[", "#1", "]"}], "]"}]}], "&"}]], "Output",
 CellChangeTimes->{3.390664541114668*^9, 3.390682913297484*^9, 
  3.425027799064707*^9, 3.426482181546537*^9, 3.43524247951943*^9, 
  3.440934795185442*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the modified Kolmogorov Flow", "Section"],

Cell[CellGroupData[{

Cell["Velocity and streamfunction", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", "y_", "]"}], ":=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"U", "[", "s", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", 
      FractionBox["\[Pi]", "2"], ",", "y"}], "}"}]}], "]"}]}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exemples of flows ", "Subsection"],

Cell["Standard Kolmogorov flow in Flow1", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Flow2", "=", 
   RowBox[{"U", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"#", " ", "+", " ", 
        RowBox[{
         FractionBox["1", "2"], 
         RowBox[{"Sin", "[", " ", 
          RowBox[{"2", " ", "#"}], "]"}]}]}], "]"}], "&"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow1", " ", "=", 
   RowBox[{"U", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Sin", "[", "#", "]"}], " ", "&"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow3", "=", 
   RowBox[{"U", "\[Rule]", 
    RowBox[{"Evaluate", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"#", " ", "+", " ", 
        RowBox[{
         FractionBox["1", "4"], 
         RowBox[{"Sin", "[", " ", 
          RowBox[{"2", " ", "#"}], "]"}]}]}], "]"}], "&"}], "]"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.426481281073178*^9, 3.426481319783541*^9}, {
  3.426482297999084*^9, 3.426482307122083*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the flow", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], "  ", "/.", " ", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", 
        RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.390664567261077*^9, 3.390664618353984*^9}, {
  3.390754328799531*^9, 3.390754344128626*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtmnk8VN//x61F1pmxU6JI0p4+JTmXUNmVUJFShESLpJSyZEtlKdkiIlmy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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{(-2) Pi, 2 Pi}, {-0.9999996658276197, 
       0.9999993650500513}}, {{-6.283185307179586, 
      6.283185307179586}, {-0.9999996658276197, 0.9999993650500513}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwk23k8VF8bAHC7ss8YSyQqSqUoqUjOJClLESqpJJUSUZSlTZaflCVLaSFK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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{(-2) Pi, 2 Pi}, {-0.9999999999999937, 
       0.9999999999999951}}, {{-6.283185307179586, 
      6.283185307179586}, {-0.9999999999999937, 0.9999999999999951}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwtm3c0198fx21lfpYRiZRVkiRJct+EzMxKUaGSJKkkpRQJScNIiqyQjCi7
cN+yZ/bI3uMz3vYev/f3nN9fzuO4577vfb2ez9fr3nPPZ7f9bfNrLExMTMxs
TEz//TXQ5zu5tnsHavxBN6et8aPG8ZzH09t27UAV5AbH9b4/APK7qZ8FRXag
k28UVqjp/oBvpXL5EGkHShyeW5VP/wCakr2/O7LsQPlssrNfpXwFVtsWdrQP
CaPn+U1Ej8XmgeuV3dOZX4TRUtaD/ucfVAKrwwbRxTHC6GBnX8jLg1VALybf
sC5SGC2KyF13GK8C+x68TxoPFUYdHMeDJM7WAIa0ic0uX2G02zGny/hgPXD3
+1P56qowumeTDzO83gR8db5FO0gJowrhN6zZutoB+uqRqfhuYfTRowb+eeUO
sN5kyNK5UxhlO/eILehdB7h3iXFNn4LPX5KpmanbCewfHD4gz4rPfzZ9MfV7
FwDfin7PDAihC8/F3F4794BVnubOx1FCqOFgdPNw3QBQsfgSeCRCCM14rF17
f34A3P3ops4IFULltV5aNogOgkkpodjLr4TQCvXUzaYbg6BTw+a61iMh9MEd
lUc7WYdAruvYAqeVEJp9tqXj1b5hcKd1lRRKFkL1zuc9yTccBeHmJhfC+IXQ
clGGatyNUVDY+CXuPbcQ+sLsw6SF/yjgqDdSjGAVQktb9WWF/oyCqPJo489z
gqhb3Np5gSNjoCpXK+BriyCqcfXhqSXCOGAof/ib/FcQPZLaxOGzfxyQs6iC
KbWC6NuT82c7dMbBpYywxLRSQXRMV49p6OE4mPs69udHliC6A4ztfNQ/DnZ9
DNz4HSqIsjhpf2uInQDaQv3aRW8FUcXVNFn+/Alw4/3hoOJXguiZ7w/Ed/6d
ANnBPSIlzwVRvZ3MlKj1CaAfqKBacU8QbW2rylU9MwncPJvvNloIogNzT6Z5
NiZBzUWRiRGyIMr5LnvytSwVmMSog1V+QZSISZ9yOEYFrQOXwvl5BNG06gtP
yAZU0Hvli7YamyAa0Xrcge5EBdM35OPezgug7c+1BxNTqEDIXeOCWpsAuv7E
44GtJA1E5dn+MGkSQLv38Id+UaQBiRWfbdfqBVCl7U6eUIMG9j2uzH1bLoCO
72wu8LlAAxo+puTRHAG0YSRaXuMdDVx9Y1/3NlwAvcT10rl0ngYm//ruSQwR
QHd7DL3+yUQHLsSvj369EUBvCkemevHQwYMwquyonwB6bkuJ+n0PHQR+cnuh
9kAAVROpHHE3pYPMJD+N0XMC6O9THav9X+jgyETy+1ULAbSzwC2qOJ0OfsnV
0vhNBVCrS2t3vfLooDSNP1JNTwCt2T1ZHV9DB+0/I5beqgqgdjU9V19gdLBR
nJKptkMAnWpzH6MeZoC6fwd51igCaKXgQkiKOgNELWZf/00QQB/OaP7T12EA
dQW4S32bAPqx/OST/WcZ4NHnlqATSxT0ctGV7ufuDGBQYDWxMUtBLyQbyph6
McCOtt6TxQwKmucIX229YIB8nolVjTEKKvlNuW3bewZY9Fx3RNooqNRtrab6
HwxQ8cG7jKmJgtI+PjT8nc8A77M4JErqKGjvxS3wBjKAMpXQoVlGQSNn4+Bo
HQPcuyClczKLghYx7SVdGWOAadXTu3WDKejPS+e42igYQC1bHnO8pqC75Njz
jotg4K2rVWdFAAVN3LDWCBLHgEKy/dtTzygor4XhIFUOA7eEHmzo3aagmY6p
bmknMKB+eN1q+00Ker1aZclRCwM8Jt7Z1Q4U1DjF0ph4CgNpfq9uGlyioKKs
ktekTTEwtRDTZWhMQX2FibmOdhj4RZQ6wqNPQTdqXhsFXsPAywMp7+q0Kajy
720BH29gQPZa9iljdQrKsEup8b6DAYfWqpzT+yno2PLbK0+fYWD450yw2XZ8
vlUxunUkBqI4Vn0usFPQQ1I5KurRGDh7gcXtCjO+fwcfhD8OA1XM5LP3V8jo
WdXP0m+SMPDdVFnk4yQZNWNw7prLxMD1BHXu+FEyWvxm0/hWFgYklrXXUwbJ
6OXKBcvuHAyExpzpK+wio+fetN4I/YUBD4Z7/EA1Gb3yZEHiQSkGDmk9DZ0s
J6P2YgSv0HJ8v+/9fWdLyOidJMFvCZUYuHgiwoHtFxn1mp78l1iLAa2ggn2y
KWRUQmM6Q7oFA2v9JaKHkshoyn55H1orBrIP1/CoxZNRmpfbytd2DMh0/2MY
fiKjH6IsjjH9w+O9b/3n7UAy+vPl32DVAQyUP2FL8PAjo2sxjnu+D2LAq4nn
vbcPGX10OIQoMoyBGQ+xB6GPyKipPevZtlEMpNRJOUa5k9FGJr3WveMYuCqh
cD7xLhklOQhtOU1goL1S43ieE85MMwndUxh4J3pKHnUgo5gXQZuDhgH92yZi
1fZk1DJqtEOGjoFCQdutfxfIKNNLbwlTDANx17xLNw3IaPYiN0NlDgMXCl5m
c54io6576hgi8xig8IYkEk7i438ZXFzE2S873l/yOBlVOdaVG7qIAWRbqsf+
o2T06erlX2eWMLBinXVD+TAZ5SKE2vAvY8CZtcxQdz8Z3Tgen3xjBQNS5+rU
TWTIqPcRsetcqxjoS2k9YLWHjBIf+9DjcY7Y7NllJ47Ho5mhfXgNA2bmo/xO
ovj4h2zuv3HmSqIz3RMio7U61IDj6xgoW1mY8SST0eps0xdZOKvEcbS+5iaj
L5Smzr7awIDa3zvVmpxk1OWz6fAszhobPcULLGTUJ3mLz2wTz+9+vexvmyR0
STd2IBFn3fNZ3y6uklCC+uFLMzgb+O+KIS6SUG4F4uvDWxg4nfMyrHyGhArk
Td1xxtl8eP7lQzoJVXKrIkThfI5o+/TAJAmVJXHf+oOzDah1Gxwhoaesbr7s
x9n2lorT+wF8/KHV63M4X42Mu6zfQ0If/5Dg2sTZsZrnzEYHCVXfGeu6hbPz
0gODHy0k9P5ocOQSzq5Sw+DaXxLq8vN64BjObhanj+yoJaGj56jH63D28C7Y
V19BQqXaNb4n4/w4Y6+E9x8Sym7R0+eJ87PetwJHikloLTG8RgdnX+41rskC
ErriGH6LA+eAYw5Mn3NIKF/u5dIifP9B15sWTH+Q0EMmdRU3cX73Xp3Klk5C
h+/y3SXgHFb6dSA/mYR+OZJZnIrHN2KG1O6cQELjb4UmnsA5StyrViKWhPpH
zeyqwPMTazyJtkaSUIMOa0kdnBM8LXMDPpBQlbRfSb/w/CZ/g6nqoSSUyHk6
XhrntI59cdNvSGggOZ3rJa6PTPbw8IRAEjoiVtE6iOupwM7Zm8eHhKarhlxy
x/VW/LbDHX1CQr9atLL9xPX4p0jL2e0hCa08yugaxvVas2PHuR5XEros+bRd
bgEDDad8jd45k9ADr1X7T+D6br6PaWo7ktA9Sqe7TuF++NdULp92mYRGPy+1
OTGD63VLUdLWmoRuTyD/kZ3GwNCBKCHKORI6+TK2cTvup6mXd1kenyaht4+v
fkzD/beqKd5peIKEtrfOv7qL+3fzdmD9lioeT5FdjG1jGGCJXviTpUxCZVz2
6YeN4PperU0XlSehfT4rvi/x+iD60+M5VYSEPm9b3UfF64nEwLBHjCCuR/vH
rtJdGNjLZ+JiQSKhfyeutZzpwIC8k9T539tJaIVYo/s7vF6pSzYrvFomohQl
96w7eD2LJXMrW8wT0eH4klDLagywsmsfE50moi/qgln24/WvZjznZOo4EeWd
EWP9+QcDVukfrWrbiajir9qMvQV4/YhuvhjaTETZQsNlY3MxIP6O+4p1AxEl
uxD4+LIxMHb3yS1qORH9Wcrpg37H9alq58OdQ0Sj9rHGeH7BQKfcJ/+WTCJa
G1FI8ovFwHHRlqDINCIa9/NhsvdnPB6b2h/2JxDR5E+BAYYfcL2VyqYZhhLR
ps/KYlKBuB5OT7e9ukNEP8pqvy93xgABkeu2uEVEH6cr8tY5YuDeIfsB0RtE
9HNY6wf0Ku5/SutUqi0Rzbz2gPueDd5fuvK2ak2IaMMr7jNLBni8aqfZwgyJ
6BDLnImjLt5fC+W4bE4R0Xp/pk/lmnh/iomk0DSI6GFhFQVtVQyMXH0qx6NA
RLFTR/IN9mJA72y+QqscESXJ5QYL4f049dTM4Sgp/P8ToLFhBwbu7ruiIS9G
ROeddB6v8WGAaVrXwoiHiMZXSt/WXWaAnZ58T4KmCKjxiM349QoGuJFQI/R5
jIAmK7E/PYgyQG6938/0IQKqve1s5EABA5hJbI03/COgeVfuuG+mMYBfOWZO
rCWgjO2JhyRDGADjb5INTyWgwRfMXFvP4eedY69Lk74S0Btnt28JmTJAoL3+
pbwv+PjbT9Q19Rhgb05JaGckAaUVSZeeVGUAqws/N0WCCKhZkDqdWYgB/iSE
tsY4E9DUjEALub90wN9gcjvTkYBe2xI5/q2cDmyWuLlKrhLQy7ZJWVyFdLCk
7wuGbAgoW5WR/p1kOpDH3FL2GhPQhp92n8qf0sH7Y2effTtAQK1rpigmsnQw
ZE8S/SVHQD2cH4lX7aQDxaCGnBopAppSn31/F5EOavp0qVQxAnor5fCs3QoN
bD4/elaBj4CuhBxOVq+igcaoQ1YOvfwoK5onzX6ZBpgSbof3tvKjw0d+BHGY
0oBianqrZR0/eqf4psg/hAbeFciZnfzNjw5MlZ9b3E0Dpu27DSQ+8qOCLpGC
q4NU0MhPUv9nyY9GJco1jVpRAZOQ6SMzI360ar3YY0iXChR3vcmvOsmPPvr+
YneaMhW8k+c6kqfEj0pYq4BEfiow1WdRCCPg41fzjaRLp0Cjz6z46To+lDmI
qLhHYgowBSpeKi/lQ2e4xuh1XFNAMdglSv03H3o63FsGLEyCdzFTwvtT+NDG
zhLux9WTwLRwiLgtgA+tvLyr1PT2JGhcaGb9c5IPLSgwXFDKnAB/HbPGj/zm
Rdt8G/xfsI+D5v4lU40sXpQgcZP7z9QYaD+r/ks3lRdNkRgF1X/HQI92edC5
SF5USXzp4dGPY2BKouPQQ09e9E9Calaw3Bhg61r1LDzOi9o0jLYfQUaBmr4W
4WQhD9ot86D7tM4w0ED9Hhpm86BW1Ql1PXuGgebR2iGLNB60H7IfUGEZBnpS
ljlXo3jQwwlcRYbFQ+AMs8MFv8c8qLLMNjYO5SHgWvAyoVqdBz2yay+xR2AQ
JMk1qZoWcaNPfuwREb/RCxxlfpQ8y+FGk0Cm6DXRXrBPKtjgRzo3Wv2Cbbdl
fQ/4LmFmQ4rmRv/+vFd1ULEH5Ak1PW314kbHksWUpmf+gSr2pgorhBvVnpHM
VXboBNTBRku7Ui60vePnbTuhFqD4qdH1bvV21FqabfCCLgS7FU/8E0zlRMse
/yNYqzVBI/PJcIUvnGjjwlxBZGgT9HB7b6EbyYlyfRB/E0drgg359Lr7rzjR
U0fMXyx/boaPNKNh601OdO9MUFfuRgtsNd9KCJHnRC28Exnhme3Q737Jbb7v
HKhHbVj5i95u+OPDLXnpJA6Ud/75sfADPbCnYMfkiWgO9ClX/SuTJz1QafOO
/a03HChffijvL9Fe2O8neabOhQOdtxDlsbHsg6oRz9UCD+LzOSp6SV0YgFO/
dNg5frCjKM9zsej3QzA1OK/mXjI7qsfg5Hr+awg6O8q9G4xhR5l3uHzc3z8E
6QK8okVv2NHavzdmK2SG4bRrq6KbMzu6jvzRkcwdhovSV2yGZHCWMfI0rRyB
eRutu03F2VEi+++iyxMj0KNVd7xIkB0d3SM8qbh9FK5477v7kZ0d7Ung7BA2
GIXrPTP+psNsKGvwcsBm1ShkCX2WVRzNhjbtGQ7d83sMlt6Y9ZAPZ0PvaNpe
NOscg77IVY1Pr9lQ7TgPB82FMcjOOFV9/zEb6qZQ8sZRYRxu0+fvl7/Ahra+
G1hr+zwO+bY+c0UKsKE/J2WG9O5MQNGbv+0eBLGiNULN5b+pk/BTVZUury8r
+qc37D2FeQqKSLfv/+LJivqCx6ZHBXEenF5ocGJF5e6cft4NpqDwOelAaX1W
tHNEaSbx3RSknAz+2cbOiq7YhZt7yVJhWGz0h5sbLGhTuLHQezUqJG+mPmZe
YEFjit8IPDKiQlJBhe6BERa0W/MANeM2FRIOrv/z/cOCTl6aNmvJokIe0eus
yk9Z0Du+y44nDtNgkIfbRLU7C+qp3cJro0WD3O3e9ZddWNDzPz60G5vRIFdw
1IdXF1nQ1ykFomkuNLiNs3n/8HEWVJiu8dDmKw2yz6lbhiwzo7c7hE61EejQ
19TgmOw0M3r+siCLsRgdsn0/t6t4nBmdmJcT+CyH8427E5PtzKhWV1xopSYd
svR/fayZw4zKpk1JmLjS4WYNKXH6DjP6mzco/04FHZpFSOcIOTHj583bZhN/
6TDhmlq5hj0zytXSOI100aEBk/1okDkzmiNxw/gjlQ7Dj/yQkjvMjEZcPFtI
52PAA7EmSXbzTGgaSSDnkikDPrt1JTeAxoT+edjuTbFiwGa1BxUZI0xoKlv/
tczLDOjRFj220cqE5u0Xux3pwoBlXAzpTzlM6N+UKUudVwxocz/oa7M7E6ob
stQuhjJghlZs3ooLE5rNzjZmVsGALITsSonrTKhKv13r7ToGTE7pHnc5h8+f
0ajs1MmA8/37ZLlVmVArUa2jlzEGPJWuoaqkyIQ+PXjMfWKeAT89Mtc7L8uE
qvZRz1xcZUBE4JHjV2EmdIvrWyMXOwYF34eY+c9uQUe1a0GPdmCw8OCvO21D
W/C0FyPNYRcG7WsGg/e0bMGQY8kCyB4Mpm8pNsOsLThjcObVb3kMajv9NV92
24Jei+izfxoYvAd4LG8sbcIYrhcTQ5fx/5+EL66MbUJV/4gNnqv4907dzbvY
tglLdxSG7nXEYP7pThHzrE341JC2W8wVg+sXEwbVbm/CQqax/GNPMVhvd458
5NIm5HScrG/zwWD0NS6dg8abML49hmDnh0Hklmvynv2b8F2W6KTOawz6Pla/
zTO+Advszpw6/QmDZ55hsRztGzCpMODgjc8YlPaNb2Yq34BhdgZVbrEYrHq1
TWUhfgPus7qKXkrCIG9k63rvpQ14b80pwucHBvui/RU6jXH+Lt0hk43BzHg1
22b1DVhlLyoOczFonhJbWiGyAUdN3Z3KfmMwvMA5MKN9HdItL8kqlGPwepF4
4bfydXjGE2Ncr8Sgakkz/Uv2OszmEqGHVWPwX5WqWUTIOtzpMyRSXY/BXZ1s
wt6n12GG3vLg5zYMYt15+p4n1qGkdgr//Q4Mov1Onvfl1+Fq4f6HSBeen/HG
vhtc6zA4QfN+dg8Gvy5GJZpXrEH3h/F7KcMY9Fg16TDKWYNPtpvqvRvBoMEm
y/ZTCWswunyXD/MYBmnsN5yP+6xB0hA1onQCg0Xbd0YfubMG9739kUCZwuAb
3r9/D9quQXV7mb3WVAwqChw5vFdjDQYefN9aRccg846Jq7sOrMFfu+UOTjMw
2LwzMlx45xqsCEg05Z3GoNte5lWe1VU4ij1SlpvF8324Hl3IWYWl81Gukwv4
fEKv9UhJq/B4jM7kz0UMJq8aNSqEr8KG05rYvSUMRpTU9V93X4WnTH809ixj
kJAYdN3XYRU6DmeU+K5gMCDACIs9uwpjlQRv7l3F4AOTus0uFXz+0j4ewzUM
MpSC/BalV+G1doZgM84OgkZ8ZKFV6Hnvz7rpOp7fFe7wg5yrcL/Venklzmd7
a8WMllZg/+6yhyobGGxAXyU6jq9AJruKXZ9x1k0wPPCiYwUGpij/XsO52J87
J65yBXokl1uab2JQ5WatenEePl4uZzoW5++nX5X9+7oCo+XLQsdxllYyNFr6
sAIHZ1W1pLdwPQtwt5ID8PEc/Vs2OAuu1FgreqzA/Tqcja9wftMTOGzkuAJD
6P45P3HmQA1u3rBagQfiC3824ez1hWvuhd4KVLjrVz2B84JfzaN41RWo2Ge4
ht+nobNTIAuUXYF8Pct6+H0bjhgbBHYLr0DXrs2f+H0c2hziIi1vW4HMRZbH
FnFupdR8pKwsw/Nj7t2jOBstv9x9aHIZvpO/HlGPc1m3/jfjrmXo3Z3mko6z
Otx+yKl6GZZkWNq8wDk7vjrfr2AZajRNXzqDs7zfS+TLt2UYVRdxTwznhBv6
VfDjMjzxajK8F4/HTuPtpj0vlyGHAXv5e5zDFKs7lh8uw4E3oSs6OPNQXl4W
cFqGSztLDjLwePsu6Y0furAMC8aB/Ruc7xVXLTqpLcPyyJCEXDx/U3EBXv77
lqFxx5WvGjjbv9DjSBBZhklNz4KK8fybG1UJ9K4uQc/U032JuF5qDgZ8Xpla
gtUle9R4cdYi60kJdi/Bi11BZ51xfSn9q1Q2+b0EBccFUoi4/lKK/Atvpi5B
8imvunO4PiXjTmkHRC5BZn1uv/e4fomOlRYlnkvwsXzz26V5XJ+G/t29N5cg
8vh+pSjOTAdPXVm1XoKlBMK1o3MYnF6ouHtYfQl6HfgaaTmDQccuv1UT+SU4
9Xaf8FncPwOFuj7OO5dgStrPktMYBhufVwQnri9CvmKfi1K4/zKIFZlCRYtQ
kz9+4hruX/NLRIOB1EWYdWxai3Ucg4spNsPJnxbhJlvF5/ejeL605wTUPBZh
zol7MxFDeP1zl/C0ObwIyR1Zh4Tw+nGz9CZFSnIRIpvdOef/YZCPkJdOJyxC
T7cfdu86MWj5zXjAi7EAX71jyutqxdfX/Ugn7tsCzGsVGOisw+Bz2Yq+GxEL
cFrlnEJBDa73+0QPJf8F+DkqOSaoCtcjX3JK6dUFiNjutOEpw+Ay0sY/Jr4A
c4z59t38hccv6eC/feHzkH6eS/t5Aq6n2Uf35nznoaDq4YDncRi0AhU8hffm
Yb7wXzu3aNw/nTbA2GweNitV7pCJwOA+7sCE2zzzkP8u1bI2EO8f59pOqK7N
QbsHucyG/hh0TZDoYJqag+GErl8FzzGYeyJve0jlHDy2M/DZlcd4/l1HXLJ9
5mDcopTHkDMGRwsPbntyZw6eTONIbcX7VcB2zzgd2zlYue3MkWy8nzXEE1vb
T8xByeQpRzUbDF5o0zi2sjwLw3rPtdgY4PpU+8iqcXsWhptYlJdK4voOE+05
e2kWBqZ/ZA4Qw/fH+Jx923gWxqF2T1SE8XzFx1+L2z8Ll29ZHjLjxes3d1ol
28QMfF3UYe2+yIAfrynEinXMwJrYszdeTDPgL5jpoVIxA6U6rb88nmLAtXs5
co4JM3BtZDlAso8BvXqKX9XazkCFf9mu2mUMGK2ieXXEZAaS395Xf13EgPBd
qfqGxgykLQps/c5lQCadKrqC2Axs3/DQrklmwOfpTSYhXdOQQ+5WThx+Xgnw
GiGfN5+G3fv1elcM8fNIpwPtjuY05CUf6/Y6yYDVSpNlgYrTUPbZr+2jagzI
NU6/X8g3DV3t4vMt5BhQJIaRAcIxOLj7VNAPNgaU0qSo1vszoL1kySOZHDp0
WBCe3LzGgJ7lUbYfU+gw+ZvYJ0VtBlz1FzkzHkOH+0gy66FMDGimcmKHYCAd
Kg4fQy88pMO7DyIbc2zoUO3FZb0JJxp0aF4vyFqlwerlJ4mXDPFzaPW579EM
GrRyjmJp20+DF77x/7k2RIP3LboKS2hUGD6Vc9i/mgYzd1scinShwp5Eej5/
OA3KFOuKnL47BeU6j7qtydBg7qFrD8rMp2B0JkUrYAcNaic+b1U7PAWBtySD
xkWD9kHoG5n5SbiWZNShTqfC6AtqrMzuk7DX0uQ3lkGFlKUDtKyHEzCwIsz4
xgEq/OJkpL/vwgTM/Vf76sxOKlTqc0qKVZuATy+OfBPgpkLT8q+2r9fGYZgE
LYwwMQVfhe5uc3gyDvftPPR9KmYKsigKFO/wHoMBi8WETY4piDmuv30aMAKf
SvbsVfkxAVu/HyKcdhiBzluUuycjJuCveYd3O7VH4NVKDj+BpxPQ91nTu4Kt
Ybjy+oARp9EEFIlICp5zH4ZyLvnJO4fHoXalaej1a0PQzBczY7CPwwipxHAT
rQGo0Gjt6C02Cp/c/Ce4S2IAqu1RNKOvj8Bye3GFrrV+aH3w9R3RnhF44dG8
AvlePzRuO/e8+OMIfPEtWtHfrg/+YncL2E0agf845w7f1uiBf6JC5l2WhuDz
skg1sNwBralHmY69H4ATDcdCr+V3wMuamrtabg/A010d1FceHZDyNXq3usEA
FGGQP3cut0NdDdU/S+v9MFMoaOvOShusARJl96r7YK/T47KE1RZoFLIqPWra
A10kf0VRVv9Czsp9E4G7OmD7b/WyFFYUHjnejvjWVcLL8roblsHFIPmw1iPn
3xVAPSLpzWIsBIqWF0PavCsBjw8rwcgKBaHlQ6mDp6rAJP1KHP16CSgiGR3o
aK4G8eV7yxT9S8G+m9yPx4brAOV+0va88kpgFiswx+/RBNYnLWvsdjcCH2PL
A5omHWCOLV3B4FojEP/udI4tpQNMibOHKn1rBAWkgNLbbJ2g80yONeuhJvDa
WWnv8fxOkFMiQE9AmsH35ExVf9F/wOVjO//E5VZwTySoQLSxBwzqWZ1xie4E
j66+Ffm6MAA0Rh/b1fd2AqKyVDlZZBB88o67JS/WBRQ5rDdOawwC819TL6Yi
u8DKtPEJRb9B8Gf/k1yHj/i8FXaOEeQhEM8XL3Q5rAfcprKc7dw7DJSmFmgy
OgPgHHfzW2WJUWCruu1ex9UBcGnoEY+cxih44yey4uc7ANSYbG9PWI+CKUnA
PlY6AKyzLvZUho+CeOsAsQStQZC+bma5nWsMkOtFTksgQ+DcZy+XyLExMJ8B
MoSPj4BjL8xlHD0mQN3+4yTXiyOA9wDL25LgCfDlq8r9yqcj4Ixi2YH+lAlg
HnPguHvZCPi0XPf3es8E+PFGtLLFeBT4CC4fyFafBC63lvre2I6BE8/Hm2/M
TgLdyVnNMZ8xUPRA/q/4tikgdo2RcCJxDMQE7w/7LDYF6mxGnWiTY+CJ9Jzv
zKkpsM+oZVH/3jhgUqx4x/JpCozvy+Bj95sAQnK9cJsyFRQnpdyxSZ4AyZZ/
v9noUkG4ZFJrVs0E+PP4z8JjKyrQFfn8yZ5/EjhiPvN7HlNBwvZX0mjEJEi2
+ulGKaEC2wkHDc/UKTCn+uZOlSYNqF61j2uunwLWWk8ObzejAf6Bi2z7pqfA
5ArtvagtDRR3WNZ04t/V2fn1Y+4TGhCr1DqrUkwFU2ENR//m0sC/xF0uM400
cON07slOCTrI5UgzT56lAcOqY6ckD9BB6PVjRy9T6EDM1oCufYwOjOQsmerP
0UHsQsldATM6KE57GZLcRweJ0aZRNC86iMuaz71MY4AcvayxwhY68KL4RAry
YeCQUdej/F46uHCf/1n9QQw0sSXSgsfpgHR0n/7xexgwBr0/+lfpwPfX5W7B
VQyczGH5gYkzQLbt6NbY82lg3HRiVeYqA0gS5e/+CZsGUDnFUsaZAd6V3B35
nDgNgtfOBG13Y4BbkkzVlpXTYOxGTcWD5wwgPSIS8odrBux+viefNY4BwsLs
2KJFZ8CssImJZDIDsOgkuz+UnwHFnNri0hkM0J94xFrx9AzIkCt401fIABHX
TfdGB8+A706i70U6GIBD+EP4w/gZYM23o9+plwHcqnq3ncmaARpHn8fEDzOA
mdxNOnfbDGDxaoioxhiAi/oi96HwLJBvHRxe58CAp8tvvTMxs8BRvaBc6RAG
tMDCVb6MWZAT8Iaz4ggGuAgHvSuLZ4F90YlHp9QwEPEjvuBY3yx4YiadK3AS
A7nzL/ftEpsD4wGVNSMWGPAqL9XtkJ8Db3IUuxjnMKATvmH/Tn0OVL9PCJuw
xkDr0TuRLDZz4HEwoSr1CgZmH1nxjH+aA9wr6ev372Lgl2GIbGzKHHjKYW3O
4o4B75112ud/zYGIb7+ynj7EAKEYPKntmgMn55bB6WcYUGCWYWQIzwOXsPxp
jdcYcPJf+OsRPg8kdunlvEvAgJLVQdqhpHkw4MBrgHzFwIrsjW3UnHmQ+6rT
aPgbBgJqepCLbfNgsfn0XrYMDCTxlv3QpCyAa7tu52bnY8Clb6N+dc8CmGa7
f4H1NwaOZBydyjq8AFTUI2/rFmGgzDRVUtpiAbSw/7yWUoKBwdCQUK6QBXAl
kfkHrRoDyVfrMkrjFoALhx1xqBYDrkc46h7/WADeeSqVdfUY2Gx/yIY1LgCa
sUWUTxMGdorY3W/hXwR6nbTMu50YGJn6FBwkvgg47BZ8Bf5hIPV3a7rOwUVw
4MFet+/dGFC7qDeWd3oRaGbBjT99GLCKPXgu6vUiMLnfKvRwBAPznH1236IX
wdfhqAjqKAbe3Q5yzs1YBMey1U5YjGOgWmPSu7FpEag/rTFlmcKAQ9KHoN6h
RWB5/QVdn4oBFj7dD1Nzi4DM+Lrdn4Z/rzc+jU1wCQQnvqEMMTDQrm2WR5RZ
Atd5JvczTWPgbtpWyS7VJcDc20GmzODr9bTpUL2wBAoNn8WIzWFAb5hrSOfm
Esi0+OJAnsf3Z1BAM3+8BKpmD+hszf+3f0GWW9FLgDXvSEDBIgbyvct4HmUs
gW7iAlfAEgYsJ+8K+aNLgLckdtBoGQOv8//Kxw0tgbGIQ2jBCgb2SXgd/T63
BNh7VQbtcN9W+Mtr/WZbBmtzjgFMa3i8z7481ya9DDgPBIbtXsfAp+Kj9kNH
l0FFhSdvwn/v09JjzpjeMth2KUZZbAMDza/DHqyfXwZJ/RdJr3F2WdDy2X5z
GRwXePJ9DmeuizNBgo+XQUehOOG/9+qkspgPe14vg4no8hP/vVdryZ+OV4xe
Bvrxhiemce4PXU87kbEMPPqoZKX/3n/XUvIM0GUwkHqiwgln4Svn/5xrWgZq
P49YfcI5u4az/urQMticl6pHcTZVyu24g2u/p7dIpg9n2serQ15sK+CwDpfT
7H/vw8xk+iuBFfDB4/77DZz33ihZipBeAfqgMuW/92q08TZL0tEVkNWzN2X5
v/dv1V28WXoroJ9ADMXv32A5pk4IPb8CxgSdr/7FOYzTU7LeaQVcjbu3E78v
g0O35Q7881wBg61/8r1xbmjvODoetAIAYq5ijLOThp/W/OcVINvyIJgfZ44k
ZWPmjBUQ2DxWXoXvP553+BwfugIotRkNHjhr3A+2F21aAX+9kSRxnP/1gFuy
QyugdOiKbhEeX3dtxoMjcyuggq6ZbIYzOS3KR4ttFTjFXS7rwfOVSTZ8bSKw
CnaMRIdcwtnIc+WDjfQquHVTg6sDz7evwdl0d71VgAQ6/k3F9SDxky3/+flV
0BAPtm3DuXBH1p93TquAs5y/5AKun4UJ/s6UoFUQ83a/zzCutxDT4qG8z6vA
/kWi6w6cFfKd6WXfV8HzdrdUHVyfDv7VLP2Nq6DMxa72Ga5fG/6bedUDq6A9
s58ag+vd7AOPc/b0KqBvSV7JncWA+leTtpeENVAzKrSrGveL0sGZl24Sa+C7
a4x2OYYBmbwQjcuKa6A184N/Pu4vUmXbV2XTNbA9WnyPL+6/bSYPbMRt18AM
34cLNrg/N9qFiVyua+DOw9PO+3H/ToxZP+p/uwasbwy0p+P+LuIYMgr8uwY4
NT/kaQ5h4Oeb58z3+9fAsYMBWQ0DeH0SlMq9jK2BgJ+xdLN+fL/SjuJH+NfB
8eL6MrUeDDjqMmb6T6+Didomr9A2DFxqeJtUc2kdmLMpY39bMGBx9pB1jss6
MLJtGGRuxvPp4FYW+GYdRHAqjek0YIDitxp+pGEdKCSe9DSswP3CF2Uo0bcO
tBweEA6VYWDr/QkmbsY6aCL1G3L/wcBU4rMbA7wboIIl78RnvL6i5Rzqr4w3
gJELknY4G+83xsnT9y9uAKqwucDvH3h9adNPtL21AX5Jmsmq4PU7fDSIT+X1
BgikXSjjSMGAMzt5cKBuA6Ts2M/CF4MB+9fZ72t7NoDhS0hViMLAOYGzBrm0
DRAXkGSv9RH3q9THrFc8m0D3cYAtEor7UUfcT8VoE0j3HT4f5oeBUt/9+4Nq
N0F3YtETDye8Hm69j5Xu3gS/nxz+8scBj+9DJsGSqU2Q9snl4oY9rneXNqbF
7Vvgs83e4ZN4//Oxetp+WW8LrFX0XyIYYmC1edJw9dwWUJxnOv9PF6+fxpYl
Yde3gPmoiE+oFr5eLbm0ar8tIKI4kNh87L960uJ9uHwL1BtXrXnJ4P0y6cRS
fesW+L1tSLVIEvfn7mRnx5EtoLK1IDkphvfLV8WpDcxMyJXRCeXtFAwwPQsN
Z93NhMSeDM+/usUAAzdOON+6zIRoH46Vt25mgJ1fZ5PUrjMhu+Pv1FvXMYDV
yNdBzttMyKHVV5W6FQzQeIl0Lt6LCWnbJzL6r4ABUItxzY7PTIih5r+nCzEM
EHMiWEizhwmR8qEMo9cZ4N8jXXO+ESakzI+z1dCWAQTz14K6qUzIFvWZc5EV
A7xRcmBxX2NCXJTDoiz0GcBL5jg9RYQZuRzyS0pHjgEuEUf/UM4zI46FjjfZ
R+iA7VPr/Cs7ZiS9wtqd8o8OUiTLpFmdmJGXFTFzTI10sHT4S+DMI2bkZrbB
outvOnh31s68IYoZ6dNLnfjyjg5KI3sH/QeYkZjq51bcynTgtLeevDXBjCzt
6qBXy9ABIb1Qx32GGdHP7P1qK0oHNsWR366ysCC1JVWHBVjoYHHg/B3NvSxI
pO2AaXA9DchKtzOtXWdBMvxvEF/Z0EDD93Klu64syLSA++oXYxq4fzTn6qQH
C2LzcbjgrQYN/NELq+p4yYJUnel26ROnAeub5u+yU1mQmo2KryYDVPAms0Hc
BWNB3rtc0VfDz9/Kx4rNRpfw7ztaWVzAz+f/StKf2zCxIp+2aR/Qw8/RMi1B
4wZEVuRhPGF3ED8VoAsGGTKHWZH7n9x600rxc7lapcagOytiLiqYSZKcAhUW
mTqVXqwImS+r9zzfFIhw/miU7seKmNzP9LuzOgk0om9eeBjOimTcNHlCbJ4E
gcwEd2IuKxKT9OIl39NJIFllla65wIoEzh072Pp3AiwMaGbLbLAilr98k3kK
JkDVyr7fvOxsyBz3vkpS/ARw2b9R1UVhQzyU1i/535sAv97EjdxRZkPGqk1E
+SgTwOzMlGj8PTZEaTXO1t1wHOx1aZEM8GRDSFoL3Q8PjYNFv0I5l+dsiJcu
ea++0DiIyn9zVC2UDan4rFtvMDQGJkQPWzT/ZEOWWO6ldd4fA8+GPANZZtmQ
4JYfBymhoyDjNu+KvSs7Er95/+tW4jCgtSguzXqwIw6Fz/N++AyDfaqWCz7e
7EigXPUP6cvDIIEpciY+hB0pulrLOC80DD4Fy04NZbMjdw0Gaid9h4Bv1slu
+xV25FNTiFen5SC4sPSwyN6HA+HhJV9wCu0FbE/HvO3DOBFdT+JtFrVm4HKP
9YxdFCfSI4wtKA00gc7rErK2CZwI+u3yDWm/JpBmeqHhYjYnYvFJ6t6FpkZg
Kdkgcr6VE0kLPmcmX9MAvpTnZJlQtiHHCOzUfPZqoMXzYlQ9bBtyb3DT2fDZ
L+D9cY++UNh2pKMxpFLEOgfKcyau0yO3I1wSKq0STbmw0006s+zLdqRbWaGo
UzcfKpjKCd3N2o7cNn9rbXDoN/zHcXC0rnk7wnEk5k3bMxQqu6l5+xC5kM8T
sRVE3Qo4dtqsgP6GC+GW8PavqG6EwYXNzmXhXIgVUk98KdkE1fdZSkRGcyF2
1GoxsmcTDGE/56/3nQupenAi4uH+ZggKbc58qedCtE48TL73sgVGyDnOWPFw
IzHIXAtyrB0asj2VK3vJjZzISvXA7LqhbZFaq3YIN8K/Jb4WnN8N3d0Xvco/
cSNKrDJYI18PjJ+41VqRyo1kBKemSfzqgct1Nk+r67mRi06mixh3H0x4r9bW
QORB5LR0Nv4aD8B16cVnXR95kIB5l3rbrCFIGvix/0I8DzIuvkespmMIyny8
1f4vhQcJ/qIyvLQ2BM25R/f3/OZBJLVkD8aeHIbJWEt7Xy8Pkk23qxJvHIZn
8n/Ij+zmRZgHTCh/ekfgd/1bnYxvvMhN9pamo7VjcDpE0qrvBy9y0THKYNfY
GFTq6eioL+BFZMcv9P5lGoe5LlodadW8yGPEIiLsyDiEoULtTpO8yMOpL7FJ
UeOwsbekZUyWD8GG+IdY7CYgSeaBRbsiH9Kxq4uW6DEBLV3lW8pV+ZB3PbWF
Au8mYBfLh+YEPT5EwCpYw6Z4Ag7JODfZO/IhTBofWF8KT8K5O4J/+77yITW2
OiF+pZNQ5Xft6YYMPsTtGllie+ck9GDzbijK40NEZSf3W9Mm4Xo4tT6qkg9J
srcLdKFMQbZCtO7COB/imjIhZWU/BQU5bta0S/MjlSraWtcXpqCViYRBhQI/
8ld5Q26Ngwo/RbRV56jwI8l+YmR7YSrctR+pDtPlR0RPJfV/U6NCGVOBKnMH
fsRaXExV9gkVqn6C5Q2J/EjKogC/8CoVjihkqDt+50fs5fPzVbhoMLg0Oos5
jx/ZMZhkJiVCg1O0J3HKVfyIelx8yr1jNBgF1J98muJH6qJHH/fdp8Fnd21E
soQIiKFA17djYzTYrt7atiVKQAJ+21o9m6Ph/jAKNpIgILwXmh9GMdFhV+Tx
bWOyBIRhOex5VoQOlcpFFoXVCIjy6HXDbkM6HBXqavKyISBCExXu7l/pUH3I
9HWtLQFZc2E7rfGTDkPSqvSErxEQicm0A4OFdKihmQ9/3CIgBA/D6wVNdBjh
9CF9xIuAJARdvVS0QocGRWdeGsQRkJX6O6cvn2TAWP967Q+JBMRF+5YPkxED
LprpMI18IyDHgvslfSwZ8MuY8oMnPwnIxXDZRZlrDLjOT7mWWUpAajdqJjle
MOB3+2ZEcIyA3FfqSLKCDJh44zHt9BQBObpir8ZZwYBRrtIR/gwC8sGBSSGq
jgEDvR5hy4sEZF3khcWjLga89kkyupuTiHSOvzDmn2VAm7g6fQoPEakNHv+0
vMSA5snuC0YEItIysOFes8GASG6NUbEwEQl97zIhux2DO5vvrsXKERFSjxa9
YxcGyV07v3YdICLzK8vTPHsxyDVQYU5SIuL9TPCtvBwGl+kiKc/ViMjI6JP3
8ocx2LK91MrBkIj8fF7qp6KLwUBNcu7+W0TERUZtKNERg956RXZX7xCRrtsn
CmKdMehhcp33830iEgiGGl+6YtDh4u+rfF5ERKdQMlzGA4OaD6+QZ94QkarU
nt0f/DCo+owXyoUSEdl3SanbAzGo4J/nZP+BiGir9/A6v8bX/577T0sMEYmd
cxZlDsPXl5nlmptJRLbd+uF+JxaDWN7FnVg2ESn93DF8/QsGx4o5q2QKiIjM
gegIkyQMttZZi38sISKmCS9851IxmDHB2uDZTERyqtVmg3Px9UlY7tecx+Px
+9Ntw2oM3sMeaR5aJiLDmnZiOrUYfFYcd273OhGJv3eOT7keg5E22HNmNhJy
S4l372wjBhsjAntKyCREVfw4daYDg73Xf8z+ECIhZO8nPhFdGJxS6dwWL0pC
6o4N7D3SjUG2NqkjPntISMFC36hpHwaPEUteax0mIefjBwooIxjUHRj/onSU
hFhmxPK5jGLQMoPvl+RxEtL+t0yoeAyDLsY2YywnSYgxf32I1iQGPXc+X5/V
JSFW8oZyD6YwGED9Rho2ICF3P9kVxVMxGP9ySaPUnITEbT8j2f/fe57VrjNZ
Z0nIC3UWyn/v6YUyOje/XCAhzlcntJcxDHaUh3x4bk9Cjkj/jWXMYJCHRWH6
5F0SciU6v95tAYM7miw5lN1JiPfjA/qaixiUjvXcufcRCVH29XZlX8Lzq1Gt
x+ZDQkgeh6bdljF4mnf60vwLEpL5QOiSxAoGbXoE74+8JCH8a9PxpTi7P7oa
VxaMxyvNtWNmFYPP9V/lZb8nISeLRjsfr2HwnfDP+oSPJOSpDq11C+fP453D
YZ9JyDWaZsujdQym5G6t+MaRkFO2B7rpOOe9kCbcTyQhDY5ec1YbGCyzNJa+
9o2E+Cy/lizEuXmPm/qZdBKif0LDRWgTg/2zn8x1fpCQkozVbiecaSUljkdy
SMiD3fmuuTivvpvwkiogIew184qrOHPa8r8XKCIhi+b5EipbGKQcVEllLyEh
vkOhJ51w3r1pU7JQRkL2SMVHheOsUP+8Y7SKhDSf8Vf4jfPxqBR6Wx0JUdO5
s9aBs97NJtaKRhLy6rIQOx3nM2rLO3JbScjuH7+MVnG23y6umNRJQqYmpVr+
e1937dTRDe8hIQGX0yM2cH7y1dnGb4CEHOU7+HkO50D30LvuI3j+I0gDgzhH
6PwKcJggIWd09G2rcE6kDEafpZEQuGG88yvOP4c5c3Sncf3qSZG8cHbrrK14
NU9C1NcCK/RwPlr/trNxmYRIz7mZcuG8WmIxJbBBQsqUfVP/4PEozBVav8BM
Rj4u5jTfwdkrtZs3lp2MyAVfQf+LLxIbIz66nYycu6Xlko3Hn+X9lUP7+MhI
3/SVtlM4l7+UOXmbREaojkcYTXj+AryoltmCZGR49mmmOc4G9zIcVkTIyOUr
juQaPP8NNkcDn+8hI/XHXcOicL28M1uLrJIhI/bj8Z+XcD1Z6MJ0Xnky0vjn
o5g+zp0HTzV9UCYj73tGTf/i+vy0l3u4R5WMTF6QmWLF+eKOv/O7T5ARccBe
oYDreYjlnHCaDhkRa7Xguj6PwYQlkX0z+mTk094XFm5zeL2g9R1XOU1G7la0
xD6YxSC1zeEyepaMmGjLsthOY/B7zb477NZkJGO4aEYb95MrZPgYXMa/v/U2
Shz323yye1LrdTLy172/JQf356anH33Cg4zoipu5XcH9jboabB14QkYuFnvR
5/B68PwaH/GeNxlR/N3i+nAYg9tMwpU3XuLxyJpVvDKAQaJkkicxkoxsn6dk
fMfrTaug0+uzMWSEc1o6fASvR+HcCjGRX/B4Mquk8bVjUGQh549UGhkpcN9D
1WjG4N6q8u1qRWSkNZl+lKcGr5+FL0WflpARjeUT4gOVGPz2w/hAWTkZ2c0/
ffBrOa7nyDbT0w1kxN2JWYOvBNeHy+gH+358vUvia8fz8HxR2KVfMVOQRo+T
x+bw+rynSSfen52CLD8UKxONxuD6a79dvtspyN+TspMqkRhM59wm9IRIQfay
PnDSfo9BwhrXttu7Kcg34T1c+QEYnMgz9L0pRUEOhKjvu/MCgyVuQUyOchTE
kvNbsqgPBu8yeFdsD1GQcw1zwtqeGGwbJEyZa1KQOR9fwT68H32PNnMw0aEg
gbtnPcVuYNDPOmTIUB//fn/MsNE1vP+0kbu1zSjI4MkTLJ4XcX1UCdap2FEQ
mUIPG35jDNpm7Pwu4k1BZHUKqHRZvF47X9wn9IKC9F5LmhHE+ydJLjqJ/JKC
SC8FDsuLY7A0XjyGJ5iCmPnx5+wSwOtjuOS7zVgKYkI+JUJhwvXyWPbuEEpB
2mdiGinNDFh27Aajr4yCJD1Tfztbi58HFr85dVdREPgmI72gnAFPu+6/0tpI
QYABIsxawICZVxQsKwYoCFuE0IxnNAO6GyirpDAJICLcOb0NVxkQO/k1PoRN
AEmuVtA3usiAjidE+D23CSCug2v7M88woLUi04QhQQB53Wl6aZ8ufl4QrPtI
FxdA8tRb3w9KMSD30JUNRSCAhHOte+4ZoEPf7vYbO04KICFV69FT7XS42arf
znxKAAkISjkaVk+H05UHM5pPCyAWbfZ/Xv+iw/b0NVu3SwJIeovYFimUDmMf
hpblPRFASDSNov0adLjjHsehWG8B5NOJa4Q1Jfx85vzwc8ALAWSQmzs9WYYO
X1y+7H7+tQCyNe6b85lAh046+2XXogSQb2TzpPEBGlQmlr7SKBRAhuRMT6KP
aDCdS2VZGhVAbk3GZlreokFptm9X+csEkDuak0dLL9PgjqU3JwZqBRCxxy5B
B7RpcLPnAubdLYAA7VwJRW4arE6eNS9fFUCCfBIvZAdT4XIly2+WLQGEsWeC
4vqMCqXHSXsQVkHEk7X03qoLFfpIHZ77xS2ITPmwjz00pEL1+HuhmTsFkfmk
SnlRFirMjJxvidQQRNJ3i04mXpuCfb/Y1Lu0BJEqwo+XsmZTkPcfJUHwlCBy
NuDJ0fvqU9BJ+IhbsIkgshHolXmTNAX3vr9P8bfF5ytwYa/4PQkj3ixa3vXB
x48WbayyTsKKdI6iDD9BxGArxoyZNgEX6gSl6IGCSKrNL+aGlgn8fnR04Xqo
IDK80vOzIH4C8gQ8eH8xQRCJLbTRazsxAZ95L7fpVQgixQVH9Vccx6Gj2+pZ
cS4h5IlvYMPekFGYbu0vR+ETQpQ30aC/bqNwVouyvo0khFh8P2ugc24UehIV
4mZ3CCFxn8j1waKj8M13O2q5nBASEJ/zIiNuBOZMVD111hdCunLSL3MmDEOW
ix+SCwKEEK8fX3srvQdhpI7yqgWnMJIyG65af64LhplfqvrMLYyEWPy9X7PR
Cd9cDggf5xdG0kY5RJ2+dEKfhz1KnsLCSJl2WkcYvQM6pfvejJcTRmbem0fm
PmmHagJtPdOG+PiO0q/yb1rgv5H78PU7YSRhYvKK40wNFPHN863csQOR+dP3
TzEyAB7sz7SYwNlovaSqQjUAaqulSG4X2YF0BbfH2LT7w1vTUagBzmvuHNwB
RH+I2vis1+Mc4vilv9f/BXQ4YuzWKroD4b432vzCzQf+HBu6Mii2A0mKs28N
ifSAlZo9Siy7diB9v95d+dX+APZEtTHvwZlD3qhnkPgAsltUxVzF+d8z09eK
AfehFUzvHsdZr7+Vud7tLtz84GHBEN+B8C+spLNHOULy3B1JfokdiOV8Rao5
6TqUPX1z5iDOr/f/C40JuAbN2C69vYPz4v5o2WP37WGC68naeZyF08xEOqKs
YEGt+ieB3TsQu5Xr3K4vz8AGaZUbKjhvPFCZ2OZuDpd6ZDk9cJ6o3zPoFq0H
eVQl2yNwPnyx5WTSAy0oESqaWIDzdSuNfRlxqvAIg+L2D2e2V6du7kmWhf//
/T/y/9//F/8PkzOJNw==
       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{(-2) Pi, 2 Pi}, {-0.999999916456827, 
       0.9999998412622314}}, {{-6.283185307179586, 
      6.283185307179586}, {-0.999999916456827, 0.9999998412622314}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.390664620255131*^9, {3.390754319447304*^9, 3.390754348143812*^9}, 
   3.42648134297052*^9, 3.426482318330053*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the streamfunction", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalPhi]1", "=", " ", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"U", "[", "y", "]"}], " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow1", ",", 
          RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        FractionBox["\[Pi]", "2"], ",", "#"}], "}"}]}], "]"}], " ", "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]2", "=", " ", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"U", "[", "y", "]"}], " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow2", ",", 
          RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        FractionBox["\[Pi]", "2"], ",", "#"}], "}"}]}], "]"}], " ", "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalPhi]3", "=", " ", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{
        RowBox[{"U", "[", "y", "]"}], " ", "/.", " ", 
        RowBox[{"{", 
         RowBox[{"Flow3", ",", 
          RowBox[{"A", "\[Rule]", "1"}]}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        FractionBox["\[Pi]", "2"], ",", "#"}], "}"}]}], "]"}], " ", "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]1", "[", "u", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]2", "[", "u", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[CapitalPhi]3", "[", "u", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"u", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.390664646390406*^9, 3.390664663227959*^9}, {
   3.390667320491786*^9, 3.390667321407797*^9}, {3.390670040542501*^9, 
   3.390670041459351*^9}, {3.390670294461126*^9, 3.390670352594835*^9}, {
   3.390670411222042*^9, 3.390670429403453*^9}, {3.390670601668711*^9, 
   3.390670609986242*^9}, {3.390670673261877*^9, 3.390670700988309*^9}, {
   3.390671351053068*^9, 3.390671418437939*^9}, {3.390672716117742*^9, 
   3.390672809451796*^9}, 3.390677858704152*^9, {3.390678502712008*^9, 
   3.39067866307086*^9}, {3.390678717085289*^9, 3.390678762643137*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2nk0lc8fB3C7e+0p7rVUSEWEaJFkprSRnUrypVTSJhWKiFTWFlsSKSFF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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{(-2) Pi, 2 Pi}, {-0.9999999999999679, 
       0.999999512844876}}, {{-6.283185307179586, 
      6.283185307179586}, {-0.9999999999999679, 0.999999512844876}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2nk4VN8fB3BZZ8YuzFiyRSWSJNlyToVKREWppNS3qKTFlq0klK1sZQmV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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{(-2) Pi, 2 Pi}, {-1.2582893954271777`, 
       1.2582884211173784`}}, {{-6.283185307179586, 
      6.283185307179586}, {-1.2582893954271777`, 1.2582884211173784`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2nk4VN//APDsM2NNzAwpJcmWJNHHdk62smQX2UKhVQsKpZBUKtmyU6GF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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->
     NCache[{{(-2) Pi, 2 Pi}, {-1.1488785482656012`, 
       1.1488778175331116`}}, {{-6.283185307179586, 
      6.283185307179586}, {-1.1488785482656012`, 1.1488778175331116`}}],
    PlotRangeClipping->True,
    PlotRangePadding->{
      Scaled[0.02], 
      Scaled[0.02]}]}], "}"}]], "Output",
 CellChangeTimes->{3.426482337577719*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plots of the forcing", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Forcing", "=", 
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"DS", "[", "  ", 
     RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.390670767525683*^9, 3.39067077766602*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[Nu]"}], " ", 
  RowBox[{
   SuperscriptBox["U", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.390672573324797*^9, 3.426482349158277*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow1", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Nu]", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow2", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Nu]", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", " ", 
    RowBox[{
     RowBox[{"Forcing", " ", "//.", 
      RowBox[{"{", 
       RowBox[{"Flow3", ",", " ", 
        RowBox[{"A", "\[Rule]", "1"}], ",", " ", 
        RowBox[{"\[Nu]", "\[Rule]", "1"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Pi]"}], ",", " ", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.390670788085214*^9, 3.390670862713017*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJw12nk8VN//B3C7GXuKGUuFqCzJlkpyTmmTfakkH0qbNm0oIrRIaSFSQoQU
UcgWcg4JZd9lyzaWMTNXtmT93h6P388fPJ6POw/3vF9nmXvO4yq6XLQ5ycPF
xVVD/vr3d7+JmPGcogxuW1wifwiwLdtnjLJKBuf/UD0/RlpDcTRGWlYGd1PK
MopJr3x02FRZWgZv0eepv0pa7G/5jLakDPZVUvshQHrphH4SEJPBXcTbGO9F
AozVJdqaC8ngSEk+s9oFAvQYLuc+IiCD/a0YzXyk698FfHDlkcGmWMJQbp4A
JSvGjngu0nFPxRk/yTkCZPo7Ue/M0vElhfE45l8CJLCqckKn6di/8vvrhBkC
hNtvOxE7Tsf1chtvb/9DgLulycvSOHS89uPNPXlTBPDUoqN8Jh1PXtBlL58k
gD1lSqalj47v+liOXhgjgIn78fL+bjpeyb9rz3kOAQx66t1/t9PxiXV5waYs
AsjnfagVaaRj29DA7tQhAogqr/SVrSXvt+bomCaDAItPgtXWV9KxSW/uVGgf
Wd9p17vGX+n45LwGY7aTrK+xRcca0XHTpYImrnayPrC7x6mAvP+WlJKhFgIk
0pS2eX+i43uCrW/s6whwurxjLD2Bjt8E7GeUFZPt1d3/qiiWju8LM5SavxBg
X2yeaVUUHdcZmHmXfiaA2rVnSUNhdLys7ErgngwCcNZaOq66Q8faHJsHba8I
8OvpF6qGPx3vtMsUHoskQN2ieu5WHzqmvKr9PhxO5ttCkTzgTsc+mtPiNx+Q
eQWWlAefoONyZye7Le5ke8a1PCKP0vEGgz2mDm5ke5xild460vHM68PJ/7mS
een7+JbY0XFV9qVMiiMBFhibdP/uIu+X2BM/toMAd3YnvzqlQsdXBddkilII
gIO9rVYrktcfX78St8QB8/WmPG3ydCxTf69A/A8HXHXinDRZQccpE5ridxgc
4HJNd4MGL1n/wGxbKeYAkPyl4HcPDXMa8X/plzjAm3h8IaWThienFyMlTnFA
zqajq4+30TBD8Z2YxREO0Czhud1US8NZ/71uOLqbA+Q79u7PLaLheK2kdUM0
DpgVaWjziaZhy5B9Ubdy2EDfNuHBphc0zHuT27swmQ2uRLobcsJo2D4zxrUp
mg1GVGhxzsE0/CQhN/3VLTZoM3I8vdObhvNC3cJembFBzqXBKUF7Gp66JHH4
cDsLXG6alQxbTsNBsn9dtLpGQYSNpUO4OA37nfpkfa56FBTWJbx+JkzDOxUq
7jz4MgoEqs20XvDSsMOya388YkZB9LdX5jET0jg2RKOex3EUVOTsDHrbKI2D
g3OKeZqYYFXkg4WCMGls2aJ9Y0X6CNhF+7XryxNp/CS9LXMmegSceab7sChY
GgfZDf739f4IyArtlC2+LY0NIiccRI6PAJMHmlvKrkrj2W0h4hdXjAD3Gw1X
6mylMc/1mZSgK8Pgx3+ywwPLpfFeo8Q/UfJDwDLWEMyKS+PihFcSDIEh0NTj
FCEuIo2lWT+l6L8HQdfxhF0GfNJY3OHrFsNvg2DsjMbrJ5NSGCdWavqdHwQ0
TyMHg2YpLGQqH8aTywAnHrtUPYmQwuDgkdWRhgNgoSgl3UBGChcMB51YLt4L
+jN/h1pTV2D7Fp8/ZjkNQP+1QNMj4eVYeZtqtbxAMjBUatAMnlmGG3cJhJwZ
qETyN8R8HzIlcEWgRjko6kJnEn/QYgYl8GzNOovfU10opzowM61PAlscZTff
3dCNrBWWhmraJbCXc4XEoehuFPiNsFlWKYFNNjyxD7/+CxHi9esj3kvgGl2D
jjfPelBJYlhT7HkJfG+mT0jBsA+J11heTHeVwOefXeueOtCHHP8ICxWfkMB7
VkhPfL7Yh/6Y3AF9jhK4+GzJDZGEPqRBuKcom0tgIqfHro3Sj55tPeifvIH8
fNqZ9Km6flQXrW1/qkscF5bdk4u1YSCuxIsRXU3iOKA4xEDwPANpvU9rsqsS
x/NK+TMH7zJQyGdVa+MCcWw7Yf0rNZeBrFoU9ytEiuOkuLFNG+UGUZ24pGG7
nTieqRh39egifWt8tUWVGEba73r3WQwjrgdaTt++imFnbSXjiyeGkVaoW7Rh
gRjW0jje5+U9jEJimXT1FDH86Qif57akYWRV2LeMEiSG30vu2HZhfhjVTTXw
lhiLYYkw2oRHwgiqdf00tKlAFHMkuf2udzBRw68/VkafRLFNDfVzEYuJWg4a
5u95L4q5bVuMmAtM1Lnr28NDUaI4wDZ3ZGz1KGIqtGp73RDFvFO2g/kuo4jv
5+yNwm2iuFGoXkG3fxRRrACjVFcUe+qsOlg2PoqEy29bVKuL4g1e5o3beVhI
MltEsVtOFE82LXP9qcBCq0NXlS3NieB31Ot2xY4sZGCyU8K4UATv+6TgtLeW
hYxwoJdplgiO77yykt7FQjs2V/bZpopg/vU7DKuYLLRPxS77RLQInl67zKWb
n40OcJ9yCPQRwax3E23vDNjo0uf7id8NRbBPhLtK5Ss2cteqEW3QE8FPV2oU
Vqaw0bW3ktfaNUSwXN+RwQ85bHTzWZTJqLwI1g2gl8nXsFHw5TSOyIIw1vgj
d+nZHBslqdZvsfoijMPqbuaOWXGQ67qMYv9sYbywU8Sjz4GD1FRC92ekCWMY
k2ace4KDPihYO0q+EsbpRCWHep2Dcmn1fk03hfHYiz4fmxgOquCvL7OHwrhx
itHi2sdBD3gzLO9vEcZ1dS2+95gcZMYd2vZZSxhf6B5LDRrnoPp5K6asojC2
6dh8V4eHQO0TdaJd3MI44Iqj5RoFAo321tkd+yqEw7Rnta4eJNCHX+ldoQVC
+PXHWL5cRwJd6go5VfJJiOy/5xOdLgSabLO6viZRCCMfDZFaNwLN19ZFMe4I
4Sxa8wPTuwQqqk5XlvYVwv3SW6NiHxDIvzIkbY+HEL6XvyGq+QmB+Mut0NuT
5OfvCR4ciiSQWFFd35k9Qnithrfu61QC1RWkn3tpJIRvlj3fxpdBoKefQyZ/
6Ath7sI0MZNsAklnWwlorBPCz/684L/+hUBtmVpPHFcLYXzytaJLMYFepkvQ
H9GEcF4g5e+GbwRanVqnyhEUws1XIirPVhGoLzk9cxWXEF6l24o6agmU+DZk
m+UMFYs8Tzmm2Uig9QlW5unDVOxIvfH6+k8CMeO0Wnp6qFjB2GvrpU4Cpb6S
cF72k4qXfESumvwikNbLuktXvlNxY4wOjhsgUJCZJ89fTMWaH4oSbYcI1LMo
F+6XR8X8ckWFfSME2pJRrCKQTsXttdb8FiwCPTl+OvfhWyrmDJbceMYh0KCU
qMnyWCq2Tb218vMYgYwqMtsjI6i4JE5tOG+cQByNxYWku1TMo+1CmE0TaM+v
hCcbfKl4kcVe1/uHQK9CTRSz3Km4S94hwPovgaaNiUyD81T89AJ1NmaWQObT
4buKj1OxcU1gSNkcWf87g5a9R6i4//Jd48p5sj8dek7X2FBxRl3PstQFAtmJ
Bv6120/F15OjZ10XyfqRenDHDirO5GHMcy8RiO9KvbzLViq+qC5Gv0baUfna
h2EtKqYXhptWkM5qkYcX11Mx7/OVz6dIC98vqZ9aTdY/7DG7SNplm+txHxqZ
3/owjwHS+WzRKR5xKi6gh1GSSEvGfQq8L0DFzaUFn4xJn7U5TJdYpODHt29c
+0K2p4RvKTliioIXJl3tlpOWzU3ctpJNwYY8xqa7yfZfObO/OmGAgsM7xxxt
yfq+y405qXVSsMd8wIPtZP0KNc/G0hsp2ERBs5mXzOe6/7ZbmyspWMr0gFHS
DDkedXqXF5VQMLvEr1yZzHc9I/DNrnwK3i7udMVvihzfzzU2V2ZQMGO6AuZM
kOPRpKHCOpmClW8W633/TY6P+WsObXEUbD9wySqPINC9DytZTi/I9rxeH3Gb
TaDuo199GU8omP+EC0V9lED6y8+In79HwWqiOPnDMDkermXpeHlSMAjafHd/
Pzke1BxKly5QsC2P0zeXHgJFdC4dCDxJwRGpxfBQF4F27zD1CrOj4GKv5X+a
Wsj+FepDaToU7LDxXOWaCrJ/C+9Z66lRcJ85y3xVKdm/Fzf05ytScEOii/oU
IhBv03WBCgkK1svmFdqSS/ZPjLh5H0cQdzPf9Ekmkv1jmd3tOiiIl2nvrRh7
RfYPz5FLRJcgbjV5pvOenM8lp5LC5qsE8dlN1LTsxwRS1NreLv1eEEecKBhW
vEYgM5uRCM0EQdyVPhVjdZnM2/2Z7Z4oQcybfTzq6DkC1eSxqzyCBXHdD41A
ZWcCee94hZrOCeJH/kbfDHcT6M3x/T6s44L4wWvxk55GZP/cnd7C5yiInySX
3AzdTKB1Pywydc0Esf+qLoPzqgRqsllKfKohiPdero7MEibQkvv7YynKgrj9
Q1nlLC+B1J4fWlUiL4jRf6XpSvMc5N/x8flvEbK97NBMGouDNpw4+sCKLYC9
bS2uPv/BQYEexRfFPgjgC/5pW6YCOCjj+QWNtUkCOCeJ+6oDuV53fpYZ2f5K
ANt+Kxl+7cZBOouXXS48FsCcrDepreR6/ytQ6UCVmwAOPzKX9Eubg7a8uG3w
YKMA/mNBMz/bzkbM/N38Ahn8OFpY9XquFBu9D839cfUdP57wXp/tIMhG511V
Q3pj+fFG67zYzhkWYkuJyn15zI8/PzHAPh0sNHapScv9PD+O8Z2hasWy0PTa
44596/hxxX8U6Svk9ydPmP+nold8uDuH+/Sg0Cj6emb8ukYEH07Qop69NcNE
d+AJo5eP+LBO+olrSwwm4ufs/e7hQ/qWgUAMZiKKifgvDQc+/FxdwsrVnYnE
lmKEoqT4sPnHmgGblhEkd67g2LWHvPjAvmuJMneG0cuKij2id3ixlXL0qbNu
w0h2bYt6wg1eHPjFRzHOnnTv2FTNWV6cQsz15msMI/qhtQ/WmvDiulDDLemN
Q2iFcWhmMz8vPuF5hvVRfgiJyJ3m1fPjwQ7p+sycKAZa/CH5ZuwyN+b3CrvQ
ZtuHrF+szaad5cZ/9+GTKwz6UOJJg29GLty4T3Jdk5FCH9rP5cJ4aMONPSWV
rjmzelHEpgwVVV1uPFQ4FtpwuxdtiLNMOjbJhbW3VmtHfOxBjh4P3zZ4cmHB
byorH093oatAxO7Mn0W0nZd9antDC8rTrcZT2bPo/fudVzZs+ow+LitLp32Z
Rvoz0jdaVnwFVw0ieY0ujqOOkLyxI3ztIDxcrvOg0zjaeu/vvuU720EWJybr
ovk4UqkStk3zawfT8fEnX6uPo7uPS88EzbaD68Kp5XzDv1HimkzlRk4HuNlZ
FFx59DfaqQEc/Oq7QNDNgeWHbcbQ4xpjw49FPcDgrvO+4bMs9G7udWyw1gD4
PuP7xsmUhZ6vvZT2d98AsD8fzdOszkK6k1DQ7tgA8LD9WVjMGkVvvzjD6tAB
kK5oqx3lNooufOLaXPt7AKwr2iNrcYWJXCUiRubTGGDFnw2sT17DqGVtwppj
0kMg4ayZiZrDMNI9quSkoTEEdLrPJsUZDCPVd0nSvTuGgNW3t0cfzQ2hG0p+
aQIXhkBwmGLzKd8hNKQWqApLhgCPllSRTMAgiszOdnRwHQaE6/wTv6ABdG21
rWtc/Aho+qAtYXFqAI0sfJ+h5I6A/MlTIfK7BpCSTreGXeUIuONfH/J5qR9p
0K3XPJ0YAbIvkkInPPtRimx/RfJOJthVbhV2+mQfckCBLnodTKAqGrhc37gP
yVqFvyxkM4GYbUEYn2IfUnK8uXwt1yj42a0S/rqzF6lKTV6NVh4FbtOz4R22
vSgh5+r7FedHwQuVNxGWO3vQra+TJopTo8D3XLv0KoUe5Lu1iCeLnwW+uazW
/Dn3C1XLFhSulWYBB+9JzeVXf6E9jXYj7/VZ4G7yK617x7oRRWGzgq4nC7QL
TuheNOpE/nHuh1QIFrhdGmUAZlrRbkv3jWsq2GC4ZmvYybxWFGxmvb2kkQ0s
fraOBl9vRTzdilHGv9hAlrM8pm2mBR3/w6Kzp9ggnfZw6fLfZqS4r77/pyIH
dJ31KU2cbURM3lzzZe4csNNDdmVlfiNaVv5ue50vB7zzy/P47d2IYnNMmy7d
4wD38Mm1RnMNKFPmYu3BlxwgVHT+futcPaqMtZ7JKuIAN6X86BWztWg6ys06
k5sAWzdPmx/zrkXvnRcu3aMSgM9MZylttgaZumxI3b6MAFEeKcf2zlUjEXbH
QXMFAlRUvFzrPV+J1hbLfZgxJEBYV0trmU8l8pYJbG82JoDTuOT95Qs/0Bup
+8Nh+wkwJRc8mrrwHe0TjnuceYgAShdvpP9aLEeOP6osvC4RgH0795iGXzn6
5NXd4OhJgLwXE5JeS2Xom42RgKIPASxLznlIcpWhv7ckT5jeI4CPlKPBbu5S
lPtD4Pi6aALsVXsxGhrwFV19n1wu/poAkqApupv7K1reI5vR9oYAya5mS9d4
StDtfu8l4Y8EaCkwLE3hxSjuZIjIDCKAvJdL97gIQlEBAR/rvhLgobepXohk
Ebr07jzxoJwA53xX9vxYWYjqSoW2JNYQoP2mgL7rmgK0ymRiK28DAfb7E8H8
qvlo3zysNG4mgNrt4s1QLw9F7cl9cqaDAC/vpDzq2pqL5I4uFlp0E0AoMKzf
G+Sgb5lDF6R6CcAMOvkke38WmsWrrPYOEsDhgQXDxuoTumrm7pM5TIAfwZu3
jR3IRJnZN5SWmGQ9j6lDasfS0WfGWIMhQQAdBYZXSPUHJCVt9XPDb7L+Nbkq
lW2paOecsTXXBAHGVe7X8w+kIDEHsa1ZkwSoX3/EFxLvEJee2BOTaQKkq29Q
vTGbhAYqkDX+Q4AQzaWmbP43aOeLQj/6XwJc0q73H5NIQB9dCmg2swSw0kvQ
UJd/jcTVQ+gX5gjg7MZMr7R4hT5u1gg4M0+AVe6PKTtOvkR7l7+y2rtAgG4v
naM5NyLQ0KNlgQKLBIjxa8lVf/oUFX2pVXhLOk9oatVO60eobMlIQXWJAJul
t9do3LyLnGb6bj8kfc5YaE7z4A1UEOZoWk+6LkvvE+XoabRH4KznH9JN7qlG
OhmWoLNqkO/feWnMtd0jVtFXwWhq5fQQaat0h2/bXweAgCxNs0zS9YmS0rbu
94GWgTG/E+lks5O6WQkhoK/zsNIo2R7mnuIOo0fhIOh2T8Jh0mo7Vt757vkC
fHJ0eZBM1nNum5eG3dFoINF9r6WdrLfl5dmzhHIcKPkqfZ9N5jH9/EVRlkw8
SBUfj+8l85J+VibpLZYIQiiyKrlknpufTp4CvElAcWuqhNsMAeyfKBXwzbwF
bLf+UwJk/tcfWon/YCUD7c80Vf8pMp/A1Fy7ljSQTTn7hzZOgLbb7cKylR8B
dv0hoD9GzgfIl078Sgf5T1KDNnHI+rfr8GU3ZYLYq4WjbSME0DQ0+UCr/QQW
jkjX+wwRoMjgqL339yyg67Rfm4dB9s/mx6mgKAf83N5+LuMXAdz03xyMz8sF
Qa2mph2dBFjUK+Ti/5QHMhZLPg7+JPtXh2n3420+wIaay+Mbyf7X2LNgF1oE
LEUsXr7/RgDDF0mPp+MQ0HvJ2P+4mAAit3glzOwxYCx0G5h/IcAI+/hr9uli
wPizl+WcRYD4b8qlWve+AnHDCeWfceT4m2t6yC1eCrpF/Z1fRRHgpvbdAw0R
pSC8QZkPRhDgSAxj8GrSN6B/UziRHkyAFR5J1Nxv5YB31OX36qsE4Hl/sOGe
eQWw3Jyq+f08AcZ6BKLsmyuAnlu5kOUpAlSbndaYHfgO3BLLCsfsCRCovN5y
O18V+Ojc0/WQXM/mR+x+HFOsA1sTj+3ZuMABE3xpmvtP1gGXqfc6SZMcwFzN
H6aTXAfe36Punh3lgLYD2Ud4tesBd60Or0E7B2QXS7ETYQPQ5BhyyWST621k
i/iwcxOQ+bbmgNMJDjiZpelel9AEPk88D049zAGOtYFteUNNQO9rZESbBQeY
8m9+ff9iMwjv2HjkxxYOWH/5uY66Xwu4Z31hQUqYA3r32R9we9UG+i9myBxO
ZgMjhs+x6q420Cm8I+NUDBu8DHh9QWPlTyCQ9wYcCmUDm3zmXWbUT3Bo/uCl
3utsUKLum3Mqsh00Xjx3NWoPG8SLxdOcwzvBg8CH7PROFtBhTrHW7e4BDd7K
zUUTo+DoFsrV1hM94PK0odWugVHwOFD2b+CdHnC0LfXKh6ZRwFQC/INfe4DK
XBVTK3sUxB8JWpm4sxfQqn0cxtxHwfJqWQsF2Acye7iUThNMMPkRfKRvGwAO
X8aX3tWNgCr1bZKX/hsAKvm6VMvCEZDwVt+j3G8AjNr+cGt9OwJsYjds8ywd
AFnM42lPbo6AjMdy5Y3mDKCq8CY8Tm0EuF340/346CCINL7oeNh3GAypfRTj
DxwGp0+upLeJDoH2N6vcftexwOO945FzPf0gRyDV5t04C0S2+UrcLesHYae3
bnZewQaUM/fDZt73AzNVO67qQ2wgUiCz6ZVnPyhKvf/0XTcb7M/cpDIk1A9e
f5rMcWZxwJb/6pbub+wDWUcZS4O3x4D5tqDbzDM94IZbwb4DsePAIV2Xa53d
T2Aft/FQ9KNpUP1+OFD+YSk4de87z6+6WbA6tO7y3d589PWOuvrDykXQoiB5
ZX5DCzJYeha3tmMR/E0fDvJ1bUGZXlzSxcxFILdrvdVIfAuKd2vmmqYuAROt
z8v8aa3olr1fi/O+JRB95J5N4lIr+VzZGKD7bQnsfMMd/bzyJ+o5s/38BWcu
+Cp8t3eqVRdyWsYoWXGYG1ZkewQucPchvpdNk8HHuOGKHwpWv1f2oRSl0rW8
Z7lh9XuTurqtfeiPbsKD397c0D7f5prN5T4UcvCYTU00N7ybODvn+KsPfY3q
6r3Xww3xhh1C7rn9aP3aFq650zyQq/NJUNtBBqr58E3nyiUeOIg8PCmXGMhj
c/aJkes8MK6Z7aJwn4FK9oVXtN7ngcJ9JuWCBQx05JxNSNZ7Hpjx+llGxspB
9Di9ZrUbwQNDMwb4HboH0YRBuVGvJy/sYZcZ7zQbRmW26bvLb/LCBR3uiG9H
h9GL85FmaYG88FpxsbK2xzAyenXOwSuCF/79Zv4OxwyjB9wSnstyeOHc2YnV
iD2MlCrs03ZM8cKapzW96++PIOsDTLn4q3zwmn3Vqg1pTKTs1qgUdIMPRh62
2B5WxETTgYWqbrf5oEtXtcmvWiaKznu82SCMD65Zc2Fk/TgTDcvp2jZk8sEo
wv6y/6ZR5N934wHPOB8sWIfO6OSOoo8XRf+6XOKHLxtqAjclsRCrUevP+HV+
OGXYIHc6m4XUtthN3Qrgh3yDb6uvlbJQIlfU7/in/ND5zNBO/T4Wehm6ntmX
xQ9/lVVGqsiz0Z1Pxh0uf/lhwHROErrPRiW00z/HuQVgywDP7o4INlq68aD1
lpAAbC7tWGhKYCPvXfWN8XIC8IDt4G2XL2x0sdmpqm+7ADztXLJ/gMNGDn+8
vrjcEiDz3PLE05SDnh+JKRh/IAA/h6npXTjIQU0If74VJgAFLm+i7zjGQZZB
gjnxiQIwnrL6vL8nB+2Sefahr4y835qy30diOeiWb17qlVoB6PmIabgtmYNQ
b0cKT5sA1G81df2TyUEGKUpvlUYE4MsYa12BMg7auC091kVYEGbiFed9mBx0
PrYxZny5ICyJzbi/Y4KDUnj/RN2SF4THUot0+uc4SLlq+4v4DYIwuqx0qUCE
QLL/VYb0WQrC0+nvvEs0CMTnNxjgEi4ID7QIr5E7RSC3q7wHjkULwuEVc1P6
5wnUdlph/dFEQXh0Zuyk7hUCpVo51PyXJQh97VX4a3wJZKdUI3u4SRBKHFmK
ux9GoCLpUfahTkE4avG8IPkFgdYLU4oPDgjCvXp1e1JiCDQ/seO03aQg5Fqx
L8rsLYESvmV/slxBgdEnNPOkPhNIJL8h0EKeAr+G1zZs+UIgzw/EYXNlCvRy
frTVsJhA+5+rcpnqUWBeiEdHfwWBsoL3NJoYUmDcs1mxoCoCrfI/nrRvFwVe
97L2E6kj0LhrjNkeOwpUXwik5LQQyPG//NW7HSnQiVok2/GTQGXWrePGJyiw
vfGaY08ngV4aLIvc4U6BfpMBLsF9ZD4bNc9DHwq0JdYrajPIfNaYAnCHAi/9
WeLNHSLQTpG7DMNwCuy4ZKJxnEXmwxWfty2aAuNlll24zyGQ9FRRsEEiBVoY
f6p4MkYg/5EOp62pFJiiprbdc5xAzK4Z7S1Z5HXmkwrDSTLPBin+zYUU6O+z
6kz/FJlnmU7bplIKnC3cuPLsv/O5Asv3elUUGHJ2e3/dDIGefjx/U7eJAnPW
936mzZL5Jty31umkwEH/plijOQKdepGkrD1AgYz+sbDd8wSqe/j1z0YWBbJS
Nj7TWCCQQUDPD81JCkymp8RPkE70WIjZME+BGxwiC14uEkjsrOxlDT4qfH/v
4C/FJQJdd9q8S12ECpXfOIjeJ91nY0dTW0GFo/FGu+tIm+29zFwvT4XiTgWB
5PMnytn2+Ms6ZSqMiUuu/3ceqqD1PmStBhVWKfKsHST9QLniuIoeFfIFdt1O
Iz1JZ+grG1IhdnIftSPtJMojtGYXFTqqrf6vk2xPBffqLkUzKvxse/CnMWmd
6W3pCnZUWK6deTSYbH800/72akcqZAqMTmSS9Qr88ji46gQV7uL6GZZP5nGp
8anqyvNU2KXnviOezKu9/OO8nDsVJic2LZz5S6BdhVW1sj5U6LFZ58cyMt8P
6SPxMnfI6wUDbyOnCRQQucaEFk6FPfv3xphMEEhD8M08O4oK997p23PjNzlf
3NemlyZQ4bt0v92PCQJpWqnSrnyiwtqonSb2owT6+SXlx74CKmwzu2ojPkKg
O+oaN1d/pULf+oK8t4NkewQ2MqoaqHBZE/uNTy+B7rqnv0hop8Ka0Grtz90E
0urTNvPuo8KlmAzl1g4C3fui92ndOBU+OZCzP7eZQHruBgG3lglBa8HzLAo5
P371FugdlhGCYbsd+KxLybwttw9vVBSCr+lvo70xgXrUoGWXlhAU8dH/70oe
gR717l65xUoI/j4Q9HAyiUBbLMvrxOyF4Cfj2RUm8QQaKNx3h+EsBGt7PY38
yPls8MJ09OlFIfh8WOJeCDn/By2sP7MfC8F0mVTPvTcJFFrYcL40Qgju2xX8
OPk6gQzV7BSiXgnBF1vOXWST68lT/kP39n0QgmkBVvGypwkECh0PJFQLwb3V
cxeELcj5odpN8W4Wgl67jrn57CVQxHPnQqsuIejAv3iqFhKIdcVlzSJLCK47
FuMgp0ugF6quv+1FhOE0XOI3kyaQ8fORxI0rhKFyaU9AtRiBOHzn7AXkhWG1
0kkNbUEC7e65gD6pC0OVbWlqsX84aDzi6iMxU2FyPWuPlW7lIFM+P9XS+8JQ
X5x22juEg45+MWja9VQYJmy0v3cwkIM8PadvfnspDJ8feKgh4cNB8cMXmsre
C8PaR8f05E9z0EyVo9/3amGoIL4/6MU2Dkp8ZtBcs0wECj0209vQzUb5FtN+
lrIi0OH4ljND9WxUK5ipVqckAteFD3P8vrHRrJeqf72uCMwQq1A2S2UjKye6
etMBEfj95IYqm+tsNL922v9npAg8vT5Jcq0QG0n2ZKg7xItA8eeMzVVzLLQu
8kJLe4oIfMD6GmvNZiEbYYZ6Z4EIrKVwrs/WstA7orGlu4v8vPT8mrIwFjqQ
l6ExoCgK3+pvvmAnxUIfTC60cZJFYU8GX04V1ygae6pk350hCpf1fVbLJZhI
p7O1tfqzKKzcdWrVvW4mynHb2Zr6XRSWHzpR1lrARCiM1nJ2RBS+KO2Z2e7B
RHVdxY2D68VgrsibbRv6R9DEZena7rdi8K5cgCAtdRhteYm+1bwRh98ZtWan
phloQPOjoesHcbgdL+gc6GKg0K+vPnHnikObisfNaqUMxGT5vtarEIe00L2l
D0IZKBoY+r5kikMV+xO+CuoM5H/FUfYTTQJubLM99eXwAGLQftbfdJSAX32D
l56+6UMfXBqg9KAE3DWu4n18oQudUrBT3zG5DG5aSr9lfrYKZfYLZu8Zk4TT
t6zv53+PAPtX8K8N5l4BNSHjqw5oAJ779fRTuKTgC19Lz6enewBh/Db+KZ8U
zOU3PuRyqwe4bpcVv0GRgoW2mzyVYnrAES2uYVMJKbhYxku52tADoHRVJHu1
FPz+Ui7LxrAXCPcdX9ACUrCV8WPdtEgfiPMKK831lYIpTiHPFV73A5mrAtpx
AVLQZrffePnnfvD0vFdM0F0pyK97y8uxoR/cdXb2PPxICipWLaSZ8Q6As7vV
189FS8HarEPKe08MAL1lX4ONCqUg39yp1SFKDPD93bjNt1kpuFPPeqbpySCY
Kecp4FmSgtp28dwtbwfB2iHJNZBXGu7MT4n4ggbBLRXdiXxhaeg08WQGEIPA
MP5qWLo8eZ27OFPMfAikR002RhlJw8GxLTJfeIfBi8fTdlduSUN+s9vhqY4j
oCxN4MvHQGkoebJnr/nlETBVJa3CfiAND8MjJ+vvkvsZ4c1Tp8OkYU5rxK3b
H0aASNC1Z/8lSsP3oR8rHi6OAP+AmeZ9ZdIwb2U1j0IkE7i6zx5cLUSD0RPB
s59yR0HakXuqK8RokJhvenmtfBSM71wxT5GkwecSEmIKraPgxjLN1+MyNChm
p621eprcr304NvpNlQbvPvpR2KTDAtnDFX7nTWhweFevvMRbFpitPWBzzJwG
t4OGGZlsFjDK7VM+aE2D12u2IcGvLFBxd/47OEyDjpWSzY+7WaBTSWvF8jM0
uOq6+AcTct/E89/zd5+DaHAufWf+KW822LtL+caHhzRo2adCSw5kg4fqGeYJ
ITQ4etwvtOYpG0jN/hh/+IIG91SrfixJYYP1zxcNj76jwXMjr/ZZ/GQDi/qT
9QIVNGhARK4Z0eKAsLzxhLlKGgwN0+Kz30but2P9PMdqabBk3Ns6eTcHHHOL
lGtvpcEmkWHqBLmfdheuPpk2RIPdru+6FQM4IGq33qytIB220m50DHzngHAb
p4oYYTq8wR7K1GjkgMfOQRFD4nRYlflW3rqTA255dercoNNho+gO340cDjib
dudcvCodvn768eAOCQKcyP+wlbWBDm1yziWcpxPAqbxNUF+HDl329eu4KxDA
plcj8bsBHcIk4ymaFgEMpJo7x0zpMC/9lniGOQH0lJZSDKzokNc16/oXOwJo
blT1umNHh8F5Fr/eHCGAkomvFP0/OgwIUb4rdIYAQr4qFsCNDk98MnBWukUA
vgeW8vev0GGGmUe3aBABFiO8mA2edCi/Y5VC8yMCjKdXB57yo0Omvl3d9AsC
tA94oEchdNgrGqsXmEaApt+xj1rD6dCw8Zq0ZSYBaha/H1GMpMPLRpoPJnII
UEJfNZP1mg491wtI1iICFKrsK1t8Q/4/779yAqUEyNG5Er4vhQ43rXVLoFcQ
IMWsTKszkw5ro83odbUESDw8tqiSS4eH2a3z7o0EeHVKtvpiAR0ef7/OfKqF
AE/93c7wltKheo2KYlAXAR4+erHZvIIOG0T2xLzsIUDgyxL+51V06Osh5hnU
TwDvLOl4tWY6LA7ZrzU9TAD3YnjJ/Scd9s/7C3uOEsCt5qxRURcd7hJl6Nez
CeDaES5C6aNDsVvFHwXHCOAyXNRuPUiHU/uCr8qME8BxavhdFJMO1/n3+glM
EuAgz/JrDA4dCno9aqiZIoCV+PbdGyfoMDv/1pkrfwiwX/70cq8/dHiJ79fO
3zME2KUa2lsyR4efLZmOprMEMNIv+CjCJQOtGqRz/OcIsMWY4XuQTwYuLHGZ
h84TQMdK3CyOIgPVHl5U8F0ggMZ/W2WZIjJw7znbjbsWCbD27PFh3WUyUKCp
/PogaYVrj3J8pWTgMSg5f3yJALJ3cu+Uy8jA827xeYWkN/5Ktx0mvbItoaaI
9C5yA0WVlYHP7xl2YtIXxqLxftKF2brdpaSx4635atLb4FbfKtLNuTcqOaQf
fZ+0rCHNlPR4KS4nA8PC98qSz7dg+ffTW6xJ/2JnPmskfWqTuXsT6Ya4uHXt
pG+E7DGeIi2rLp3bQTpkFEhKy8vA0Akloy7Sn1/rpB8i7b6dR7eHtIgYndVO
2iGlNZdBWvHMsoK5f5YT5Pt3PqtfKvRAfqUMDCmv3jtM2tl7YZ0Taas6hRwm
6czBvuO9pO1fdm0gSJfv6NThWSUDDTvL9P+9D9sZ3cy9hjT74N7Nv0nz21bE
niD9dkp09cS//D4Uu90lrS1jJzBJWpNasD2JdKC7NuOf7VFaxxDp1PqM+9P/
8pN9m0JZLQPFGu0s/50v3/KI81Il7Sz8RGSG9Hv1MNo50hSF7xf+/ss38OFg
MGm++Ypls//Oo3vvZqeS1hM7mvbPi8+v23JIhzXZVs79y3fispK4ggy8FpRu
Pk96vcW53xtJ/72cWP7PhsknsBXp2ZCNWxdIW/M5PblM2pFhHf/Pp5wPOT0l
zXdRmJfcbwDvfKsNn0i3bnA88s9PpPbPN5JGirve/3PiJePKSdJJ+7+O//Pn
SsOXUooy0PvdT+1/5+U1a/XP6JNW33bP9Z/7AjZuOUQ6hacq4p//dK4XvE6a
ufi28J9Ftii1vCDdt1Gu/Z8VwuTefCYd/EyF+OdNnBXu7aS7N5bP/fP/vc8M
//995v8BzEIywQ==
       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->{All, All},
    PlotRangeClipping->True,
    PlotRangePadding->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUWnk01d8XNc/jm0wlCq8kCUWS+0klZE6Sr4QiISpEaDCEUihSqSShKJEh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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->{All, All},
    PlotRangeClipping->True,
    PlotRangePadding->{Automatic, Automatic}], ",", 
   GraphicsBox[{{}, {}, 
     {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwUm3k4lN8XwOcd69hmMIOIkFSoZClZupekRPYiXwmpVLKULUmSqJSEJFtl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       "]]}},
    AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
    Axes->True,
    AxesOrigin->{0, 0},
    PlotRange->{All, All},
    PlotRangeClipping->True,
    PlotRangePadding->{Automatic, Automatic}]}], "}"}]], "Output",
 CellChangeTimes->{3.39067258606042*^9, 3.426482355150845*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definition of the pertubation problem", "Section"],

Cell[CellGroupData[{

Cell["2D Navier-Stokes with scaling", "Subsection"],

Cell[TextData[{
 StyleBox["We have taken u = ", "Text"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", "\[Psi]"}], " ", "and", " ", 
     "v"}], " ", "=", " ", 
    RowBox[{"-", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "x"], " ", "\[Psi]"}]}]}], 
   TraditionalForm]]],
 " (mechanical definition)\na linear friction term has been included"
}], "Text",
 CellChangeTimes->{{3.426482418893406*^9, 3.426482446426562*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Epsilon]", "2"], 
     RowBox[{
      SubscriptBox["\[PartialD]", "T"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], "-", " ", 
    RowBox[{"\[Epsilon]", " ", 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "+", "\n", 
    "      ", 
    RowBox[{"\[Epsilon]", 
     RowBox[{
      SubscriptBox["\[PartialD]", "y"], " ", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], 
     RowBox[{
      SubscriptBox["\[PartialD]", "X"], " ", 
      RowBox[{"\[CapitalDelta]", "[", 
       RowBox[{"\[Psi]", "[", 
        RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], " ", "+", " ", 
    RowBox[{
     SuperscriptBox["\[Epsilon]", "2"], " ", "r", " ", 
     RowBox[{"\[CapitalDelta]", "[", 
      RowBox[{"\[Psi]", "[", 
       RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}], "-", "\n", "      ",
     
    RowBox[{"DS", "[", 
     RowBox[{"\[Psi]", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "+", " ", 
    RowBox[{"DS", "[", 
     RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}], "-", 
    RowBox[{
     SuperscriptBox["\[Epsilon]", "2"], " ", "r", " ", 
     RowBox[{"\[CapitalDelta]", "[", 
      RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "]"}]}]}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expansion", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Psi]", "[", 
   RowBox[{"T_", ",", "X_", ",", "y_"}], "]"}], " ", ":=", "  ", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", "y", "]"}], "+", " ", 
   RowBox[{"\[Psi]0", "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}], " ", "+", " ", 
   RowBox[{"\[Epsilon]", " ", 
    RowBox[{"\[Psi]1", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", " ", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "2"], " ", 
    RowBox[{"\[Psi]2", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "3"], " ", 
    RowBox[{"\[Psi]3", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}], " ", "+", 
   RowBox[{
    SuperscriptBox["\[Epsilon]", "4"], " ", 
    RowBox[{"\[Psi]4", "[", 
     RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NS2", " ", "=", " ", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{"NS", ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], 
     ",", "\[Epsilon]"}], "]"}]}], ";"}]], "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 0", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a0", " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"NS2", ",", "\[Epsilon]", ",", "0"}], "]"}], " ", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.390670926849189*^9, 3.390670929065336*^9}, {
  3.435242735920909*^9, 3.435242737311652*^9}}],

Cell[BoxData[
 RowBox[{"\[Nu]", " ", 
  RowBox[{
   SuperscriptBox["\[Psi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "0", ",", "4"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]], "Output",
 CellChangeTimes->{3.390678823846986*^9, 3.390682929300749*^9, 
  3.425027810497574*^9, 3.426482473473366*^9, 3.435242738682069*^9, 
  3.440934806007048*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rule0", "=", " ", 
   RowBox[{"\[Psi]0", " ", "\[Rule]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[CurlyPhi]0", "[", 
       RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{3.390681907654223*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check solution", "Subsection",
 CellChangeTimes->{{3.390678855279064*^9, 3.390678858243424*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"a0", "  ", "/.", " ", 
   RowBox[{"{", "Rule0", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.390678863918808*^9, 3.390678875669255*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390678876493269*^9, 3.390682937436411*^9, 
  3.42502784539913*^9, 3.426482480486966*^9, 3.435242742531613*^9, 
  3.440934810000128*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solvability condition", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Solva", "[", 
   RowBox[{"expr_", ",", "Rules___"}], "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"expr", " ", "//.", " ", 
      RowBox[{"Flatten", "[", " ", 
       RowBox[{"{", "Rules", "}"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "/.", " ", 
   RowBox[{
    RowBox[{"g___", "[", 
     RowBox[{"2", " ", "\[Pi]"}], "]"}], "\[Rule]", 
    RowBox[{"g", "[", "0", "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.390679102145506*^9, 3.390679165889273*^9, {3.390679210300995*^9, 
   3.39067921238817*^9}, 3.390679402425532*^9, 3.39067948301195*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 1", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"Expand", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"NS2", ",", "\[Epsilon]", ",", "1"}], "]"}], "]"}], " ", "/.", 
    " ", "Rule0"}], " ", "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{"\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["\[Psi]1", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.390678908206668*^9, 3.390683176524406*^9, 
  3.425027835922944*^9, 3.426482490973815*^9, 3.43524274589521*^9, 
  3.440934813354573*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define linear operator ", "Subsection",
 CellChangeTimes->{{3.390678945191502*^9, 3.390678950514289*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[ScriptCapitalL]", "[", "f_", "]"}], ":=", " ", 
  RowBox[{"+", " ", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     RowBox[{"y", ",", "y"}]], " ", 
    RowBox[{"(", 
     RowBox[{"\[Nu]", " ", 
      RowBox[{
       SubscriptBox["\[PartialD]", 
        RowBox[{"y", ",", "y"}]], " ", "f"}]}], " ", ")"}]}]}]}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extraction and integration of second member", "Subsection",
 CellChangeTimes->{{3.390678974429958*^9, 3.390678979870936*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1a", "=", 
  RowBox[{"-", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"a1", ",", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "]"}], "]"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["U", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.390679242492046*^9, 3.390683182118472*^9, 
  3.42502785176874*^9, 3.426482520705334*^9, 3.435242749037539*^9, 
  3.44093481718162*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a1aI2", "=", 
  RowBox[{"Integrate", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"a1a", ",", "y"}], "]"}], ",", "y"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390679017335649*^9, 3.390679021090757*^9}, {
  3.390679107674369*^9, 3.390679108798944*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"U", "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.39067924800052*^9, 3.390683184297355*^9, 
  3.425027864831148*^9, 3.426482523536815*^9, 3.435242750709577*^9, 
  3.440934820266308*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reconstruction and check of the first order equation ", "Subsection",
 CellChangeTimes->{{3.390679267228349*^9, 3.390679269181258*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a1N", "=", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]1", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], " ", "-", " ", 
    RowBox[{"a1a", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a1N", " ", "-", " ", "a1"}], "]"}]}], "Input",
 CellChangeTimes->{3.390679283716788*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390679287127626*^9, 3.390683197337177*^9, 
  3.425027871997249*^9, 3.426482590957023*^9, 3.43524275284234*^9, 
  3.440934843690147*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solvability condition", "Subsection"],

Cell["\<\
The solvability condition is obviously satisfied with this second member \
since it has a primitive (even two primitives)\
\>", "Text",
 CellChangeTimes->{{3.390678993758279*^9, 3.390679007048743*^9}, {
  3.390679119155573*^9, 3.390679128002315*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solva", "[", "a1a", "]"}], " ", "/.", " ", 
  RowBox[{
   RowBox[{"g___", "[", 
    RowBox[{"2", " ", "\[Pi]"}], "]"}], "\[Rule]", 
   RowBox[{"g", "[", "0", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.390679131347663*^9, 3.390679174309201*^9}, {
  3.390679229252935*^9, 3.390679231690457*^9}, {3.390679293245503*^9, 
  3.390679305282895*^9}, {3.390679349549418*^9, 3.390679358132628*^9}, {
  3.390679411737399*^9, 3.390679453347095*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.390679175106337*^9, 3.39067923248563*^9, {3.390679295079024*^9, 
   3.390679306676009*^9}, {3.390679342873702*^9, 3.390679373290216*^9}, 
   3.390679415788164*^9, 3.390679455771656*^9, 3.390679505474723*^9, 
   3.390683200778802*^9, 3.425027874124379*^9, 3.426482611256275*^9, 
   3.435242754990334*^9, 3.440934845588575*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rule1", " ", "=", 
   RowBox[{"\[Psi]1", " ", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"f1", "[", "#3", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"#1", ",", "#2"}], "]"}]}], " ", "&"}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.390681918599517*^9, 3.435242767178152*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 2", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a2", " ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"NS2", ",", "\[Epsilon]", ",", "2"}], "]"}], "   ", "//.", " ", 
     
     RowBox[{"{", 
      RowBox[{"Rule0", ",", "Rule1"}], "}"}]}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"]}], "-", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{"\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["\[Psi]2", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.440934901835451*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], "2"]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a2a", "=", 
  RowBox[{"-", 
   RowBox[{"Factor", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"a2", " ", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", "2"}], "]"}], " ", "]"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a2a", "]"}]}], "Input",
 CellChangeTimes->{{3.390679739667549*^9, 3.390679759425323*^9}}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["f1", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.390679761319636*^9, 3.390683226964403*^9, 
  3.425027896058797*^9, 3.426482684264569*^9, 3.435242787646237*^9, 
  3.44093492542628*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390679761319636*^9, 3.390683226964403*^9, 
  3.425027896058797*^9, 3.426482684264569*^9, 3.435242787646237*^9, 
  3.440934925585821*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"term", " ", "in", " ", "factor", " ", "of", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "2"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2b", "=", 
   RowBox[{"-", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Coefficient", "[", 
      RowBox[{"a2", "  ", ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", "1"}], "]"}], " ", "]"}]}]}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{"a2b", ",", "y"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a2b", "]"}]}], "Input",
 CellChangeTimes->{{3.390679771754734*^9, 3.390679824261578*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.390679826598987*^9, 3.39068322923733*^9, 
  3.42502790133796*^9, 3.426482701337494*^9, 3.43524279294117*^9, 
  3.440934927800813*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{3.390679826598987*^9, 3.39068322923733*^9, 
  3.42502790133796*^9, 3.426482701337494*^9, 3.43524279294117*^9, 
  3.440934927825798*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390679826598987*^9, 3.39068322923733*^9, 
  3.42502790133796*^9, 3.426482701337494*^9, 3.43524279294117*^9, 
  3.440934928206195*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Reconstruction and check of the second order equation\
\>", "Subsection",
 CellChangeTimes->{{3.390679858820757*^9, 3.390679866600646*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a2N", " ", "=", " ", 
   RowBox[{
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]2", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}], "  ", "-", " ", 
    RowBox[{"a2b", "  ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "-", " ", 
    RowBox[{"a2a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a2N", " ", "-", " ", "a2"}], "]"}]}], "Input",
 CellChangeTimes->{3.390679854533293*^9, 3.440934935468279*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390679874056163*^9, 3.390683234626147*^9, 
  3.425027907346783*^9, 3.426482729030036*^9, 3.435242799029521*^9, 
  3.440934937864863*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rule2", " ", "=", "  ", 
   RowBox[{"\[Psi]2", "  ", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f2a", "[", "#3", "]"}], "  ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "2"]}], "+", " ", 
       RowBox[{
        RowBox[{"f2b", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"#1", ",", "#2"}], "]"}]}]}], "  ", "&"}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.390681891814121*^9, {3.435242805070817*^9, 3.435242807517606*^9}, 
   3.435242991199595*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 3", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a3", " ", "=", " ", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"NS2", ",", "\[Epsilon]", ",", "3"}], "]"}], "   ", "//.", " ", 
     
     RowBox[{"{", 
      RowBox[{"Rule0", ",", "Rule1", ",", "Rule2"}], "}"}]}], " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.390680015704548*^9, 3.390680016623519*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["f2a", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "3"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"f2a", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      RowBox[{"f1", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f1", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["f2b", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "[", "y", "]"}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], ")"}]}], "-", 
     RowBox[{
      RowBox[{"f2b", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"r", "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f1", "\[Prime]",
           MultilineFunction->None], "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "-", 
     RowBox[{"2", " ", "\[Nu]", " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], ")"}]}], "+", 
  RowBox[{"\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["\[Psi]3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.390680009725874*^9, 3.390680033652046*^9}, 
   3.390683264943959*^9, 3.425027917613399*^9, 3.426482822391779*^9, 
   3.435242813251386*^9, 3.435242996310612*^9, 3.440934949737318*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extraction of second member and solvability", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a31", "=", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"Expand", "[", "a3", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], ",", " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], ",", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.435242823459472*^9, 3.435242824249451*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["f2a", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "3"]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "r"}], " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           SuperscriptBox["f1", "\[Prime]",
            MultilineFunction->None], "[", "y", "]"}]}], " ", 
         RowBox[{
          SuperscriptBox["f1", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"U", "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f2a", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"f2a", "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["U", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         RowBox[{"f1", "[", "y", "]"}], " ", 
         RowBox[{
          SuperscriptBox["f1", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "y", "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["f2b", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "y", "]"}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"U", "[", "y", "]"}]}], "+", 
     RowBox[{"2", " ", "\[Nu]", " ", 
      RowBox[{
       SuperscriptBox["f1", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "-", 
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}], "+", 
     RowBox[{
      RowBox[{"f2b", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["U", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{"\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["\[Psi]3", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.390680068504099*^9, 3.39068326611316*^9, 
  3.425027924088492*^9, 3.426482825789231*^9, 3.43524282594636*^9, 
  3.43524299939769*^9, 3.440934957522114*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "3"]}], ":", " ", 
  "a3a"}]], "Subsubsection",
 CellChangeTimes->{{3.390717425963535*^9, 3.390717427150516*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a3a", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a31", ",", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "3"]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a3a", "]"}]}], "Input",
 CellChangeTimes->{{3.39068007854919*^9, 3.390680088621709*^9}, 
   3.426482832630331*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["f2a", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.390680100687946*^9, 3.390683267274152*^9, 
  3.425027931178261*^9, 3.426482834068044*^9, 3.435242831177978*^9, 
  3.435243004507183*^9, 3.44093496516852*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390680100687946*^9, 3.390683267274152*^9, 
  3.425027931178261*^9, 3.426482834068044*^9, 3.435242831177978*^9, 
  3.435243004507183*^9, 3.440934965341847*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a3b"}]], "Subsubsection",
 CellChangeTimes->{{3.390717443967141*^9, 3.390717445468429*^9}, {
  3.440934975369048*^9, 3.440934977793371*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a3b", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{
       RowBox[{"Expand", "[", "a31", "]"}], ",", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], ",", "1"}], "]"}], ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{"a3b", ",", "y"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a3b", "]"}]}], "Input",
 CellChangeTimes->{{3.390680139203963*^9, 3.390680187702874*^9}, 
   3.426482863653702*^9, {3.440935048200892*^9, 3.440935059469374*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["f2b", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{{3.390680166978953*^9, 3.390680189020657*^9}, 
   3.390683273018188*^9, 3.425027954242223*^9, 3.426482865006003*^9, 
   3.435242839110393*^9, 3.440934979926712*^9, 3.440935064971717*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], "2"], "+", 
  RowBox[{"2", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{{3.390680166978953*^9, 3.390680189020657*^9}, 
   3.390683273018188*^9, 3.425027954242223*^9, 3.426482865006003*^9, 
   3.435242839110393*^9, 3.440934979926712*^9, 3.440935064997253*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.390680166978953*^9, 3.390680189020657*^9}, 
   3.390683273018188*^9, 3.425027954242223*^9, 3.426482865006003*^9, 
   3.435242839110393*^9, 3.440934979926712*^9, 3.440935065261033*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a3d"}]], "Subsubsection",
 CellChangeTimes->{{3.390717500257329*^9, 3.390717501514914*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a3d", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a31", ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"a3d", "-", 
    RowBox[{"U", "[", "y", "]"}]}], ",", "y"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", 
  RowBox[{"a3d", "-", 
   RowBox[{"U", "[", "y", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.390680235234807*^9, 3.390680257390126*^9}, {
  3.390680332850553*^9, 3.390680336289889*^9}, {3.390680377418042*^9, 
  3.390680418308147*^9}, {3.42502826460675*^9, 3.425028288895835*^9}, {
  3.426482983591986*^9, 3.426483009207409*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"U", "[", "y", "]"}], "-", 
  RowBox[{"2", " ", "\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.425028290101528*^9, {3.426482984564769*^9, 3.426483010252491*^9}, 
   3.435242849822231*^9, 3.440935078211488*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.425028290101528*^9, {3.426482984564769*^9, 3.426483010252491*^9}, 
   3.435242849822231*^9, 3.440935078302959*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.425028290101528*^9, {3.426482984564769*^9, 3.426483010252491*^9}, 
   3.435242849822231*^9, 3.44093507881241*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
   "The", " ", "solvability", " ", "condition", " ", "is", " ", "satisfied", 
    " ", "due", " ", "to", " ", "the", " ", "hypothesis", " ", "that", " ", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", 
      RowBox[{"2", "\[Pi]"}]], 
     RowBox[{
      RowBox[{"U", "[", "y", "]"}], 
      RowBox[{"\[DifferentialD]", "y"}]}]}]}], "=", "0"}], ",", " ", 
  RowBox[{"no", " ", "other", " ", "contribution"}]}]], "Text",
 CellChangeTimes->{{3.390680425675709*^9, 3.39068044653285*^9}, {
  3.39068117426152*^9, 3.390681219436827*^9}, {3.425029879386288*^9, 
  3.425029883976041*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a3g"}]], "Subsubsection",
 CellChangeTimes->{{3.390717566752485*^9, 3.390717575774918*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a3g", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a31", ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a3g", "]"}]}], "Input",
 CellChangeTimes->{{3.390681348209801*^9, 3.390681357384278*^9}, 
   3.426483094059346*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f1", "\[Prime]\[Prime]",
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{3.390681359359138*^9, 3.390683312865471*^9, 
  3.425027983320735*^9, 3.42648309501249*^9, 3.435242866520894*^9, 
  3.440935087639336*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390681359359138*^9, 3.390683312865471*^9, 
  3.425027983320735*^9, 3.42648309501249*^9, 3.435242866520894*^9, 
  3.440935087687066*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Terms due to friction ", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a3r", "=", " ", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a31", ",", 
     RowBox[{"r", "  ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a3r", "]"}]}], "Input",
 CellChangeTimes->{{3.390681372635225*^9, 3.390681389143276*^9}, 
   3.426483145072734*^9}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["f1", "\[Prime]\[Prime]",
   MultilineFunction->None], "[", "y", "]"}]], "Output",
 CellChangeTimes->{{3.390681377159686*^9, 3.390681389981817*^9}, 
   3.390683318083122*^9, 3.425027985170832*^9, 3.426483146180824*^9, 
   3.435242871410592*^9, 3.440935107878147*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.390681377159686*^9, 3.390681389981817*^9}, 
   3.390683318083122*^9, 3.425027985170832*^9, 3.426483146180824*^9, 
   3.435242871410592*^9, 3.440935107892403*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reconstruction and check of the third order equation", "Subsubsection",
 CellChangeTimes->{{3.390681413548687*^9, 3.390681460017959*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a3N", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a3g"}], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "-", " ", 
    RowBox[{"a3d", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "-", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], 
     RowBox[{"(", 
      RowBox[{"a3b", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], "  ", ")"}]}], "-", " ", 
    RowBox[{"a3a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "3"]}], "-", " ", 
    RowBox[{"r", " ", "a3r", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "+", "  ", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]3", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a3N", "-", "a3"}], " ", "]"}]}], "Input",
 CellChangeTimes->{
  3.390681405615139*^9, 3.390681505891665*^9, {3.426483154872881*^9, 
   3.426483171816463*^9}, {3.435242877887911*^9, 3.435242893112076*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.390681508633096*^9, 3.390683325694142*^9, 3.425027990381736*^9, 
   3.426483180365625*^9, 3.435242895038843*^9, 3.435243010488121*^9, {
   3.440935103462884*^9, 3.440935109575183*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Symbolic solution", "Subsection",
 CellChangeTimes->{{3.390681577363179*^9, 3.390681582810041*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Rule3", "=", " ", 
   RowBox[{"\[Psi]3", " ", "->", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"f3g", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"#1", ",", "#2"}], "]"}]}], "+", " ", 
       RowBox[{
        RowBox[{"f3d", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"#1", ",", "#2"}], "]"}]}], " ", "+", " ", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"#1", ",", "#2"}], "]"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"f3b", "[", "#3", "]"}], " ", 
          RowBox[{
           SuperscriptBox["\[CurlyPhi]0", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"#1", ",", "#2"}], "]"}]}], "  ", ")"}]}], "+", " ", 
       RowBox[{
        RowBox[{"f3a", "[", "#3", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"#1", ",", "#2"}], "]"}], "3"]}], "+", " ", 
       RowBox[{"r", " ", 
        RowBox[{"f3r", "[", "#3", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"#1", ",", "#2"}], "]"}]}]}], "   ", "&"}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.390681678765864*^9, 3.390681867149357*^9}, {
   3.42506912716673*^9, 3.425069140340351*^9}, 3.435242945419141*^9, {
   3.435243028002652*^9, 3.435243034865994*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Order 4", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a4", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Coefficient", "[", 
      RowBox[{"NS2", ",", "\[Epsilon]", ",", "4"}], "]"}], "   ", "//.", " ", 
     
     RowBox[{"{", 
      RowBox[{"Rule0", ",", "Rule1", ",", "Rule2", ",", "Rule3"}], "}"}]}], 
    " ", ",", 
    RowBox[{"Trig", "\[Rule]", "True"}]}], "]"}], " "}]], "Input",
 CellChangeTimes->{{3.39068194717953*^9, 3.390681948711536*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "r"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"r", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["f2a", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f2b", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"f2a", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"f2b", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SuperscriptBox["f2b", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "y", "]"}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{"\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{"2", " ", "\[Nu]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "2"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], "2"], "+", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "1"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[CurlyPhi]0", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"0", ",", "3"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{
       SuperscriptBox["f3r", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3a", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "3"]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3b", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3d", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3g", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "2"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"f3r", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"f3a", "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"f3b", "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"f3b", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"f3d", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"f3g", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{
       SuperscriptBox["f3r", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{
       SuperscriptBox["f3a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"f1", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3d", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3g", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{"\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["\[Psi]4", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.390681965782791*^9, 3.390683495691437*^9, 3.390715545946169*^9, 
   3.425027997436009*^9, {3.426483240800326*^9, 3.426483255461099*^9}, 
   3.43524304602395*^9, 3.440935118034394*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Terms", " ", "containing", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}]}]], "Subsection",
 CellChangeTimes->{{3.390718640004023*^9, 3.39071864464657*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Terms in ",
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], "4"]]],
 " : a4a"
}], "Subsubsection",
 CellChangeTimes->{{3.390715713135312*^9, 3.390715714715937*^9}, {
  3.390716144269373*^9, 3.390716198533856*^9}, {3.390716387620823*^9, 
  3.390716392902702*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4a", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a4", "]"}], ",", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "4"]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4a", "]"}]}], "Input",
 CellChangeTimes->{{3.390681998410071*^9, 3.390682004350973*^9}, 
   3.426483264730635*^9}],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SuperscriptBox["f3a", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.390682005637619*^9, 3.390683502424913*^9, 
  3.390715560722117*^9, 3.39075245563781*^9, 3.425028000428712*^9, 
  3.426483336458113*^9, 3.435243051116983*^9, 3.440935128003398*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390682005637619*^9, 3.390683502424913*^9, 
  3.390715560722117*^9, 3.39075245563781*^9, 3.425028000428712*^9, 
  3.426483336458113*^9, 3.435243051116983*^9, 3.440935128150875*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Terms in ",
 Cell[BoxData[
  RowBox[{" ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "3"]}]]]
}], "Subsubsection",
 CellChangeTimes->{{3.390716247887847*^9, 3.39071625962561*^9}, {
  3.390716397281938*^9, 3.390716402250611*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Coefficient", "[", 
  RowBox[{
   RowBox[{"Expand", "[", "a4", "]"}], ",", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "3"]}], "]"}]], "Input",
 CellChangeTimes->{{3.39071615410313*^9, 3.390716154936977*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390683511898401*^9, 3.390715569248792*^9, 
  3.390752459511889*^9, 3.425028004414145*^9, 3.426483349081592*^9, 
  3.435243053830012*^9, 3.440935140814895*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Terms in ",
 Cell[BoxData[
  RowBox[{" ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"]}]]]
}], "Subsubsection",
 CellChangeTimes->{{3.390716237786896*^9, 3.39071623867973*^9}, {
  3.39071640762751*^9, 3.390716413126068*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a42", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{
    RowBox[{"Expand", "[", "a4", "]"}], ",", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], "2"]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390716270154983*^9, 3.390716286480157*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "r"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"r", " ", 
   RowBox[{
    SuperscriptBox["f3r", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"f3a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f3b", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.39071628848073*^9, 3.390752465394817*^9, 
  3.425028005684926*^9, 3.42648335163238*^9, 3.435243055543519*^9, 
  3.440935155076553*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Terms", " ", "in", " ", "r", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"]}], ":", " ", 
  "a4u"}]], "Subsubsection",
 CellChangeTimes->{{3.390716631707762*^9, 3.390716680431323*^9}, {
  3.390716741763095*^9, 3.390716742614631*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4u", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a42", "]"}], ",", "r"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4u", "]"}]}], "Input",
 CellChangeTimes->{{3.390716695690897*^9, 3.390716738864331*^9}, {
   3.390716789936732*^9, 3.390716811662907*^9}, 3.426483379171069*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["f2a", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "-", 
  RowBox[{
   SuperscriptBox["f3r", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.390716812577715*^9, 3.390752475364668*^9, 
  3.425028013171103*^9, 3.426483380361684*^9, 3.43524306659413*^9, 
  3.440935158392808*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.390716812577715*^9, 3.390752475364668*^9, 
  3.425028013171103*^9, 3.426483380361684*^9, 3.43524306659413*^9, 
  3.440935158574052*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Terms", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"], 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a4c"}]], "Subsubsection",
 CellChangeTimes->{{3.390716826834526*^9, 3.390716869115194*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4c", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a42", "]"}], ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{"a4c", ",", "y"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4c", "]"}]}], "Input",
 CellChangeTimes->{
  3.390716490828679*^9, 3.390716547851341*^9, {3.39071687794787*^9, 
   3.390716940257855*^9}, 3.426483386031172*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"f3a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["f3b", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{{3.390716896726086*^9, 3.390716943473454*^9}, 
   3.42502801523228*^9, 3.426483386965484*^9, 3.435243075282483*^9, 
   3.440935161578437*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"f3a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"f2a", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["f3b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{{3.390716896726086*^9, 3.390716943473454*^9}, 
   3.42502801523228*^9, 3.426483386965484*^9, 3.435243075282483*^9, 
   3.440935161607715*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.390716896726086*^9, 3.390716943473454*^9}, 
   3.42502801523228*^9, 3.426483386965484*^9, 3.435243075282483*^9, 
   3.440935162754961*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Terms", " ", "in", "  ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsubsection",
 CellChangeTimes->{{3.390717681085667*^9, 3.390717696237663*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a43", "=", 
  RowBox[{"Coefficient", "[", " ", 
   RowBox[{
    RowBox[{"Expand", "[", "a4", "]"}], ",", 
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.390717700757388*^9, 3.390717710013966*^9}, {
  3.426483487240932*^9, 3.42648349199136*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", "\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"f3b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f3d", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f3g", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.390717712368712*^9, 3.425028018748741*^9, {3.426483489068619*^9, 
   3.426483492902363*^9}, 3.435243081032207*^9, 3.440935165318082*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "3"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], ":", " ", "a4g"}]], "Subsubsection",
 CellChangeTimes->{{3.39071848429144*^9, 3.390718485405162*^9}, {
  3.390723909704893*^9, 3.390723912170447*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4g", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", " ", 
    RowBox[{
     RowBox[{"Expand", "[", "a43", "]"}], ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "3"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{"a4g", ",", "y"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4g", "]"}]}], "Input",
 CellChangeTimes->{{3.390717940756991*^9, 3.390718019630993*^9}, {
   3.390718434103952*^9, 3.39071849675311*^9}, {3.390723892038979*^9, 
   3.390723947378715*^9}, 3.426483585559023*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", "\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f3b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["f3d", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.39071845784826*^9, 3.390723895955413*^9, 
  3.390723950877356*^9, 3.39075248580045*^9, 3.425028030926784*^9, 
  3.426483586717626*^9, 3.435243099060373*^9, 3.440935167681804*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", "\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f3b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f2b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["f3d", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{3.39071845784826*^9, 3.390723895955413*^9, 
  3.390723950877356*^9, 3.39075248580045*^9, 3.425028030926784*^9, 
  3.426483586717626*^9, 3.435243099060373*^9, 3.440935167775741*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.39071845784826*^9, 3.390723895955413*^9, 
  3.390723950877356*^9, 3.39075248580045*^9, 3.425028030926784*^9, 
  3.426483586717626*^9, 3.435243099060373*^9, 3.440935168824117*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "1"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", "a4h"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4h", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", " ", 
    RowBox[{
     RowBox[{"Expand", "[", "a43", "]"}], ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4h", "]"}]}], "Input",
 CellChangeTimes->{{3.390717940756991*^9, 3.390718019630993*^9}, {
   3.390718520509772*^9, 3.390718548818052*^9}, 3.426483693391291*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["f3g", 
    TagBox[
     RowBox[{"(", "3", ")"}],
     Derivative],
    MultilineFunction->None], "[", "y", "]"}]}]], "Output",
 CellChangeTimes->{{3.39071854089243*^9, 3.390718550295663*^9}, 
   3.390752491400131*^9, 3.42502803543924*^9, 3.426483699937201*^9, 
   3.43524310260061*^9, 3.440935171957925*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.39071854089243*^9, 3.390718550295663*^9}, 
   3.390752491400131*^9, 3.42502803543924*^9, 3.426483699937201*^9, 
   3.43524310260061*^9, 3.440935172113776*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", " ", "terms", " ", "that", " ", "do", " ", "not", " ", 
  "contain", " ", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}]}]], "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"a45", " ", "=", " ", 
  RowBox[{"a4", " ", "/.", " ", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], " ", "\[Rule]", " ", "0"}]}]}]], "Input",\

 CellChangeTimes->{{3.390718670630374*^9, 3.390718683578782*^9}, {
  3.390718881632958*^9, 3.390718881992257*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "r"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{"r", " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
  RowBox[{"\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{"2", " ", "\[Nu]", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["f2a", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f2b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{
   SuperscriptBox["\[CurlyPhi]0", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "2"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"T", ",", "X"}], "]"}], "-", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{"f3r", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"f3b", "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"f3d", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{"f3g", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"r", " ", 
      RowBox[{
       SuperscriptBox["f3r", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3b", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "2"]}], "+", 
     RowBox[{
      RowBox[{"f1", "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3d", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "4"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f3g", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "y", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{"\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["\[Psi]4", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X", ",", "y"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.390718750108915*^9, 3.390718883375155*^9, 
  3.425028038945901*^9, 3.426483757274132*^9, 3.435243111264753*^9, 
  3.440935183850393*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "4"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  RowBox[{"a4l", ":", " ", 
   RowBox[{
   "contribution", " ", "to", " ", "the", " ", "amplitude", " ", 
    "equation"}]}]}]], "Subsubsection",
 CellChangeTimes->{{3.390719955348824*^9, 3.390719965883354*^9}, {
  3.390720272659909*^9, 3.390720281839062*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4l", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{"a45", ",", "  ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"a4l", "+", "\[Nu]", "-", " ", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], " ", 
     RowBox[{"U", "[", "y", "]"}]}]}], ",", "y"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", 
  RowBox[{"a4l", "+", "\[Nu]", "-", 
   RowBox[{
    RowBox[{"f1", "[", "y", "]"}], " ", 
    RowBox[{"U", "[", "y", "]"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "\[Nu]"}], "+", 
    RowBox[{
     RowBox[{"f1", "[", "y", "]"}], " ", 
     RowBox[{"U", "[", "y", "]"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.390719994704023*^9, 3.390720009354227*^9}, {
  3.39072009459687*^9, 3.390720221306606*^9}, {3.425029944673524*^9, 
  3.425029981098377*^9}, {3.426483851051508*^9, 3.426483872620552*^9}, {
  3.426483908081422*^9, 3.426483912004233*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "\[Nu]"}], "+", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{"U", "[", "y", "]"}]}], "-", 
  RowBox[{"2", " ", "\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3d", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f3d", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.390720101655298*^9, 3.390720137142222*^9}, 
   3.390720167241107*^9, 3.390720223006969*^9, 3.390752426995448*^9, 
   3.425028149789585*^9, 3.425029983204654*^9, 3.426483852206809*^9, 
   3.42648388595429*^9, 3.42648391663633*^9, 3.435243260732413*^9, 
   3.44093518738027*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", "\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3d", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f3d", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.390720101655298*^9, 3.390720137142222*^9}, 
   3.390720167241107*^9, 3.390720223006969*^9, 3.390752426995448*^9, 
   3.425028149789585*^9, 3.425029983204654*^9, 3.426483852206809*^9, 
   3.42648388595429*^9, 3.42648391663633*^9, 3.435243260732413*^9, 
   3.440935187482873*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.390720101655298*^9, 3.390720137142222*^9}, 
   3.390720167241107*^9, 3.390720223006969*^9, 3.390752426995448*^9, 
   3.425028149789585*^9, 3.425029983204654*^9, 3.426483852206809*^9, 
   3.42648388595429*^9, 3.42648391663633*^9, 3.435243260732413*^9, 
   3.440935188034607*^9}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", 
   RowBox[{"2", " ", "\[Pi]"}]], 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Nu]"}], "+", 
     RowBox[{
      RowBox[{"f1", "[", "y", "]"}], " ", 
      RowBox[{"U", "[", "y", "]"}]}]}], ")"}], 
   RowBox[{"\[DifferentialD]", "y"}]}]}]], "Output",
 CellChangeTimes->{{3.390720101655298*^9, 3.390720137142222*^9}, 
   3.390720167241107*^9, 3.390720223006969*^9, 3.390752426995448*^9, 
   3.425028149789585*^9, 3.425029983204654*^9, 3.426483852206809*^9, 
   3.42648388595429*^9, 3.42648391663633*^9, 3.435243260732413*^9, 
   3.440935188194446*^9}]
}, Open  ]],

Cell["The last line is the contribution to the amplitude equation", "Text",
 CellChangeTimes->{{3.390720234792088*^9, 3.390720254399545*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  RowBox[{"a4n", " ", ":", " ", 
   RowBox[{
   "Contributes", " ", "to", " ", "the", " ", "amplitude", " ", 
    "equation"}]}]}]], "Subsubsection",
 CellChangeTimes->{{3.39072345533593*^9, 3.390723466085078*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4n", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a45", "]"}], ",", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{"a4n", ",", "y"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4n", "]"}]}], "Input",
 CellChangeTimes->{{3.390720578610295*^9, 3.390720612639237*^9}, {
   3.390723408678264*^9, 3.390723446511658*^9}, {3.390752637719135*^9, 
   3.390752650039228*^9}, 3.426483977213076*^9}],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3g", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f3g", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.390723410205102*^9, 3.390723447375707*^9}, 
   3.390752537370727*^9, 3.39075266359123*^9, 3.425028060749434*^9, 
   3.426483978547657*^9, 3.435243158101508*^9, 3.440935197165806*^9}],

Cell[BoxData[
 RowBox[{"y", "+", 
  RowBox[{
   SuperscriptBox["f2b", "\[Prime]",
    MultilineFunction->None], "[", "y", "]"}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3g", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f3g", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.390723410205102*^9, 3.390723447375707*^9}, 
   3.390752537370727*^9, 3.39075266359123*^9, 3.425028060749434*^9, 
   3.426483978547657*^9, 3.435243158101508*^9, 3.440935197189739*^9}],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]"}]], "Output",
 CellChangeTimes->{{3.390723410205102*^9, 3.390723447375707*^9}, 
   3.390752537370727*^9, 3.39075266359123*^9, 3.425028060749434*^9, 
   3.426483978547657*^9, 3.435243158101508*^9, 3.440935198215645*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   SuperscriptBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], ":", " ", 
  "a4o"}]], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4o", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"Expand", "[", "a45", "]"}], ",", " ", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{"a4o", ",", "y"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4o", "]"}]}], "Input",
 CellChangeTimes->{{3.390723497425863*^9, 3.390723550861603*^9}, {
   3.390752653721076*^9, 3.390752659438592*^9}, 3.426484049583481*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"4", " ", "\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f3b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.390723513357679*^9, 3.390723552925233*^9, 3.390724640906597*^9, 
   3.390752543564517*^9, 3.390752667681262*^9, 3.425028067418053*^9, {
   3.42648404295812*^9, 3.426484050740312*^9}, 3.435243161119208*^9, 
   3.440935220526307*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", "\[Nu]", " ", 
   RowBox[{
    SuperscriptBox["f2a", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f1", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f3b", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{
   RowBox[{"f1", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.390723513357679*^9, 3.390723552925233*^9, 3.390724640906597*^9, 
   3.390752543564517*^9, 3.390752667681262*^9, 3.425028067418053*^9, {
   3.42648404295812*^9, 3.426484050740312*^9}, 3.435243161119208*^9, 
   3.440935220549145*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.390723513357679*^9, 3.390723552925233*^9, 3.390724640906597*^9, 
   3.390752543564517*^9, 3.390752667681262*^9, 3.425028067418053*^9, {
   3.42648404295812*^9, 3.426484050740312*^9}, 3.435243161119208*^9, 
   3.440935221230904*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Term", " ", "in", "  ", 
   RowBox[{
    SuperscriptBox["\[CurlyPhi]0", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"0", ",", "2"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"T", ",", "X"}], "]"}]}], " ", ":", " ", 
  RowBox[{"a4p", " ", ":", " ", 
   RowBox[{
   "Contributes", " ", "to", " ", "the", " ", "amplitude", " ", "equation", 
    " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"if", " ", "r"}], "\[NotEqual]", "0"}], 
     ")"}]}]}]}]], "Subsubsection",
 CellChangeTimes->{{3.390724588727745*^9, 3.390724594331478*^9}, {
  3.390724665136685*^9, 3.390724681108904*^9}, {3.426484103852565*^9, 
  3.426484116597418*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"a4p", "=", 
  RowBox[{"-", 
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Expand", "[", "a45", "]"}], " ", "/.", "  ", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]1", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], "\[Rule]", "0"}]}], ",", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Integrate", "[", 
  RowBox[{"a4p", ",", "y"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solva", "[", "a4p", "]"}]}], "Input",
 CellChangeTimes->{{3.390723497425863*^9, 3.390723550861603*^9}, {
   3.39072461145365*^9, 3.390724637556068*^9}, {3.390752680063845*^9, 
   3.390752686149087*^9}, {3.390753520449438*^9, 3.390753533506066*^9}, 
   3.426484122052574*^9}],

Cell[BoxData[
 RowBox[{"r", "+", 
  RowBox[{"r", " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"r", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3r", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"r", " ", 
   RowBox[{"f3r", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.390724627402165*^9, 3.390724646182704*^9}, 
   3.390752555335926*^9, 3.390752687130699*^9, 3.390753534487211*^9, 
   3.42502807282768*^9, 3.426484123161744*^9, 3.435243164335467*^9, 
   3.440935230212998*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", " ", "y"}], "+", 
  RowBox[{"r", " ", 
   RowBox[{
    SuperscriptBox["f2b", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "+", 
  RowBox[{"r", " ", 
   RowBox[{"U", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["f3r", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}], "-", 
  RowBox[{"r", " ", 
   RowBox[{"f3r", "[", "y", "]"}], " ", 
   RowBox[{
    SuperscriptBox["U", "\[Prime]",
     MultilineFunction->None], "[", "y", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.390724627402165*^9, 3.390724646182704*^9}, 
   3.390752555335926*^9, 3.390752687130699*^9, 3.390753534487211*^9, 
   3.42502807282768*^9, 3.426484123161744*^9, 3.435243164335467*^9, 
   3.44093523031215*^9}],

Cell[BoxData[
 RowBox[{"2", " ", "\[Pi]", " ", "r"}]], "Output",
 CellChangeTimes->{{3.390724627402165*^9, 3.390724646182704*^9}, 
   3.390752555335926*^9, 3.390752687130699*^9, 3.390753534487211*^9, 
   3.42502807282768*^9, 3.426484123161744*^9, 3.435243164335467*^9, 
   3.440935231349362*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Verification", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"a4NN", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "a4o"}], " ", 
     SuperscriptBox[
      RowBox[{
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}], " "}], "2"]}], "-", 
    RowBox[{"a4n", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "-", "  ", 
    RowBox[{"a4l", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], " ", "-", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "1"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}], 
     RowBox[{"(", " ", 
      RowBox[{
       RowBox[{"a4g", "  ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}], "+", 
       RowBox[{"a4h", " ", 
        RowBox[{
         SuperscriptBox["\[CurlyPhi]0", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"T", ",", "X"}], "]"}]}]}], ")"}]}], " ", "-", 
    "\[IndentingNewLine]", 
    RowBox[{
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"], 
     RowBox[{"(", 
      RowBox[{"a4c", " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]0", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "2"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"T", ",", "X"}], "]"}]}], " ", ")"}]}], "-", " ", 
    RowBox[{"a4a", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "4"]}], "-", 
    RowBox[{"a4u", "  ", "r", " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[CurlyPhi]0", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"T", ",", "X"}], "]"}], "2"]}], "-", "  ", 
    RowBox[{"a4p", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "  ", "+", 
    RowBox[{"\[ScriptCapitalL]", "[", 
     RowBox[{"\[Psi]4", "[", 
      RowBox[{"T", ",", "X", ",", "y"}], "]"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{"Simplify", "[", 
  RowBox[{"a4", " ", "-", "a4NN"}], "]"}]}], "Input",
 CellChangeTimes->{
  3.390723746043361*^9, 3.390723801270776*^9, {3.390724055860201*^9, 
   3.390724068331209*^9}, {3.390724109504559*^9, 3.390724155995239*^9}, {
   3.390724205846529*^9, 3.39072421259735*^9}, {3.390724699724001*^9, 
   3.390724728266582*^9}, {3.390753015423626*^9, 3.390753054363384*^9}, {
   3.390753138696508*^9, 3.390753149771328*^9}, {3.42648419143468*^9, 
   3.426484240598957*^9}, {3.426484494676714*^9, 3.426484514796925*^9}, {
   3.435243189900489*^9, 3.435243232655303*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.425028192469687*^9, 3.426484243251068*^9, 
  3.426484516260905*^9, 3.435243236478637*^9, 3.435243267088883*^9, 
  3.44093523300463*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discussion ", "Section 1",
 CellChangeTimes->{{3.425028204445061*^9, 3.425028208257798*^9}, {
  3.426485059211144*^9, 3.426485063178433*^9}}],

Cell["The amplitude equation is ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[CurlyPhi]0", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "2"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"T", ",", "X"}], "]"}], "+", 
    RowBox[{"r", " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "2"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}], "-", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{"\[Nu]", " ", "-", " ", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"2", " ", "\[Pi]"}]], 
        RowBox[{
         SubsuperscriptBox["\[Integral]", "0", 
          RowBox[{"2", " ", "\[Pi]"}]], " ", 
         RowBox[{
          RowBox[{"f1", "[", "y", "]"}], " ", 
          RowBox[{"U", "[", "y", "]"}], " ", 
          RowBox[{"\[DifferentialD]", "y"}]}]}]}]}], ")"}], " ", 
     RowBox[{
      SuperscriptBox["\[CurlyPhi]0", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"0", ",", "4"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"T", ",", "X"}], "]"}]}]}], "=", "0"}]}]], "Input",
 CellChangeTimes->{{3.426484733675036*^9, 3.426484744914948*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.435243274993702*^9, {3.440935236697507*^9, 3.440935242627502*^9}}]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.426485078326088*^9, 3.426485083267697*^9}}],

Cell[TextData[{
 "After integration by part, using the fact that \[Nu] f1''=-U, the integral \
is ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"2", " ", "\[Pi]", " ", "\[Nu]"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"2", "\[Pi]"}]], 
    RowBox[{
     SuperscriptBox["\[CapitalPsi]", "2"], "dy"}]}], TraditionalForm]]],
 "\nHence we have again a negative viscosity effect  with a threshold which \
requires to calculate f1[y].\nFriction appears in this equation because it \
has been assumed of order ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Epsilon]", "2"], TraditionalForm]]],
 ". \n\nThe amplitude aquation has been obtained independently of any \
symmetry hypothesis\nThe only hypothesis is that ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", 
     RowBox[{"2", "\[Pi]"}]], 
    RowBox[{
     RowBox[{"U", "[", "y", "]"}], 
     RowBox[{"\[DifferentialD]", "y"}]}]}], "=", "0"}]], "Text",
  CellChangeTimes->{{3.390680425675709*^9, 3.39068044653285*^9}, {
   3.39068117426152*^9, 3.390681219436827*^9}}],
 "."
}], "Text",
 CellChangeTimes->{{3.390753769523389*^9, 3.390753950584068*^9}, {
   3.426484639780922*^9, 3.426484641055868*^9}, {3.426484753258664*^9, 
   3.426484796309226*^9}, {3.426485086625311*^9, 3.426485221422034*^9}, 
   3.42648527152193*^9, {3.426485318408028*^9, 3.42648536822918*^9}, {
   3.426486782326475*^9, 3.426486802554758*^9}}],

Cell[CellGroupData[{

Cell["Solution of the first order problem for f1", "Subsection"],

Cell["f1 is solution of ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Nu]", 
   RowBox[{
    SubscriptBox["\[PartialD]", 
     RowBox[{"y", ",", "y"}]], " ", 
    RowBox[{"f1", "[", "y", "]"}]}]}], " ", "=", " ", 
  RowBox[{"-", " ", 
   RowBox[{"U", "[", "y", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.426485385892542*^9, 3.426485387814065*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"We", " ", "solve", " ", "for", " ", 
   RowBox[{"\[Chi]", "[", "y", "]"}], " ", "such", " ", "that", " ", 
   RowBox[{"f1", "[", "y", "]"}]}], "=", " ", 
  RowBox[{
   FractionBox["A", "\[Nu]"], 
   RowBox[{"\[Chi]", "[", "y", "]"}]}]}]], "Text",
 CellChangeTimes->{{3.39075812045151*^9, 3.390758124224784*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Chi]1", "=", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"\[CapitalPhi]1", "[", "s", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "0", ",", "#"}], "}"}]}], "]"}], " ", "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]2", "=", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"\[CapitalPhi]2", "[", "s", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "0", ",", "#"}], "}"}]}], "]"}], " ", "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]3", "=", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"\[CapitalPhi]3", "[", "s", "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "0", ",", "#"}], "}"}]}], "]"}], " ", "&"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]1b", "=", 
   RowBox[{
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Sin", "[", 
           RowBox[{"\[Theta]", "[", "u", "]"}], "]"}]}], " ", "/.", " ", 
         "Flow1"}], ",", 
        RowBox[{"{", 
         RowBox[{"u", ",", 
          FractionBox["\[Pi]", "2"], ",", "s"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ",", "0", ",", "#"}], "}"}]}], "]"}], "&"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.39075428065067*^9, 3.390754398849251*^9, {3.390757834903305*^9, 
   3.39075788521187*^9}, {3.390758111005344*^9, 3.390758132309807*^9}, {
   3.390758183323575*^9, 3.390758191072424*^9}, {3.390758293883874*^9, 
   3.39075835201606*^9}, {3.390758690745687*^9, 3.390758692669895*^9}, {
   3.390764763945636*^9, 3.390764996653697*^9}, 3.390765124968968*^9, {
   3.390765200359646*^9, 3.390765228905692*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[Chi]1", "[", "y", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[Chi]2", "[", "y", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"\[Chi]3", "[", "y", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.390754118651275*^9, 3.390754188946627*^9}, {
  3.390757894043746*^9, 3.390757915491363*^9}, {3.390758241392206*^9, 
  3.39075827408951*^9}, {3.390758317941711*^9, 3.390758328896129*^9}}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.390754216484133*^9, 3.390754436077136*^9, 
  3.390754540113345*^9, 3.390758238584371*^9, 3.390758308326169*^9, 
  3.390758428966202*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"\[CapitalPhi]1", "[", "u", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"u", ",", 
     RowBox[{
      RowBox[{"-", "2"}], "\[Pi]"}], ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.390758421930125*^9, 3.390758423528646*^9}, {
  3.390758498950089*^9, 3.390758517049241*^9}, {3.390758616141141*^9, 
  3.390758658085964*^9}, {3.390758733367635*^9, 3.390758739004457*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwt2nk0lc8fB3C7e+0p7rVUSEWEaJFkprSRnUrypVTSJhWKiFTWFlsSKSFF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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->
   NCache[{{(-2) Pi, 2 Pi}, {-0.9999999999999679, 
     0.999999512844876}}, {{-6.283185307179586, 
    6.283185307179586}, {-0.9999999999999679, 0.999999512844876}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.390758468786013*^9, 3.390758524294181*^9, 3.390758644178625*^9, {
   3.390758700768435*^9, 3.39075874913685*^9}, 3.390764390007582*^9, 
   3.390764654247064*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
As \[Chi] is a a second integral of U, its shape is mostly determined by the \
main periodicity of the flow. Hence, one expects fairly small variations of \
the instability criterion from the standard Kolmogorov case.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Instability criterion (with no friction)", "Subsection",
 CellChangeTimes->{{3.426487180418947*^9, 3.426487185387546*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"NIntegrate", "[", 
   RowBox[{
    RowBox[{
     FractionBox["1", 
      RowBox[{"2", " ", "\[Pi]"}]], 
     SuperscriptBox[
      RowBox[{"\[CapitalPhi]1", "[", "s", "]"}], "2"]}], " ", ",", 
    RowBox[{"{", 
     RowBox[{"s", ",", "0", ",", 
      RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "\[Pi]"}]], 
    SuperscriptBox[
     RowBox[{"\[CapitalPhi]2", "[", "s", "]"}], "2"]}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"NIntegrate", "[", 
  RowBox[{
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " ", "\[Pi]"}]], 
    SuperscriptBox[
     RowBox[{"\[CapitalPhi]3", "[", "s", "]"}], "2"]}], " ", ",", 
   RowBox[{"{", 
    RowBox[{"s", ",", "0", ",", 
     RowBox[{"2", " ", "\[Pi]"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.390764684727724*^9, 3.3907646926225*^9}, {
  3.426486928249643*^9, 3.426486980666095*^9}, {3.426487066041045*^9, 
  3.42648710652789*^9}}],

Cell[BoxData["0.5000000000000013`"], "Output",
 CellChangeTimes->{3.426486983527899*^9, 3.426487071913936*^9, 
  3.42648710845155*^9}],

Cell[BoxData["0.6995824769199799`"], "Output",
 CellChangeTimes->{3.426486983527899*^9, 3.426487071913936*^9, 
  3.426487110151728*^9}],

Cell[BoxData["0.6150960452239593`"], "Output",
 CellChangeTimes->{3.426486983527899*^9, 3.426487071913936*^9, 
  3.426487111969162*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"We", " ", "recover", " ", "exactly", " ", 
   FractionBox["1", "2"], "for", " ", "the", " ", "standard", " ", 
   "Kolmogorov", " ", "flow", " ", "and", " ", "0.6995824769200031", " ", 
   "for", " ", "Flow2"}], ",", " ", 
  RowBox[{
  "which", " ", "means", " ", "that", " ", "the", " ", "critical", " ", 
   "Reynolds", " ", "number", " ", "changes", " ", "from", " ", 
   SqrtBox["2"], "to", " ", 
   SqrtBox["1.42942"], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"assuming", " ", "r"}], "=", "0"}], ")"}], "."}]}]}]], "Text",
 CellChangeTimes->{{3.426487197575732*^9, 3.426487203273554*^9}}],

Cell["Dump the current state of this workspace and reload it", "Text",
 CellChangeTimes->{{3.390682242390671*^9, 3.39068226197896*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DumpSave", "[", 
  RowBox[{"\"\<CH-lin1-nu-12.m6.mx\>\"", ",", "\"\<Global`\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.390682446653891*^9, 3.390682448560004*^9}, {
  3.390682947962211*^9, 3.390682958133923*^9}, {3.390682990244123*^9, 
  3.39068299641654*^9}, {3.426487159040666*^9, 3.426487162043775*^9}, {
  3.440935267421955*^9, 3.440935268177049*^9}}],

Cell[BoxData[
 RowBox[{"{", "\<\"Global`\"\>", "}"}]], "Output",
 CellChangeTimes->{3.39068300903526*^9, 3.39068345337478*^9, 
  3.390683641315236*^9, 3.390758792860904*^9, 3.42648723473755*^9, 
  3.440935276599785*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", "CH-lin1-nu-12.m6.mx"}]], "Input",
 CellChangeTimes->{{3.390682268698063*^9, 3.390682280328718*^9}, {
  3.390715412172866*^9, 3.3907154139878*^9}, {3.390752038963308*^9, 
  3.39075204087001*^9}, {3.426487166928679*^9, 3.426487167607492*^9}, {
  3.440935272650725*^9, 3.440935273848563*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{888, 705},
WindowMargins->{{167, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"], Inherited, 
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"]}, {
   Cell[
    TextData[{
      ValueBox["FileName"]}], "Header"], Inherited, 
   Cell[
    TextData[{
      CounterBox["Page"]}], "PageNumber"]}},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{611.25, 789.5625},
"PostScriptOutputFile"->"/home/legras/h2/CH/CH-lin1-nu-10.m6.ps",
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{54, 54}, {72, 72}}},
Magnification->1.,
FrontEndVersion->"6.0 for Linux x86 (32-bit) (June 19, 2007)",
StyleDefinitions->"Report.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 253, 5, 180, "Title"],
Cell[846, 30, 290, 12, 259, "Author"],
Cell[CellGroupData[{
Cell[1161, 46, 2538, 77, 114, "Subtitle"],
Cell[CellGroupData[{
Cell[3724, 127, 27, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[3776, 131, 33, 0, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[3834, 135, 149, 3, 30, "Input",
 InitializationCell->True],
Cell[3986, 140, 412, 9, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4447, 155, 32, 0, 31, "Subsubsection"],
Cell[4482, 157, 118, 3, 30, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[4637, 165, 34, 0, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[4696, 169, 437, 14, 36, "Input",
 InitializationCell->True],
Cell[5136, 185, 507, 15, 51, "Output"]
}, Open  ]],
Cell[5658, 203, 52, 0, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5747, 208, 54, 0, 31, "Subsubsection"],
Cell[5804, 210, 34, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[5863, 214, 303, 8, 30, "Input",
 InitializationCell->True],
Cell[6169, 224, 336, 8, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6566, 239, 61, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[6652, 243, 49, 0, 38, "Subsection"],
Cell[6704, 245, 298, 9, 53, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[7039, 259, 40, 0, 38, "Subsection"],
Cell[7082, 261, 49, 0, 29, "Text"],
Cell[7134, 263, 1043, 33, 118, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8214, 301, 39, 0, 38, "Subsection"],
Cell[CellGroupData[{
Cell[8278, 305, 1382, 42, 65, "Input"],
Cell[9663, 349, 68635, 1147, 154, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[78347, 1502, 49, 0, 38, "Subsection"],
Cell[CellGroupData[{
Cell[78421, 1506, 2942, 81, 190, "Input"],
Cell[81366, 1589, 41369, 699, 154, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[122784, 2294, 42, 0, 38, "Subsection"],
Cell[CellGroupData[{
Cell[122851, 2298, 259, 6, 30, "Input"],
Cell[123113, 2306, 274, 9, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[123424, 2320, 1588, 44, 65, "Input"],
Cell[125015, 2366, 78194, 1297, 151, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[203270, 3670, 56, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[203351, 3674, 51, 0, 38, "Subsection"],
Cell[203405, 3676, 494, 15, 48, "Text"],
Cell[203902, 3693, 1728, 47, 73, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[205667, 3745, 31, 0, 38, "Subsection"],
Cell[205701, 3747, 865, 23, 35, "Input",
 InitializationCell->True],
Cell[206569, 3772, 361, 11, 30, "Input",
 InitializationCell->True]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[206979, 3789, 26, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[207030, 3793, 299, 7, 30, "Input"],
Cell[207332, 3802, 427, 12, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[207796, 3819, 39, 0, 38, "Subsection"],
Cell[207838, 3821, 283, 8, 30, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[208158, 3834, 102, 1, 38, "Subsection"],
Cell[CellGroupData[{
Cell[208285, 3839, 191, 4, 30, "Input"],
Cell[208479, 3845, 185, 3, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[208725, 3855, 40, 0, 68, "Section"],
Cell[208768, 3857, 711, 19, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209516, 3881, 26, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[209567, 3885, 268, 7, 30, "Input"],
Cell[209838, 3894, 788, 25, 49, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210663, 3924, 111, 1, 38, "Subsection"],
Cell[210777, 3927, 360, 11, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211174, 3943, 131, 1, 38, "Subsection"],
Cell[CellGroupData[{
Cell[211330, 3948, 404, 13, 37, "Input"],
Cell[211737, 3963, 298, 7, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212072, 3975, 294, 7, 30, "Input"],
Cell[212369, 3984, 230, 5, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[212648, 3995, 141, 1, 38, "Subsection"],
Cell[CellGroupData[{
Cell[212814, 4000, 599, 18, 52, "Input"],
Cell[213416, 4020, 185, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[213650, 4029, 43, 0, 38, "Subsection"],
Cell[213696, 4031, 260, 5, 29, "Text"],
Cell[CellGroupData[{
Cell[213981, 4040, 472, 10, 32, "Input"],
Cell[214456, 4052, 378, 6, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[214883, 4064, 39, 0, 38, "Subsection"],
Cell[214925, 4066, 539, 17, 37, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[215513, 4089, 26, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[215564, 4093, 356, 10, 30, "Input"],
Cell[215923, 4105, 1513, 53, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217473, 4163, 65, 0, 38, "Subsection"],
Cell[CellGroupData[{
Cell[217563, 4167, 329, 10, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[217917, 4181, 603, 17, 54, "Input"],
Cell[218523, 4200, 341, 10, 49, "Output"],
Cell[218867, 4212, 186, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[219102, 4221, 297, 9, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[219424, 4234, 675, 19, 71, "Input"],
Cell[220102, 4255, 511, 14, 47, "Output"],
Cell[220616, 4271, 495, 14, 47, "Output"],
Cell[221114, 4287, 183, 3, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[221358, 4297, 149, 3, 38, "Subsection"],
Cell[CellGroupData[{
Cell[221532, 4304, 934, 28, 53, "Input"],
Cell[222469, 4334, 186, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[222704, 4343, 39, 0, 38, "Subsection"],
Cell[222746, 4345, 997, 31, 41, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[223792, 4382, 26, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[223843, 4386, 445, 11, 30, "Input"],
Cell[224291, 4399, 4291, 142, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[228619, 4546, 65, 0, 38, "Subsection"],
Cell[CellGroupData[{
Cell[228709, 4550, 1215, 39, 37, "Input"],
Cell[229927, 4591, 3968, 127, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[233932, 4723, 412, 13, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[234369, 4740, 553, 17, 55, "Input"],
Cell[234925, 4759, 364, 10, 49, "Output"],
Cell[235292, 4771, 208, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[235549, 4780, 642, 20, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[236216, 4804, 1004, 28, 71, "Input"],
Cell[237223, 4834, 1169, 35, 49, "Output"],
Cell[238395, 4871, 968, 26, 48, "Output"],
Cell[239366, 4899, 234, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[239649, 4908, 375, 11, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[240049, 4923, 877, 24, 71, "Input"],
Cell[240929, 4949, 683, 19, 47, "Output"],
Cell[241615, 4970, 640, 19, 47, "Output"],
Cell[242258, 4991, 166, 3, 45, "Output"]
}, Open  ]],
Cell[242439, 4997, 637, 15, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[243113, 5017, 375, 11, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[243513, 5032, 514, 15, 54, "Input"],
Cell[244030, 5049, 280, 6, 47, "Output"],
Cell[244313, 5057, 185, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[244547, 5066, 47, 0, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[244619, 5070, 554, 16, 54, "Input"],
Cell[245176, 5088, 307, 6, 47, "Output"],
Cell[245486, 5096, 212, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[245747, 5105, 143, 1, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[245915, 5110, 2145, 68, 75, "Input"],
Cell[248063, 5180, 237, 4, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[248361, 5191, 105, 1, 38, "Subsection"],
Cell[248469, 5194, 2393, 71, 103, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[250911, 5271, 26, 0, 68, "Section"],
Cell[CellGroupData[{
Cell[250962, 5275, 459, 12, 30, "Input"],
Cell[251424, 5289, 18633, 626, 343, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[270094, 5920, 369, 11, 41, "Subsection"],
Cell[CellGroupData[{
Cell[270488, 5935, 477, 16, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[270990, 5955, 589, 18, 55, "Input"],
Cell[271582, 5975, 386, 10, 49, "Output"],
Cell[271971, 5987, 229, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[272249, 5996, 443, 15, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[272717, 6015, 428, 13, 38, "Input"],
Cell[273148, 6030, 208, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[273405, 6039, 442, 15, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[273872, 6058, 465, 14, 38, "Input"],
Cell[274340, 6074, 3456, 119, 90, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[277845, 6199, 471, 14, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[278341, 6217, 377, 9, 48, "Input"],
Cell[278721, 6228, 446, 13, 49, "Output"],
Cell[279170, 6243, 185, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[279404, 6252, 623, 20, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[280052, 6276, 684, 19, 71, "Input"],
Cell[280739, 6297, 1583, 50, 67, "Output"],
Cell[282325, 6349, 1202, 34, 47, "Output"],
Cell[283530, 6385, 189, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[283768, 6394, 339, 10, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[284132, 6408, 484, 14, 37, "Input"],
Cell[284619, 6424, 3322, 115, 90, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[287990, 6545, 642, 20, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[288657, 6569, 738, 19, 71, "Input"],
Cell[289398, 6590, 1313, 40, 49, "Output"],
Cell[290714, 6632, 1196, 34, 47, "Output"],
Cell[291913, 6668, 228, 3, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[292190, 6677, 533, 18, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[292748, 6699, 601, 16, 54, "Input"],
Cell[293352, 6717, 496, 14, 49, "Output"],
Cell[293851, 6733, 209, 3, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[294121, 6743, 328, 10, 41, "Subsection"],
Cell[CellGroupData[{
Cell[294474, 6757, 469, 14, 34, "Input"],
Cell[294946, 6773, 7048, 235, 164, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[302031, 7013, 550, 16, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[302606, 7033, 1341, 38, 88, "Input"],
Cell[303950, 7073, 930, 24, 47, "Output"],
Cell[304883, 7099, 802, 21, 47, "Output"],
Cell[305688, 7122, 328, 5, 45, "Output"],
Cell[306019, 7129, 632, 16, 67, "Output"]
}, Open  ]],
Cell[306666, 7148, 141, 1, 29, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[306844, 7154, 504, 15, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[307373, 7173, 734, 19, 71, "Input"],
Cell[308110, 7194, 682, 17, 47, "Output"],
Cell[308795, 7213, 658, 17, 47, "Output"],
Cell[309456, 7232, 259, 4, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[309764, 7242, 374, 13, 33, "Subsubsection"],
Cell[CellGroupData[{
Cell[310163, 7259, 759, 21, 72, "Input"],
Cell[310925, 7282, 1200, 35, 49, "Output"],
Cell[312128, 7319, 1143, 33, 47, "Output"],
Cell[313274, 7354, 284, 5, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[313607, 7365, 708, 21, 32, "Subsubsection"],
Cell[CellGroupData[{
Cell[314340, 7390, 1110, 31, 71, "Input"],
Cell[315453, 7423, 754, 19, 47, "Output"],
Cell[316210, 7444, 752, 20, 47, "Output"],
Cell[316965, 7466, 295, 5, 45, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[317309, 7477, 37, 0, 31, "Subsubsection"],
Cell[CellGroupData[{
Cell[317371, 7481, 4043, 125, 118, "Input"],
Cell[321417, 7608, 185, 3, 45, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[321675, 7619, 147, 2, 71, "Section 1"],
Cell[321825, 7623, 42, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[321892, 7627, 1304, 42, 57, "Input"],
Cell[323199, 7671, 119, 2, 45, "Output"]
}, Open  ]],
Cell[323333, 7676, 92, 1, 30, "Input"],
Cell[323428, 7679, 1496, 38, 139, "Text"],
Cell[CellGroupData[{
Cell[324949, 7721, 64, 0, 38, "Subsection"],
Cell[325016, 7723, 34, 0, 29, "Text"],
Cell[325053, 7725, 314, 9, 32, "Input"],
Cell[325370, 7736, 346, 8, 43, "Text"],
Cell[325719, 7746, 1896, 54, 105, "Input"],
Cell[CellGroupData[{
Cell[327640, 7804, 912, 25, 65, "Input"],
Cell[328555, 7831, 193, 3, 45, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[328785, 7839, 468, 11, 30, "Input"],
Cell[329256, 7852, 24042, 404, 259, 15314, 258, "CachedBoxData", "BoxData", \
"Output"]
}, Open  ]],
Cell[353313, 8259, 241, 4, 48, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353591, 8268, 128, 1, 38, "Subsection"],
Cell[CellGroupData[{
Cell[353744, 8273, 1179, 35, 167, "Input"],
Cell[354926, 8310, 134, 2, 45, "Output"],
Cell[355063, 8314, 135, 2, 45, "Output"],
Cell[355201, 8318, 135, 2, 45, "Output"]
}, Open  ]],
Cell[355351, 8323, 646, 15, 67, "Text"],
Cell[356000, 8340, 135, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[356160, 8345, 385, 7, 30, "Input"],
Cell[356548, 8354, 219, 4, 45, "Output"]
}, Open  ]],
Cell[356782, 8361, 319, 5, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
